#include <cstring>
#include <limits>

#include "CompletionModel.h"
#include "Quality.h"
#include "clang/Sema/CodeCompleteConsumer.h"
#include "llvm/ADT/bit.h"

#define BIT(X) (1 << X)

namespace clang {
namespace clangd {

using SymbolCategory_type = clang::clangd::SymbolQualitySignals::SymbolCategory;
using ContextKind_type = clang::CodeCompletionContext::Kind;
using Scope_type = clang::clangd::SymbolRelevanceSignals::AccessibleScope;

uint32_t Example::OrderEncode(float F) {
  static_assert(std::numeric_limits<float>::is_iec559, "");
  constexpr uint32_t TopBit = ~(~uint32_t{0} >> 1);

  // Get the bits of the float. Endianness is the same as for integers.
  uint32_t U = llvm::bit_cast<uint32_t>(F);
  std::memcpy(&U, &F, sizeof(U));
  // IEEE 754 floats compare like sign-magnitude integers.
  if (U & TopBit)    // Negative float.
    return 0 - U;    // Map onto the low half of integers, order reversed.
  return U + TopBit; // Positive floats map onto the high half of integers.
}

namespace {
LLVM_ATTRIBUTE_NOINLINE float EvaluateTree0(const Example& E) {
  t0_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t0_n232;
  t0_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t0_n199;
  t0_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t0_n124;
  t0_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t0_n57;
  t0_n4: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t0_n26;
  t0_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n7;
  t0_n6: return -0.12079951167106628;
  t0_n7: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t0_n9;
  t0_n8: return 0.061142247170209885;
  t0_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t0_n13;
  t0_n10: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t0_n12;
  t0_n11: return -0.12391144037246704;
  t0_n12: return -0.026990002021193504;
  t0_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t0_n15;
  t0_n14: return 0.018572721630334854;
  t0_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t0_n17;
  t0_n16: return 0.15703141689300537;
  t0_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n19;
  t0_n18: return 0.1773659735918045;
  t0_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n25;
  t0_n20: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t0_n24;
  t0_n21: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t0_n23;
  t0_n22: return 0.20000000298023224;
  t0_n23: return 0.20000000298023224;
  t0_n24: return 0.14621421694755554;
  t0_n25: return 0.19240888953208923;
  t0_n26: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n30;
  t0_n27: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n29;
  t0_n28: return 0.06444863229990005;
  t0_n29: return 0.1855955868959427;
  t0_n30: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t0_n40;
  t0_n31: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n37;
  t0_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t0_n34;
  t0_n33: return 0.17781588435173035;
  t0_n34: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t0_n36;
  t0_n35: return 0.17779812216758728;
  t0_n36: return 0.19931510090827942;
  t0_n37: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t0_n39;
  t0_n38: return 0.1787724494934082;
  t0_n39: return 0.19916342198848724;
  t0_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t0_n42;
  t0_n41: return 0.17418637871742249;
  t0_n42: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t0_n46;
  t0_n43: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n45;
  t0_n44: return 0.1877955049276352;
  t0_n45: return 0.19817236065864563;
  t0_n46: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t0_n56;
  t0_n47: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t0_n49;
  t0_n48: return 0.20000000298023224;
  t0_n49: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t0_n55;
  t0_n50: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t0_n54;
  t0_n51: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t0_n53;
  t0_n52: return 0.1981440782546997;
  t0_n53: return 0.20000000298023224;
  t0_n54: return 0.19614481925964355;
  t0_n55: return 0.19921576976776123;
  t0_n56: return 0.19941894710063934;
  t0_n57: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t0_n117;
  t0_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t0_n74;
  t0_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n61;
  t0_n60: return 0.11802919209003448;
  t0_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t0_n65;
  t0_n62: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t0_n64;
  t0_n63: return 0.12647944688796997;
  t0_n64: return 0.17280472815036774;
  t0_n65: if (E.getNumReferences() >= 3347567040 /*69539.5*/) goto t0_n67;
  t0_n66: return 0.17839567363262177;
  t0_n67: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t0_n69;
  t0_n68: return 0.1969286948442459;
  t0_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t0_n71;
  t0_n70: return 0.20000000298023224;
  t0_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t0_n73;
  t0_n72: return 0.20000000298023224;
  t0_n73: return 0.20000000298023224;
  t0_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n76;
  t0_n75: return 0.16014410555362701;
  t0_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t0_n80;
  t0_n77: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t0_n79;
  t0_n78: return 0.10176723450422287;
  t0_n79: return 0.1980476826429367;
  t0_n80: if (E.getNumReferences() >= 3335188480 /*25976.0*/) goto t0_n94;
  t0_n81: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t0_n89;
  t0_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t0_n88;
  t0_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t0_n85;
  t0_n84: return 0.17472603917121887;
  t0_n85: if (E.getNumReferences() >= 3331445760 /*18666.0*/) goto t0_n87;
  t0_n86: return 0.1908876597881317;
  t0_n87: return 0.20000000298023224;
  t0_n88: return 0.17501217126846313;
  t0_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t0_n91;
  t0_n90: return 0.17833831906318665;
  t0_n91: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t0_n93;
  t0_n92: return 0.187881201505661;
  t0_n93: return 0.19937188923358917;
  t0_n94: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t0_n98;
  t0_n95: if (E.getNumReferences() >= 3357991456 /*170888.5*/) goto t0_n97;
  t0_n96: return 0.1930556446313858;
  t0_n97: return 0.17461903393268585;
  t0_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t0_n100;
  t0_n99: return 0.19675719738006592;
  t0_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n112;
  t0_n101: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t0_n111;
  t0_n102: if (E.getNumReferences() >= 3347866752 /*71881.0*/) goto t0_n104;
  t0_n103: return 0.20000000298023224;
  t0_n104: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t0_n106;
  t0_n105: return 0.20000000298023224;
  t0_n106: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t0_n108;
  t0_n107: return 0.16305941343307495;
  t0_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t0_n110;
  t0_n109: return 0.20000000298023224;
  t0_n110: return 0.20000000298023224;
  t0_n111: return 0.20000000298023224;
  t0_n112: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t0_n114;
  t0_n113: return 0.19862937927246094;
  t0_n114: if (E.getNumReferences() >= 3339920000 /*37666.5*/) goto t0_n116;
  t0_n115: return 0.20000000298023224;
  t0_n116: return 0.20000000298023224;
  t0_n117: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n119;
  t0_n118: return -0.027393395081162453;
  t0_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n121;
  t0_n120: return 0.06317751854658127;
  t0_n121: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t0_n123;
  t0_n122: return 0.07462543994188309;
  t0_n123: return 0.1521744430065155;
  t0_n124: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t0_n160;
  t0_n125: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n147;
  t0_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t0_n132;
  t0_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t0_n129;
  t0_n128: return -0.02582113817334175;
  t0_n129: if (E.getNumReferences() >= 3306979328 /*2504.0*/) goto t0_n131;
  t0_n130: return 0.1625605672597885;
  t0_n131: return 0.20000000298023224;
  t0_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n134;
  t0_n133: return 0.13989154994487762;
  t0_n134: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t0_n140;
  t0_n135: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t0_n137;
  t0_n136: return 0.12005230039358139;
  t0_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t0_n139;
  t0_n138: return 0.18763314187526703;
  t0_n139: return 0.19849012792110443;
  t0_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t0_n144;
  t0_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t0_n143;
  t0_n142: return 0.06016721948981285;
  t0_n143: return 0.1677456796169281;
  t0_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t0_n146;
  t0_n145: return -0.013765337876975536;
  t0_n146: return 0.18368329107761383;
  t0_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n149;
  t0_n148: return 0.17693720757961273;
  t0_n149: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t0_n151;
  t0_n150: return 0.1785055547952652;
  t0_n151: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n159;
  t0_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n158;
  t0_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t0_n155;
  t0_n154: return 0.18721753358840942;
  t0_n155: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t0_n157;
  t0_n156: return 0.1538866013288498;
  t0_n157: return 0.19920213520526886;
  t0_n158: return 0.19387505948543549;
  t0_n159: return 0.1912827491760254;
  t0_n160: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n162;
  t0_n161: return 0.15168944001197815;
  t0_n162: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t0_n188;
  t0_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t0_n165;
  t0_n164: return 0.012881728820502758;
  t0_n165: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t0_n181;
  t0_n166: if (E.getNumReferences() >= 3332027904 /*19803.0*/) goto t0_n170;
  t0_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t0_n169;
  t0_n168: return 0.18983542919158936;
  t0_n169: return 0.16867470741271973;
  t0_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t0_n174;
  t0_n171: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t0_n173;
  t0_n172: return 0.19392213225364685;
  t0_n173: return 0.20000000298023224;
  t0_n174: if (E.getNumReferences() >= 3333710848 /*23090.0*/) goto t0_n178;
  t0_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n177;
  t0_n176: return 0.1994200497865677;
  t0_n177: return 0.20000000298023224;
  t0_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t0_n180;
  t0_n179: return 0.20000000298023224;
  t0_n180: return 0.19904161989688873;
  t0_n181: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n183;
  t0_n182: return 0.1641821414232254;
  t0_n183: if (E.getNumReferences() >= 3314309120 /*4491.0*/) goto t0_n185;
  t0_n184: return 0.18643628060817719;
  t0_n185: if (E.getNumReferences() >= 3319552000 /*7051.0*/) goto t0_n187;
  t0_n186: return 0.20000000298023224;
  t0_n187: return 0.19677825272083282;
  t0_n188: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t0_n198;
  t0_n189: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t0_n197;
  t0_n190: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t0_n196;
  t0_n191: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t0_n193;
  t0_n192: return 0.20000000298023224;
  t0_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n195;
  t0_n194: return 0.20000000298023224;
  t0_n195: return 0.20000000298023224;
  t0_n196: return 0.20000000298023224;
  t0_n197: return 0.19828557968139648;
  t0_n198: return 0.18800073862075806;
  t0_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t0_n207;
  t0_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t0_n204;
  t0_n201: if (E.getFileProximityDistance() >= 3252682752 /*28.0*/) goto t0_n203;
  t0_n202: return 0.18233279883861542;
  t0_n203: return 0.20000000298023224;
  t0_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n206;
  t0_n205: return 0.18986621499061584;
  t0_n206: return 0.19835087656974792;
  t0_n207: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t0_n215;
  t0_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t0_n212;
  t0_n209: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t0_n211;
  t0_n210: return 0.18936631083488464;
  t0_n211: return 0.19875085353851318;
  t0_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t0_n214;
  t0_n213: return 0.20000000298023224;
  t0_n214: return 0.20000000298023224;
  t0_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t0_n223;
  t0_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t0_n222;
  t0_n217: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t0_n219;
  t0_n218: return 0.20000000298023224;
  t0_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n221;
  t0_n220: return 0.20000000298023224;
  t0_n221: return 0.20000000298023224;
  t0_n222: return 0.20000000298023224;
  t0_n223: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t0_n225;
  t0_n224: return 0.19947533309459686;
  t0_n225: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t0_n231;
  t0_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t0_n230;
  t0_n227: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t0_n229;
  t0_n228: return 0.20000000298023224;
  t0_n229: return 0.20000000298023224;
  t0_n230: return 0.19799521565437317;
  t0_n231: return 0.20000000298023224;
  t0_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t0_n238;
  t0_n233: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n237;
  t0_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n236;
  t0_n235: return 0.18191476166248322;
  t0_n236: return 0.19283226132392883;
  t0_n237: return 0.19608449935913086;
  t0_n238: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t0_n252;
  t0_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t0_n245;
  t0_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t0_n242;
  t0_n241: return 0.19304229319095612;
  t0_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t0_n244;
  t0_n243: return 0.19672870635986328;
  t0_n244: return 0.19354674220085144;
  t0_n245: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t0_n251;
  t0_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t0_n248;
  t0_n247: return 0.0008015634957700968;
  t0_n248: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t0_n250;
  t0_n249: return 0.19255712628364563;
  t0_n250: return -0.038249850273132324;
  t0_n251: return 0.1875191479921341;
  t0_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t0_n254;
  t0_n253: return 0.19669055938720703;
  t0_n254: return 0.19533346593379974;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree1(const Example& E) {
  t1_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t1_n200;
  t1_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t1_n163;
  t1_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t1_n100;
  t1_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t1_n41;
  t1_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t1_n6;
  t1_n5: return -0.15091364085674286;
  t1_n6: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t1_n30;
  t1_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t1_n19;
  t1_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t1_n16;
  t1_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n11;
  t1_n10: return 0.05477355793118477;
  t1_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t1_n15;
  t1_n12: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t1_n14;
  t1_n13: return 0.1500079184770584;
  t1_n14: return 0.16085197031497955;
  t1_n15: return 0.12589889764785767;
  t1_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n18;
  t1_n17: return 0.14148353040218353;
  t1_n18: return 0.16466857492923737;
  t1_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t1_n21;
  t1_n20: return 0.1660798341035843;
  t1_n21: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t1_n27;
  t1_n22: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t1_n24;
  t1_n23: return 0.17266814410686493;
  t1_n24: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t1_n26;
  t1_n25: return 0.17533309757709503;
  t1_n26: return 0.1711902618408203;
  t1_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t1_n29;
  t1_n28: return 0.12080799788236618;
  t1_n29: return 0.16948175430297852;
  t1_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n32;
  t1_n31: return -0.152507945895195;
  t1_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n34;
  t1_n33: return 0.062293633818626404;
  t1_n34: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t1_n36;
  t1_n35: return 0.05149541795253754;
  t1_n36: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n38;
  t1_n37: return 0.1726255863904953;
  t1_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t1_n40;
  t1_n39: return 0.15064777433872223;
  t1_n40: return 0.17015288770198822;
  t1_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n47;
  t1_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n46;
  t1_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t1_n45;
  t1_n44: return -0.0333033986389637;
  t1_n45: return 0.17266905307769775;
  t1_n46: return 0.1643076390028;
  t1_n47: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t1_n91;
  t1_n48: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t1_n84;
  t1_n49: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t1_n75;
  t1_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n64;
  t1_n51: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t1_n53;
  t1_n52: return 0.15230365097522736;
  t1_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t1_n55;
  t1_n54: return 0.15409699082374573;
  t1_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t1_n57;
  t1_n56: return 0.15844541788101196;
  t1_n57: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t1_n59;
  t1_n58: return 0.16402532160282135;
  t1_n59: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t1_n61;
  t1_n60: return 0.1747535616159439;
  t1_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t1_n63;
  t1_n62: return 0.1657407134771347;
  t1_n63: return 0.1731444001197815;
  t1_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n66;
  t1_n65: return 0.16987277567386627;
  t1_n66: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t1_n70;
  t1_n67: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t1_n69;
  t1_n68: return 0.17380395531654358;
  t1_n69: return 0.1460210531949997;
  t1_n70: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t1_n74;
  t1_n71: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t1_n73;
  t1_n72: return 0.1738666445016861;
  t1_n73: return 0.17415137588977814;
  t1_n74: return 0.17075440287590027;
  t1_n75: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t1_n79;
  t1_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n78;
  t1_n77: return 0.17766523361206055;
  t1_n78: return 0.17750349640846252;
  t1_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t1_n81;
  t1_n80: return 0.14760884642601013;
  t1_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t1_n83;
  t1_n82: return 0.17773769795894623;
  t1_n83: return 0.16723182797431946;
  t1_n84: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t1_n86;
  t1_n85: return 0.16861175000667572;
  t1_n86: if (E.getNumReferences() >= 3341684224 /*44558.0*/) goto t1_n88;
  t1_n87: return 0.16913868486881256;
  t1_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t1_n90;
  t1_n89: return 0.17053745687007904;
  t1_n90: return 0.17202283442020416;
  t1_n91: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t1_n93;
  t1_n92: return 0.17003630101680756;
  t1_n93: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t1_n97;
  t1_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t1_n96;
  t1_n95: return 0.15597844123840332;
  t1_n96: return 0.17304491996765137;
  t1_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t1_n99;
  t1_n98: return 0.17289558053016663;
  t1_n99: return 0.17391082644462585;
  t1_n100: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n158;
  t1_n101: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t1_n125;
  t1_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n118;
  t1_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t1_n105;
  t1_n104: return -0.14724932610988617;
  t1_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n107;
  t1_n106: return -0.01228698343038559;
  t1_n107: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t1_n117;
  t1_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t1_n112;
  t1_n109: if (E.getNumReferences() >= 3299139584 /*1319.0*/) goto t1_n111;
  t1_n110: return 0.12740346789360046;
  t1_n111: return 0.17001742124557495;
  t1_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t1_n114;
  t1_n113: return 0.10638996958732605;
  t1_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t1_n116;
  t1_n115: return -0.00790400430560112;
  t1_n116: return 0.17062979936599731;
  t1_n117: return 0.16796031594276428;
  t1_n118: if (E.getNumReferences() >= 3270770688 /*122.0*/) goto t1_n122;
  t1_n119: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t1_n121;
  t1_n120: return 0.16088688373565674;
  t1_n121: return -0.1807948499917984;
  t1_n122: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n124;
  t1_n123: return 0.17053326964378357;
  t1_n124: return 0.1730729192495346;
  t1_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n127;
  t1_n126: return 0.07471071928739548;
  t1_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t1_n153;
  t1_n128: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t1_n140;
  t1_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t1_n131;
  t1_n130: return 0.04588872194290161;
  t1_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n139;
  t1_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t1_n134;
  t1_n133: return 0.16948504745960236;
  t1_n134: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t1_n136;
  t1_n135: return 0.1631210446357727;
  t1_n136: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t1_n138;
  t1_n137: return 0.14138923585414886;
  t1_n138: return 0.18068403005599976;
  t1_n139: return 0.15891848504543304;
  t1_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n142;
  t1_n141: return 0.16755996644496918;
  t1_n142: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t1_n150;
  t1_n143: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t1_n149;
  t1_n144: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t1_n146;
  t1_n145: return 0.17185594141483307;
  t1_n146: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t1_n148;
  t1_n147: return 0.17316903173923492;
  t1_n148: return 0.1699805110692978;
  t1_n149: return 0.12834183871746063;
  t1_n150: if (E.getNumReferences() >= 3361046624 /*218625.5*/) goto t1_n152;
  t1_n151: return 0.17364922165870667;
  t1_n152: return 0.17049680650234222;
  t1_n153: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t1_n155;
  t1_n154: return 0.17084209620952606;
  t1_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n157;
  t1_n156: return 0.1738344430923462;
  t1_n157: return 0.1729537546634674;
  t1_n158: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t1_n162;
  t1_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n161;
  t1_n160: return 0.1625131517648697;
  t1_n161: return 0.17122158408164978;
  t1_n162: return 0.1756647527217865;
  t1_n163: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n179;
  t1_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n168;
  t1_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n167;
  t1_n166: return 0.043860942125320435;
  t1_n167: return 0.17042915523052216;
  t1_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n176;
  t1_n169: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t1_n171;
  t1_n170: return 0.16159118711948395;
  t1_n171: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t1_n173;
  t1_n172: return 0.17422351241111755;
  t1_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n175;
  t1_n174: return 0.17429384589195251;
  t1_n175: return 0.15205422043800354;
  t1_n176: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t1_n178;
  t1_n177: return 0.17339584231376648;
  t1_n178: return 0.17394539713859558;
  t1_n179: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t1_n187;
  t1_n180: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t1_n186;
  t1_n181: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t1_n185;
  t1_n182: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t1_n184;
  t1_n183: return 0.17305228114128113;
  t1_n184: return 0.17637899518013;
  t1_n185: return 0.17330048978328705;
  t1_n186: return 0.1749802976846695;
  t1_n187: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t1_n195;
  t1_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t1_n192;
  t1_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t1_n191;
  t1_n190: return 0.17090068757534027;
  t1_n191: return 0.1732286959886551;
  t1_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t1_n194;
  t1_n193: return 0.17361842095851898;
  t1_n194: return 0.17327235639095306;
  t1_n195: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t1_n197;
  t1_n196: return 0.1735181212425232;
  t1_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t1_n199;
  t1_n198: return 0.17096033692359924;
  t1_n199: return 0.1762663573026657;
  t1_n200: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t1_n232;
  t1_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n209;
  t1_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n204;
  t1_n203: return 0.1645682454109192;
  t1_n204: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t1_n208;
  t1_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t1_n207;
  t1_n206: return 0.17240653932094574;
  t1_n207: return 0.17337630689144135;
  t1_n208: return -0.1254286766052246;
  t1_n209: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n223;
  t1_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n222;
  t1_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n215;
  t1_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t1_n214;
  t1_n213: return -0.030446210876107216;
  t1_n214: return 0.1743224859237671;
  t1_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t1_n217;
  t1_n216: return 0.15891949832439423;
  t1_n217: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t1_n221;
  t1_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n220;
  t1_n219: return 0.17585204541683197;
  t1_n220: return 0.1754288375377655;
  t1_n221: return -0.20791785418987274;
  t1_n222: return 0.1737327128648758;
  t1_n223: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t1_n229;
  t1_n224: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t1_n228;
  t1_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t1_n227;
  t1_n226: return -0.018497085198760033;
  t1_n227: return 0.17353105545043945;
  t1_n228: return 0.1728522926568985;
  t1_n229: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t1_n231;
  t1_n230: return 0.1719209849834442;
  t1_n231: return 0.17153580486774445;
  t1_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t1_n244;
  t1_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t1_n239;
  t1_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n236;
  t1_n235: return 0.16320472955703735;
  t1_n236: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t1_n238;
  t1_n237: return 0.1761353611946106;
  t1_n238: return -0.001039095688611269;
  t1_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t1_n243;
  t1_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n242;
  t1_n241: return 0.17092837393283844;
  t1_n242: return 0.17707902193069458;
  t1_n243: return 0.17628850042819977;
  t1_n244: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t1_n252;
  t1_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t1_n247;
  t1_n246: return 0.17169058322906494;
  t1_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t1_n249;
  t1_n248: return 0.1748499721288681;
  t1_n249: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t1_n251;
  t1_n250: return 0.17445120215415955;
  t1_n251: return 0.17385268211364746;
  t1_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t1_n254;
  t1_n253: return 0.1731099635362625;
  t1_n254: return 0.1733504682779312;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree2(const Example& E) {
  t2_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t2_n208;
  t2_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t2_n175;
  t2_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t2_n106;
  t2_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t2_n41;
  t2_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t2_n6;
  t2_n5: return -0.133283793926239;
  t2_n6: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t2_n30;
  t2_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t2_n19;
  t2_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t2_n16;
  t2_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n11;
  t2_n10: return 0.07656025886535645;
  t2_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t2_n15;
  t2_n12: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t2_n14;
  t2_n13: return 0.13152086734771729;
  t2_n14: return 0.1417326182126999;
  t2_n15: return 0.10664967447519302;
  t2_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t2_n18;
  t2_n17: return 0.12508608400821686;
  t2_n18: return 0.14405442774295807;
  t2_n19: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t2_n21;
  t2_n20: return 0.1429975926876068;
  t2_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t2_n23;
  t2_n22: return 0.14844773709774017;
  t2_n23: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t2_n27;
  t2_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t2_n26;
  t2_n25: return 0.15496468544006348;
  t2_n26: return 0.1491556018590927;
  t2_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t2_n29;
  t2_n28: return 0.11798620223999023;
  t2_n29: return 0.15261682868003845;
  t2_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n32;
  t2_n31: return -0.13154757022857666;
  t2_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n34;
  t2_n33: return 0.05591406673192978;
  t2_n34: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t2_n36;
  t2_n35: return 0.044244393706321716;
  t2_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n38;
  t2_n37: return 0.1516924500465393;
  t2_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t2_n40;
  t2_n39: return 0.13413147628307343;
  t2_n40: return 0.15042981505393982;
  t2_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n49;
  t2_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n48;
  t2_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t2_n45;
  t2_n44: return -0.039107292890548706;
  t2_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n47;
  t2_n46: return 0.1497890204191208;
  t2_n47: return 0.15605702996253967;
  t2_n48: return 0.14486345648765564;
  t2_n49: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t2_n97;
  t2_n50: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t2_n88;
  t2_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n73;
  t2_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n62;
  t2_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t2_n55;
  t2_n54: return 0.1279214322566986;
  t2_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t2_n57;
  t2_n56: return 0.12952971458435059;
  t2_n57: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t2_n59;
  t2_n58: return 0.1426417976617813;
  t2_n59: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t2_n61;
  t2_n60: return 0.1562812775373459;
  t2_n61: return 0.15334844589233398;
  t2_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t2_n64;
  t2_n63: return 0.14401467144489288;
  t2_n64: if (E.getNumReferences() >= 3341684224 /*44558.0*/) goto t2_n66;
  t2_n65: return 0.14768342673778534;
  t2_n66: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t2_n72;
  t2_n67: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n69;
  t2_n68: return 0.15198349952697754;
  t2_n69: if (E.getNumReferences() >= 3356454464 /*146873.0*/) goto t2_n71;
  t2_n70: return 0.15132135152816772;
  t2_n71: return 0.14691652357578278;
  t2_n72: return -0.23428891599178314;
  t2_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n75;
  t2_n74: return 0.14979501068592072;
  t2_n75: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t2_n79;
  t2_n76: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t2_n78;
  t2_n77: return 0.1529514640569687;
  t2_n78: return 0.13581416010856628;
  t2_n79: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t2_n87;
  t2_n80: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t2_n84;
  t2_n81: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t2_n83;
  t2_n82: return 0.15381106734275818;
  t2_n83: return -0.2077629417181015;
  t2_n84: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t2_n86;
  t2_n85: return 0.1538122594356537;
  t2_n86: return 0.15379232168197632;
  t2_n87: return 0.15146464109420776;
  t2_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t2_n92;
  t2_n89: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n91;
  t2_n90: return 0.14640307426452637;
  t2_n91: return 0.15305066108703613;
  t2_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n96;
  t2_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t2_n95;
  t2_n94: return 0.1561584621667862;
  t2_n95: return 0.15588101744651794;
  t2_n96: return -0.20534925162792206;
  t2_n97: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t2_n99;
  t2_n98: return 0.1506338119506836;
  t2_n99: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t2_n103;
  t2_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t2_n102;
  t2_n101: return 0.1336551457643509;
  t2_n102: return 0.15281569957733154;
  t2_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t2_n105;
  t2_n104: return 0.1526758372783661;
  t2_n105: return 0.1535707414150238;
  t2_n106: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n164;
  t2_n107: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t2_n133;
  t2_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t2_n124;
  t2_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t2_n111;
  t2_n110: return -0.12758612632751465;
  t2_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n113;
  t2_n112: return -0.06837106496095657;
  t2_n113: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t2_n123;
  t2_n114: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t2_n118;
  t2_n115: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t2_n117;
  t2_n116: return 0.10928419977426529;
  t2_n117: return 0.151849627494812;
  t2_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t2_n120;
  t2_n119: return 0.0870794951915741;
  t2_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t2_n122;
  t2_n121: return -0.004111700225621462;
  t2_n122: return 0.15054772794246674;
  t2_n123: return 0.14818798005580902;
  t2_n124: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t2_n130;
  t2_n125: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t2_n129;
  t2_n126: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t2_n128;
  t2_n127: return 0.13847200572490692;
  t2_n128: return 0.15455810725688934;
  t2_n129: return -0.15978623926639557;
  t2_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t2_n132;
  t2_n131: return 0.1426544338464737;
  t2_n132: return 0.15348438918590546;
  t2_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n135;
  t2_n134: return 0.05193212255835533;
  t2_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t2_n161;
  t2_n136: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t2_n148;
  t2_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t2_n139;
  t2_n138: return 0.02436218596994877;
  t2_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n147;
  t2_n140: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n142;
  t2_n141: return 0.14910759031772614;
  t2_n142: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t2_n144;
  t2_n143: return 0.14314158260822296;
  t2_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t2_n146;
  t2_n145: return 0.1194673553109169;
  t2_n146: return 0.15822046995162964;
  t2_n147: return 0.1404583901166916;
  t2_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n150;
  t2_n149: return 0.14690779149532318;
  t2_n150: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t2_n158;
  t2_n151: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t2_n157;
  t2_n152: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t2_n154;
  t2_n153: return 0.15155918896198273;
  t2_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t2_n156;
  t2_n155: return 0.1530529260635376;
  t2_n156: return 0.1498764008283615;
  t2_n157: return 0.09187895059585571;
  t2_n158: if (E.getNumReferences() >= 3361046624 /*218625.5*/) goto t2_n160;
  t2_n159: return 0.1537080556154251;
  t2_n160: return 0.15092475712299347;
  t2_n161: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t2_n163;
  t2_n162: return 0.1504388153553009;
  t2_n163: return 0.1531168818473816;
  t2_n164: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t2_n172;
  t2_n165: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n167;
  t2_n166: return 0.14124099910259247;
  t2_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n171;
  t2_n168: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t2_n170;
  t2_n169: return 0.14913100004196167;
  t2_n170: return 0.15464331209659576;
  t2_n171: return 0.15086820721626282;
  t2_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t2_n174;
  t2_n173: return 0.1553458422422409;
  t2_n174: return 0.15285758674144745;
  t2_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n191;
  t2_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n180;
  t2_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t2_n179;
  t2_n178: return -0.022871391847729683;
  t2_n179: return 0.1508995145559311;
  t2_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t2_n188;
  t2_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t2_n183;
  t2_n182: return 0.1381033957004547;
  t2_n183: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t2_n185;
  t2_n184: return 0.15351207554340363;
  t2_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n187;
  t2_n186: return 0.1538107991218567;
  t2_n187: return 0.12698757648468018;
  t2_n188: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t2_n190;
  t2_n189: return 0.15297596156597137;
  t2_n190: return 0.15336363017559052;
  t2_n191: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t2_n197;
  t2_n192: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t2_n196;
  t2_n193: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t2_n195;
  t2_n194: return 0.1531568467617035;
  t2_n195: return 0.15304860472679138;
  t2_n196: return 0.15437668561935425;
  t2_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t2_n205;
  t2_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t2_n202;
  t2_n199: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t2_n201;
  t2_n200: return 0.1497684270143509;
  t2_n201: return 0.15299098193645477;
  t2_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t2_n204;
  t2_n203: return 0.15331102907657623;
  t2_n204: return 0.1530337929725647;
  t2_n205: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t2_n207;
  t2_n206: return 0.15416307747364044;
  t2_n207: return 0.15337632596492767;
  t2_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t2_n238;
  t2_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n219;
  t2_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n212;
  t2_n211: return 0.1440243422985077;
  t2_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t2_n218;
  t2_n213: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t2_n215;
  t2_n214: return 0.15269339084625244;
  t2_n215: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n217;
  t2_n216: return 0.1529308706521988;
  t2_n217: return 0.1522054225206375;
  t2_n218: return -0.10300616174936295;
  t2_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t2_n231;
  t2_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n230;
  t2_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n225;
  t2_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t2_n224;
  t2_n223: return -0.08178834617137909;
  t2_n224: return 0.15332281589508057;
  t2_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t2_n227;
  t2_n226: return 0.1412745714187622;
  t2_n227: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t2_n229;
  t2_n228: return 0.15475565195083618;
  t2_n229: return -0.17009080946445465;
  t2_n230: return 0.15295350551605225;
  t2_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n235;
  t2_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t2_n234;
  t2_n233: return 0.15320010483264923;
  t2_n234: return 0.1525789499282837;
  t2_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t2_n237;
  t2_n236: return 0.15172122418880463;
  t2_n237: return 0.15143021941184998;
  t2_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t2_n248;
  t2_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t2_n243;
  t2_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n242;
  t2_n241: return 0.14508500695228577;
  t2_n242: return 0.15544523298740387;
  t2_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t2_n247;
  t2_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n246;
  t2_n245: return 0.15400546789169312;
  t2_n246: return 0.1562241017818451;
  t2_n247: return 0.15588527917861938;
  t2_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t2_n252;
  t2_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t2_n251;
  t2_n250: return 0.15181264281272888;
  t2_n251: return 0.15424948930740356;
  t2_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t2_n254;
  t2_n253: return 0.1531326323747635;
  t2_n254: return 0.15396717190742493;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree3(const Example& E) {
  t3_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t3_n208;
  t3_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t3_n175;
  t3_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t3_n110;
  t3_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t3_n41;
  t3_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t3_n6;
  t3_n5: return -0.1204330176115036;
  t3_n6: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t3_n30;
  t3_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t3_n19;
  t3_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t3_n16;
  t3_n9: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t3_n15;
  t3_n10: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n12;
  t3_n11: return 0.08824971318244934;
  t3_n12: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t3_n14;
  t3_n13: return 0.11693461984395981;
  t3_n14: return 0.1275223046541214;
  t3_n15: return 0.08346706628799438;
  t3_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t3_n18;
  t3_n17: return 0.11292148381471634;
  t3_n18: return 0.12999244034290314;
  t3_n19: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t3_n21;
  t3_n20: return 0.12903906404972076;
  t3_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t3_n23;
  t3_n22: return 0.1344074010848999;
  t3_n23: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t3_n27;
  t3_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t3_n26;
  t3_n25: return 0.14141340553760529;
  t3_n26: return 0.13674995303153992;
  t3_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t3_n29;
  t3_n28: return 0.10628057271242142;
  t3_n29: return 0.13875740766525269;
  t3_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n32;
  t3_n31: return -0.11721540242433548;
  t3_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n34;
  t3_n33: return 0.06393055617809296;
  t3_n34: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t3_n36;
  t3_n35: return -0.00043427685159258544;
  t3_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t3_n40;
  t3_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n39;
  t3_n38: return 0.13770294189453125;
  t3_n39: return 0.12343572080135345;
  t3_n40: return 0.13588464260101318;
  t3_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t3_n49;
  t3_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t3_n46;
  t3_n43: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n45;
  t3_n44: return -0.034344382584095;
  t3_n45: return 0.13136006891727448;
  t3_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n48;
  t3_n47: return 0.1344141662120819;
  t3_n48: return 0.14192871749401093;
  t3_n49: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t3_n101;
  t3_n50: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t3_n90;
  t3_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n75;
  t3_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n64;
  t3_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t3_n55;
  t3_n54: return 0.11161486804485321;
  t3_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n57;
  t3_n56: return 0.1155828982591629;
  t3_n57: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t3_n59;
  t3_n58: return 0.12801359593868256;
  t3_n59: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t3_n61;
  t3_n60: return 0.1425664722919464;
  t3_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n63;
  t3_n62: return 0.13518792390823364;
  t3_n63: return 0.14209319651126862;
  t3_n64: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t3_n66;
  t3_n65: return 0.13083583116531372;
  t3_n66: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t3_n68;
  t3_n67: return 0.1338840126991272;
  t3_n68: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t3_n74;
  t3_n69: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n71;
  t3_n70: return 0.13880455493927002;
  t3_n71: if (E.getNumReferences() >= 3356454464 /*146873.0*/) goto t3_n73;
  t3_n72: return 0.13821831345558167;
  t3_n73: return 0.13438640534877777;
  t3_n74: return -0.19527609646320343;
  t3_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n77;
  t3_n76: return 0.13634338974952698;
  t3_n77: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t3_n81;
  t3_n78: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t3_n80;
  t3_n79: return 0.13949155807495117;
  t3_n80: return 0.12266673892736435;
  t3_n81: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t3_n89;
  t3_n82: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t3_n86;
  t3_n83: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t3_n85;
  t3_n84: return 0.1404382884502411;
  t3_n85: return -0.17007437348365784;
  t3_n86: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t3_n88;
  t3_n87: return 0.14041678607463837;
  t3_n88: return 0.14080794155597687;
  t3_n89: return 0.1385136842727661;
  t3_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t3_n96;
  t3_n91: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n95;
  t3_n92: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t3_n94;
  t3_n93: return 0.14224322140216827;
  t3_n94: return 0.13457348942756653;
  t3_n95: return 0.13982658088207245;
  t3_n96: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n100;
  t3_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t3_n99;
  t3_n98: return 0.1419159173965454;
  t3_n99: return 0.14184363186359406;
  t3_n100: return -0.18263313174247742;
  t3_n101: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t3_n103;
  t3_n102: return 0.1371743530035019;
  t3_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t3_n107;
  t3_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t3_n106;
  t3_n105: return 0.1212882250547409;
  t3_n106: return 0.13973192870616913;
  t3_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t3_n109;
  t3_n108: return 0.1392742246389389;
  t3_n109: return 0.14037735760211945;
  t3_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n166;
  t3_n111: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t3_n137;
  t3_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t3_n128;
  t3_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t3_n115;
  t3_n114: return -0.11261919885873795;
  t3_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n117;
  t3_n116: return -0.06276673823595047;
  t3_n117: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t3_n127;
  t3_n118: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t3_n122;
  t3_n119: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t3_n121;
  t3_n120: return 0.09549877792596817;
  t3_n121: return 0.1385771930217743;
  t3_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t3_n124;
  t3_n123: return 0.07433127611875534;
  t3_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t3_n126;
  t3_n125: return -0.0031157447956502438;
  t3_n126: return 0.13701224327087402;
  t3_n127: return 0.13425131142139435;
  t3_n128: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t3_n134;
  t3_n129: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t3_n133;
  t3_n130: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t3_n132;
  t3_n131: return 0.12487947940826416;
  t3_n132: return 0.13906612992286682;
  t3_n133: return -0.14553101360797882;
  t3_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n136;
  t3_n135: return 0.12794062495231628;
  t3_n136: return 0.13959991931915283;
  t3_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n139;
  t3_n138: return 0.06500580906867981;
  t3_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t3_n163;
  t3_n140: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t3_n152;
  t3_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t3_n143;
  t3_n142: return 0.009600312449038029;
  t3_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n151;
  t3_n144: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n146;
  t3_n145: return 0.13542282581329346;
  t3_n146: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t3_n148;
  t3_n147: return 0.12905986607074738;
  t3_n148: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t3_n150;
  t3_n149: return 0.11207016557455063;
  t3_n150: return 0.14389507472515106;
  t3_n151: return 0.1273270547389984;
  t3_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t3_n154;
  t3_n153: return 0.13303056359291077;
  t3_n154: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t3_n162;
  t3_n155: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t3_n161;
  t3_n156: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t3_n158;
  t3_n157: return 0.13820381462574005;
  t3_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t3_n160;
  t3_n159: return 0.13991540670394897;
  t3_n160: return 0.13560201227664948;
  t3_n161: return 0.08063444495201111;
  t3_n162: return 0.1405167132616043;
  t3_n163: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t3_n165;
  t3_n164: return 0.13715477287769318;
  t3_n165: return 0.13972711563110352;
  t3_n166: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t3_n174;
  t3_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n169;
  t3_n168: return 0.12713909149169922;
  t3_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n173;
  t3_n170: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t3_n172;
  t3_n171: return 0.13620653748512268;
  t3_n172: return 0.1407044529914856;
  t3_n173: return 0.13742958009243011;
  t3_n174: return 0.14127114415168762;
  t3_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t3_n191;
  t3_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n180;
  t3_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t3_n179;
  t3_n178: return -0.01099332980811596;
  t3_n179: return 0.1373530626296997;
  t3_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t3_n188;
  t3_n181: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t3_n183;
  t3_n182: return 0.12371889501810074;
  t3_n183: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t3_n185;
  t3_n184: return 0.13992975652217865;
  t3_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n187;
  t3_n186: return 0.14004194736480713;
  t3_n187: return 0.1134493425488472;
  t3_n188: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t3_n190;
  t3_n189: return 0.13938522338867188;
  t3_n190: return 0.13996073603630066;
  t3_n191: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t3_n197;
  t3_n192: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t3_n196;
  t3_n193: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t3_n195;
  t3_n194: return 0.14001934230327606;
  t3_n195: return 0.13988569378852844;
  t3_n196: return 0.14103291928768158;
  t3_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t3_n205;
  t3_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t3_n202;
  t3_n199: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t3_n201;
  t3_n200: return 0.13570933043956757;
  t3_n201: return 0.13970209658145905;
  t3_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t3_n204;
  t3_n203: return 0.14017435908317566;
  t3_n204: return 0.13984468579292297;
  t3_n205: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t3_n207;
  t3_n206: return 0.14031049609184265;
  t3_n207: return 0.14106346666812897;
  t3_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t3_n238;
  t3_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n217;
  t3_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n212;
  t3_n211: return 0.1298855096101761;
  t3_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t3_n216;
  t3_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t3_n215;
  t3_n214: return 0.13843801617622375;
  t3_n215: return 0.139500692486763;
  t3_n216: return -0.09115998446941376;
  t3_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t3_n231;
  t3_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n230;
  t3_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n223;
  t3_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t3_n222;
  t3_n221: return -0.04582589119672775;
  t3_n222: return 0.1396026909351349;
  t3_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t3_n225;
  t3_n224: return 0.12141555547714233;
  t3_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n229;
  t3_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t3_n228;
  t3_n227: return 0.14089390635490417;
  t3_n228: return -0.15300801396369934;
  t3_n229: return 0.14157257974147797;
  t3_n230: return 0.13919265568256378;
  t3_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n235;
  t3_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t3_n234;
  t3_n233: return 0.1399143785238266;
  t3_n234: return 0.13935180008411407;
  t3_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t3_n237;
  t3_n236: return 0.13858456909656525;
  t3_n237: return 0.1381283849477768;
  t3_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t3_n248;
  t3_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t3_n243;
  t3_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n242;
  t3_n241: return 0.13119500875473022;
  t3_n242: return 0.14192305505275726;
  t3_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t3_n247;
  t3_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n246;
  t3_n245: return 0.1411043107509613;
  t3_n246: return 0.14264418184757233;
  t3_n247: return 0.14277209341526031;
  t3_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t3_n252;
  t3_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t3_n251;
  t3_n250: return 0.13855332136154175;
  t3_n251: return 0.14121687412261963;
  t3_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t3_n254;
  t3_n253: return 0.14014697074890137;
  t3_n254: return 0.14132735133171082;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree4(const Example& E) {
  t4_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t4_n208;
  t4_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t4_n181;
  t4_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t4_n118;
  t4_n3: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t4_n53;
  t4_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t4_n14;
  t4_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t4_n11;
  t4_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t4_n8;
  t4_n7: return -0.00011980631097685546;
  t4_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n10;
  t4_n9: return -0.13037718832492828;
  t4_n10: return -0.12400064617395401;
  t4_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t4_n13;
  t4_n12: return 0.02150256559252739;
  t4_n13: return 0.1516893357038498;
  t4_n14: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t4_n42;
  t4_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t4_n31;
  t4_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n26;
  t4_n17: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t4_n25;
  t4_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n20;
  t4_n19: return 0.08278460055589676;
  t4_n20: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t4_n22;
  t4_n21: return 0.105562724173069;
  t4_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t4_n24;
  t4_n23: return 0.1159939169883728;
  t4_n24: return 0.12627074122428894;
  t4_n25: return 0.06974900513887405;
  t4_n26: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t4_n30;
  t4_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t4_n29;
  t4_n28: return 0.09180619567632675;
  t4_n29: return 0.1179983913898468;
  t4_n30: return 0.12673504650592804;
  t4_n31: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t4_n33;
  t4_n32: return 0.1182960495352745;
  t4_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t4_n35;
  t4_n34: return 0.12410110980272293;
  t4_n35: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t4_n39;
  t4_n36: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t4_n38;
  t4_n37: return 0.1321878731250763;
  t4_n38: return 0.1260734647512436;
  t4_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n41;
  t4_n40: return 0.09228869527578354;
  t4_n41: return 0.12924227118492126;
  t4_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n44;
  t4_n43: return -0.10240945965051651;
  t4_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n46;
  t4_n45: return 0.05783577263355255;
  t4_n46: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t4_n48;
  t4_n47: return 0.007513059303164482;
  t4_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t4_n52;
  t4_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n51;
  t4_n50: return 0.12745356559753418;
  t4_n51: return 0.11066359281539917;
  t4_n52: return 0.12579523026943207;
  t4_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t4_n61;
  t4_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n58;
  t4_n55: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n57;
  t4_n56: return -0.022672263905405998;
  t4_n57: return 0.12118544429540634;
  t4_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n60;
  t4_n59: return 0.12299049645662308;
  t4_n60: return 0.13208577036857605;
  t4_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t4_n109;
  t4_n62: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t4_n100;
  t4_n63: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n85;
  t4_n64: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n74;
  t4_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t4_n67;
  t4_n66: return 0.10073628276586533;
  t4_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t4_n69;
  t4_n68: return 0.10787418484687805;
  t4_n69: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t4_n71;
  t4_n70: return 0.11826545745134354;
  t4_n71: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t4_n73;
  t4_n72: return 0.1327129304409027;
  t4_n73: return 0.1297278106212616;
  t4_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t4_n76;
  t4_n75: return 0.12161669135093689;
  t4_n76: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t4_n78;
  t4_n77: return 0.1254672110080719;
  t4_n78: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t4_n84;
  t4_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t4_n81;
  t4_n80: return 0.12968407571315765;
  t4_n81: if (E.getNumReferences() >= 3356454464 /*146873.0*/) goto t4_n83;
  t4_n82: return 0.12899793684482574;
  t4_n83: return 0.12471718341112137;
  t4_n84: return -0.18162168562412262;
  t4_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n87;
  t4_n86: return 0.1273355633020401;
  t4_n87: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t4_n91;
  t4_n88: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t4_n90;
  t4_n89: return 0.13142964243888855;
  t4_n90: return 0.12226037681102753;
  t4_n91: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t4_n99;
  t4_n92: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t4_n96;
  t4_n93: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t4_n95;
  t4_n94: return 0.13121187686920166;
  t4_n95: return -0.15203113853931427;
  t4_n96: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t4_n98;
  t4_n97: return 0.13116788864135742;
  t4_n98: return 0.1318351775407791;
  t4_n99: return 0.12939037382602692;
  t4_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t4_n104;
  t4_n101: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n103;
  t4_n102: return 0.12765207886695862;
  t4_n103: return 0.13061551749706268;
  t4_n104: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t4_n108;
  t4_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t4_n107;
  t4_n106: return 0.13202622532844543;
  t4_n107: return 0.1321810781955719;
  t4_n108: return -0.16530804336071014;
  t4_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t4_n113;
  t4_n110: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t4_n112;
  t4_n111: return 0.12507092952728271;
  t4_n112: return 0.13102613389492035;
  t4_n113: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t4_n115;
  t4_n114: return 0.12814205884933472;
  t4_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t4_n117;
  t4_n116: return 0.1298857033252716;
  t4_n117: return 0.1312725692987442;
  t4_n118: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n168;
  t4_n119: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t4_n145;
  t4_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t4_n136;
  t4_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t4_n123;
  t4_n122: return -0.0990992933511734;
  t4_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n125;
  t4_n124: return -0.04187201336026192;
  t4_n125: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t4_n135;
  t4_n126: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t4_n130;
  t4_n127: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t4_n129;
  t4_n128: return 0.08492990583181381;
  t4_n129: return 0.1289561539888382;
  t4_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t4_n132;
  t4_n131: return 0.05860279127955437;
  t4_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t4_n134;
  t4_n133: return -0.0040860529989004135;
  t4_n134: return 0.12704111635684967;
  t4_n135: return 0.12396207451820374;
  t4_n136: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t4_n142;
  t4_n137: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t4_n141;
  t4_n138: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t4_n140;
  t4_n139: return 0.11355147510766983;
  t4_n140: return 0.12945899367332458;
  t4_n141: return -0.1311863362789154;
  t4_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t4_n144;
  t4_n143: return 0.11862269788980484;
  t4_n144: return 0.12997157871723175;
  t4_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n147;
  t4_n146: return 0.06020234897732735;
  t4_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t4_n165;
  t4_n148: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t4_n154;
  t4_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t4_n151;
  t4_n150: return 0.014503761194646358;
  t4_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t4_n153;
  t4_n152: return 0.12471770495176315;
  t4_n153: return 0.11718671768903732;
  t4_n154: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t4_n156;
  t4_n155: return 0.12273207306861877;
  t4_n156: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t4_n164;
  t4_n157: if (E.getNumReferences() >= 3350889856 /*95499.0*/) goto t4_n163;
  t4_n158: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t4_n160;
  t4_n159: return 0.12865211069583893;
  t4_n160: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t4_n162;
  t4_n161: return 0.13085277378559113;
  t4_n162: return 0.12587197124958038;
  t4_n163: return 0.07199150323867798;
  t4_n164: return 0.1315421760082245;
  t4_n165: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t4_n167;
  t4_n166: return 0.1275501847267151;
  t4_n167: return 0.13041375577449799;
  t4_n168: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t4_n180;
  t4_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n171;
  t4_n170: return 0.11771033704280853;
  t4_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n175;
  t4_n172: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t4_n174;
  t4_n173: return 0.12486705929040909;
  t4_n174: return 0.13076971471309662;
  t4_n175: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t4_n177;
  t4_n176: return 0.12794850766658783;
  t4_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t4_n179;
  t4_n178: return 0.1687382161617279;
  t4_n179: return 0.048748381435871124;
  t4_n180: return 0.13170671463012695;
  t4_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t4_n193;
  t4_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n186;
  t4_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t4_n185;
  t4_n184: return -0.023818938061594963;
  t4_n185: return 0.12835869193077087;
  t4_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t4_n190;
  t4_n187: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t4_n189;
  t4_n188: return 0.11277836561203003;
  t4_n189: return 0.128361314535141;
  t4_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t4_n192;
  t4_n191: return 0.12976807355880737;
  t4_n192: return 0.1306358128786087;
  t4_n193: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t4_n197;
  t4_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t4_n196;
  t4_n195: return 0.13084447383880615;
  t4_n196: return 0.13187165558338165;
  t4_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t4_n205;
  t4_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t4_n202;
  t4_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t4_n201;
  t4_n200: return 0.12571308016777039;
  t4_n201: return 0.13053598999977112;
  t4_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t4_n204;
  t4_n203: return 0.13111430406570435;
  t4_n204: return 0.13072632253170013;
  t4_n205: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t4_n207;
  t4_n206: return 0.13192588090896606;
  t4_n207: return 0.13129131495952606;
  t4_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t4_n238;
  t4_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n217;
  t4_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n212;
  t4_n211: return 0.11941647529602051;
  t4_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t4_n216;
  t4_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t4_n215;
  t4_n214: return 0.12906840443611145;
  t4_n215: return 0.1302323192358017;
  t4_n216: return -0.10368392616510391;
  t4_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t4_n231;
  t4_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t4_n230;
  t4_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n223;
  t4_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t4_n222;
  t4_n221: return -0.040684185922145844;
  t4_n222: return 0.12997625768184662;
  t4_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t4_n225;
  t4_n224: return 0.1016077995300293;
  t4_n225: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t4_n229;
  t4_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n228;
  t4_n227: return 0.13122738897800446;
  t4_n228: return 0.13243570923805237;
  t4_n229: return -0.14311252534389496;
  t4_n230: return 0.12940353155136108;
  t4_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n235;
  t4_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t4_n234;
  t4_n233: return 0.13074102997779846;
  t4_n234: return 0.13013486564159393;
  t4_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t4_n237;
  t4_n236: return 0.12941282987594604;
  t4_n237: return 0.1288728266954422;
  t4_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t4_n248;
  t4_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t4_n243;
  t4_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n242;
  t4_n241: return 0.11836336553096771;
  t4_n242: return 0.13269884884357452;
  t4_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t4_n247;
  t4_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n246;
  t4_n245: return 0.13222922384738922;
  t4_n246: return 0.13333725929260254;
  t4_n247: return 0.13374334573745728;
  t4_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t4_n252;
  t4_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t4_n251;
  t4_n250: return 0.12952646613121033;
  t4_n251: return 0.13223955035209656;
  t4_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t4_n254;
  t4_n253: return 0.13121181726455688;
  t4_n254: return 0.13238316774368286;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree5(const Example& E) {
  t5_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t5_n210;
  t5_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t5_n183;
  t5_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t5_n116;
  t5_n3: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t5_n59;
  t5_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t5_n22;
  t5_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t5_n17;
  t5_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t5_n14;
  t5_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n9;
  t5_n8: return -0.08246518671512604;
  t5_n9: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t5_n13;
  t5_n10: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n12;
  t5_n11: return 0.10485164821147919;
  t5_n12: return 0.16447512805461884;
  t5_n13: return 0.022166235372424126;
  t5_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n16;
  t5_n15: return -0.12325362116098404;
  t5_n16: return -0.11497645825147629;
  t5_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t5_n19;
  t5_n18: return 0.02503075823187828;
  t5_n19: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t5_n21;
  t5_n20: return 0.1555223912000656;
  t5_n21: return 0.12956663966178894;
  t5_n22: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t5_n48;
  t5_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t5_n37;
  t5_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n32;
  t5_n25: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t5_n31;
  t5_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n28;
  t5_n27: return 0.07328794151544571;
  t5_n28: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t5_n30;
  t5_n29: return 0.09581243246793747;
  t5_n30: return 0.10851171612739563;
  t5_n31: return 0.06038171425461769;
  t5_n32: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t5_n36;
  t5_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n35;
  t5_n34: return 0.08210990577936172;
  t5_n35: return 0.10952675342559814;
  t5_n36: return 0.11901907622814178;
  t5_n37: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t5_n39;
  t5_n38: return 0.11047732830047607;
  t5_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t5_n41;
  t5_n40: return 0.11634153127670288;
  t5_n41: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t5_n45;
  t5_n42: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t5_n44;
  t5_n43: return 0.12574072182178497;
  t5_n44: return 0.11729124188423157;
  t5_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n47;
  t5_n46: return 0.07906555384397507;
  t5_n47: return 0.12265865504741669;
  t5_n48: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n50;
  t5_n49: return -0.09572849422693253;
  t5_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n52;
  t5_n51: return 0.05296313017606735;
  t5_n52: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t5_n54;
  t5_n53: return 0.0028017389122396708;
  t5_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t5_n58;
  t5_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n57;
  t5_n56: return 0.1196630671620369;
  t5_n57: return 0.10264015942811966;
  t5_n58: return 0.11838161200284958;
  t5_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t5_n67;
  t5_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n64;
  t5_n61: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n63;
  t5_n62: return -0.01760932244360447;
  t5_n63: return 0.1132378950715065;
  t5_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n66;
  t5_n65: return 0.11439701169729233;
  t5_n66: return 0.12489776313304901;
  t5_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t5_n107;
  t5_n68: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t5_n98;
  t5_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n89;
  t5_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n80;
  t5_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t5_n73;
  t5_n72: return 0.09204074740409851;
  t5_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t5_n75;
  t5_n74: return 0.09913092106580734;
  t5_n75: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t5_n77;
  t5_n76: return 0.1091567799448967;
  t5_n77: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t5_n79;
  t5_n78: return 0.1254485845565796;
  t5_n79: return 0.12214037775993347;
  t5_n80: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t5_n82;
  t5_n81: return 0.11407013982534409;
  t5_n82: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t5_n84;
  t5_n83: return 0.11826757341623306;
  t5_n84: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t5_n88;
  t5_n85: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t5_n87;
  t5_n86: return 0.12276632338762283;
  t5_n87: return 0.12125788629055023;
  t5_n88: return -0.16854263842105865;
  t5_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n91;
  t5_n90: return 0.11965116113424301;
  t5_n91: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t5_n95;
  t5_n92: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t5_n94;
  t5_n93: return 0.12440533190965652;
  t5_n94: return 0.1150340884923935;
  t5_n95: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t5_n97;
  t5_n96: return 0.12405123561620712;
  t5_n97: return 0.12227573245763779;
  t5_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t5_n102;
  t5_n99: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n101;
  t5_n100: return 0.1196770966053009;
  t5_n101: return 0.12369400262832642;
  t5_n102: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t5_n106;
  t5_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t5_n105;
  t5_n104: return 0.12485748529434204;
  t5_n105: return 0.12493136525154114;
  t5_n106: return -0.15667559206485748;
  t5_n107: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t5_n111;
  t5_n108: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t5_n110;
  t5_n109: return 0.11714440584182739;
  t5_n110: return 0.12430502474308014;
  t5_n111: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t5_n113;
  t5_n112: return 0.12104270607233047;
  t5_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t5_n115;
  t5_n114: return 0.1230480819940567;
  t5_n115: return 0.12465094774961472;
  t5_n116: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n170;
  t5_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t5_n147;
  t5_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t5_n138;
  t5_n119: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t5_n133;
  t5_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t5_n122;
  t5_n121: return -0.08983761072158813;
  t5_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n124;
  t5_n123: return 0.008554327301681042;
  t5_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t5_n128;
  t5_n125: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t5_n127;
  t5_n126: return 0.08926698565483093;
  t5_n127: return 0.12172023952007294;
  t5_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t5_n130;
  t5_n129: return 0.07259354740381241;
  t5_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t5_n132;
  t5_n131: return -0.01041330210864544;
  t5_n132: return 0.11994793266057968;
  t5_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n135;
  t5_n134: return 0.05254447087645531;
  t5_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t5_n137;
  t5_n136: return -0.11969910562038422;
  t5_n137: return 0.11612097173929214;
  t5_n138: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t5_n144;
  t5_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t5_n143;
  t5_n140: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t5_n142;
  t5_n141: return 0.10364782065153122;
  t5_n142: return 0.12190599739551544;
  t5_n143: return -0.13495953381061554;
  t5_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t5_n146;
  t5_n145: return 0.10960251092910767;
  t5_n146: return 0.12294292449951172;
  t5_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n149;
  t5_n148: return 0.010330276563763618;
  t5_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t5_n167;
  t5_n150: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t5_n156;
  t5_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t5_n153;
  t5_n152: return -0.001054544234648347;
  t5_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t5_n155;
  t5_n154: return 0.11708949506282806;
  t5_n155: return 0.10950405895709991;
  t5_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t5_n158;
  t5_n157: return 0.11517553776502609;
  t5_n158: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t5_n166;
  t5_n159: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t5_n165;
  t5_n160: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t5_n162;
  t5_n161: return 0.12148863822221756;
  t5_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t5_n164;
  t5_n163: return 0.12410426884889603;
  t5_n164: return 0.12050491571426392;
  t5_n165: return 0.0866250991821289;
  t5_n166: return 0.1248498484492302;
  t5_n167: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t5_n169;
  t5_n168: return 0.12020380795001984;
  t5_n169: return 0.12339581549167633;
  t5_n170: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t5_n182;
  t5_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n173;
  t5_n172: return 0.10954398661851883;
  t5_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n177;
  t5_n174: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t5_n176;
  t5_n175: return 0.1173727810382843;
  t5_n176: return 0.12380734086036682;
  t5_n177: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t5_n179;
  t5_n178: return 0.12081331759691238;
  t5_n179: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t5_n181;
  t5_n180: return 0.1632082611322403;
  t5_n181: return 0.03827841207385063;
  t5_n182: return 0.12498895078897476;
  t5_n183: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t5_n195;
  t5_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n188;
  t5_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t5_n187;
  t5_n186: return -0.00734816724434495;
  t5_n187: return 0.12085331976413727;
  t5_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t5_n192;
  t5_n189: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t5_n191;
  t5_n190: return 0.10164695233106613;
  t5_n191: return 0.12107010185718536;
  t5_n192: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t5_n194;
  t5_n193: return 0.12263202667236328;
  t5_n194: return 0.12363939732313156;
  t5_n195: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t5_n199;
  t5_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t5_n198;
  t5_n197: return 0.12404220551252365;
  t5_n198: return 0.12517571449279785;
  t5_n199: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t5_n207;
  t5_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t5_n204;
  t5_n201: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t5_n203;
  t5_n202: return 0.11891496181488037;
  t5_n203: return 0.12356136739253998;
  t5_n204: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t5_n206;
  t5_n205: return 0.12440799176692963;
  t5_n206: return 0.12419634312391281;
  t5_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t5_n209;
  t5_n208: return 0.12518806755542755;
  t5_n209: return 0.1245139092206955;
  t5_n210: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t5_n238;
  t5_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n219;
  t5_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n214;
  t5_n213: return 0.1115230917930603;
  t5_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t5_n218;
  t5_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t5_n217;
  t5_n216: return 0.12214123457670212;
  t5_n217: return 0.12336272746324539;
  t5_n218: return -0.09089649468660355;
  t5_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n231;
  t5_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t5_n230;
  t5_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n225;
  t5_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t5_n224;
  t5_n223: return -0.044322870671749115;
  t5_n224: return 0.1228397861123085;
  t5_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t5_n227;
  t5_n226: return 0.09020587056875229;
  t5_n227: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t5_n229;
  t5_n228: return 0.12455291301012039;
  t5_n229: return -0.13367854058742523;
  t5_n230: return 0.1221235990524292;
  t5_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n235;
  t5_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t5_n234;
  t5_n233: return 0.12399512529373169;
  t5_n234: return 0.12328121066093445;
  t5_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t5_n237;
  t5_n236: return 0.1225079894065857;
  t5_n237: return 0.12186058610677719;
  t5_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t5_n248;
  t5_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t5_n243;
  t5_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n242;
  t5_n241: return 0.11127940565347672;
  t5_n242: return 0.12598751485347748;
  t5_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t5_n247;
  t5_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n246;
  t5_n245: return 0.12638694047927856;
  t5_n246: return 0.12666495144367218;
  t5_n247: return 0.1272842437028885;
  t5_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t5_n252;
  t5_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t5_n251;
  t5_n250: return 0.12263109534978867;
  t5_n251: return 0.12573689222335815;
  t5_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t5_n254;
  t5_n253: return 0.12447214126586914;
  t5_n254: return 0.12587770819664001;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree6(const Example& E) {
  t6_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t6_n210;
  t6_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t6_n181;
  t6_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t6_n116;
  t6_n3: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t6_n53;
  t6_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t6_n40;
  t6_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t6_n25;
  t6_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t6_n18;
  t6_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n9;
  t6_n8: return -0.07694527506828308;
  t6_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t6_n15;
  t6_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t6_n14;
  t6_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n13;
  t6_n12: return 0.09366220235824585;
  t6_n13: return 0.148265540599823;
  t6_n14: return 0.019576098769903183;
  t6_n15: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t6_n17;
  t6_n16: return 0.15084686875343323;
  t6_n17: return 0.16081175208091736;
  t6_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t6_n20;
  t6_n19: return 0.08417658507823944;
  t6_n20: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t6_n22;
  t6_n21: return 0.11901114881038666;
  t6_n22: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t6_n24;
  t6_n23: return 0.12081567943096161;
  t6_n24: return 0.11749343574047089;
  t6_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t6_n29;
  t6_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n28;
  t6_n27: return -0.11381218582391739;
  t6_n28: return -0.10071047395467758;
  t6_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n31;
  t6_n30: return -0.010966906324028969;
  t6_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t6_n33;
  t6_n32: return 0.08624853193759918;
  t6_n33: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t6_n37;
  t6_n34: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t6_n36;
  t6_n35: return 0.13918271660804749;
  t6_n36: return 0.11404117196798325;
  t6_n37: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t6_n39;
  t6_n38: return 0.11902166903018951;
  t6_n39: return 0.09488772600889206;
  t6_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n42;
  t6_n41: return -0.01503479853272438;
  t6_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n44;
  t6_n43: return 0.054352983832359314;
  t6_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t6_n50;
  t6_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n49;
  t6_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t6_n48;
  t6_n47: return 0.12691329419612885;
  t6_n48: return 0.11438445746898651;
  t6_n49: return 0.09642253071069717;
  t6_n50: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t6_n52;
  t6_n51: return 0.10210377722978592;
  t6_n52: return 0.11493503302335739;
  t6_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t6_n61;
  t6_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t6_n58;
  t6_n55: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n57;
  t6_n56: return -0.019194869324564934;
  t6_n57: return 0.10730741918087006;
  t6_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n60;
  t6_n59: return 0.1076255738735199;
  t6_n60: return 0.11946488171815872;
  t6_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t6_n107;
  t6_n62: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t6_n98;
  t6_n63: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n83;
  t6_n64: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n74;
  t6_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t6_n67;
  t6_n66: return 0.08718814700841904;
  t6_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n69;
  t6_n68: return 0.08843041956424713;
  t6_n69: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t6_n71;
  t6_n70: return 0.10282241553068161;
  t6_n71: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t6_n73;
  t6_n72: return 0.12006963789463043;
  t6_n73: return 0.11652491986751556;
  t6_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t6_n76;
  t6_n75: return 0.10999485850334167;
  t6_n76: if (E.getNumReferences() >= 3341246080 /*42846.5*/) goto t6_n78;
  t6_n77: return 0.11575620621442795;
  t6_n78: if (E.getNumReferences() >= 3364158080 /*272340.0*/) goto t6_n82;
  t6_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t6_n81;
  t6_n80: return 0.11759170144796371;
  t6_n81: return 0.11575504392385483;
  t6_n82: return -0.14012761414051056;
  t6_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n85;
  t6_n84: return 0.11453889310359955;
  t6_n85: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t6_n89;
  t6_n86: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t6_n88;
  t6_n87: return 0.12215220928192139;
  t6_n88: return 0.10887303948402405;
  t6_n89: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t6_n97;
  t6_n90: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t6_n94;
  t6_n91: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t6_n93;
  t6_n92: return 0.1190926730632782;
  t6_n93: return -0.14053958654403687;
  t6_n94: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t6_n96;
  t6_n95: return 0.1193011924624443;
  t6_n96: return 0.12044071406126022;
  t6_n97: return 0.11722931265830994;
  t6_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t6_n102;
  t6_n99: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n101;
  t6_n100: return 0.11341708898544312;
  t6_n101: return 0.11863100528717041;
  t6_n102: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t6_n106;
  t6_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t6_n105;
  t6_n104: return 0.11966031044721603;
  t6_n105: return 0.11959598958492279;
  t6_n106: return -0.14092107117176056;
  t6_n107: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t6_n109;
  t6_n108: return 0.11486894637346268;
  t6_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t6_n113;
  t6_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t6_n112;
  t6_n111: return 0.09547129273414612;
  t6_n112: return 0.11884362995624542;
  t6_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t6_n115;
  t6_n114: return 0.11788350343704224;
  t6_n115: return 0.11981629580259323;
  t6_n116: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n168;
  t6_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t6_n145;
  t6_n118: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t6_n140;
  t6_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t6_n133;
  t6_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t6_n122;
  t6_n121: return -0.0817423090338707;
  t6_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n124;
  t6_n123: return 0.004224621690809727;
  t6_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t6_n128;
  t6_n125: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t6_n127;
  t6_n126: return 0.08264568448066711;
  t6_n127: return 0.11623498052358627;
  t6_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t6_n130;
  t6_n129: return 0.06518735736608505;
  t6_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t6_n132;
  t6_n131: return -0.01168738678097725;
  t6_n132: return 0.11409099400043488;
  t6_n133: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t6_n137;
  t6_n134: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t6_n136;
  t6_n135: return 0.088108591735363;
  t6_n136: return 0.1156032383441925;
  t6_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n139;
  t6_n138: return 0.10262138396501541;
  t6_n139: return 0.11700879037380219;
  t6_n140: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n142;
  t6_n141: return 0.08917643874883652;
  t6_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t6_n144;
  t6_n143: return -0.07815256714820862;
  t6_n144: return 0.10972098261117935;
  t6_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n147;
  t6_n146: return 0.007304436527192593;
  t6_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t6_n165;
  t6_n148: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t6_n154;
  t6_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t6_n151;
  t6_n150: return -0.007949978113174438;
  t6_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t6_n153;
  t6_n152: return 0.11108005046844482;
  t6_n153: return 0.10171493142843246;
  t6_n154: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t6_n156;
  t6_n155: return 0.10885337740182877;
  t6_n156: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t6_n164;
  t6_n157: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t6_n163;
  t6_n158: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t6_n160;
  t6_n159: return 0.11590472608804703;
  t6_n160: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t6_n162;
  t6_n161: return 0.11909585446119308;
  t6_n162: return 0.11455501616001129;
  t6_n163: return 0.07241708785295486;
  t6_n164: return 0.12002451717853546;
  t6_n165: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t6_n167;
  t6_n166: return 0.11472001671791077;
  t6_n167: return 0.11811206489801407;
  t6_n168: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t6_n180;
  t6_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n171;
  t6_n170: return 0.10293734818696976;
  t6_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n175;
  t6_n172: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t6_n174;
  t6_n173: return 0.11301813274621964;
  t6_n174: return 0.1183653250336647;
  t6_n175: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t6_n177;
  t6_n176: return 0.11532328277826309;
  t6_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t6_n179;
  t6_n178: return 0.1577204167842865;
  t6_n179: return 0.06319843232631683;
  t6_n180: return 0.11995402723550797;
  t6_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t6_n193;
  t6_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n186;
  t6_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t6_n185;
  t6_n184: return -0.024076901376247406;
  t6_n185: return 0.11487280577421188;
  t6_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t6_n190;
  t6_n187: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t6_n189;
  t6_n188: return 0.09653716534376144;
  t6_n189: return 0.11526694148778915;
  t6_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t6_n192;
  t6_n191: return 0.1169799193739891;
  t6_n192: return 0.11845660209655762;
  t6_n193: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t6_n197;
  t6_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t6_n196;
  t6_n195: return 0.11907438188791275;
  t6_n196: return 0.12033944576978683;
  t6_n197: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t6_n205;
  t6_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t6_n202;
  t6_n199: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t6_n201;
  t6_n200: return 0.11376825720071793;
  t6_n201: return 0.11842282861471176;
  t6_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t6_n204;
  t6_n203: return 0.11952733993530273;
  t6_n204: return 0.11944061517715454;
  t6_n205: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t6_n207;
  t6_n206: return 0.11956767737865448;
  t6_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t6_n209;
  t6_n208: return 0.11413019895553589;
  t6_n209: return 0.12293189764022827;
  t6_n210: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t6_n238;
  t6_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n219;
  t6_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n214;
  t6_n213: return 0.10403391718864441;
  t6_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t6_n218;
  t6_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t6_n217;
  t6_n216: return 0.1162342056632042;
  t6_n217: return 0.11813230812549591;
  t6_n218: return 0.01899571903049946;
  t6_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n231;
  t6_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t6_n230;
  t6_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n225;
  t6_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t6_n224;
  t6_n223: return -0.030664870515465736;
  t6_n224: return 0.11728805303573608;
  t6_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t6_n227;
  t6_n226: return 0.07740702480077744;
  t6_n227: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t6_n229;
  t6_n228: return 0.11929808557033539;
  t6_n229: return -0.12399277836084366;
  t6_n230: return 0.1167450025677681;
  t6_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n235;
  t6_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t6_n234;
  t6_n233: return 0.11898418515920639;
  t6_n234: return 0.11821065843105316;
  t6_n235: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t6_n237;
  t6_n236: return 0.11734418570995331;
  t6_n237: return 0.11662206798791885;
  t6_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t6_n248;
  t6_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t6_n243;
  t6_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n242;
  t6_n241: return 0.10602554678916931;
  t6_n242: return 0.12102727591991425;
  t6_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t6_n247;
  t6_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n246;
  t6_n245: return 0.1215435341000557;
  t6_n246: return 0.1217925027012825;
  t6_n247: return 0.12241791933774948;
  t6_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t6_n252;
  t6_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t6_n251;
  t6_n250: return 0.11682932823896408;
  t6_n251: return 0.12104137241840363;
  t6_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t6_n254;
  t6_n253: return 0.1197219043970108;
  t6_n254: return 0.12119611352682114;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree7(const Example& E) {
  t7_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t7_n212;
  t7_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t7_n187;
  t7_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t7_n130;
  t7_n3: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t7_n67;
  t7_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t7_n24;
  t7_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t7_n19;
  t7_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t7_n16;
  t7_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n9;
  t7_n8: return -0.07651832699775696;
  t7_n9: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t7_n11;
  t7_n10: return 0.03678275644779205;
  t7_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n13;
  t7_n12: return 0.09451880306005478;
  t7_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n15;
  t7_n14: return 0.13966608047485352;
  t7_n15: return 0.1410679966211319;
  t7_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n18;
  t7_n17: return -0.11414434760808945;
  t7_n18: return -0.10379552841186523;
  t7_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t7_n21;
  t7_n20: return 0.021868770942091942;
  t7_n21: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t7_n23;
  t7_n22: return 0.13303282856941223;
  t7_n23: return 0.10801086574792862;
  t7_n24: if (E.getFileProximityDistance() >= 3255173120 /*33.5*/) goto t7_n54;
  t7_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t7_n45;
  t7_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n40;
  t7_n27: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n39;
  t7_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n30;
  t7_n29: return 0.061667975038290024;
  t7_n30: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t7_n38;
  t7_n31: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t7_n33;
  t7_n32: return 0.08006995171308517;
  t7_n33: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t7_n35;
  t7_n34: return 0.0987827256321907;
  t7_n35: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t7_n37;
  t7_n36: return 0.11787135899066925;
  t7_n37: return 0.11937885731458664;
  t7_n38: return 0.10030659288167953;
  t7_n39: return 0.05393628031015396;
  t7_n40: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t7_n44;
  t7_n41: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n43;
  t7_n42: return 0.067432701587677;
  t7_n43: return 0.0999528244137764;
  t7_n44: return 0.1096913293004036;
  t7_n45: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t7_n47;
  t7_n46: return 0.10127498209476471;
  t7_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t7_n49;
  t7_n48: return 0.10896171629428864;
  t7_n49: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t7_n51;
  t7_n50: return 0.11702041327953339;
  t7_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n53;
  t7_n52: return 0.06855163723230362;
  t7_n53: return 0.11374770849943161;
  t7_n54: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n56;
  t7_n55: return -0.07861299812793732;
  t7_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n58;
  t7_n57: return 0.044826820492744446;
  t7_n58: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t7_n60;
  t7_n59: return 0.009964678436517715;
  t7_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t7_n64;
  t7_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n63;
  t7_n62: return 0.10979517549276352;
  t7_n63: return 0.09482519328594208;
  t7_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t7_n66;
  t7_n65: return -0.3470112979412079;
  t7_n66: return 0.11045931279659271;
  t7_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t7_n87;
  t7_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t7_n70;
  t7_n69: return -0.046384941786527634;
  t7_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t7_n82;
  t7_n71: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n75;
  t7_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n74;
  t7_n73: return 0.07555894553661346;
  t7_n74: return 0.10914449393749237;
  t7_n75: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t7_n77;
  t7_n76: return 0.11636073887348175;
  t7_n77: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t7_n79;
  t7_n78: return 0.10632868111133575;
  t7_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n81;
  t7_n80: return 0.12015494704246521;
  t7_n81: return 0.11594400554895401;
  t7_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n84;
  t7_n83: return 0.12442126870155334;
  t7_n84: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t7_n86;
  t7_n85: return 0.14177241921424866;
  t7_n86: return 0.12350218743085861;
  t7_n87: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t7_n119;
  t7_n88: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t7_n110;
  t7_n89: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n103;
  t7_n90: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n100;
  t7_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t7_n93;
  t7_n92: return 0.08010321855545044;
  t7_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t7_n95;
  t7_n94: return 0.08414481580257416;
  t7_n95: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t7_n97;
  t7_n96: return 0.09454834461212158;
  t7_n97: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t7_n99;
  t7_n98: return 0.11624400317668915;
  t7_n99: return 0.11206576228141785;
  t7_n100: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t7_n102;
  t7_n101: return 0.10269846767187119;
  t7_n102: return 0.11259423941373825;
  t7_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n105;
  t7_n104: return 0.10878776013851166;
  t7_n105: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t7_n109;
  t7_n106: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t7_n108;
  t7_n107: return 0.11546321958303452;
  t7_n108: return 0.1037277951836586;
  t7_n109: return 0.11493141204118729;
  t7_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t7_n114;
  t7_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n113;
  t7_n112: return 0.10894259810447693;
  t7_n113: return 0.11489898711442947;
  t7_n114: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t7_n118;
  t7_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t7_n117;
  t7_n116: return 0.11595240980386734;
  t7_n117: return 0.11570192873477936;
  t7_n118: return -0.13659068942070007;
  t7_n119: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n123;
  t7_n120: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t7_n122;
  t7_n121: return 0.1083010584115982;
  t7_n122: return 0.1158897876739502;
  t7_n123: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t7_n127;
  t7_n124: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t7_n126;
  t7_n125: return 0.15177322924137115;
  t7_n126: return 0.10818535089492798;
  t7_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t7_n129;
  t7_n128: return 0.11396890133619308;
  t7_n129: return 0.11622614413499832;
  t7_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n174;
  t7_n131: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t7_n153;
  t7_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t7_n148;
  t7_n133: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t7_n143;
  t7_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t7_n136;
  t7_n135: return -0.017825448885560036;
  t7_n136: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t7_n138;
  t7_n137: return 0.04682198911905289;
  t7_n138: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n140;
  t7_n139: return 0.09786824882030487;
  t7_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t7_n142;
  t7_n141: return -0.0028368905186653137;
  t7_n142: return 0.11079441756010056;
  t7_n143: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n145;
  t7_n144: return 0.0810122862458229;
  t7_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t7_n147;
  t7_n146: return -0.10663174837827682;
  t7_n147: return 0.10410875082015991;
  t7_n148: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t7_n152;
  t7_n149: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t7_n151;
  t7_n150: return 0.09043923765420914;
  t7_n151: return -0.1289406418800354;
  t7_n152: return 0.10844844579696655;
  t7_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n155;
  t7_n154: return 0.03135048598051071;
  t7_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t7_n171;
  t7_n156: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t7_n160;
  t7_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t7_n159;
  t7_n158: return 0.003141457913443446;
  t7_n159: return 0.10377974063158035;
  t7_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t7_n162;
  t7_n161: return 0.1031254306435585;
  t7_n162: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t7_n170;
  t7_n163: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t7_n169;
  t7_n164: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t7_n166;
  t7_n165: return 0.11135101318359375;
  t7_n166: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t7_n168;
  t7_n167: return 0.11550747603178024;
  t7_n168: return 0.10996823012828827;
  t7_n169: return 0.06432437151670456;
  t7_n170: return 0.11651279777288437;
  t7_n171: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t7_n173;
  t7_n172: return 0.11025538295507431;
  t7_n173: return 0.11423131823539734;
  t7_n174: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t7_n186;
  t7_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n177;
  t7_n176: return 0.09669717401266098;
  t7_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n181;
  t7_n178: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t7_n180;
  t7_n179: return 0.1069055050611496;
  t7_n180: return 0.11382551491260529;
  t7_n181: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t7_n183;
  t7_n182: return 0.11099054664373398;
  t7_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t7_n185;
  t7_n184: return 0.1542593538761139;
  t7_n185: return 0.08924993872642517;
  t7_n186: return 0.11601562798023224;
  t7_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t7_n199;
  t7_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n192;
  t7_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t7_n191;
  t7_n190: return -0.03711888939142227;
  t7_n191: return 0.10977572202682495;
  t7_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t7_n196;
  t7_n193: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t7_n195;
  t7_n194: return 0.0898740217089653;
  t7_n195: return 0.11054060608148575;
  t7_n196: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t7_n198;
  t7_n197: return 0.1125241219997406;
  t7_n198: return 0.11462436616420746;
  t7_n199: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t7_n203;
  t7_n200: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t7_n202;
  t7_n201: return 0.11548912525177002;
  t7_n202: return 0.11691773682832718;
  t7_n203: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t7_n209;
  t7_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t7_n208;
  t7_n205: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t7_n207;
  t7_n206: return 0.1095297783613205;
  t7_n207: return 0.11462422460317612;
  t7_n208: return 0.11616656929254532;
  t7_n209: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t7_n211;
  t7_n210: return 0.1163925975561142;
  t7_n211: return 0.11587662249803543;
  t7_n212: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t7_n240;
  t7_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n221;
  t7_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n216;
  t7_n215: return 0.0990118607878685;
  t7_n216: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t7_n220;
  t7_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t7_n219;
  t7_n218: return 0.11234888434410095;
  t7_n219: return 0.11404508352279663;
  t7_n220: return 0.00979738961905241;
  t7_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n233;
  t7_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t7_n232;
  t7_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n227;
  t7_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t7_n226;
  t7_n225: return -0.030750200152397156;
  t7_n226: return 0.1128266453742981;
  t7_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t7_n229;
  t7_n228: return 0.07501054555177689;
  t7_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t7_n231;
  t7_n230: return 0.11510385572910309;
  t7_n231: return -0.11895431578159332;
  t7_n232: return 0.11200570315122604;
  t7_n233: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n237;
  t7_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t7_n236;
  t7_n235: return 0.11515509337186813;
  t7_n236: return 0.1142982542514801;
  t7_n237: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t7_n239;
  t7_n238: return 0.11345380544662476;
  t7_n239: return 0.11260415613651276;
  t7_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t7_n250;
  t7_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t7_n245;
  t7_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n244;
  t7_n243: return 0.09579700231552124;
  t7_n244: return 0.11725304275751114;
  t7_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t7_n249;
  t7_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n248;
  t7_n247: return 0.11788005381822586;
  t7_n248: return 0.11799407750368118;
  t7_n249: return 0.11875198036432266;
  t7_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t7_n254;
  t7_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t7_n253;
  t7_n252: return 0.11300672590732574;
  t7_n253: return 0.11746147274971008;
  t7_n254: return 0.11641047894954681;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree8(const Example& E) {
  t8_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t8_n214;
  t8_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t8_n191;
  t8_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t8_n128;
  t8_n3: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t8_n49;
  t8_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t8_n30;
  t8_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t8_n21;
  t8_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t8_n16;
  t8_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n9;
  t8_n8: return -0.06547743082046509;
  t8_n9: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t8_n11;
  t8_n10: return 0.03532000631093979;
  t8_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n13;
  t8_n12: return 0.09117697179317474;
  t8_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t8_n15;
  t8_n14: return 0.1301424503326416;
  t8_n15: return 0.12945537269115448;
  t8_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t8_n18;
  t8_n17: return 0.07200779765844345;
  t8_n18: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t8_n20;
  t8_n19: return 0.11174715310335159;
  t8_n20: return 0.11420679837465286;
  t8_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t8_n25;
  t8_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n24;
  t8_n23: return -0.10846680402755737;
  t8_n24: return -0.09971440583467484;
  t8_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t8_n27;
  t8_n26: return 0.0015377497766166925;
  t8_n27: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t8_n29;
  t8_n28: return 0.12166021764278412;
  t8_n29: return 0.09845957159996033;
  t8_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n38;
  t8_n31: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t8_n37;
  t8_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n34;
  t8_n33: return 0.059349365532398224;
  t8_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t8_n36;
  t8_n35: return 0.011213590390980244;
  t8_n36: return 0.10559426248073578;
  t8_n37: return -0.011112953536212444;
  t8_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n40;
  t8_n39: return 0.0448327474296093;
  t8_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t8_n46;
  t8_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n45;
  t8_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t8_n44;
  t8_n43: return 0.11176303029060364;
  t8_n44: return 0.10594355314970016;
  t8_n45: return 0.08839324116706848;
  t8_n46: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t8_n48;
  t8_n47: return 0.09425932168960571;
  t8_n48: return 0.10637087374925613;
  t8_n49: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t8_n101;
  t8_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t8_n88;
  t8_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n81;
  t8_n52: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t8_n62;
  t8_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t8_n55;
  t8_n54: return -0.044328365474939346;
  t8_n55: if (E.getNumReferences() >= 3332280320 /*20296.0*/) goto t8_n57;
  t8_n56: return 0.050923947244882584;
  t8_n57: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t8_n59;
  t8_n58: return 0.09309293329715729;
  t8_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t8_n61;
  t8_n60: return 0.10062727332115173;
  t8_n61: return 0.11192172765731812;
  t8_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n76;
  t8_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n65;
  t8_n64: return -0.038678381592035294;
  t8_n65: if (E.getNumReferences() >= 3337697792 /*30877.0*/) goto t8_n73;
  t8_n66: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t8_n72;
  t8_n67: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t8_n71;
  t8_n68: if (E.getNumReferences() >= 3294666752 /*898.5*/) goto t8_n70;
  t8_n69: return 0.10408595949411392;
  t8_n70: return 0.16123764216899872;
  t8_n71: return 0.10283596068620682;
  t8_n72: return 0.07165191322565079;
  t8_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n75;
  t8_n74: return 0.12342588603496552;
  t8_n75: return 0.11476241052150726;
  t8_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n78;
  t8_n77: return 0.10061712563037872;
  t8_n78: if (E.getNumReferences() >= 3344831744 /*56853.0*/) goto t8_n80;
  t8_n79: return 0.0995582640171051;
  t8_n80: return 0.126464381814003;
  t8_n81: if (E.getNumReferences() >= 3332623360 /*20966.0*/) goto t8_n83;
  t8_n82: return 0.11869504302740097;
  t8_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n85;
  t8_n84: return 0.09879282861948013;
  t8_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n87;
  t8_n86: return 0.10661789029836655;
  t8_n87: return 0.11118782311677933;
  t8_n88: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t8_n92;
  t8_n89: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t8_n91;
  t8_n90: return 0.07970006763935089;
  t8_n91: return 0.10395988821983337;
  t8_n92: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t8_n98;
  t8_n93: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t8_n95;
  t8_n94: return 0.10644859820604324;
  t8_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t8_n97;
  t8_n96: return 0.10919098556041718;
  t8_n97: return 0.11378417164087296;
  t8_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t8_n100;
  t8_n99: return 0.08550520241260529;
  t8_n100: return 0.11729203164577484;
  t8_n101: if (E.getNumReferences() >= 3316905984 /*5759.0*/) goto t8_n109;
  t8_n102: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t8_n104;
  t8_n103: return 0.1302957832813263;
  t8_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t8_n106;
  t8_n105: return 0.15932682156562805;
  t8_n106: if (E.getNumReferences() >= 3309508608 /*3121.5*/) goto t8_n108;
  t8_n107: return 0.16140031814575195;
  t8_n108: return 0.16877815127372742;
  t8_n109: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t8_n111;
  t8_n110: return 0.12127749621868134;
  t8_n111: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n127;
  t8_n112: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t8_n116;
  t8_n113: if (E.getNumReferences() >= 3337152512 /*29812.0*/) goto t8_n115;
  t8_n114: return 0.14036574959754944;
  t8_n115: return 0.10967881232500076;
  t8_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t8_n120;
  t8_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t8_n119;
  t8_n118: return 0.12818646430969238;
  t8_n119: return 0.16637516021728516;
  t8_n120: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t8_n122;
  t8_n121: return 0.11963826417922974;
  t8_n122: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t8_n126;
  t8_n123: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t8_n125;
  t8_n124: return 0.17955699563026428;
  t8_n125: return 0.18985846638679504;
  t8_n126: return 0.11659557372331619;
  t8_n127: return 0.14087316393852234;
  t8_n128: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n176;
  t8_n129: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t8_n155;
  t8_n130: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t8_n150;
  t8_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t8_n137;
  t8_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t8_n134;
  t8_n133: return -0.02350633591413498;
  t8_n134: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t8_n136;
  t8_n135: return 0.09085749834775925;
  t8_n136: return -0.09804926067590714;
  t8_n137: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t8_n143;
  t8_n138: if (E.getNumReferences() >= 3316554752 /*5587.5*/) goto t8_n140;
  t8_n139: return 0.04247909039258957;
  t8_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n142;
  t8_n141: return 0.10219305008649826;
  t8_n142: return 0.112519770860672;
  t8_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t8_n149;
  t8_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n146;
  t8_n145: return 0.10158360749483109;
  t8_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t8_n148;
  t8_n147: return -0.0020382446236908436;
  t8_n148: return 0.10430170595645905;
  t8_n149: return 0.12071332335472107;
  t8_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n152;
  t8_n151: return 0.08259961009025574;
  t8_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t8_n154;
  t8_n153: return -0.0674571767449379;
  t8_n154: return 0.09947020560503006;
  t8_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n157;
  t8_n156: return 0.041217803955078125;
  t8_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t8_n173;
  t8_n158: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t8_n162;
  t8_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t8_n161;
  t8_n160: return 0.0010269013000652194;
  t8_n161: return 0.09941023588180542;
  t8_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n164;
  t8_n163: return 0.09760589897632599;
  t8_n164: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t8_n172;
  t8_n165: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t8_n171;
  t8_n166: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t8_n168;
  t8_n167: return 0.10767178982496262;
  t8_n168: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t8_n170;
  t8_n169: return 0.11259830743074417;
  t8_n170: return 0.10641951858997345;
  t8_n171: return 0.059029098600149155;
  t8_n172: return 0.1137610375881195;
  t8_n173: if (E.getNumReferences() >= 3281518592 /*304.0*/) goto t8_n175;
  t8_n174: return 0.10660836100578308;
  t8_n175: return 0.1108003556728363;
  t8_n176: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t8_n188;
  t8_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n179;
  t8_n178: return 0.09269571304321289;
  t8_n179: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n183;
  t8_n180: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t8_n182;
  t8_n181: return 0.10306692868471146;
  t8_n182: return 0.11009225994348526;
  t8_n183: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t8_n185;
  t8_n184: return 0.1070241779088974;
  t8_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t8_n187;
  t8_n186: return 0.14922408759593964;
  t8_n187: return 0.05147448554635048;
  t8_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n190;
  t8_n189: return 0.11346691101789474;
  t8_n190: return 0.11292967200279236;
  t8_n191: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t8_n201;
  t8_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n196;
  t8_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n195;
  t8_n194: return -0.0362948402762413;
  t8_n195: return 0.10571350157260895;
  t8_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t8_n200;
  t8_n197: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t8_n199;
  t8_n198: return 0.0841469094157219;
  t8_n199: return 0.10599817335605621;
  t8_n200: return 0.10902093350887299;
  t8_n201: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t8_n205;
  t8_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t8_n204;
  t8_n203: return 0.11261291056871414;
  t8_n204: return 0.11422496289014816;
  t8_n205: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t8_n211;
  t8_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t8_n210;
  t8_n207: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t8_n209;
  t8_n208: return 0.10614977031946182;
  t8_n209: return 0.11155606806278229;
  t8_n210: return 0.11340656131505966;
  t8_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t8_n213;
  t8_n212: return 0.11328229308128357;
  t8_n213: return 0.11301282048225403;
  t8_n214: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t8_n240;
  t8_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n221;
  t8_n216: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n218;
  t8_n217: return 0.09297329932451248;
  t8_n218: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t8_n220;
  t8_n219: return 0.11021395772695541;
  t8_n220: return 0.013255096040666103;
  t8_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n233;
  t8_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t8_n232;
  t8_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n227;
  t8_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t8_n226;
  t8_n225: return -0.01040442194789648;
  t8_n226: return 0.10941698402166367;
  t8_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t8_n229;
  t8_n228: return 0.06740029156208038;
  t8_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t8_n231;
  t8_n230: return 0.11191198229789734;
  t8_n231: return -0.11607234179973602;
  t8_n232: return 0.10851335525512695;
  t8_n233: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t8_n237;
  t8_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t8_n236;
  t8_n235: return 0.11212385445833206;
  t8_n236: return 0.11105799674987793;
  t8_n237: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t8_n239;
  t8_n238: return 0.11012834310531616;
  t8_n239: return 0.10928084701299667;
  t8_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t8_n250;
  t8_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t8_n245;
  t8_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n244;
  t8_n243: return 0.08945435285568237;
  t8_n244: return 0.11415990442037582;
  t8_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t8_n249;
  t8_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n248;
  t8_n247: return 0.11485791206359863;
  t8_n248: return 0.1152067556977272;
  t8_n249: return 0.11592748761177063;
  t8_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t8_n254;
  t8_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t8_n253;
  t8_n252: return 0.10827924311161041;
  t8_n253: return 0.11478926241397858;
  t8_n254: return 0.11369560658931732;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree9(const Example& E) {
  t9_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t9_n222;
  t9_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t9_n199;
  t9_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t9_n146;
  t9_n3: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t9_n67;
  t9_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t9_n40;
  t9_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t9_n25;
  t9_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t9_n18;
  t9_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t9_n9;
  t9_n8: return -0.06853244453668594;
  t9_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t9_n17;
  t9_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t9_n12;
  t9_n11: return 0.014664157293736935;
  t9_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n14;
  t9_n13: return 0.07626525312662125;
  t9_n14: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t9_n16;
  t9_n15: return 0.12836135923862457;
  t9_n16: return 0.123404361307621;
  t9_n17: return 0.12466690689325333;
  t9_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t9_n20;
  t9_n19: return 0.06838180124759674;
  t9_n20: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t9_n22;
  t9_n21: return 0.10847064852714539;
  t9_n22: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t9_n24;
  t9_n23: return 0.11218585819005966;
  t9_n24: return 0.10261552780866623;
  t9_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n27;
  t9_n26: return -0.1022336557507515;
  t9_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t9_n29;
  t9_n28: return -0.09916984289884567;
  t9_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t9_n37;
  t9_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t9_n32;
  t9_n31: return -0.0063174511305987835;
  t9_n32: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t9_n34;
  t9_n33: return 0.07727540284395218;
  t9_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t9_n36;
  t9_n35: return 0.08833754807710648;
  t9_n36: return 0.11304349452257156;
  t9_n37: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t9_n39;
  t9_n38: return 0.11535986512899399;
  t9_n39: return 0.09239251166582108;
  t9_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n56;
  t9_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n43;
  t9_n42: return -0.034604188054800034;
  t9_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t9_n51;
  t9_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n46;
  t9_n45: return 0.0062573933973908424;
  t9_n46: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t9_n48;
  t9_n47: return 0.056136537343263626;
  t9_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t9_n50;
  t9_n49: return 0.09645510464906693;
  t9_n50: return 0.16783428192138672;
  t9_n51: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t9_n55;
  t9_n52: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t9_n54;
  t9_n53: return 0.14581839740276337;
  t9_n54: return 0.15345625579357147;
  t9_n55: return -0.11681395024061203;
  t9_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n58;
  t9_n57: return 0.047244250774383545;
  t9_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t9_n64;
  t9_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n63;
  t9_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t9_n62;
  t9_n61: return 0.10968109965324402;
  t9_n62: return 0.10323546081781387;
  t9_n63: return 0.08427122980356216;
  t9_n64: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t9_n66;
  t9_n65: return 0.08797973394393921;
  t9_n66: return 0.10257167369127274;
  t9_n67: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t9_n121;
  t9_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t9_n106;
  t9_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n91;
  t9_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n80;
  t9_n71: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t9_n73;
  t9_n72: return -0.03532494232058525;
  t9_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t9_n75;
  t9_n74: return 0.029815077781677246;
  t9_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n77;
  t9_n76: return 0.09339139610528946;
  t9_n77: if (E.getNumReferences() >= 3344831744 /*56853.0*/) goto t9_n79;
  t9_n78: return 0.09372197091579437;
  t9_n79: return 0.1256445050239563;
  t9_n80: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t9_n82;
  t9_n81: return 0.06578553467988968;
  t9_n82: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t9_n88;
  t9_n83: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t9_n85;
  t9_n84: return 0.09656242281198502;
  t9_n85: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t9_n87;
  t9_n86: return 0.09546219557523727;
  t9_n87: return 0.11074887961149216;
  t9_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t9_n90;
  t9_n89: return 0.10143651813268661;
  t9_n90: return 0.10981237143278122;
  t9_n91: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n99;
  t9_n92: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t9_n96;
  t9_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n95;
  t9_n94: return 0.0857071653008461;
  t9_n95: return 0.14868102967739105;
  t9_n96: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t9_n98;
  t9_n97: return 0.08117634057998657;
  t9_n98: return 0.11107300966978073;
  t9_n99: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t9_n101;
  t9_n100: return 0.12696416676044464;
  t9_n101: if (E.getNumReferences() >= 3314670592 /*4667.5*/) goto t9_n103;
  t9_n102: return 0.15038248896598816;
  t9_n103: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t9_n105;
  t9_n104: return 0.1523316204547882;
  t9_n105: return 0.10626910626888275;
  t9_n106: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t9_n112;
  t9_n107: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t9_n111;
  t9_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t9_n110;
  t9_n109: return 0.021774036809802055;
  t9_n110: return 0.10641668736934662;
  t9_n111: return 0.09974052011966705;
  t9_n112: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t9_n118;
  t9_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t9_n115;
  t9_n114: return 0.10275077819824219;
  t9_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t9_n117;
  t9_n116: return 0.10636093467473984;
  t9_n117: return 0.11149490624666214;
  t9_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t9_n120;
  t9_n119: return 0.08102115988731384;
  t9_n120: return 0.11682812124490738;
  t9_n121: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t9_n123;
  t9_n122: return 0.12695525586605072;
  t9_n123: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t9_n125;
  t9_n124: return 0.12007838487625122;
  t9_n125: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t9_n129;
  t9_n126: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n128;
  t9_n127: return 0.12413899600505829;
  t9_n128: return 0.13873377442359924;
  t9_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t9_n137;
  t9_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n136;
  t9_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t9_n133;
  t9_n132: return 0.12737759947776794;
  t9_n133: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t9_n135;
  t9_n134: return 0.15666936337947845;
  t9_n135: return 0.15686967968940735;
  t9_n136: return 0.13967114686965942;
  t9_n137: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t9_n139;
  t9_n138: return 0.11949263513088226;
  t9_n139: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t9_n145;
  t9_n140: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t9_n144;
  t9_n141: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t9_n143;
  t9_n142: return 0.16278627514839172;
  t9_n143: return 0.16207823157310486;
  t9_n144: return 0.1669691652059555;
  t9_n145: return 0.1123083159327507;
  t9_n146: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n184;
  t9_n147: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t9_n165;
  t9_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t9_n154;
  t9_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t9_n151;
  t9_n150: return -0.010888531804084778;
  t9_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t9_n153;
  t9_n152: return 0.08725670725107193;
  t9_n153: return -0.1270279437303543;
  t9_n154: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t9_n160;
  t9_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n157;
  t9_n156: return 0.01755915954709053;
  t9_n157: if (E.getNumReferences() >= 3277455360 /*218.0*/) goto t9_n159;
  t9_n158: return 0.07728233188390732;
  t9_n159: return 0.10869486629962921;
  t9_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n162;
  t9_n161: return 0.09986427426338196;
  t9_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t9_n164;
  t9_n163: return -0.0009319137898273766;
  t9_n164: return 0.101384237408638;
  t9_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n167;
  t9_n166: return 0.02540426142513752;
  t9_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t9_n181;
  t9_n168: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t9_n170;
  t9_n169: return 0.0926477238535881;
  t9_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n172;
  t9_n171: return 0.0933849886059761;
  t9_n172: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t9_n180;
  t9_n173: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t9_n179;
  t9_n174: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t9_n176;
  t9_n175: return 0.1049264594912529;
  t9_n176: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t9_n178;
  t9_n177: return 0.1103455126285553;
  t9_n178: return 0.1030270904302597;
  t9_n179: return 0.05997699499130249;
  t9_n180: return 0.11159674823284149;
  t9_n181: if (E.getNumReferences() >= 3276111872 /*197.5*/) goto t9_n183;
  t9_n182: return 0.10308925807476044;
  t9_n183: return 0.1081802099943161;
  t9_n184: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t9_n196;
  t9_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n187;
  t9_n186: return 0.08642741292715073;
  t9_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n191;
  t9_n188: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t9_n190;
  t9_n189: return 0.10024666041135788;
  t9_n190: return 0.10751419514417648;
  t9_n191: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t9_n193;
  t9_n192: return 0.10404530167579651;
  t9_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n195;
  t9_n194: return 0.14279907941818237;
  t9_n195: return 0.0563400536775589;
  t9_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n198;
  t9_n197: return 0.1109919622540474;
  t9_n198: return 0.11049427837133408;
  t9_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t9_n209;
  t9_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n204;
  t9_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t9_n203;
  t9_n202: return -0.09902960062026978;
  t9_n203: return 0.10273673385381699;
  t9_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t9_n208;
  t9_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t9_n207;
  t9_n206: return 0.07701864093542099;
  t9_n207: return 0.10220222175121307;
  t9_n208: return 0.10581668466329575;
  t9_n209: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t9_n213;
  t9_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t9_n212;
  t9_n211: return 0.11033472418785095;
  t9_n212: return 0.11246601492166519;
  t9_n213: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t9_n219;
  t9_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t9_n218;
  t9_n215: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t9_n217;
  t9_n216: return 0.10279238224029541;
  t9_n217: return 0.10918153822422028;
  t9_n218: return 0.11122792959213257;
  t9_n219: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t9_n221;
  t9_n220: return 0.11085425317287445;
  t9_n221: return 0.11061243712902069;
  t9_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t9_n240;
  t9_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n229;
  t9_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n226;
  t9_n225: return 0.08910759538412094;
  t9_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t9_n228;
  t9_n227: return 0.10714796930551529;
  t9_n228: return -0.06444110721349716;
  t9_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t9_n237;
  t9_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t9_n236;
  t9_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n233;
  t9_n232: return 0.10619659721851349;
  t9_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t9_n235;
  t9_n234: return 0.06257414817810059;
  t9_n235: return 0.1091151311993599;
  t9_n236: return 0.10513731092214584;
  t9_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t9_n239;
  t9_n238: return 0.1091422364115715;
  t9_n239: return 0.10707225650548935;
  t9_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t9_n250;
  t9_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t9_n245;
  t9_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n244;
  t9_n243: return 0.08384349197149277;
  t9_n244: return 0.11169914901256561;
  t9_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t9_n249;
  t9_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n248;
  t9_n247: return 0.11316007375717163;
  t9_n248: return 0.11295861750841141;
  t9_n249: return 0.11372324079275131;
  t9_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t9_n254;
  t9_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t9_n253;
  t9_n252: return 0.10733778774738312;
  t9_n253: return 0.11260776221752167;
  t9_n254: return 0.11138442158699036;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree10(const Example& E) {
  t10_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t10_n222;
  t10_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t10_n199;
  t10_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t10_n146;
  t10_n3: if (E.getNumReferences() >= 3289784320 /*600.5*/) goto t10_n57;
  t10_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t10_n22;
  t10_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t10_n19;
  t10_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t10_n8;
  t10_n7: return -0.06894181668758392;
  t10_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n18;
  t10_n9: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t10_n11;
  t10_n10: return 0.012452631257474422;
  t10_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n15;
  t10_n12: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t10_n14;
  t10_n13: return 0.08269309997558594;
  t10_n14: return 0.03459428250789642;
  t10_n15: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n17;
  t10_n16: return 0.12227106839418411;
  t10_n17: return 0.11711292713880539;
  t10_n18: return 0.11693963408470154;
  t10_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n21;
  t10_n20: return -0.10570283234119415;
  t10_n21: return -0.09751439094543457;
  t10_n22: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t10_n44;
  t10_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t10_n37;
  t10_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n26;
  t10_n25: return 0.029324455186724663;
  t10_n26: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t10_n36;
  t10_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n35;
  t10_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n34;
  t10_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t10_n31;
  t10_n30: return 0.06864874809980392;
  t10_n31: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t10_n33;
  t10_n32: return 0.09322725981473923;
  t10_n33: return 0.10988599807024002;
  t10_n34: return 0.04464532434940338;
  t10_n35: return 0.08172885328531265;
  t10_n36: return 0.08956414461135864;
  t10_n37: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t10_n39;
  t10_n38: return 0.08989109098911285;
  t10_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t10_n41;
  t10_n40: return 0.10211652517318726;
  t10_n41: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t10_n43;
  t10_n42: return 0.11002326756715775;
  t10_n43: return 0.10216384381055832;
  t10_n44: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n46;
  t10_n45: return -0.060805972665548325;
  t10_n46: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t10_n48;
  t10_n47: return -0.08108234405517578;
  t10_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n50;
  t10_n49: return 0.042658984661102295;
  t10_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t10_n56;
  t10_n51: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n55;
  t10_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t10_n54;
  t10_n53: return 0.10525105148553848;
  t10_n54: return 0.10112606734037399;
  t10_n55: return 0.08229856938123703;
  t10_n56: return 0.09999354183673859;
  t10_n57: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t10_n117;
  t10_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n102;
  t10_n59: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n87;
  t10_n60: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n72;
  t10_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t10_n63;
  t10_n62: return -0.03083433397114277;
  t10_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n65;
  t10_n64: return 0.03034846857190132;
  t10_n65: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t10_n67;
  t10_n66: return 0.08971010893583298;
  t10_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t10_n71;
  t10_n68: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t10_n70;
  t10_n69: return 0.1252216100692749;
  t10_n70: return 0.1006692424416542;
  t10_n71: return 0.07417521625757217;
  t10_n72: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t10_n74;
  t10_n73: return 0.056223221123218536;
  t10_n74: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t10_n84;
  t10_n75: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t10_n81;
  t10_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t10_n78;
  t10_n77: return 0.0861545130610466;
  t10_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t10_n80;
  t10_n79: return 0.06957665830850601;
  t10_n80: return 0.10926280915737152;
  t10_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t10_n83;
  t10_n82: return 0.09390223026275635;
  t10_n83: return 0.10799024999141693;
  t10_n84: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t10_n86;
  t10_n85: return 0.0903552919626236;
  t10_n86: return 0.1086459532380104;
  t10_n87: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n95;
  t10_n88: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t10_n92;
  t10_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n91;
  t10_n90: return 0.07689394801855087;
  t10_n91: return 0.1396564394235611;
  t10_n92: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t10_n94;
  t10_n93: return 0.07230648398399353;
  t10_n94: return 0.10940157622098923;
  t10_n95: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t10_n97;
  t10_n96: return 0.1197822242975235;
  t10_n97: if (E.getNumReferences() >= 3314670592 /*4667.5*/) goto t10_n99;
  t10_n98: return 0.13512660562992096;
  t10_n99: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t10_n101;
  t10_n100: return 0.14311550557613373;
  t10_n101: return 0.10401536524295807;
  t10_n102: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t10_n108;
  t10_n103: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t10_n107;
  t10_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n106;
  t10_n105: return 0.026601118966937065;
  t10_n106: return 0.09735067188739777;
  t10_n107: return 0.0959782674908638;
  t10_n108: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t10_n114;
  t10_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n111;
  t10_n110: return 0.0988479033112526;
  t10_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t10_n113;
  t10_n112: return 0.10345815867185593;
  t10_n113: return 0.10959935188293457;
  t10_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t10_n116;
  t10_n115: return 0.07534542679786682;
  t10_n116: return 0.1155477836728096;
  t10_n117: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t10_n121;
  t10_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t10_n120;
  t10_n119: return 0.13385005295276642;
  t10_n120: return 0.1141357272863388;
  t10_n121: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t10_n123;
  t10_n122: return 0.11384086310863495;
  t10_n123: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t10_n127;
  t10_n124: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n126;
  t10_n125: return 0.11808019131422043;
  t10_n126: return 0.13269375264644623;
  t10_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t10_n135;
  t10_n128: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n134;
  t10_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t10_n131;
  t10_n130: return 0.12207780033349991;
  t10_n131: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t10_n133;
  t10_n132: return 0.14571928977966309;
  t10_n133: return 0.1450662761926651;
  t10_n134: return 0.13335147500038147;
  t10_n135: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t10_n137;
  t10_n136: return 0.11515205353498459;
  t10_n137: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t10_n145;
  t10_n138: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t10_n144;
  t10_n139: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t10_n141;
  t10_n140: return 0.14767928421497345;
  t10_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t10_n143;
  t10_n142: return 0.14850039780139923;
  t10_n143: return 0.14701487123966217;
  t10_n144: return 0.1514456570148468;
  t10_n145: return 0.10995613038539886;
  t10_n146: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n184;
  t10_n147: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t10_n167;
  t10_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t10_n154;
  t10_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t10_n151;
  t10_n150: return -0.011554036289453506;
  t10_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t10_n153;
  t10_n152: return 0.08311271667480469;
  t10_n153: return -0.12483438849449158;
  t10_n154: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t10_n158;
  t10_n155: if (E.getNumReferences() >= 3316554752 /*5587.5*/) goto t10_n157;
  t10_n156: return 0.035072196274995804;
  t10_n157: return 0.10248743742704391;
  t10_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n164;
  t10_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n161;
  t10_n160: return 0.08550386875867844;
  t10_n161: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t10_n163;
  t10_n162: return 0.12371379882097244;
  t10_n163: return 0.08183826506137848;
  t10_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t10_n166;
  t10_n165: return -0.0036435374058783054;
  t10_n166: return 0.09796370565891266;
  t10_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n169;
  t10_n168: return 0.026908719912171364;
  t10_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t10_n181;
  t10_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t10_n172;
  t10_n171: return -0.01022934541106224;
  t10_n172: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t10_n178;
  t10_n173: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t10_n175;
  t10_n174: return 0.09475945681333542;
  t10_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t10_n177;
  t10_n176: return 0.09824615716934204;
  t10_n177: return 0.10859653353691101;
  t10_n178: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t10_n180;
  t10_n179: return 0.07902844995260239;
  t10_n180: return 0.10910018533468246;
  t10_n181: if (E.getNumReferences() >= 3276111872 /*197.5*/) goto t10_n183;
  t10_n182: return 0.09969764202833176;
  t10_n183: return 0.10577958077192307;
  t10_n184: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t10_n196;
  t10_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n187;
  t10_n186: return 0.08248349279165268;
  t10_n187: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t10_n193;
  t10_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n192;
  t10_n189: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t10_n191;
  t10_n190: return 0.09428401291370392;
  t10_n191: return 0.1043204665184021;
  t10_n192: return 0.10058761388063431;
  t10_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n195;
  t10_n194: return 0.1400451809167862;
  t10_n195: return 0.10396529734134674;
  t10_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n198;
  t10_n197: return 0.10840704292058945;
  t10_n198: return 0.10859359800815582;
  t10_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t10_n209;
  t10_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n204;
  t10_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t10_n203;
  t10_n202: return -0.08066617697477341;
  t10_n203: return 0.0981026217341423;
  t10_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t10_n208;
  t10_n205: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t10_n207;
  t10_n206: return 0.0712357833981514;
  t10_n207: return 0.09864891320466995;
  t10_n208: return 0.10276862233877182;
  t10_n209: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t10_n213;
  t10_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t10_n212;
  t10_n211: return 0.10850802809000015;
  t10_n212: return 0.11120191216468811;
  t10_n213: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t10_n219;
  t10_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t10_n218;
  t10_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t10_n217;
  t10_n216: return 0.09979444742202759;
  t10_n217: return 0.10726556181907654;
  t10_n218: return 0.10950817912817001;
  t10_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t10_n221;
  t10_n220: return 0.10839203745126724;
  t10_n221: return 0.10917434096336365;
  t10_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t10_n240;
  t10_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n229;
  t10_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n226;
  t10_n225: return 0.08369584381580353;
  t10_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t10_n228;
  t10_n227: return 0.10459012538194656;
  t10_n228: return -0.05232534185051918;
  t10_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t10_n237;
  t10_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t10_n236;
  t10_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n233;
  t10_n232: return 0.10309281945228577;
  t10_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t10_n235;
  t10_n234: return 0.05460306629538536;
  t10_n235: return 0.1066644936800003;
  t10_n236: return 0.10218971967697144;
  t10_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t10_n239;
  t10_n238: return 0.1069466844201088;
  t10_n239: return 0.1047702357172966;
  t10_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t10_n250;
  t10_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t10_n245;
  t10_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n244;
  t10_n243: return 0.08609756082296371;
  t10_n244: return 0.10966736078262329;
  t10_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t10_n249;
  t10_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n248;
  t10_n247: return 0.11006668955087662;
  t10_n248: return 0.11116715520620346;
  t10_n249: return 0.11201436817646027;
  t10_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t10_n254;
  t10_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t10_n253;
  t10_n252: return 0.10426368564367294;
  t10_n253: return 0.11085938662290573;
  t10_n254: return 0.1095844954252243;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree11(const Example& E) {
  t11_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t11_n222;
  t11_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t11_n203;
  t11_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t11_n152;
  t11_n3: if (E.getNumReferences() >= 3289554944 /*586.5*/) goto t11_n65;
  t11_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t11_n38;
  t11_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t11_n25;
  t11_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t11_n20;
  t11_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t11_n9;
  t11_n8: return -0.06579383462667465;
  t11_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t11_n17;
  t11_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t11_n16;
  t11_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n15;
  t11_n12: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t11_n14;
  t11_n13: return 0.04017297178506851;
  t11_n14: return 0.08299686014652252;
  t11_n15: return 0.1174796000123024;
  t11_n16: return -0.0038561176043003798;
  t11_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t11_n19;
  t11_n18: return 0.10800515115261078;
  t11_n19: return 0.11587008833885193;
  t11_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t11_n22;
  t11_n21: return 0.05759033188223839;
  t11_n22: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t11_n24;
  t11_n23: return 0.10367309302091599;
  t11_n24: return 0.10783699154853821;
  t11_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n27;
  t11_n26: return -0.0969264805316925;
  t11_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t11_n29;
  t11_n28: return -0.09221488982439041;
  t11_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t11_n35;
  t11_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t11_n32;
  t11_n31: return -0.0001715273829177022;
  t11_n32: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t11_n34;
  t11_n33: return 0.07902790606021881;
  t11_n34: return 0.07958292961120605;
  t11_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t11_n37;
  t11_n36: return 0.11027774214744568;
  t11_n37: return 0.08513261377811432;
  t11_n38: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n58;
  t11_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n41;
  t11_n40: return -0.02546115592122078;
  t11_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t11_n49;
  t11_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n44;
  t11_n43: return 0.0036681299097836018;
  t11_n44: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t11_n46;
  t11_n45: return 0.056537892669439316;
  t11_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t11_n48;
  t11_n47: return 0.08941182494163513;
  t11_n48: return 0.1514987200498581;
  t11_n49: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t11_n57;
  t11_n50: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t11_n52;
  t11_n51: return 0.13061915338039398;
  t11_n52: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t11_n54;
  t11_n53: return 0.08946020156145096;
  t11_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n56;
  t11_n55: return -0.1444183886051178;
  t11_n56: return 0.14999547600746155;
  t11_n57: return -0.10993263125419617;
  t11_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n60;
  t11_n59: return 0.03400709852576256;
  t11_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n62;
  t11_n61: return 0.09789445251226425;
  t11_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t11_n64;
  t11_n63: return 0.07756313681602478;
  t11_n64: return 0.09518016874790192;
  t11_n65: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t11_n123;
  t11_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t11_n110;
  t11_n67: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n95;
  t11_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n84;
  t11_n69: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t11_n83;
  t11_n70: if (E.getNumReferences() >= 3350478720 /*92287.0*/) goto t11_n72;
  t11_n71: return 0.04577914625406265;
  t11_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n74;
  t11_n73: return 0.0878198891878128;
  t11_n74: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t11_n82;
  t11_n75: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t11_n81;
  t11_n76: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t11_n80;
  t11_n77: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t11_n79;
  t11_n78: return 0.12409322708845139;
  t11_n79: return 0.09639009833335876;
  t11_n80: return 0.10966116189956665;
  t11_n81: return 0.128379687666893;
  t11_n82: return 0.08490176498889923;
  t11_n83: return -0.04484656825661659;
  t11_n84: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t11_n86;
  t11_n85: return 0.05283517390489578;
  t11_n86: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t11_n92;
  t11_n87: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t11_n89;
  t11_n88: return 0.08969519287347794;
  t11_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t11_n91;
  t11_n90: return 0.09029529243707657;
  t11_n91: return 0.10645601153373718;
  t11_n92: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t11_n94;
  t11_n93: return 0.08639171719551086;
  t11_n94: return 0.10729516297578812;
  t11_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n103;
  t11_n96: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t11_n100;
  t11_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n99;
  t11_n98: return 0.07307653874158859;
  t11_n99: return 0.13108839094638824;
  t11_n100: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t11_n102;
  t11_n101: return 0.06883018463850021;
  t11_n102: return 0.10748856514692307;
  t11_n103: if (E.getNumReferences() >= 3315311616 /*4980.5*/) goto t11_n105;
  t11_n104: return 0.11783990263938904;
  t11_n105: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t11_n107;
  t11_n106: return 0.10788179188966751;
  t11_n107: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t11_n109;
  t11_n108: return 0.1340516209602356;
  t11_n109: return 0.1018492579460144;
  t11_n110: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t11_n116;
  t11_n111: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t11_n115;
  t11_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t11_n114;
  t11_n113: return 0.021960949525237083;
  t11_n114: return 0.091550812125206;
  t11_n115: return 0.09238975495100021;
  t11_n116: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t11_n122;
  t11_n117: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t11_n119;
  t11_n118: return 0.10051321238279343;
  t11_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t11_n121;
  t11_n120: return 0.06525825709104538;
  t11_n121: return 0.11404350399971008;
  t11_n122: return 0.11024269461631775;
  t11_n123: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t11_n129;
  t11_n124: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t11_n126;
  t11_n125: return 0.09535157680511475;
  t11_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n128;
  t11_n127: return 0.10553183406591415;
  t11_n128: return 0.1307184398174286;
  t11_n129: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t11_n131;
  t11_n130: return 0.10797587782144547;
  t11_n131: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n151;
  t11_n132: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t11_n134;
  t11_n133: return 0.11411508917808533;
  t11_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n140;
  t11_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t11_n137;
  t11_n136: return 0.11763742566108704;
  t11_n137: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t11_n139;
  t11_n138: return 0.13391102850437164;
  t11_n139: return 0.13618358969688416;
  t11_n140: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t11_n142;
  t11_n141: return 0.11177453398704529;
  t11_n142: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t11_n150;
  t11_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t11_n149;
  t11_n144: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t11_n146;
  t11_n145: return 0.13571150600910187;
  t11_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t11_n148;
  t11_n147: return 0.1369863897562027;
  t11_n148: return 0.14310699701309204;
  t11_n149: return 0.14013652503490448;
  t11_n150: return 0.10788334906101227;
  t11_n151: return 0.1277266889810562;
  t11_n152: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n190;
  t11_n153: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t11_n171;
  t11_n154: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t11_n166;
  t11_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n157;
  t11_n156: return -0.11314450949430466;
  t11_n157: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n159;
  t11_n158: return 0.023062217980623245;
  t11_n159: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t11_n165;
  t11_n160: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t11_n164;
  t11_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t11_n163;
  t11_n162: return 0.08018583804368973;
  t11_n163: return 0.09493445605039597;
  t11_n164: return 0.10489436239004135;
  t11_n165: return 0.01943764090538025;
  t11_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n168;
  t11_n167: return 0.07162822037935257;
  t11_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t11_n170;
  t11_n169: return -0.11593618243932724;
  t11_n170: return 0.09007140249013901;
  t11_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n173;
  t11_n172: return 0.013027012348175049;
  t11_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t11_n187;
  t11_n174: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t11_n176;
  t11_n175: return 0.08392925560474396;
  t11_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n178;
  t11_n177: return 0.08477269858121872;
  t11_n178: if (E.getNumReferences() >= 3350339968 /*91203.0*/) goto t11_n184;
  t11_n179: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t11_n181;
  t11_n180: return 0.0991453304886818;
  t11_n181: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t11_n183;
  t11_n182: return 0.10714035481214523;
  t11_n183: return 0.09692596644163132;
  t11_n184: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t11_n186;
  t11_n185: return 0.03907909244298935;
  t11_n186: return 0.10883732885122299;
  t11_n187: if (E.getNumReferences() >= 3276111872 /*197.5*/) goto t11_n189;
  t11_n188: return 0.09675264358520508;
  t11_n189: return 0.10366126149892807;
  t11_n190: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t11_n200;
  t11_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n193;
  t11_n192: return 0.07715988159179688;
  t11_n193: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t11_n197;
  t11_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n196;
  t11_n195: return 0.09987743198871613;
  t11_n196: return 0.0979619026184082;
  t11_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n199;
  t11_n198: return 0.13522189855575562;
  t11_n199: return 0.06470903754234314;
  t11_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n202;
  t11_n201: return 0.10657093673944473;
  t11_n202: return 0.10685867071151733;
  t11_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t11_n213;
  t11_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n208;
  t11_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t11_n207;
  t11_n206: return -0.06793522089719772;
  t11_n207: return 0.09491673111915588;
  t11_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t11_n212;
  t11_n209: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t11_n211;
  t11_n210: return 0.06614193320274353;
  t11_n211: return 0.0956873968243599;
  t11_n212: return 0.10013145208358765;
  t11_n213: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t11_n217;
  t11_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t11_n216;
  t11_n215: return 0.10699084401130676;
  t11_n216: return 0.11019746959209442;
  t11_n217: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t11_n221;
  t11_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t11_n220;
  t11_n219: return 0.10125678777694702;
  t11_n220: return 0.107998788356781;
  t11_n221: return 0.10777629911899567;
  t11_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t11_n240;
  t11_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n229;
  t11_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n226;
  t11_n225: return 0.07922739535570145;
  t11_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t11_n228;
  t11_n227: return 0.10226548463106155;
  t11_n228: return -0.07848593592643738;
  t11_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t11_n237;
  t11_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t11_n236;
  t11_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n233;
  t11_n232: return 0.10044308751821518;
  t11_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t11_n235;
  t11_n234: return 0.05074216052889824;
  t11_n235: return 0.1045994982123375;
  t11_n236: return 0.09937219321727753;
  t11_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t11_n239;
  t11_n238: return 0.10506173968315125;
  t11_n239: return 0.10278452932834625;
  t11_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t11_n250;
  t11_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t11_n245;
  t11_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n244;
  t11_n243: return 0.07947266846895218;
  t11_n244: return 0.1083064079284668;
  t11_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t11_n249;
  t11_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n248;
  t11_n247: return 0.1094546690583229;
  t11_n248: return 0.10977908223867416;
  t11_n249: return 0.1106608584523201;
  t11_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t11_n254;
  t11_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t11_n253;
  t11_n252: return 0.10440175980329514;
  t11_n253: return 0.10962507128715515;
  t11_n254: return 0.10818728059530258;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree12(const Example& E) {
  t12_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t12_n222;
  t12_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t12_n203;
  t12_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t12_n160;
  t12_n3: if (E.getNumReferences() >= 3288932352 /*548.5*/) goto t12_n51;
  t12_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t12_n22;
  t12_n5: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t12_n19;
  t12_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t12_n8;
  t12_n7: return -0.05947907269001007;
  t12_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t12_n16;
  t12_n9: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t12_n11;
  t12_n10: return 0.01679440774023533;
  t12_n11: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t12_n15;
  t12_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n14;
  t12_n13: return 0.07828737050294876;
  t12_n14: return 0.1147882267832756;
  t12_n15: return 0.0455186702311039;
  t12_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t12_n18;
  t12_n17: return 0.10257267951965332;
  t12_n18: return 0.11297492682933807;
  t12_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n21;
  t12_n20: return -0.10164188593626022;
  t12_n21: return -0.09096655249595642;
  t12_n22: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t12_n40;
  t12_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t12_n33;
  t12_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n26;
  t12_n25: return 0.021478427574038506;
  t12_n26: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t12_n30;
  t12_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t12_n29;
  t12_n28: return 0.05488815903663635;
  t12_n29: return 0.06986016780138016;
  t12_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t12_n32;
  t12_n31: return 0.08261949568986893;
  t12_n32: return 0.10169872641563416;
  t12_n33: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t12_n35;
  t12_n34: return 0.0815439447760582;
  t12_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t12_n37;
  t12_n36: return 0.09710436314344406;
  t12_n37: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t12_n39;
  t12_n38: return 0.10674409568309784;
  t12_n39: return 0.09629680961370468;
  t12_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n42;
  t12_n41: return -0.05082354322075844;
  t12_n42: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t12_n44;
  t12_n43: return -0.08767537027597427;
  t12_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n46;
  t12_n45: return 0.03543271869421005;
  t12_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t12_n50;
  t12_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n49;
  t12_n48: return 0.0947757139801979;
  t12_n49: return 0.0722113698720932;
  t12_n50: return 0.09369350969791412;
  t12_n51: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t12_n131;
  t12_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t12_n118;
  t12_n53: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n99;
  t12_n54: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t12_n82;
  t12_n55: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t12_n73;
  t12_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t12_n58;
  t12_n57: return -0.014107156544923782;
  t12_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n60;
  t12_n59: return 0.04769973084330559;
  t12_n60: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t12_n66;
  t12_n61: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n63;
  t12_n62: return 0.10562342405319214;
  t12_n63: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t12_n65;
  t12_n64: return 0.13425853848457336;
  t12_n65: return 0.11512649059295654;
  t12_n66: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t12_n70;
  t12_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n69;
  t12_n68: return 0.126725435256958;
  t12_n69: return 0.10584300011396408;
  t12_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t12_n72;
  t12_n71: return 0.12121367454528809;
  t12_n72: return -0.03515598177909851;
  t12_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n75;
  t12_n74: return 0.10159583389759064;
  t12_n75: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t12_n81;
  t12_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t12_n78;
  t12_n77: return 0.10602238774299622;
  t12_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t12_n80;
  t12_n79: return 0.11973530799150467;
  t12_n80: return 0.009303427301347256;
  t12_n81: return 0.12315909564495087;
  t12_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t12_n84;
  t12_n83: return -0.04083368554711342;
  t12_n84: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t12_n86;
  t12_n85: return 0.0295286625623703;
  t12_n86: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t12_n94;
  t12_n87: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t12_n89;
  t12_n88: return 0.07591849565505981;
  t12_n89: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t12_n91;
  t12_n90: return 0.04357365518808365;
  t12_n91: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t12_n93;
  t12_n92: return 0.111052967607975;
  t12_n93: return 0.10561221837997437;
  t12_n94: if (E.getNumReferences() >= 3346550272 /*63566.0*/) goto t12_n98;
  t12_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t12_n97;
  t12_n96: return 0.08112434297800064;
  t12_n97: return 0.11945769190788269;
  t12_n98: return 0.1068475991487503;
  t12_n99: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t12_n107;
  t12_n100: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n106;
  t12_n101: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t12_n103;
  t12_n102: return 0.06679829210042953;
  t12_n103: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t12_n105;
  t12_n104: return 0.06620751321315765;
  t12_n105: return 0.10597112774848938;
  t12_n106: return 0.12037666141986847;
  t12_n107: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t12_n109;
  t12_n108: return 0.10831144452095032;
  t12_n109: if (E.getNumReferences() >= 3314670592 /*4667.5*/) goto t12_n111;
  t12_n110: return 0.11807990819215775;
  t12_n111: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t12_n117;
  t12_n112: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t12_n116;
  t12_n113: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t12_n115;
  t12_n114: return 0.1372307389974594;
  t12_n115: return 0.13534148037433624;
  t12_n116: return 0.13778743147850037;
  t12_n117: return 0.10356183350086212;
  t12_n118: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t12_n128;
  t12_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t12_n127;
  t12_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t12_n122;
  t12_n121: return 0.017148753628134727;
  t12_n122: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t12_n126;
  t12_n123: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t12_n125;
  t12_n124: return 0.10889720171689987;
  t12_n125: return 0.12185942381620407;
  t12_n126: return 0.08184568583965302;
  t12_n127: return 0.08938590437173843;
  t12_n128: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t12_n130;
  t12_n129: return 0.09593269973993301;
  t12_n130: return 0.1091126948595047;
  t12_n131: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t12_n135;
  t12_n132: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t12_n134;
  t12_n133: return 0.12915223836898804;
  t12_n134: return 0.0987958088517189;
  t12_n135: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t12_n137;
  t12_n136: return 0.10399075597524643;
  t12_n137: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n155;
  t12_n138: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t12_n140;
  t12_n139: return 0.10977837443351746;
  t12_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t12_n144;
  t12_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t12_n143;
  t12_n142: return 0.11288796365261078;
  t12_n143: return 0.1285760998725891;
  t12_n144: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t12_n146;
  t12_n145: return 0.10930103808641434;
  t12_n146: if (E.getNumReferences() >= 3333289472 /*22267.0*/) goto t12_n154;
  t12_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t12_n153;
  t12_n148: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t12_n150;
  t12_n149: return 0.12692245841026306;
  t12_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t12_n152;
  t12_n151: return 0.1296205371618271;
  t12_n152: return 0.13468678295612335;
  t12_n153: return 0.1319226622581482;
  t12_n154: return 0.10385016351938248;
  t12_n155: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t12_n159;
  t12_n156: if (E.getNumReferences() >= 3319711744 /*7129.0*/) goto t12_n158;
  t12_n157: return 0.13379809260368347;
  t12_n158: return 0.13472987711429596;
  t12_n159: return 0.1068042516708374;
  t12_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n188;
  t12_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t12_n181;
  t12_n162: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t12_n176;
  t12_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t12_n165;
  t12_n164: return -0.11084145307540894;
  t12_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n167;
  t12_n166: return 0.020866796374320984;
  t12_n167: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t12_n175;
  t12_n168: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t12_n174;
  t12_n169: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t12_n173;
  t12_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t12_n172;
  t12_n171: return 0.07988076657056808;
  t12_n172: return 0.09153573960065842;
  t12_n173: return -0.11092475801706314;
  t12_n174: return 0.10477197915315628;
  t12_n175: return 0.01782882772386074;
  t12_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n178;
  t12_n177: return 0.06900789588689804;
  t12_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t12_n180;
  t12_n179: return -0.11438912153244019;
  t12_n180: return 0.08628913760185242;
  t12_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n183;
  t12_n182: return 0.0056274146772921085;
  t12_n183: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t12_n185;
  t12_n184: return 0.08104356378316879;
  t12_n185: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n187;
  t12_n186: return 0.08256027847528458;
  t12_n187: return 0.09834179282188416;
  t12_n188: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t12_n200;
  t12_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n191;
  t12_n190: return 0.07307735830545425;
  t12_n191: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t12_n197;
  t12_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n196;
  t12_n193: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t12_n195;
  t12_n194: return 0.08648844808340073;
  t12_n195: return 0.09963613748550415;
  t12_n196: return 0.09567975252866745;
  t12_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t12_n199;
  t12_n198: return 0.13367284834384918;
  t12_n199: return 0.06292009353637695;
  t12_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n202;
  t12_n201: return 0.10490160435438156;
  t12_n202: return 0.10516589879989624;
  t12_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t12_n213;
  t12_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n208;
  t12_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t12_n207;
  t12_n206: return -0.044961556792259216;
  t12_n207: return 0.09400244802236557;
  t12_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t12_n212;
  t12_n209: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t12_n211;
  t12_n210: return 0.06021488830447197;
  t12_n211: return 0.09227823466062546;
  t12_n212: return 0.09770937263965607;
  t12_n213: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t12_n217;
  t12_n214: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t12_n216;
  t12_n215: return 0.1072666198015213;
  t12_n216: return 0.108050137758255;
  t12_n217: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t12_n221;
  t12_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t12_n220;
  t12_n219: return 0.09929375350475311;
  t12_n220: return 0.10693669319152832;
  t12_n221: return 0.1066160798072815;
  t12_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t12_n240;
  t12_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n229;
  t12_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n226;
  t12_n225: return 0.07508399337530136;
  t12_n226: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t12_n228;
  t12_n227: return 0.10014152526855469;
  t12_n228: return -0.07068818062543869;
  t12_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t12_n237;
  t12_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t12_n236;
  t12_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n233;
  t12_n232: return 0.09780130535364151;
  t12_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t12_n235;
  t12_n234: return 0.06326586753129959;
  t12_n235: return 0.10243970155715942;
  t12_n236: return 0.09666267037391663;
  t12_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t12_n239;
  t12_n238: return 0.10325590521097183;
  t12_n239: return 0.1008005291223526;
  t12_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t12_n250;
  t12_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t12_n245;
  t12_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n244;
  t12_n243: return 0.07802943885326385;
  t12_n244: return 0.10679663717746735;
  t12_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t12_n249;
  t12_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n248;
  t12_n247: return 0.1070803627371788;
  t12_n248: return 0.10863887518644333;
  t12_n249: return 0.10961427539587021;
  t12_n250: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t12_n254;
  t12_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t12_n253;
  t12_n252: return 0.10078494250774384;
  t12_n253: return 0.10855970531702042;
  t12_n254: return 0.10698916763067245;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree13(const Example& E) {
  t13_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t13_n226;
  t13_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t13_n211;
  t13_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t13_n160;
  t13_n3: if (E.getNumReferences() >= 3279650816 /*251.5*/) goto t13_n49;
  t13_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t13_n34;
  t13_n5: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t13_n23;
  t13_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t13_n12;
  t13_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t13_n9;
  t13_n8: return -0.00427229842171073;
  t13_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t13_n11;
  t13_n10: return 0.09521917253732681;
  t13_n11: return 0.11381188780069351;
  t13_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t13_n20;
  t13_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n15;
  t13_n14: return 0.027293680235743523;
  t13_n15: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t13_n17;
  t13_n16: return 0.05383661761879921;
  t13_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t13_n19;
  t13_n18: return 0.0790724977850914;
  t13_n19: return 0.09844401478767395;
  t13_n20: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t13_n22;
  t13_n21: return 0.09962568432092667;
  t13_n22: return 0.10442037880420685;
  t13_n23: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n25;
  t13_n24: return -0.09410659223794937;
  t13_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t13_n27;
  t13_n26: return -0.09123560041189194;
  t13_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t13_n33;
  t13_n28: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t13_n30;
  t13_n29: return -0.0025724724400788546;
  t13_n30: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t13_n32;
  t13_n31: return 0.07461866736412048;
  t13_n32: return 0.06769025325775146;
  t13_n33: return 0.08119551092386246;
  t13_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n36;
  t13_n35: return -0.01716025359928608;
  t13_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n44;
  t13_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t13_n39;
  t13_n38: return 0.04946554824709892;
  t13_n39: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t13_n41;
  t13_n40: return 0.12081724405288696;
  t13_n41: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t13_n43;
  t13_n42: return 0.12968450784683228;
  t13_n43: return -0.11721250414848328;
  t13_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n46;
  t13_n45: return 0.08971454948186874;
  t13_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t13_n48;
  t13_n47: return 0.06344039738178253;
  t13_n48: return 0.0873006284236908;
  t13_n49: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t13_n137;
  t13_n50: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t13_n114;
  t13_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n95;
  t13_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n58;
  t13_n53: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t13_n55;
  t13_n54: return -0.04583188146352768;
  t13_n55: if (E.getNumReferences() >= 3315905536 /*5270.5*/) goto t13_n57;
  t13_n56: return 0.03632405027747154;
  t13_n57: return 0.08766630291938782;
  t13_n58: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t13_n78;
  t13_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t13_n61;
  t13_n60: return -0.027221379801630974;
  t13_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n63;
  t13_n62: return 0.05622824653983116;
  t13_n63: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t13_n77;
  t13_n64: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t13_n70;
  t13_n65: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t13_n69;
  t13_n66: if (E.getNumReferences() >= 3293249536 /*812.0*/) goto t13_n68;
  t13_n67: return 0.13330966234207153;
  t13_n68: return 0.13060976564884186;
  t13_n69: return 0.11177151650190353;
  t13_n70: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t13_n74;
  t13_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t13_n73;
  t13_n72: return 0.12736395001411438;
  t13_n73: return 0.11628518253564835;
  t13_n74: if (E.getNumReferences() >= 3325332480 /*11555.0*/) goto t13_n76;
  t13_n75: return 0.023848554119467735;
  t13_n76: return 0.0984242707490921;
  t13_n77: return 0.11207287013530731;
  t13_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n90;
  t13_n79: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t13_n89;
  t13_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n82;
  t13_n81: return 0.10108617693185806;
  t13_n82: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t13_n84;
  t13_n83: return 0.11512497067451477;
  t13_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t13_n86;
  t13_n85: return 0.10110590606927872;
  t13_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n88;
  t13_n87: return 0.12114068120718002;
  t13_n88: return 0.11139904707670212;
  t13_n89: return 0.02827148325741291;
  t13_n90: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t13_n94;
  t13_n91: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t13_n93;
  t13_n92: return 0.11909864842891693;
  t13_n93: return 0.12972784042358398;
  t13_n94: return 0.09964592009782791;
  t13_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t13_n103;
  t13_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n102;
  t13_n97: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t13_n99;
  t13_n98: return 0.06146992743015289;
  t13_n99: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t13_n101;
  t13_n100: return 0.0518890805542469;
  t13_n101: return 0.10323052108287811;
  t13_n102: return 0.12000031769275665;
  t13_n103: if (E.getNumReferences() >= 3315342336 /*4995.5*/) goto t13_n105;
  t13_n104: return 0.11162035167217255;
  t13_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t13_n107;
  t13_n106: return 0.10150875896215439;
  t13_n107: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t13_n113;
  t13_n108: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t13_n112;
  t13_n109: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t13_n111;
  t13_n110: return 0.13239659368991852;
  t13_n111: return 0.1278836578130722;
  t13_n112: return 0.13050876557826996;
  t13_n113: return 0.10193446278572083;
  t13_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n122;
  t13_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n117;
  t13_n116: return -0.012794425711035728;
  t13_n117: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t13_n119;
  t13_n118: return 0.08069130778312683;
  t13_n119: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t13_n121;
  t13_n120: return 0.12366446852684021;
  t13_n121: return 0.10537247359752655;
  t13_n122: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t13_n126;
  t13_n123: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t13_n125;
  t13_n124: return 0.10004632920026779;
  t13_n125: return 0.06652258336544037;
  t13_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t13_n128;
  t13_n127: return 0.11082284152507782;
  t13_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t13_n136;
  t13_n129: if (E.getNumReferences() >= 3338301440 /*32056.0*/) goto t13_n131;
  t13_n130: return 0.13062338531017303;
  t13_n131: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t13_n133;
  t13_n132: return 0.08644653856754303;
  t13_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t13_n135;
  t13_n134: return 0.10178505629301071;
  t13_n135: return 0.10632220655679703;
  t13_n136: return 0.07380237430334091;
  t13_n137: if (E.getNumReferences() >= 3308636160 /*2908.5*/) goto t13_n141;
  t13_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t13_n140;
  t13_n139: return 0.138036847114563;
  t13_n140: return 0.11355844885110855;
  t13_n141: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t13_n143;
  t13_n142: return 0.10048478096723557;
  t13_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t13_n149;
  t13_n144: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n148;
  t13_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t13_n147;
  t13_n146: return 0.10967327654361725;
  t13_n147: return 0.12279706448316574;
  t13_n148: return 0.11932878941297531;
  t13_n149: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t13_n151;
  t13_n150: return 0.10708080977201462;
  t13_n151: if (E.getNumReferences() >= 3333289472 /*22267.0*/) goto t13_n159;
  t13_n152: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t13_n158;
  t13_n153: if (E.getNumReferences() >= 3318694912 /*6632.5*/) goto t13_n155;
  t13_n154: return 0.12040301412343979;
  t13_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t13_n157;
  t13_n156: return 0.12343394011259079;
  t13_n157: return 0.12834948301315308;
  t13_n158: return 0.12567929923534393;
  t13_n159: return 0.10259904712438583;
  t13_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n194;
  t13_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t13_n179;
  t13_n162: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n178;
  t13_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t13_n169;
  t13_n164: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t13_n166;
  t13_n165: return -0.005733537022024393;
  t13_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n168;
  t13_n167: return 0.07877806574106216;
  t13_n168: return 0.10048748552799225;
  t13_n169: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t13_n173;
  t13_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n172;
  t13_n171: return -0.0417984202504158;
  t13_n172: return 0.058724187314510345;
  t13_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t13_n177;
  t13_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n176;
  t13_n175: return 0.05693957209587097;
  t13_n176: return 0.09653718769550323;
  t13_n177: return 0.1072884276509285;
  t13_n178: return 0.07612177729606628;
  t13_n179: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n181;
  t13_n180: return -0.009992293082177639;
  t13_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t13_n193;
  t13_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t13_n184;
  t13_n183: return -0.040638260543346405;
  t13_n184: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t13_n190;
  t13_n185: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t13_n187;
  t13_n186: return 0.08326543122529984;
  t13_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t13_n189;
  t13_n188: return 0.08935269713401794;
  t13_n189: return 0.10498280823230743;
  t13_n190: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t13_n192;
  t13_n191: return 0.06320104002952576;
  t13_n192: return 0.10688306391239166;
  t13_n193: return 0.09459489583969116;
  t13_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n198;
  t13_n195: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n197;
  t13_n196: return 0.06668178737163544;
  t13_n197: return 0.10000945627689362;
  t13_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n204;
  t13_n199: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t13_n201;
  t13_n200: return 0.08334636688232422;
  t13_n201: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n203;
  t13_n202: return 0.10104721784591675;
  t13_n203: return 0.10649557411670685;
  t13_n204: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t13_n208;
  t13_n205: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t13_n207;
  t13_n206: return 0.09287883341312408;
  t13_n207: return 0.10556674748659134;
  t13_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t13_n210;
  t13_n209: return 0.1260083019733429;
  t13_n210: return 0.09959600120782852;
  t13_n211: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t13_n219;
  t13_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n216;
  t13_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t13_n215;
  t13_n214: return -0.041407469660043716;
  t13_n215: return 0.08979424834251404;
  t13_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t13_n218;
  t13_n217: return 0.09283924102783203;
  t13_n218: return 0.06349675357341766;
  t13_n219: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t13_n221;
  t13_n220: return 0.1071629524230957;
  t13_n221: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t13_n225;
  t13_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t13_n224;
  t13_n223: return 0.09675222635269165;
  t13_n224: return 0.10597708076238632;
  t13_n225: return 0.1056610494852066;
  t13_n226: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t13_n242;
  t13_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n231;
  t13_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n230;
  t13_n229: return 0.07065246999263763;
  t13_n230: return 0.09786402434110641;
  t13_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n239;
  t13_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t13_n238;
  t13_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t13_n235;
  t13_n234: return 0.09542027115821838;
  t13_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t13_n237;
  t13_n236: return 0.04699840024113655;
  t13_n237: return 0.10079647600650787;
  t13_n238: return 0.09391700476408005;
  t13_n239: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t13_n241;
  t13_n240: return 0.10168428719043732;
  t13_n241: return 0.09906555712223053;
  t13_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t13_n252;
  t13_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t13_n247;
  t13_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t13_n246;
  t13_n245: return 0.07325878739356995;
  t13_n246: return 0.10569486767053604;
  t13_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t13_n251;
  t13_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t13_n250;
  t13_n249: return 0.10560904443264008;
  t13_n250: return 0.10772459954023361;
  t13_n251: return 0.10860088467597961;
  t13_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t13_n254;
  t13_n253: return 0.10770808160305023;
  t13_n254: return 0.10632012784481049;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree14(const Example& E) {
  t14_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t14_n224;
  t14_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t14_n207;
  t14_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t14_n68;
  t14_n3: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t14_n27;
  t14_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n6;
  t14_n5: return -0.0651426762342453;
  t14_n6: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t14_n24;
  t14_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t14_n21;
  t14_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n10;
  t14_n9: return -0.017711402848362923;
  t14_n10: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t14_n20;
  t14_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n13;
  t14_n12: return -0.1119973435997963;
  t14_n13: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t14_n19;
  t14_n14: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t14_n18;
  t14_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t14_n17;
  t14_n16: return 0.07091665267944336;
  t14_n17: return 0.11561950296163559;
  t14_n18: return -0.11117683351039886;
  t14_n19: return -0.05111325904726982;
  t14_n20: return 0.10209978371858597;
  t14_n21: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n23;
  t14_n22: return 0.07005593180656433;
  t14_n23: return 0.09708401560783386;
  t14_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n26;
  t14_n25: return 0.006223167758435011;
  t14_n26: return 0.08124203234910965;
  t14_n27: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n47;
  t14_n28: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t14_n46;
  t14_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n35;
  t14_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n32;
  t14_n31: return 0.06993338465690613;
  t14_n32: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t14_n34;
  t14_n33: return 0.10497727245092392;
  t14_n34: return 0.11229278892278671;
  t14_n35: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t14_n45;
  t14_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n38;
  t14_n37: return 0.0935264378786087;
  t14_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n44;
  t14_n39: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t14_n41;
  t14_n40: return 0.11199841648340225;
  t14_n41: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t14_n43;
  t14_n42: return 0.1196088045835495;
  t14_n43: return 0.11882944405078888;
  t14_n44: return 0.04071899503469467;
  t14_n45: return 0.1190328374505043;
  t14_n46: return -0.021808460354804993;
  t14_n47: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t14_n61;
  t14_n48: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t14_n60;
  t14_n49: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t14_n59;
  t14_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n56;
  t14_n51: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n53;
  t14_n52: return 0.07054976373910904;
  t14_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n55;
  t14_n54: return 0.10886835306882858;
  t14_n55: return 0.10356344282627106;
  t14_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t14_n58;
  t14_n57: return 0.07705479115247726;
  t14_n58: return 0.1019461378455162;
  t14_n59: return 0.01031743735074997;
  t14_n60: return 0.10743779689073563;
  t14_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t14_n63;
  t14_n62: return 0.09744227677583694;
  t14_n63: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t14_n67;
  t14_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n66;
  t14_n65: return 0.1048942357301712;
  t14_n66: return 0.10727610439062119;
  t14_n67: return 0.10024398565292358;
  t14_n68: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t14_n142;
  t14_n69: if (E.getNumReferences() >= 3294633984 /*896.5*/) goto t14_n113;
  t14_n70: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t14_n82;
  t14_n71: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n79;
  t14_n72: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t14_n74;
  t14_n73: return 0.041878316551446915;
  t14_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n78;
  t14_n75: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t14_n77;
  t14_n76: return 0.054741375148296356;
  t14_n77: return 0.08247809112071991;
  t14_n78: return -0.00017354161536786705;
  t14_n79: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t14_n81;
  t14_n80: return 0.11503197997808456;
  t14_n81: return 0.11631883680820465;
  t14_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t14_n96;
  t14_n83: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n85;
  t14_n84: return -0.056474316865205765;
  t14_n85: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t14_n91;
  t14_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t14_n88;
  t14_n87: return -0.028664376586675644;
  t14_n88: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n90;
  t14_n89: return 0.057680584490299225;
  t14_n90: return 0.08783527463674545;
  t14_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n93;
  t14_n92: return 0.07568788528442383;
  t14_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n95;
  t14_n94: return 0.10817340016365051;
  t14_n95: return 0.09564092755317688;
  t14_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n98;
  t14_n97: return 0.05566256120800972;
  t14_n98: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t14_n106;
  t14_n99: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t14_n105;
  t14_n100: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t14_n102;
  t14_n101: return 0.0392170250415802;
  t14_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t14_n104;
  t14_n103: return 0.09649576246738434;
  t14_n104: return 0.11832375079393387;
  t14_n105: return 0.09861258417367935;
  t14_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t14_n108;
  t14_n107: return 0.15513412654399872;
  t14_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n112;
  t14_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n111;
  t14_n110: return 0.15510646998882294;
  t14_n111: return 0.13178585469722748;
  t14_n112: return 0.15143056213855743;
  t14_n113: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t14_n135;
  t14_n114: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n134;
  t14_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n123;
  t14_n116: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t14_n118;
  t14_n117: return 0.032777268439531326;
  t14_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t14_n122;
  t14_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n121;
  t14_n120: return 0.12900102138519287;
  t14_n121: return 0.12031852453947067;
  t14_n122: return 0.11226537078619003;
  t14_n123: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t14_n127;
  t14_n124: if (E.getNumReferences() >= 3294674944 /*899.0*/) goto t14_n126;
  t14_n125: return 0.14707466959953308;
  t14_n126: return 0.10257268697023392;
  t14_n127: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t14_n133;
  t14_n128: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t14_n130;
  t14_n129: return 0.11307501792907715;
  t14_n130: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n132;
  t14_n131: return 0.13278938829898834;
  t14_n132: return 0.11838682740926743;
  t14_n133: return 0.09479658305644989;
  t14_n134: return 0.11414322257041931;
  t14_n135: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t14_n139;
  t14_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n138;
  t14_n137: return 0.12767460942268372;
  t14_n138: return -0.1498386263847351;
  t14_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t14_n141;
  t14_n140: return 0.08359793573617935;
  t14_n141: return 0.09647728502750397;
  t14_n142: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n190;
  t14_n143: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t14_n189;
  t14_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t14_n186;
  t14_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n185;
  t14_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t14_n166;
  t14_n147: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t14_n151;
  t14_n148: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n150;
  t14_n149: return 0.010868972167372704;
  t14_n150: return 0.0832286924123764;
  t14_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t14_n155;
  t14_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t14_n154;
  t14_n153: return -0.031010163947939873;
  t14_n154: return 0.10228375345468521;
  t14_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t14_n159;
  t14_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n158;
  t14_n157: return 0.14296415448188782;
  t14_n158: return 0.13247358798980713;
  t14_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n165;
  t14_n160: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n162;
  t14_n161: return 0.16496506333351135;
  t14_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n164;
  t14_n163: return 0.1408810168504715;
  t14_n164: return 0.1453968584537506;
  t14_n165: return 0.10052715241909027;
  t14_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t14_n172;
  t14_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n169;
  t14_n168: return 0.08265627175569534;
  t14_n169: if (E.getNumReferences() >= 3331838976 /*19434.0*/) goto t14_n171;
  t14_n170: return 0.10532116889953613;
  t14_n171: return 0.11650216579437256;
  t14_n172: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t14_n184;
  t14_n173: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t14_n175;
  t14_n174: return 0.10141593217849731;
  t14_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n181;
  t14_n176: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n180;
  t14_n177: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t14_n179;
  t14_n178: return 0.22546294331550598;
  t14_n179: return 0.1479322612285614;
  t14_n180: return 0.09123296290636063;
  t14_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n183;
  t14_n182: return 0.14474396407604218;
  t14_n183: return 0.1029386967420578;
  t14_n184: return 0.17527668178081512;
  t14_n185: return 0.04543857276439667;
  t14_n186: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t14_n188;
  t14_n187: return 0.11094824224710464;
  t14_n188: return 0.11925950646400452;
  t14_n189: return -0.11490331590175629;
  t14_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t14_n196;
  t14_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n193;
  t14_n192: return 0.0878908559679985;
  t14_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t14_n195;
  t14_n194: return 0.062295470386743546;
  t14_n195: return 0.08339153230190277;
  t14_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n200;
  t14_n197: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t14_n199;
  t14_n198: return 0.09901473671197891;
  t14_n199: return 0.10573612153530121;
  t14_n200: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t14_n204;
  t14_n201: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t14_n203;
  t14_n202: return 0.09179113805294037;
  t14_n203: return 0.10441265255212784;
  t14_n204: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t14_n206;
  t14_n205: return 0.1237359493970871;
  t14_n206: return 0.10642862319946289;
  t14_n207: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t14_n215;
  t14_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t14_n214;
  t14_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n211;
  t14_n210: return -0.03806758299469948;
  t14_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n213;
  t14_n212: return 0.08511682599782944;
  t14_n213: return 0.0559593066573143;
  t14_n214: return 0.09555428475141525;
  t14_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t14_n219;
  t14_n216: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t14_n218;
  t14_n217: return 0.1062157079577446;
  t14_n218: return 0.10708757489919662;
  t14_n219: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t14_n223;
  t14_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t14_n222;
  t14_n221: return 0.09477247297763824;
  t14_n222: return 0.10529960691928864;
  t14_n223: return 0.10482154786586761;
  t14_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t14_n242;
  t14_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t14_n229;
  t14_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n228;
  t14_n227: return 0.06545069813728333;
  t14_n228: return 0.09558168798685074;
  t14_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t14_n239;
  t14_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n236;
  t14_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n233;
  t14_n232: return 0.09244994074106216;
  t14_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t14_n235;
  t14_n234: return 0.043373625725507736;
  t14_n235: return 0.0989702120423317;
  t14_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t14_n238;
  t14_n237: return 0.10082586109638214;
  t14_n238: return 0.09833516925573349;
  t14_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t14_n241;
  t14_n240: return 0.09305420517921448;
  t14_n241: return 0.09628482908010483;
  t14_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t14_n252;
  t14_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t14_n247;
  t14_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n246;
  t14_n245: return 0.06721276789903641;
  t14_n246: return 0.10421966761350632;
  t14_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t14_n251;
  t14_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t14_n250;
  t14_n249: return 0.10197018831968307;
  t14_n250: return 0.10692442953586578;
  t14_n251: return 0.10801646113395691;
  t14_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t14_n254;
  t14_n253: return 0.10688631236553192;
  t14_n254: return 0.10538673400878906;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree15(const Example& E) {
  t15_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t15_n228;
  t15_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t15_n217;
  t15_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t15_n84;
  t15_n3: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t15_n21;
  t15_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t15_n20;
  t15_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t15_n17;
  t15_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t15_n8;
  t15_n7: return -0.07458433508872986;
  t15_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t15_n10;
  t15_n9: return -0.04134067893028259;
  t15_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n16;
  t15_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t15_n13;
  t15_n12: return 0.09624151140451431;
  t15_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n15;
  t15_n14: return 0.15304921567440033;
  t15_n15: return -0.27883991599082947;
  t15_n16: return -0.0031900315079838037;
  t15_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t15_n19;
  t15_n18: return -0.062029335647821426;
  t15_n19: return 0.04432067275047302;
  t15_n20: return -0.08402161300182343;
  t15_n21: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t15_n59;
  t15_n22: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n48;
  t15_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n33;
  t15_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t15_n26;
  t15_n25: return -0.021411392837762833;
  t15_n26: if (E.getNumReferences() >= 3319521280 /*7036.0*/) goto t15_n28;
  t15_n27: return 0.026076195761561394;
  t15_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n30;
  t15_n29: return 0.07508769631385803;
  t15_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n32;
  t15_n31: return 0.07091135531663895;
  t15_n32: return 0.10107428580522537;
  t15_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n39;
  t15_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n36;
  t15_n35: return -0.008620675653219223;
  t15_n36: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t15_n38;
  t15_n37: return 0.0641559436917305;
  t15_n38: return 0.10113269835710526;
  t15_n39: if (E.getNumReferences() >= 3334782720 /*25183.5*/) goto t15_n43;
  t15_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n42;
  t15_n41: return 0.06192973628640175;
  t15_n42: return 0.09065695106983185;
  t15_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t15_n45;
  t15_n44: return 0.09432007372379303;
  t15_n45: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t15_n47;
  t15_n46: return 0.09705395251512527;
  t15_n47: return 0.07299456745386124;
  t15_n48: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t15_n58;
  t15_n49: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t15_n51;
  t15_n50: return 0.06786078959703445;
  t15_n51: if (E.getNumReferences() >= 3315311616 /*4980.5*/) goto t15_n53;
  t15_n52: return 0.10312062501907349;
  t15_n53: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t15_n55;
  t15_n54: return 0.09036644548177719;
  t15_n55: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t15_n57;
  t15_n56: return 0.11761315166950226;
  t15_n57: return 0.06449182331562042;
  t15_n58: return 0.09354879707098007;
  t15_n59: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t15_n65;
  t15_n60: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t15_n64;
  t15_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t15_n63;
  t15_n62: return 0.1244569793343544;
  t15_n63: return 0.13514560461044312;
  t15_n64: return 0.08899008482694626;
  t15_n65: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t15_n67;
  t15_n66: return 0.0953805148601532;
  t15_n67: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n83;
  t15_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n72;
  t15_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t15_n71;
  t15_n70: return 0.10250407457351685;
  t15_n71: return 0.11633191257715225;
  t15_n72: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t15_n74;
  t15_n73: return 0.10359320789575577;
  t15_n74: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t15_n82;
  t15_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t15_n77;
  t15_n76: return 0.1093168705701828;
  t15_n77: if (E.getNumReferences() >= 3318611968 /*6592.0*/) goto t15_n79;
  t15_n78: return 0.11567235738039017;
  t15_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t15_n81;
  t15_n80: return 0.11867634207010269;
  t15_n81: return 0.12391141057014465;
  t15_n82: return 0.0998341366648674;
  t15_n83: return 0.11392863839864731;
  t15_n84: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t15_n160;
  t15_n85: if (E.getNumReferences() >= 3294650368 /*897.5*/) goto t15_n127;
  t15_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t15_n104;
  t15_n87: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t15_n97;
  t15_n88: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n94;
  t15_n89: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t15_n91;
  t15_n90: return 0.026541123166680336;
  t15_n91: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n93;
  t15_n92: return 0.08519451320171356;
  t15_n93: return 0.07003793120384216;
  t15_n94: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t15_n96;
  t15_n95: return 0.11528033763170242;
  t15_n96: return 0.11617103219032288;
  t15_n97: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n99;
  t15_n98: return -0.039221521466970444;
  t15_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t15_n103;
  t15_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t15_n102;
  t15_n101: return -0.031970977783203125;
  t15_n102: return 0.062291473150253296;
  t15_n103: return 0.07530064880847931;
  t15_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n106;
  t15_n105: return 0.056779421865940094;
  t15_n106: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t15_n118;
  t15_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n117;
  t15_n108: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t15_n110;
  t15_n109: return 0.047768328338861465;
  t15_n110: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t15_n114;
  t15_n111: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t15_n113;
  t15_n112: return 0.11203517764806747;
  t15_n113: return 0.11764170974493027;
  t15_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t15_n116;
  t15_n115: return 0.09224548190832138;
  t15_n116: return 0.11508835107088089;
  t15_n117: return 0.09530052542686462;
  t15_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t15_n120;
  t15_n119: return 0.14231932163238525;
  t15_n120: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n126;
  t15_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n125;
  t15_n122: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n124;
  t15_n123: return 0.14959557354450226;
  t15_n124: return 0.13104045391082764;
  t15_n125: return 0.13465069234371185;
  t15_n126: return 0.13280710577964783;
  t15_n127: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t15_n133;
  t15_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t15_n132;
  t15_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t15_n131;
  t15_n130: return 0.04015637934207916;
  t15_n131: return 0.13871432840824127;
  t15_n132: return 0.12287326157093048;
  t15_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n145;
  t15_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t15_n144;
  t15_n135: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n143;
  t15_n136: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t15_n138;
  t15_n137: return 0.04201512783765793;
  t15_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t15_n142;
  t15_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n141;
  t15_n140: return 0.12524834275245667;
  t15_n141: return 0.11688528954982758;
  t15_n142: return 0.10865837335586548;
  t15_n143: return 0.10800961405038834;
  t15_n144: return 0.08658129721879959;
  t15_n145: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t15_n155;
  t15_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n150;
  t15_n147: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n149;
  t15_n148: return 0.07176510244607925;
  t15_n149: return 0.11289148032665253;
  t15_n150: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t15_n152;
  t15_n151: return 0.10112842172384262;
  t15_n152: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t15_n154;
  t15_n153: return 0.13149258494377136;
  t15_n154: return 0.10307790338993073;
  t15_n155: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t15_n159;
  t15_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n158;
  t15_n157: return 0.12714722752571106;
  t15_n158: return 0.11621872335672379;
  t15_n159: return 0.09085364639759064;
  t15_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n204;
  t15_n161: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t15_n203;
  t15_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n178;
  t15_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t15_n167;
  t15_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t15_n166;
  t15_n165: return 0.0795278325676918;
  t15_n166: return 0.04169662296772003;
  t15_n167: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t15_n177;
  t15_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t15_n170;
  t15_n169: return -0.12967337667942047;
  t15_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n172;
  t15_n171: return 0.10328757762908936;
  t15_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t15_n174;
  t15_n173: return 0.08037953823804855;
  t15_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t15_n176;
  t15_n175: return 0.10772444307804108;
  t15_n176: return 0.12282005697488785;
  t15_n177: return -0.10292021185159683;
  t15_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t15_n184;
  t15_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t15_n181;
  t15_n180: return 0.0784236341714859;
  t15_n181: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t15_n183;
  t15_n182: return 0.10603485256433487;
  t15_n183: return 0.11721882224082947;
  t15_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n202;
  t15_n185: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n199;
  t15_n186: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t15_n188;
  t15_n187: return 0.06906413286924362;
  t15_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n198;
  t15_n189: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t15_n195;
  t15_n190: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t15_n194;
  t15_n191: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t15_n193;
  t15_n192: return 0.22579325735569;
  t15_n193: return 0.1680600941181183;
  t15_n194: return 0.07476432621479034;
  t15_n195: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t15_n197;
  t15_n196: return 0.11612097173929214;
  t15_n197: return 0.13787171244621277;
  t15_n198: return 0.10028191655874252;
  t15_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n201;
  t15_n200: return 0.1480880081653595;
  t15_n201: return 0.14342980086803436;
  t15_n202: return 0.053090911358594894;
  t15_n203: return -0.09975038468837738;
  t15_n204: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t15_n208;
  t15_n205: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n207;
  t15_n206: return 0.08228632062673569;
  t15_n207: return 0.067634217441082;
  t15_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n210;
  t15_n209: return 0.09731446206569672;
  t15_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t15_n214;
  t15_n211: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t15_n213;
  t15_n212: return 0.08946286141872406;
  t15_n213: return 0.10296697169542313;
  t15_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t15_n216;
  t15_n215: return 0.11929710954427719;
  t15_n216: return 0.041948575526475906;
  t15_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t15_n223;
  t15_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t15_n222;
  t15_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n221;
  t15_n220: return -0.045569390058517456;
  t15_n221: return 0.0759270116686821;
  t15_n222: return 0.09310828149318695;
  t15_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t15_n225;
  t15_n224: return 0.1060977578163147;
  t15_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t15_n227;
  t15_n226: return 0.09761158376932144;
  t15_n227: return 0.10398033261299133;
  t15_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t15_n242;
  t15_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t15_n233;
  t15_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n232;
  t15_n231: return 0.06207228824496269;
  t15_n232: return 0.09303316473960876;
  t15_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t15_n241;
  t15_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n238;
  t15_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t15_n237;
  t15_n236: return 0.09035370498895645;
  t15_n237: return 0.09734134376049042;
  t15_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t15_n240;
  t15_n239: return 0.09940025955438614;
  t15_n240: return 0.09682422876358032;
  t15_n241: return 0.09091218560934067;
  t15_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t15_n252;
  t15_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t15_n247;
  t15_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t15_n246;
  t15_n245: return 0.054816555231809616;
  t15_n246: return 0.10320450365543365;
  t15_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t15_n251;
  t15_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t15_n250;
  t15_n249: return 0.10045668482780457;
  t15_n250: return 0.10608786344528198;
  t15_n251: return 0.10709629952907562;
  t15_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t15_n254;
  t15_n253: return 0.10621697455644608;
  t15_n254: return 0.10474418103694916;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree16(const Example& E) {
  t16_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t16_n228;
  t16_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t16_n217;
  t16_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t16_n70;
  t16_n3: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t16_n21;
  t16_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t16_n6;
  t16_n5: return -0.043929323554039;
  t16_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t16_n12;
  t16_n7: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n9;
  t16_n8: return -0.09273163974285126;
  t16_n9: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t16_n11;
  t16_n10: return 0.028328407555818558;
  t16_n11: return 0.07855052500963211;
  t16_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n14;
  t16_n13: return 0.0007161966641433537;
  t16_n14: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t16_n16;
  t16_n15: return 0.10158178210258484;
  t16_n16: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t16_n20;
  t16_n17: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t16_n19;
  t16_n18: return 0.1063777431845665;
  t16_n19: return 0.06857730448246002;
  t16_n20: return 0.008727574720978737;
  t16_n21: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t16_n41;
  t16_n22: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n36;
  t16_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t16_n33;
  t16_n24: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t16_n26;
  t16_n25: return -0.02228308469057083;
  t16_n26: if (E.getNumReferences() >= 3348207616 /*74544.0*/) goto t16_n28;
  t16_n27: return 0.04870791360735893;
  t16_n28: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t16_n32;
  t16_n29: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t16_n31;
  t16_n30: return 0.08010875433683395;
  t16_n31: return 0.10440400242805481;
  t16_n32: return 0.10382455587387085;
  t16_n33: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t16_n35;
  t16_n34: return 0.06288570165634155;
  t16_n35: return 0.10472723841667175;
  t16_n36: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t16_n38;
  t16_n37: return 0.07088177651166916;
  t16_n38: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t16_n40;
  t16_n39: return 0.11090930551290512;
  t16_n40: return -0.2111329436302185;
  t16_n41: if (E.getNumReferences() >= 3319640064 /*7094.0*/) goto t16_n45;
  t16_n42: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n44;
  t16_n43: return 0.06373985856771469;
  t16_n44: return 0.0994240939617157;
  t16_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n59;
  t16_n46: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n52;
  t16_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t16_n49;
  t16_n48: return 0.03422550857067108;
  t16_n49: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n51;
  t16_n50: return 0.0806569829583168;
  t16_n51: return 0.09992627799510956;
  t16_n52: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t16_n54;
  t16_n53: return 0.08890819549560547;
  t16_n54: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t16_n58;
  t16_n55: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t16_n57;
  t16_n56: return 0.11793233454227448;
  t16_n57: return 0.12080693244934082;
  t16_n58: return 0.09929011017084122;
  t16_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t16_n67;
  t16_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t16_n62;
  t16_n61: return 0.07834476232528687;
  t16_n62: if (E.getNumReferences() >= 3327415808 /*13589.5*/) goto t16_n66;
  t16_n63: if (E.getNumReferences() >= 3322781184 /*9063.5*/) goto t16_n65;
  t16_n64: return 0.10801836103200912;
  t16_n65: return 0.1157984659075737;
  t16_n66: return 0.09731516987085342;
  t16_n67: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t16_n69;
  t16_n68: return 0.11619309335947037;
  t16_n69: return 0.0995875671505928;
  t16_n70: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t16_n158;
  t16_n71: if (E.getNumReferences() >= 3309346816 /*3082.0*/) goto t16_n129;
  t16_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t16_n112;
  t16_n73: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t16_n87;
  t16_n74: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n84;
  t16_n75: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t16_n77;
  t16_n76: return 0.024889592081308365;
  t16_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n79;
  t16_n78: return 0.05580703541636467;
  t16_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t16_n81;
  t16_n80: return 0.07858147472143173;
  t16_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n83;
  t16_n82: return -0.1785253882408142;
  t16_n83: return 0.11416144669055939;
  t16_n84: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t16_n86;
  t16_n85: return 0.11276564002037048;
  t16_n86: return 0.11254443228244781;
  t16_n87: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t16_n103;
  t16_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n90;
  t16_n89: return -0.04636048525571823;
  t16_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t16_n98;
  t16_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t16_n95;
  t16_n92: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t16_n94;
  t16_n93: return 0.0710248276591301;
  t16_n94: return -0.03881388157606125;
  t16_n95: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n97;
  t16_n96: return 0.0563608855009079;
  t16_n97: return 0.08645347505807877;
  t16_n98: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t16_n102;
  t16_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n101;
  t16_n100: return 0.10133069008588791;
  t16_n101: return 0.08640710264444351;
  t16_n102: return -0.14164914190769196;
  t16_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t16_n107;
  t16_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t16_n106;
  t16_n105: return 0.059307169169187546;
  t16_n106: return 0.12383387237787247;
  t16_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t16_n111;
  t16_n108: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t16_n110;
  t16_n109: return -0.0013380198506638408;
  t16_n110: return 0.12643349170684814;
  t16_n111: return 0.08656224608421326;
  t16_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n114;
  t16_n113: return 0.05504552274942398;
  t16_n114: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t16_n120;
  t16_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t16_n119;
  t16_n116: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t16_n118;
  t16_n117: return 0.08587725460529327;
  t16_n118: return 0.10082904249429703;
  t16_n119: return 0.06621867418289185;
  t16_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t16_n122;
  t16_n121: return 0.13331453502178192;
  t16_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t16_n128;
  t16_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n127;
  t16_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n126;
  t16_n125: return 0.14027516543865204;
  t16_n126: return 0.1255120187997818;
  t16_n127: return 0.12824268639087677;
  t16_n128: return 0.12083341181278229;
  t16_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n139;
  t16_n130: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t16_n138;
  t16_n131: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n135;
  t16_n132: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t16_n134;
  t16_n133: return 0.048773907124996185;
  t16_n134: return 0.10442424565553665;
  t16_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t16_n137;
  t16_n136: return 0.0969642847776413;
  t16_n137: return 0.11296811699867249;
  t16_n138: return 0.0847570151090622;
  t16_n139: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t16_n153;
  t16_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n144;
  t16_n141: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n143;
  t16_n142: return 0.07069218903779984;
  t16_n143: return 0.11203036457300186;
  t16_n144: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t16_n146;
  t16_n145: return 0.10042542964220047;
  t16_n146: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t16_n152;
  t16_n147: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t16_n149;
  t16_n148: return 0.12134648859500885;
  t16_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t16_n151;
  t16_n150: return 0.12979531288146973;
  t16_n151: return 0.14782629907131195;
  t16_n152: return 0.10206875205039978;
  t16_n153: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t16_n157;
  t16_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n156;
  t16_n155: return 0.12317453324794769;
  t16_n156: return 0.1148969978094101;
  t16_n157: return 0.09143218398094177;
  t16_n158: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n202;
  t16_n159: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t16_n201;
  t16_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n178;
  t16_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t16_n165;
  t16_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t16_n164;
  t16_n163: return 0.07359911501407623;
  t16_n164: return 0.03329899534583092;
  t16_n165: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t16_n177;
  t16_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t16_n168;
  t16_n167: return -0.12478349357843399;
  t16_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n172;
  t16_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t16_n171;
  t16_n170: return 0.08454003185033798;
  t16_n171: return 0.10709602385759354;
  t16_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t16_n174;
  t16_n173: return 0.08232142776250839;
  t16_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t16_n176;
  t16_n175: return 0.10346034914255142;
  t16_n176: return 0.11907084286212921;
  t16_n177: return -0.10573814064264297;
  t16_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t16_n184;
  t16_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t16_n181;
  t16_n180: return 0.07726706564426422;
  t16_n181: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t16_n183;
  t16_n182: return 0.10256966948509216;
  t16_n183: return 0.11552521586418152;
  t16_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t16_n200;
  t16_n185: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n197;
  t16_n186: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t16_n188;
  t16_n187: return 0.06320499628782272;
  t16_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n196;
  t16_n189: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t16_n193;
  t16_n190: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t16_n192;
  t16_n191: return 0.15254457294940948;
  t16_n192: return -0.002879087347537279;
  t16_n193: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t16_n195;
  t16_n194: return 0.11371646821498871;
  t16_n195: return 0.13025428354740143;
  t16_n196: return 0.09082522988319397;
  t16_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n199;
  t16_n198: return 0.14040787518024445;
  t16_n199: return 0.13862812519073486;
  t16_n200: return 0.08857335895299911;
  t16_n201: return -0.10377553105354309;
  t16_n202: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t16_n208;
  t16_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n205;
  t16_n204: return 0.08248725533485413;
  t16_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t16_n207;
  t16_n206: return 0.058404356241226196;
  t16_n207: return 0.07972630858421326;
  t16_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n210;
  t16_n209: return 0.0955289974808693;
  t16_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t16_n214;
  t16_n211: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t16_n213;
  t16_n212: return 0.08647239953279495;
  t16_n213: return 0.10172007232904434;
  t16_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t16_n216;
  t16_n215: return 0.11803045123815536;
  t16_n216: return 0.04968561604619026;
  t16_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t16_n223;
  t16_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t16_n222;
  t16_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n221;
  t16_n220: return -0.03693278133869171;
  t16_n221: return 0.0723537802696228;
  t16_n222: return 0.09089160710573196;
  t16_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t16_n225;
  t16_n224: return 0.10584483295679092;
  t16_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t16_n227;
  t16_n226: return 0.0960618257522583;
  t16_n227: return 0.10348790884017944;
  t16_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t16_n242;
  t16_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t16_n233;
  t16_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n232;
  t16_n231: return 0.05729282274842262;
  t16_n232: return 0.09074150025844574;
  t16_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t16_n241;
  t16_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n238;
  t16_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t16_n237;
  t16_n236: return 0.08725550025701523;
  t16_n237: return 0.09516587108373642;
  t16_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n240;
  t16_n239: return 0.09806624054908752;
  t16_n240: return 0.09555763751268387;
  t16_n241: return 0.08863522857427597;
  t16_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t16_n252;
  t16_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t16_n247;
  t16_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t16_n246;
  t16_n245: return 0.055783480405807495;
  t16_n246: return 0.10188669711351395;
  t16_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t16_n251;
  t16_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t16_n250;
  t16_n249: return 0.0962231382727623;
  t16_n250: return 0.10527244955301285;
  t16_n251: return 0.10628551244735718;
  t16_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t16_n254;
  t16_n253: return 0.10557590425014496;
  t16_n254: return 0.10425006598234177;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree17(const Example& E) {
  t17_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t17_n228;
  t17_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t17_n217;
  t17_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t17_n88;
  t17_n3: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t17_n47;
  t17_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n46;
  t17_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t17_n19;
  t17_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t17_n8;
  t17_n7: return -0.06787480413913727;
  t17_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t17_n10;
  t17_n9: return -0.03842611983418465;
  t17_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n18;
  t17_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t17_n13;
  t17_n12: return 0.09285801649093628;
  t17_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n17;
  t17_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n16;
  t17_n15: return 0.14105795323848724;
  t17_n16: return 0.14125332236289978;
  t17_n17: return -0.2505941689014435;
  t17_n18: return -0.026135042309761047;
  t17_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t17_n21;
  t17_n20: return -0.05627795681357384;
  t17_n21: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t17_n35;
  t17_n22: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t17_n24;
  t17_n23: return 0.015537355095148087;
  t17_n24: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t17_n28;
  t17_n25: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n27;
  t17_n26: return 0.1279165893793106;
  t17_n27: return 0.10089468955993652;
  t17_n28: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t17_n32;
  t17_n29: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t17_n31;
  t17_n30: return 0.14877505600452423;
  t17_n31: return 0.182429239153862;
  t17_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t17_n34;
  t17_n33: return 0.15457843244075775;
  t17_n34: return 0.17129990458488464;
  t17_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t17_n39;
  t17_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n38;
  t17_n37: return 0.0825614184141159;
  t17_n38: return 0.09762369096279144;
  t17_n39: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t17_n43;
  t17_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t17_n42;
  t17_n41: return 0.10442540049552917;
  t17_n42: return 0.13090397417545319;
  t17_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n45;
  t17_n44: return 0.1337658017873764;
  t17_n45: return 0.09161185473203659;
  t17_n46: return -0.07933938503265381;
  t17_n47: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t17_n79;
  t17_n48: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n72;
  t17_n49: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n61;
  t17_n50: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t17_n52;
  t17_n51: return -0.018528640270233154;
  t17_n52: if (E.getNumReferences() >= 3319521280 /*7036.0*/) goto t17_n54;
  t17_n53: return 0.02609597146511078;
  t17_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n56;
  t17_n55: return 0.06462936848402023;
  t17_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n58;
  t17_n57: return 0.0656939223408699;
  t17_n58: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t17_n60;
  t17_n59: return 0.12124847620725632;
  t17_n60: return 0.09469275921583176;
  t17_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n67;
  t17_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n64;
  t17_n63: return -0.008768279105424881;
  t17_n64: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t17_n66;
  t17_n65: return 0.05919089540839195;
  t17_n66: return 0.09722638130187988;
  t17_n67: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t17_n71;
  t17_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n70;
  t17_n69: return 0.05464703217148781;
  t17_n70: return 0.08652553707361221;
  t17_n71: return 0.09203411638736725;
  t17_n72: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t17_n76;
  t17_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t17_n75;
  t17_n74: return 0.06570228189229965;
  t17_n75: return 0.09944029897451401;
  t17_n76: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t17_n78;
  t17_n77: return 0.11068416386842728;
  t17_n78: return -0.17918407917022705;
  t17_n79: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t17_n85;
  t17_n80: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t17_n84;
  t17_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t17_n83;
  t17_n82: return 0.12240880727767944;
  t17_n83: return 0.1290513426065445;
  t17_n84: return 0.08224137872457504;
  t17_n85: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t17_n87;
  t17_n86: return 0.08909645676612854;
  t17_n87: return 0.10119274258613586;
  t17_n88: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t17_n160;
  t17_n89: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t17_n137;
  t17_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t17_n122;
  t17_n91: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t17_n101;
  t17_n92: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n98;
  t17_n93: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t17_n95;
  t17_n94: return 0.02417825721204281;
  t17_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n97;
  t17_n96: return 0.05332084000110626;
  t17_n97: return 0.08163303881883621;
  t17_n98: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t17_n100;
  t17_n99: return 0.10607292503118515;
  t17_n100: return 0.10990169644355774;
  t17_n101: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t17_n115;
  t17_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n104;
  t17_n103: return -0.041936542838811874;
  t17_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t17_n110;
  t17_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t17_n109;
  t17_n106: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t17_n108;
  t17_n107: return 0.07018512487411499;
  t17_n108: return -0.034712836146354675;
  t17_n109: return 0.056493062525987625;
  t17_n110: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t17_n114;
  t17_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n113;
  t17_n112: return 0.10033517330884933;
  t17_n113: return 0.08163676410913467;
  t17_n114: return -0.136590376496315;
  t17_n115: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n119;
  t17_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t17_n118;
  t17_n117: return 0.05833333358168602;
  t17_n118: return 0.12094241380691528;
  t17_n119: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n121;
  t17_n120: return 0.01438909862190485;
  t17_n121: return 0.08385226875543594;
  t17_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n124;
  t17_n123: return 0.05516565591096878;
  t17_n124: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t17_n128;
  t17_n125: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t17_n127;
  t17_n126: return 0.09097940474748611;
  t17_n127: return 0.06105718016624451;
  t17_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t17_n130;
  t17_n129: return 0.1282411366701126;
  t17_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n136;
  t17_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n135;
  t17_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n134;
  t17_n133: return 0.13311508297920227;
  t17_n134: return 0.1211174875497818;
  t17_n135: return 0.12262964248657227;
  t17_n136: return 0.11157940328121185;
  t17_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t17_n143;
  t17_n138: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t17_n142;
  t17_n139: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n141;
  t17_n140: return 0.05048526078462601;
  t17_n141: return 0.10129130631685257;
  t17_n142: return 0.08184551447629929;
  t17_n143: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t17_n155;
  t17_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n146;
  t17_n145: return 0.08177092671394348;
  t17_n146: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t17_n148;
  t17_n147: return 0.09712732583284378;
  t17_n148: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t17_n154;
  t17_n149: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t17_n151;
  t17_n150: return 0.11772455275058746;
  t17_n151: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n153;
  t17_n152: return 0.14221228659152985;
  t17_n153: return 0.12598338723182678;
  t17_n154: return 0.09818112850189209;
  t17_n155: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t17_n159;
  t17_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n158;
  t17_n157: return 0.12061285227537155;
  t17_n158: return 0.11395056545734406;
  t17_n159: return 0.08513856679201126;
  t17_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n202;
  t17_n161: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t17_n201;
  t17_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n180;
  t17_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t17_n167;
  t17_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t17_n166;
  t17_n165: return 0.06873799115419388;
  t17_n166: return 0.03750455752015114;
  t17_n167: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t17_n179;
  t17_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t17_n170;
  t17_n169: return -0.12246974557638168;
  t17_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n172;
  t17_n171: return 0.09909835457801819;
  t17_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t17_n174;
  t17_n173: return 0.07550685852766037;
  t17_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t17_n176;
  t17_n175: return 0.09904054552316666;
  t17_n176: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n178;
  t17_n177: return 0.1298241913318634;
  t17_n178: return 0.08444047719240189;
  t17_n179: return -0.09726324677467346;
  t17_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t17_n186;
  t17_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t17_n183;
  t17_n182: return 0.07223202288150787;
  t17_n183: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t17_n185;
  t17_n184: return 0.09915608167648315;
  t17_n185: return 0.11330397427082062;
  t17_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n200;
  t17_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n197;
  t17_n188: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t17_n190;
  t17_n189: return 0.0651857778429985;
  t17_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n196;
  t17_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t17_n195;
  t17_n192: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t17_n194;
  t17_n193: return 0.14082995057106018;
  t17_n194: return 0.013792723417282104;
  t17_n195: return 0.12390189617872238;
  t17_n196: return -0.03255408629775047;
  t17_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n199;
  t17_n198: return 0.13222751021385193;
  t17_n199: return 0.13261456787586212;
  t17_n200: return 0.07889794558286667;
  t17_n201: return -0.10021496564149857;
  t17_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t17_n206;
  t17_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n205;
  t17_n204: return 0.07535311579704285;
  t17_n205: return 0.04875481501221657;
  t17_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n210;
  t17_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n209;
  t17_n208: return 0.07523921132087708;
  t17_n209: return 0.09300398826599121;
  t17_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t17_n212;
  t17_n211: return 0.08492173999547958;
  t17_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t17_n214;
  t17_n213: return -0.14231549203395844;
  t17_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t17_n216;
  t17_n215: return 0.11559645086526871;
  t17_n216: return 0.14281749725341797;
  t17_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t17_n223;
  t17_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t17_n222;
  t17_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n221;
  t17_n220: return -0.02713131345808506;
  t17_n221: return 0.06851441413164139;
  t17_n222: return 0.08798515796661377;
  t17_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t17_n225;
  t17_n224: return 0.10569102317094803;
  t17_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t17_n227;
  t17_n226: return 0.09465999901294708;
  t17_n227: return 0.10293618589639664;
  t17_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t17_n242;
  t17_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t17_n233;
  t17_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n232;
  t17_n231: return 0.05342940241098404;
  t17_n232: return 0.08826317638158798;
  t17_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t17_n241;
  t17_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n238;
  t17_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t17_n237;
  t17_n236: return 0.08446567505598068;
  t17_n237: return 0.09334573894739151;
  t17_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t17_n240;
  t17_n239: return 0.09667423367500305;
  t17_n240: return 0.09423716366291046;
  t17_n241: return 0.08592279255390167;
  t17_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t17_n252;
  t17_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t17_n247;
  t17_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t17_n246;
  t17_n245: return 0.04786746948957443;
  t17_n246: return 0.10083850473165512;
  t17_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t17_n251;
  t17_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t17_n250;
  t17_n249: return 0.0966801866889;
  t17_n250: return 0.10472741723060608;
  t17_n251: return 0.10577129572629929;
  t17_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t17_n254;
  t17_n253: return 0.10493633896112442;
  t17_n254: return 0.10368882864713669;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree18(const Example& E) {
  t18_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t18_n228;
  t18_n1: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t18_n217;
  t18_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t18_n60;
  t18_n3: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t18_n23;
  t18_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n8;
  t18_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t18_n7;
  t18_n6: return -0.03803091496229172;
  t18_n7: return -0.08662264794111252;
  t18_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n22;
  t18_n9: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t18_n11;
  t18_n10: return 0.022465188056230545;
  t18_n11: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t18_n13;
  t18_n12: return 0.061006393283605576;
  t18_n13: if (E.getNumReferences() >= 3315736576 /*5188.0*/) goto t18_n15;
  t18_n14: return 0.09767300635576248;
  t18_n15: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t18_n17;
  t18_n16: return 0.08664707839488983;
  t18_n17: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t18_n21;
  t18_n18: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t18_n20;
  t18_n19: return 0.11171255260705948;
  t18_n20: return 0.11498711258172989;
  t18_n21: return 0.09264931082725525;
  t18_n22: return 0.06929314136505127;
  t18_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t18_n43;
  t18_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t18_n42;
  t18_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n31;
  t18_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n28;
  t18_n27: return 0.061326105147600174;
  t18_n28: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t18_n30;
  t18_n29: return 0.08974531292915344;
  t18_n30: return 0.10931236296892166;
  t18_n31: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t18_n41;
  t18_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t18_n34;
  t18_n33: return 0.08861710876226425;
  t18_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n40;
  t18_n35: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t18_n37;
  t18_n36: return 0.10791963338851929;
  t18_n37: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t18_n39;
  t18_n38: return 0.11500661820173264;
  t18_n39: return 0.1137288361787796;
  t18_n40: return 0.014876269735395908;
  t18_n41: return 0.11480008065700531;
  t18_n42: return -0.009165040217339993;
  t18_n43: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t18_n55;
  t18_n44: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t18_n54;
  t18_n45: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t18_n53;
  t18_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n50;
  t18_n47: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n49;
  t18_n48: return 0.05827334150671959;
  t18_n49: return 0.10216585546731949;
  t18_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t18_n52;
  t18_n51: return 0.05992761254310608;
  t18_n52: return 0.09629028290510178;
  t18_n53: return -0.031178178265690804;
  t18_n54: return 0.10238134115934372;
  t18_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t18_n57;
  t18_n56: return 0.08781755715608597;
  t18_n57: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t18_n59;
  t18_n58: return 0.10405620187520981;
  t18_n59: return 0.09232895076274872;
  t18_n60: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t18_n150;
  t18_n61: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t18_n123;
  t18_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t18_n104;
  t18_n63: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t18_n83;
  t18_n64: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n74;
  t18_n65: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t18_n67;
  t18_n66: return 0.023334631696343422;
  t18_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n69;
  t18_n68: return 0.05092048645019531;
  t18_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t18_n71;
  t18_n70: return 0.07206263393163681;
  t18_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n73;
  t18_n72: return -0.15889109671115875;
  t18_n73: return 0.10672829300165176;
  t18_n74: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t18_n76;
  t18_n75: return 0.10215650498867035;
  t18_n76: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t18_n78;
  t18_n77: return 0.10608422756195068;
  t18_n78: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t18_n82;
  t18_n79: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t18_n81;
  t18_n80: return 0.10052814334630966;
  t18_n81: return 0.1295863389968872;
  t18_n82: return 0.13220137357711792;
  t18_n83: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t18_n97;
  t18_n84: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n86;
  t18_n85: return -0.03705385699868202;
  t18_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t18_n92;
  t18_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t18_n91;
  t18_n88: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t18_n90;
  t18_n89: return 0.06619735807180405;
  t18_n90: return -0.031808000057935715;
  t18_n91: return 0.052962902933359146;
  t18_n92: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t18_n96;
  t18_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n95;
  t18_n94: return 0.09777562320232391;
  t18_n95: return 0.07867398113012314;
  t18_n96: return -0.1382952630519867;
  t18_n97: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t18_n101;
  t18_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t18_n100;
  t18_n99: return 0.05073346197605133;
  t18_n100: return 0.11376345902681351;
  t18_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t18_n103;
  t18_n102: return 0.01571480557322502;
  t18_n103: return 0.07981503754854202;
  t18_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t18_n106;
  t18_n105: return 0.0513591468334198;
  t18_n106: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t18_n114;
  t18_n107: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t18_n113;
  t18_n108: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t18_n110;
  t18_n109: return 0.03025796264410019;
  t18_n110: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t18_n112;
  t18_n111: return 0.10855968296527863;
  t18_n112: return 0.08532002568244934;
  t18_n113: return 0.08892448246479034;
  t18_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t18_n116;
  t18_n115: return 0.12145376205444336;
  t18_n116: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n122;
  t18_n117: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n121;
  t18_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n120;
  t18_n119: return 0.1279468685388565;
  t18_n120: return 0.11745796352624893;
  t18_n121: return 0.1183212623000145;
  t18_n122: return 0.10509228706359863;
  t18_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t18_n131;
  t18_n124: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t18_n130;
  t18_n125: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t18_n129;
  t18_n126: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n128;
  t18_n127: return 0.048397619277238846;
  t18_n128: return 0.09608625620603561;
  t18_n129: return 0.102444589138031;
  t18_n130: return 0.07770359516143799;
  t18_n131: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t18_n145;
  t18_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n136;
  t18_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n135;
  t18_n134: return 0.06462275236845016;
  t18_n135: return 0.10810758918523788;
  t18_n136: if (E.getNumReferences() >= 3330029056 /*16141.5*/) goto t18_n138;
  t18_n137: return 0.09431582689285278;
  t18_n138: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t18_n144;
  t18_n139: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t18_n141;
  t18_n140: return 0.1155514121055603;
  t18_n141: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t18_n143;
  t18_n142: return 0.13791756331920624;
  t18_n143: return 0.12707430124282837;
  t18_n144: return 0.09594082832336426;
  t18_n145: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t18_n149;
  t18_n146: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n148;
  t18_n147: return 0.11833721399307251;
  t18_n148: return 0.11315073072910309;
  t18_n149: return 0.08777209371328354;
  t18_n150: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n208;
  t18_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t18_n207;
  t18_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n186;
  t18_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t18_n175;
  t18_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n156;
  t18_n155: return -0.1280006617307663;
  t18_n156: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n166;
  t18_n157: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t18_n161;
  t18_n158: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t18_n160;
  t18_n159: return -0.10116294771432877;
  t18_n160: return 0.07306891679763794;
  t18_n161: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t18_n165;
  t18_n162: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t18_n164;
  t18_n163: return 0.07848112285137177;
  t18_n164: return -0.0038332385011017323;
  t18_n165: return -0.11432473361492157;
  t18_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t18_n168;
  t18_n167: return 0.03591925650835037;
  t18_n168: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t18_n170;
  t18_n169: return 0.06743372231721878;
  t18_n170: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t18_n174;
  t18_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n173;
  t18_n172: return 0.0939590260386467;
  t18_n173: return 0.07263316214084625;
  t18_n174: return 0.061751510947942734;
  t18_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t18_n177;
  t18_n176: return -0.11985090374946594;
  t18_n177: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t18_n181;
  t18_n178: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n180;
  t18_n179: return -0.026014555245637894;
  t18_n180: return 0.08121920377016068;
  t18_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t18_n185;
  t18_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n184;
  t18_n183: return 0.06476835161447525;
  t18_n184: return 0.09653657674789429;
  t18_n185: return 0.11034319549798965;
  t18_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t18_n192;
  t18_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t18_n189;
  t18_n188: return 0.07056497037410736;
  t18_n189: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t18_n191;
  t18_n190: return 0.09449733048677444;
  t18_n191: return 0.11170969158411026;
  t18_n192: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n206;
  t18_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n203;
  t18_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t18_n196;
  t18_n195: return 0.06062910333275795;
  t18_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n202;
  t18_n197: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t18_n201;
  t18_n198: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t18_n200;
  t18_n199: return 0.13280948996543884;
  t18_n200: return -0.0013354640686884522;
  t18_n201: return 0.11910200864076614;
  t18_n202: return 0.08783616125583649;
  t18_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n205;
  t18_n204: return 0.12478920817375183;
  t18_n205: return 0.1304868459701538;
  t18_n206: return 0.07490529865026474;
  t18_n207: return -0.10004983097314835;
  t18_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t18_n210;
  t18_n209: return 0.06536269187927246;
  t18_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n212;
  t18_n211: return 0.09105654805898666;
  t18_n212: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t18_n214;
  t18_n213: return 0.08305097371339798;
  t18_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t18_n216;
  t18_n215: return 0.11410412192344666;
  t18_n216: return 0.049583010375499725;
  t18_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t18_n223;
  t18_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t18_n222;
  t18_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n221;
  t18_n220: return -0.01864858716726303;
  t18_n221: return 0.06425798684358597;
  t18_n222: return 0.0859752967953682;
  t18_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t18_n225;
  t18_n224: return 0.10560378432273865;
  t18_n225: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t18_n227;
  t18_n226: return 0.09313683211803436;
  t18_n227: return 0.10257557779550552;
  t18_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t18_n242;
  t18_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t18_n233;
  t18_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n232;
  t18_n231: return 0.05070669203996658;
  t18_n232: return 0.08495151251554489;
  t18_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t18_n241;
  t18_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n238;
  t18_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t18_n237;
  t18_n236: return 0.08133240044116974;
  t18_n237: return 0.09119682013988495;
  t18_n238: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t18_n240;
  t18_n239: return 0.0952216312289238;
  t18_n240: return 0.0897068977355957;
  t18_n241: return 0.08311630040407181;
  t18_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t18_n252;
  t18_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t18_n247;
  t18_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t18_n246;
  t18_n245: return 0.04281450808048248;
  t18_n246: return 0.0992877408862114;
  t18_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t18_n251;
  t18_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t18_n250;
  t18_n249: return 0.09296120703220367;
  t18_n250: return 0.10396013408899307;
  t18_n251: return 0.10521509498357773;
  t18_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t18_n254;
  t18_n253: return 0.10453527420759201;
  t18_n254: return 0.10329734534025192;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree19(const Example& E) {
  t19_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t19_n224;
  t19_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t19_n89;
  t19_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t19_n84;
  t19_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n61;
  t19_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t19_n60;
  t19_n5: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t19_n7;
  t19_n6: return -0.041252631694078445;
  t19_n7: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t19_n25;
  t19_n8: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t19_n24;
  t19_n9: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t19_n13;
  t19_n10: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n12;
  t19_n11: return 0.014680483378469944;
  t19_n12: return 0.08482184261083603;
  t19_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n15;
  t19_n14: return 0.08139672130346298;
  t19_n15: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t19_n23;
  t19_n16: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t19_n18;
  t19_n17: return 0.1128191277384758;
  t19_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n22;
  t19_n19: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t19_n21;
  t19_n20: return 0.10882458090782166;
  t19_n21: return 0.10391276329755783;
  t19_n22: return 0.032587822526693344;
  t19_n23: return 0.11219605058431625;
  t19_n24: return -0.025440800935029984;
  t19_n25: if (E.getNumReferences() >= 3319640064 /*7094.0*/) goto t19_n33;
  t19_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t19_n30;
  t19_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n29;
  t19_n28: return 0.03163371607661247;
  t19_n29: return 0.11333060264587402;
  t19_n30: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t19_n32;
  t19_n31: return 0.0320863239467144;
  t19_n32: return 0.09745816141366959;
  t19_n33: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t19_n57;
  t19_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n40;
  t19_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t19_n39;
  t19_n36: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t19_n38;
  t19_n37: return 0.06258900463581085;
  t19_n38: return 0.0812964215874672;
  t19_n39: return 0.09862139821052551;
  t19_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n42;
  t19_n41: return 0.07613325119018555;
  t19_n42: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t19_n56;
  t19_n43: if (E.getNumReferences() >= 3328529408 /*14677.0*/) goto t19_n45;
  t19_n44: return 0.10779105871915817;
  t19_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t19_n47;
  t19_n46: return 0.11426301300525665;
  t19_n47: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t19_n49;
  t19_n48: return 0.11567050963640213;
  t19_n49: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t19_n53;
  t19_n50: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t19_n52;
  t19_n51: return 0.10576621443033218;
  t19_n52: return 0.13324962556362152;
  t19_n53: if (E.getNumReferences() >= 3331241984 /*18268.0*/) goto t19_n55;
  t19_n54: return 0.1284535974264145;
  t19_n55: return 0.1290154755115509;
  t19_n56: return 0.08514901995658875;
  t19_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t19_n59;
  t19_n58: return 0.08796185255050659;
  t19_n59: return 0.10337304323911667;
  t19_n60: return -0.08277449756860733;
  t19_n61: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t19_n65;
  t19_n62: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n64;
  t19_n63: return 0.02871512994170189;
  t19_n64: return 0.06479569524526596;
  t19_n65: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t19_n81;
  t19_n66: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t19_n68;
  t19_n67: return 0.06468010693788528;
  t19_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t19_n70;
  t19_n69: return 0.06053495779633522;
  t19_n70: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t19_n72;
  t19_n71: return 0.15515775978565216;
  t19_n72: if (E.getNumReferences() >= 3309828096 /*3199.5*/) goto t19_n74;
  t19_n73: return 0.11022049933671951;
  t19_n74: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t19_n80;
  t19_n75: if (E.getNumReferences() >= 3325494272 /*11713.0*/) goto t19_n77;
  t19_n76: return 0.10766854882240295;
  t19_n77: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t19_n79;
  t19_n78: return 0.11379656940698624;
  t19_n79: return 0.11122222244739532;
  t19_n80: return 0.09519150853157043;
  t19_n81: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t19_n83;
  t19_n82: return 0.11010897159576416;
  t19_n83: return -0.16601364314556122;
  t19_n84: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t19_n86;
  t19_n85: return 0.06358295679092407;
  t19_n86: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t19_n88;
  t19_n87: return 0.09419234097003937;
  t19_n88: return 0.10250589996576309;
  t19_n89: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t19_n153;
  t19_n90: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t19_n130;
  t19_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t19_n117;
  t19_n92: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t19_n108;
  t19_n93: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n99;
  t19_n94: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t19_n96;
  t19_n95: return 0.025264175608754158;
  t19_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n98;
  t19_n97: return 0.036552440375089645;
  t19_n98: return 0.07389792054891586;
  t19_n99: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t19_n101;
  t19_n100: return 0.09892670810222626;
  t19_n101: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t19_n103;
  t19_n102: return 0.10401519387960434;
  t19_n103: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t19_n107;
  t19_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t19_n106;
  t19_n105: return 0.08989930897951126;
  t19_n106: return 0.12860901653766632;
  t19_n107: return 0.12521573901176453;
  t19_n108: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t19_n110;
  t19_n109: return -0.01958444155752659;
  t19_n110: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t19_n114;
  t19_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t19_n113;
  t19_n112: return 0.04936930537223816;
  t19_n113: return 0.10842178016901016;
  t19_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t19_n116;
  t19_n115: return 0.015748286619782448;
  t19_n116: return 0.07740968465805054;
  t19_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n119;
  t19_n118: return 0.047171447426080704;
  t19_n119: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t19_n123;
  t19_n120: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t19_n122;
  t19_n121: return 0.09292712807655334;
  t19_n122: return 0.061091963201761246;
  t19_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n125;
  t19_n124: return 0.11665474623441696;
  t19_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n129;
  t19_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n128;
  t19_n127: return 0.12078613042831421;
  t19_n128: return 0.11390858888626099;
  t19_n129: return 0.09795073419809341;
  t19_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t19_n136;
  t19_n131: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t19_n135;
  t19_n132: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n134;
  t19_n133: return 0.04717133939266205;
  t19_n134: return 0.09506282210350037;
  t19_n135: return 0.07849244773387909;
  t19_n136: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t19_n148;
  t19_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n139;
  t19_n138: return 0.07208787649869919;
  t19_n139: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t19_n141;
  t19_n140: return 0.08923517167568207;
  t19_n141: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t19_n147;
  t19_n142: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t19_n144;
  t19_n143: return 0.11471889913082123;
  t19_n144: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t19_n146;
  t19_n145: return 0.13307107985019684;
  t19_n146: return 0.1114005446434021;
  t19_n147: return 0.09227467328310013;
  t19_n148: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t19_n152;
  t19_n149: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n151;
  t19_n150: return 0.11666318029165268;
  t19_n151: return 0.11213172972202301;
  t19_n152: return 0.08997370302677155;
  t19_n153: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t19_n223;
  t19_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n202;
  t19_n155: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n193;
  t19_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t19_n180;
  t19_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n159;
  t19_n158: return -0.1230221539735794;
  t19_n159: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t19_n163;
  t19_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n162;
  t19_n161: return 0.000353206938598305;
  t19_n162: return 0.060949306935071945;
  t19_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t19_n171;
  t19_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t19_n166;
  t19_n165: return -0.034136224538087845;
  t19_n166: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t19_n170;
  t19_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n169;
  t19_n168: return 0.09276311099529266;
  t19_n169: return 0.03979102522134781;
  t19_n170: return -0.06852495670318604;
  t19_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t19_n175;
  t19_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n174;
  t19_n173: return 0.08319224417209625;
  t19_n174: return 0.09630633145570755;
  t19_n175: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t19_n179;
  t19_n176: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n178;
  t19_n177: return 0.1257074922323227;
  t19_n178: return 0.10122671723365784;
  t19_n179: return -0.04881294071674347;
  t19_n180: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t19_n192;
  t19_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t19_n183;
  t19_n182: return -0.11804090440273285;
  t19_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n185;
  t19_n184: return 0.09014355391263962;
  t19_n185: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t19_n187;
  t19_n186: return 0.0670701414346695;
  t19_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t19_n189;
  t19_n188: return 0.09211332350969315;
  t19_n189: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n191;
  t19_n190: return 0.12239458411931992;
  t19_n191: return 0.07925587147474289;
  t19_n192: return -0.0941106528043747;
  t19_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n195;
  t19_n194: return 0.06237979605793953;
  t19_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n197;
  t19_n196: return 0.08972452580928802;
  t19_n197: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t19_n199;
  t19_n198: return 0.07979388535022736;
  t19_n199: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t19_n201;
  t19_n200: return 0.11198204755783081;
  t19_n201: return 0.14513622224330902;
  t19_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t19_n208;
  t19_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t19_n205;
  t19_n204: return 0.06523347645998001;
  t19_n205: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t19_n207;
  t19_n206: return 0.09045501053333282;
  t19_n207: return 0.11001641303300858;
  t19_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n222;
  t19_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n219;
  t19_n210: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t19_n212;
  t19_n211: return 0.07859555631875992;
  t19_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t19_n218;
  t19_n213: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t19_n217;
  t19_n214: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t19_n216;
  t19_n215: return 0.1256270855665207;
  t19_n216: return 0.009016445837914944;
  t19_n217: return 0.11626280844211578;
  t19_n218: return -0.051587510854005814;
  t19_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n221;
  t19_n220: return 0.11743059754371643;
  t19_n221: return 0.12235661596059799;
  t19_n222: return 0.06924007833003998;
  t19_n223: return -0.07991296052932739;
  t19_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t19_n238;
  t19_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t19_n229;
  t19_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n228;
  t19_n227: return 0.04674442484974861;
  t19_n228: return 0.08255256712436676;
  t19_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t19_n237;
  t19_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n234;
  t19_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n233;
  t19_n232: return 0.07867465913295746;
  t19_n233: return 0.08928316831588745;
  t19_n234: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t19_n236;
  t19_n235: return 0.09371563047170639;
  t19_n236: return 0.08842722326517105;
  t19_n237: return 0.08022903650999069;
  t19_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t19_n252;
  t19_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t19_n247;
  t19_n240: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t19_n244;
  t19_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n243;
  t19_n242: return 0.046469200402498245;
  t19_n243: return 0.09800243377685547;
  t19_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n246;
  t19_n245: return 0.11265657842159271;
  t19_n246: return -0.02423366717994213;
  t19_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t19_n251;
  t19_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t19_n250;
  t19_n249: return 0.09045221656560898;
  t19_n250: return 0.10338488221168518;
  t19_n251: return 0.1045740395784378;
  t19_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t19_n254;
  t19_n253: return 0.1039339229464531;
  t19_n254: return 0.1027916669845581;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree20(const Example& E) {
  t20_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t20_n224;
  t20_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t20_n65;
  t20_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t20_n60;
  t20_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n41;
  t20_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t20_n20;
  t20_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t20_n13;
  t20_n6: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t20_n8;
  t20_n7: return -0.03750084713101387;
  t20_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n10;
  t20_n9: return 0.08529295027256012;
  t20_n10: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t20_n12;
  t20_n11: return 0.09898042678833008;
  t20_n12: return 0.10908405482769012;
  t20_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n15;
  t20_n14: return -0.07610669732093811;
  t20_n15: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t20_n19;
  t20_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n18;
  t20_n17: return -0.06505297869443893;
  t20_n18: return 0.08237334340810776;
  t20_n19: return 0.025482797995209694;
  t20_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n22;
  t20_n21: return 0.011446668766438961;
  t20_n22: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t20_n28;
  t20_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t20_n25;
  t20_n24: return 0.09755279868841171;
  t20_n25: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t20_n27;
  t20_n26: return 0.10396908223628998;
  t20_n27: return 0.11262358725070953;
  t20_n28: if (E.getNumReferences() >= 3307687936 /*2677.0*/) goto t20_n40;
  t20_n29: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t20_n31;
  t20_n30: return 0.010836216621100903;
  t20_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t20_n35;
  t20_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n34;
  t20_n33: return 0.060227490961551666;
  t20_n34: return 0.1033381000161171;
  t20_n35: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t20_n39;
  t20_n36: if (E.getNumReferences() >= 3302678528 /*1751.0*/) goto t20_n38;
  t20_n37: return 0.09863197058439255;
  t20_n38: return 0.11495398730039597;
  t20_n39: return 0.00845232605934143;
  t20_n40: return 0.08163411170244217;
  t20_n41: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t20_n45;
  t20_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n44;
  t20_n43: return 0.029076993465423584;
  t20_n44: return 0.06260780245065689;
  t20_n45: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t20_n57;
  t20_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t20_n48;
  t20_n47: return 0.0615314282476902;
  t20_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t20_n50;
  t20_n49: return 0.05741335451602936;
  t20_n50: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t20_n52;
  t20_n51: return 0.1454186737537384;
  t20_n52: if (E.getNumReferences() >= 3309828096 /*3199.5*/) goto t20_n56;
  t20_n53: if (E.getNumReferences() >= 3272671232 /*145.0*/) goto t20_n55;
  t20_n54: return 0.14579588174819946;
  t20_n55: return 0.1051219031214714;
  t20_n56: return 0.10196232050657272;
  t20_n57: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t20_n59;
  t20_n58: return 0.10918238759040833;
  t20_n59: return -0.16168741881847382;
  t20_n60: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t20_n62;
  t20_n61: return 0.059633709490299225;
  t20_n62: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t20_n64;
  t20_n63: return 0.09252098947763443;
  t20_n64: return 0.10208412259817123;
  t20_n65: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t20_n155;
  t20_n66: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t20_n128;
  t20_n67: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t20_n87;
  t20_n68: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n78;
  t20_n69: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t20_n71;
  t20_n70: return 0.021817702800035477;
  t20_n71: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t20_n75;
  t20_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t20_n74;
  t20_n73: return 0.06205614283680916;
  t20_n74: return 0.10868088155984879;
  t20_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n77;
  t20_n76: return 0.070552758872509;
  t20_n77: return 0.028483031317591667;
  t20_n78: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t20_n80;
  t20_n79: return 0.1024247333407402;
  t20_n80: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t20_n82;
  t20_n81: return 0.1042613610625267;
  t20_n82: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t20_n86;
  t20_n83: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t20_n85;
  t20_n84: return 0.12382552027702332;
  t20_n85: return 0.18502962589263916;
  t20_n86: return 0.1292969286441803;
  t20_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t20_n117;
  t20_n88: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t20_n98;
  t20_n89: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n91;
  t20_n90: return -0.03790534287691116;
  t20_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n93;
  t20_n92: return -0.10149919241666794;
  t20_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t20_n95;
  t20_n94: return 0.05271906033158302;
  t20_n95: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t20_n97;
  t20_n96: return 0.08858192712068558;
  t20_n97: return -0.13180451095104218;
  t20_n98: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t20_n102;
  t20_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t20_n101;
  t20_n100: return 0.04814025014638901;
  t20_n101: return 0.10316929221153259;
  t20_n102: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t20_n108;
  t20_n103: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t20_n105;
  t20_n104: return -0.003604368306696415;
  t20_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t20_n107;
  t20_n106: return 0.10444484651088715;
  t20_n107: return 0.13006135821342468;
  t20_n108: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t20_n116;
  t20_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n111;
  t20_n110: return 0.07842588424682617;
  t20_n111: if (E.getNumReferences() >= 3294330880 /*878.0*/) goto t20_n113;
  t20_n112: return 0.08224945515394211;
  t20_n113: if (E.getNumReferences() >= 3299852288 /*1406.0*/) goto t20_n115;
  t20_n114: return 0.1119329184293747;
  t20_n115: return 0.005113099701702595;
  t20_n116: return 0.06284986436367035;
  t20_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n119;
  t20_n118: return 0.04564015567302704;
  t20_n119: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t20_n121;
  t20_n120: return 0.05746937915682793;
  t20_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n123;
  t20_n122: return 0.11097146570682526;
  t20_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n127;
  t20_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n126;
  t20_n125: return 0.11841461062431335;
  t20_n126: return 0.11233469098806381;
  t20_n127: return 0.09241421520709991;
  t20_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n136;
  t20_n129: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t20_n133;
  t20_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n132;
  t20_n131: return 0.04417378455400467;
  t20_n132: return 0.09255407005548477;
  t20_n133: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t20_n135;
  t20_n134: return 0.06916038691997528;
  t20_n135: return 0.09556686878204346;
  t20_n136: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t20_n148;
  t20_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n139;
  t20_n138: return 0.06786075979471207;
  t20_n139: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t20_n141;
  t20_n140: return 0.0848383679986;
  t20_n141: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t20_n147;
  t20_n142: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t20_n144;
  t20_n143: return 0.11297638714313507;
  t20_n144: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t20_n146;
  t20_n145: return 0.1293671429157257;
  t20_n146: return 0.11033894866704941;
  t20_n147: return 0.08949806541204453;
  t20_n148: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t20_n152;
  t20_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n151;
  t20_n150: return 0.11385606974363327;
  t20_n151: return 0.11390956491231918;
  t20_n152: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t20_n154;
  t20_n153: return 0.035163093358278275;
  t20_n154: return 0.0942227691411972;
  t20_n155: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t20_n223;
  t20_n156: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n202;
  t20_n157: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n193;
  t20_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t20_n180;
  t20_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n161;
  t20_n160: return -0.12046770751476288;
  t20_n161: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n179;
  t20_n162: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t20_n164;
  t20_n163: return 0.006793489679694176;
  t20_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t20_n172;
  t20_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t20_n167;
  t20_n166: return -0.04034753143787384;
  t20_n167: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t20_n171;
  t20_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n170;
  t20_n169: return 0.08344151824712753;
  t20_n170: return 0.03357525169849396;
  t20_n171: return -0.059171728789806366;
  t20_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t20_n176;
  t20_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n175;
  t20_n174: return 0.08727708458900452;
  t20_n175: return 0.12184564769268036;
  t20_n176: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t20_n178;
  t20_n177: return 0.12288923561573029;
  t20_n178: return -0.07432906329631805;
  t20_n179: return 0.059088580310344696;
  t20_n180: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t20_n192;
  t20_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t20_n183;
  t20_n182: return -0.11653995513916016;
  t20_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n185;
  t20_n184: return 0.0879327654838562;
  t20_n185: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t20_n187;
  t20_n186: return 0.06075740605592728;
  t20_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t20_n189;
  t20_n188: return 0.08710499852895737;
  t20_n189: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n191;
  t20_n190: return 0.11943497508764267;
  t20_n191: return 0.07563497126102448;
  t20_n192: return -0.09407338500022888;
  t20_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n195;
  t20_n194: return 0.06148038059473038;
  t20_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n197;
  t20_n196: return 0.08693090826272964;
  t20_n197: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t20_n199;
  t20_n198: return 0.07810443639755249;
  t20_n199: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t20_n201;
  t20_n200: return 0.11027955263853073;
  t20_n201: return 0.14058806002140045;
  t20_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t20_n208;
  t20_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t20_n205;
  t20_n204: return 0.06202095374464989;
  t20_n205: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t20_n207;
  t20_n206: return 0.08568938076496124;
  t20_n207: return 0.10781590640544891;
  t20_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n222;
  t20_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n219;
  t20_n210: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t20_n212;
  t20_n211: return 0.07519925385713577;
  t20_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t20_n218;
  t20_n213: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t20_n217;
  t20_n214: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t20_n216;
  t20_n215: return 0.1205364316701889;
  t20_n216: return -0.00794061180204153;
  t20_n217: return 0.11260874569416046;
  t20_n218: return 0.08755996823310852;
  t20_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n221;
  t20_n220: return 0.11278398334980011;
  t20_n221: return 0.11434684693813324;
  t20_n222: return 0.05748733878135681;
  t20_n223: return -0.07974559813737869;
  t20_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t20_n238;
  t20_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t20_n229;
  t20_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n228;
  t20_n227: return 0.04277215152978897;
  t20_n228: return 0.07950848340988159;
  t20_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t20_n237;
  t20_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n234;
  t20_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n233;
  t20_n232: return 0.07539836317300797;
  t20_n233: return 0.0871601477265358;
  t20_n234: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t20_n236;
  t20_n235: return 0.09223172068595886;
  t20_n236: return 0.08629985898733139;
  t20_n237: return 0.07747206091880798;
  t20_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t20_n252;
  t20_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t20_n247;
  t20_n240: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t20_n244;
  t20_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n243;
  t20_n242: return 0.042327459901571274;
  t20_n243: return 0.09685162454843521;
  t20_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n246;
  t20_n245: return 0.11151184886693954;
  t20_n246: return -0.021423742175102234;
  t20_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t20_n251;
  t20_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t20_n250;
  t20_n249: return 0.08955726027488708;
  t20_n250: return 0.1027236357331276;
  t20_n251: return 0.10389205813407898;
  t20_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t20_n254;
  t20_n253: return 0.10314469784498215;
  t20_n254: return 0.10211843997240067;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree21(const Example& E) {
  t21_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t21_n228;
  t21_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t21_n131;
  t21_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t21_n126;
  t21_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n117;
  t21_n4: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t21_n68;
  t21_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t21_n57;
  t21_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t21_n20;
  t21_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t21_n9;
  t21_n8: return -0.0637674406170845;
  t21_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t21_n11;
  t21_n10: return -0.04174390062689781;
  t21_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n19;
  t21_n12: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t21_n14;
  t21_n13: return 0.09015722572803497;
  t21_n14: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n18;
  t21_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n17;
  t21_n16: return 0.1317012459039688;
  t21_n17: return 0.13253383338451385;
  t21_n18: return -0.16130219399929047;
  t21_n19: return -0.02722049504518509;
  t21_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t21_n22;
  t21_n21: return -0.04842088371515274;
  t21_n22: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t21_n44;
  t21_n23: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t21_n31;
  t21_n24: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t21_n28;
  t21_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t21_n27;
  t21_n26: return -0.004091278649866581;
  t21_n27: return 0.07969820499420166;
  t21_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n30;
  t21_n29: return 0.07513368129730225;
  t21_n30: return 0.08150684088468552;
  t21_n31: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t21_n35;
  t21_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n34;
  t21_n33: return 0.12401089072227478;
  t21_n34: return 0.09698754549026489;
  t21_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t21_n37;
  t21_n36: return 0.13881467282772064;
  t21_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t21_n43;
  t21_n38: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t21_n40;
  t21_n39: return 0.12904152274131775;
  t21_n40: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t21_n42;
  t21_n41: return 0.16046662628650665;
  t21_n42: return -0.13312655687332153;
  t21_n43: return 0.15988294780254364;
  t21_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t21_n48;
  t21_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t21_n47;
  t21_n46: return 0.04440266638994217;
  t21_n47: return 0.09535535424947739;
  t21_n48: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t21_n52;
  t21_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t21_n51;
  t21_n50: return 0.10257643461227417;
  t21_n51: return 0.12461967766284943;
  t21_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n56;
  t21_n53: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t21_n55;
  t21_n54: return 0.13222043216228485;
  t21_n55: return 0.12578855454921722;
  t21_n56: return 0.08953901380300522;
  t21_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t21_n65;
  t21_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n60;
  t21_n59: return -0.09332738071680069;
  t21_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t21_n64;
  t21_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n63;
  t21_n62: return -0.038348350673913956;
  t21_n63: return 0.07887139916419983;
  t21_n64: return 0.010339183732867241;
  t21_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n67;
  t21_n66: return 0.0030118965078145266;
  t21_n67: return 0.0741790384054184;
  t21_n68: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t21_n94;
  t21_n69: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n85;
  t21_n70: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t21_n84;
  t21_n71: if (E.getNumReferences() >= 3354933440 /*127089.5*/) goto t21_n79;
  t21_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t21_n74;
  t21_n73: return 0.013851573690772057;
  t21_n74: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n76;
  t21_n75: return 0.04516209661960602;
  t21_n76: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t21_n78;
  t21_n77: return 0.12156503647565842;
  t21_n78: return 0.09257543087005615;
  t21_n79: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n81;
  t21_n80: return 0.07030769437551498;
  t21_n81: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t21_n83;
  t21_n82: return 0.09221429377794266;
  t21_n83: return 0.10753558576107025;
  t21_n84: return -0.01949804462492466;
  t21_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n89;
  t21_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n88;
  t21_n87: return -0.00038330498500727117;
  t21_n88: return 0.0648307278752327;
  t21_n89: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t21_n91;
  t21_n90: return 0.062046557664871216;
  t21_n91: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t21_n93;
  t21_n92: return 0.13140814006328583;
  t21_n93: return 0.08537527173757553;
  t21_n94: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t21_n112;
  t21_n95: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t21_n111;
  t21_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t21_n98;
  t21_n97: return 0.11489829421043396;
  t21_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t21_n108;
  t21_n99: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t21_n101;
  t21_n100: return 0.13147927820682526;
  t21_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n107;
  t21_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t21_n104;
  t21_n103: return 0.13375723361968994;
  t21_n104: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t21_n106;
  t21_n105: return 0.14942072331905365;
  t21_n106: return 0.1555061787366867;
  t21_n107: return 0.09745560586452484;
  t21_n108: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t21_n110;
  t21_n109: return 0.15713223814964294;
  t21_n110: return 0.1607862412929535;
  t21_n111: return 0.12001683562994003;
  t21_n112: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t21_n114;
  t21_n113: return 0.07633835077285767;
  t21_n114: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t21_n116;
  t21_n115: return 0.08083406835794449;
  t21_n116: return 0.09565266966819763;
  t21_n117: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t21_n119;
  t21_n118: return 0.03863409161567688;
  t21_n119: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t21_n123;
  t21_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t21_n122;
  t21_n121: return 0.05635671690106392;
  t21_n122: return 0.09324062615633011;
  t21_n123: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t21_n125;
  t21_n124: return 0.10852286964654922;
  t21_n125: return -0.15606990456581116;
  t21_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t21_n128;
  t21_n127: return 0.054902780801057816;
  t21_n128: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t21_n130;
  t21_n129: return 0.09052251279354095;
  t21_n130: return 0.10139475017786026;
  t21_n131: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t21_n181;
  t21_n132: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t21_n168;
  t21_n133: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t21_n155;
  t21_n134: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n144;
  t21_n135: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t21_n137;
  t21_n136: return 0.024295581504702568;
  t21_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t21_n139;
  t21_n138: return 0.06562107056379318;
  t21_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n141;
  t21_n140: return 0.010576224885880947;
  t21_n141: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t21_n143;
  t21_n142: return 0.09944246709346771;
  t21_n143: return 0.1133391484618187;
  t21_n144: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t21_n146;
  t21_n145: return 0.10058087110519409;
  t21_n146: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t21_n148;
  t21_n147: return 0.10518155992031097;
  t21_n148: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t21_n154;
  t21_n149: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t21_n153;
  t21_n150: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t21_n152;
  t21_n151: return 0.07950989902019501;
  t21_n152: return 0.14054948091506958;
  t21_n153: return 0.1316937357187271;
  t21_n154: return 0.12374350428581238;
  t21_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t21_n157;
  t21_n156: return -0.012066377326846123;
  t21_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n159;
  t21_n158: return 0.043897777795791626;
  t21_n159: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t21_n161;
  t21_n160: return 0.05360548943281174;
  t21_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n163;
  t21_n162: return 0.10615114122629166;
  t21_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n167;
  t21_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n166;
  t21_n165: return 0.11573851108551025;
  t21_n166: return 0.10717818140983582;
  t21_n167: return 0.09254322201013565;
  t21_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n174;
  t21_n169: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t21_n173;
  t21_n170: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n172;
  t21_n171: return 0.04275349900126457;
  t21_n172: return 0.08913807570934296;
  t21_n173: return 0.0736815333366394;
  t21_n174: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t21_n176;
  t21_n175: return 0.07916736602783203;
  t21_n176: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t21_n180;
  t21_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n179;
  t21_n178: return 0.11209819465875626;
  t21_n179: return 0.11317616701126099;
  t21_n180: return 0.08438151329755783;
  t21_n181: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t21_n227;
  t21_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n206;
  t21_n183: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n199;
  t21_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t21_n186;
  t21_n185: return 0.04669920355081558;
  t21_n186: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t21_n198;
  t21_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t21_n189;
  t21_n188: return -0.11545996367931366;
  t21_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n191;
  t21_n190: return 0.0834159106016159;
  t21_n191: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t21_n193;
  t21_n192: return 0.06066546216607094;
  t21_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n197;
  t21_n194: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t21_n196;
  t21_n195: return 0.11389999091625214;
  t21_n196: return 0.09542833268642426;
  t21_n197: return 0.06279809027910233;
  t21_n198: return -0.09391489624977112;
  t21_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n201;
  t21_n200: return 0.05747269466519356;
  t21_n201: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t21_n205;
  t21_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n204;
  t21_n203: return 0.08465512841939926;
  t21_n204: return 0.07489856332540512;
  t21_n205: return 0.1146414503455162;
  t21_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t21_n212;
  t21_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t21_n209;
  t21_n208: return 0.05867448076605797;
  t21_n209: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t21_n211;
  t21_n210: return 0.07906220108270645;
  t21_n211: return 0.10698077827692032;
  t21_n212: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n226;
  t21_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n223;
  t21_n214: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t21_n216;
  t21_n215: return 0.07148497551679611;
  t21_n216: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t21_n222;
  t21_n217: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t21_n221;
  t21_n218: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t21_n220;
  t21_n219: return 0.11456239223480225;
  t21_n220: return -0.016337504610419273;
  t21_n221: return 0.1100461483001709;
  t21_n222: return 0.08414001762866974;
  t21_n223: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n225;
  t21_n224: return 0.10954972356557846;
  t21_n225: return 0.10943955183029175;
  t21_n226: return 0.05786583572626114;
  t21_n227: return -0.07162168622016907;
  t21_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t21_n242;
  t21_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t21_n233;
  t21_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n232;
  t21_n231: return 0.040314577519893646;
  t21_n232: return 0.07652152329683304;
  t21_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t21_n241;
  t21_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n238;
  t21_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t21_n237;
  t21_n236: return 0.07177077233791351;
  t21_n237: return 0.08507171273231506;
  t21_n238: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t21_n240;
  t21_n239: return 0.09047505259513855;
  t21_n240: return 0.08437895029783249;
  t21_n241: return 0.07482842355966568;
  t21_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t21_n252;
  t21_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t21_n247;
  t21_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t21_n246;
  t21_n245: return 0.03903985023498535;
  t21_n246: return 0.09586634486913681;
  t21_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t21_n251;
  t21_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t21_n250;
  t21_n249: return 0.08556656539440155;
  t21_n250: return 0.10212759673595428;
  t21_n251: return 0.10329724848270416;
  t21_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t21_n254;
  t21_n253: return 0.10267733782529831;
  t21_n254: return 0.10194625705480576;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree22(const Example& E) {
  t22_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t22_n228;
  t22_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t22_n97;
  t22_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t22_n92;
  t22_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n75;
  t22_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t22_n72;
  t22_n5: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t22_n23;
  t22_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n8;
  t22_n7: return -0.04521164298057556;
  t22_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n10;
  t22_n9: return 0.014125242829322815;
  t22_n10: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t22_n22;
  t22_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n19;
  t22_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n14;
  t22_n13: return -0.12007568031549454;
  t22_n14: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t22_n16;
  t22_n15: return 0.06044100970029831;
  t22_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t22_n18;
  t22_n17: return 0.05975402519106865;
  t22_n18: return 0.08696945756673813;
  t22_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n21;
  t22_n20: return 0.08984199166297913;
  t22_n21: return 0.05108078196644783;
  t22_n22: return -0.12327039986848831;
  t22_n23: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t22_n47;
  t22_n24: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n42;
  t22_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n33;
  t22_n26: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t22_n28;
  t22_n27: return 0.03241107985377312;
  t22_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n30;
  t22_n29: return 0.07171054184436798;
  t22_n30: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t22_n32;
  t22_n31: return 0.09304501861333847;
  t22_n32: return 0.105484239757061;
  t22_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n35;
  t22_n34: return 0.052515801042318344;
  t22_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t22_n41;
  t22_n36: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t22_n40;
  t22_n37: if (E.getNumReferences() >= 3302604800 /*1742.0*/) goto t22_n39;
  t22_n38: return 0.08699925243854523;
  t22_n39: return 0.10272364318370819;
  t22_n40: return 0.11197648197412491;
  t22_n41: return 0.07986811548471451;
  t22_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n44;
  t22_n43: return -0.002336851553991437;
  t22_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n46;
  t22_n45: return -0.05142727121710777;
  t22_n46: return 0.07428868860006332;
  t22_n47: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t22_n57;
  t22_n48: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t22_n56;
  t22_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t22_n51;
  t22_n50: return 0.10515067726373672;
  t22_n51: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t22_n53;
  t22_n52: return 0.14194530248641968;
  t22_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t22_n55;
  t22_n54: return 0.1285526156425476;
  t22_n55: return 0.14650051295757294;
  t22_n56: return 0.10948926955461502;
  t22_n57: if (E.getNumReferences() >= 3308660736 /*2914.5*/) goto t22_n69;
  t22_n58: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n68;
  t22_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t22_n61;
  t22_n60: return 0.11238603293895721;
  t22_n61: if (E.getNumReferences() >= 3276242944 /*199.5*/) goto t22_n65;
  t22_n62: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t22_n64;
  t22_n63: return 0.14315468072891235;
  t22_n64: return 0.14810633659362793;
  t22_n65: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t22_n67;
  t22_n66: return 0.11739278584718704;
  t22_n67: return 0.13046082854270935;
  t22_n68: return 0.06714363396167755;
  t22_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t22_n71;
  t22_n70: return 0.090487040579319;
  t22_n71: return 0.09604073315858841;
  t22_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t22_n74;
  t22_n73: return -0.09322939813137054;
  t22_n74: return -0.07009044289588928;
  t22_n75: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t22_n89;
  t22_n76: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t22_n80;
  t22_n77: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n79;
  t22_n78: return 0.035518746823072433;
  t22_n79: return 0.05645189806818962;
  t22_n80: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t22_n82;
  t22_n81: return 0.05552844703197479;
  t22_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t22_n84;
  t22_n83: return 0.05218341201543808;
  t22_n84: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t22_n86;
  t22_n85: return 0.13455405831336975;
  t22_n86: if (E.getNumReferences() >= 3309828096 /*3199.5*/) goto t22_n88;
  t22_n87: return 0.09905225038528442;
  t22_n88: return 0.09883066266775131;
  t22_n89: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t22_n91;
  t22_n90: return 0.10744518041610718;
  t22_n91: return -0.15405236184597015;
  t22_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t22_n94;
  t22_n93: return 0.05086821690201759;
  t22_n94: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t22_n96;
  t22_n95: return 0.08856385946273804;
  t22_n96: return 0.10102096945047379;
  t22_n97: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t22_n185;
  t22_n98: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t22_n162;
  t22_n99: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t22_n125;
  t22_n100: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n114;
  t22_n101: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t22_n103;
  t22_n102: return 0.023331349715590477;
  t22_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t22_n109;
  t22_n104: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n106;
  t22_n105: return 0.061724115163087845;
  t22_n106: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t22_n108;
  t22_n107: return 0.09889163076877594;
  t22_n108: return 0.12537674605846405;
  t22_n109: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t22_n111;
  t22_n110: return 0.09102116525173187;
  t22_n111: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n113;
  t22_n112: return 0.1166694238781929;
  t22_n113: return 0.10433409363031387;
  t22_n114: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t22_n116;
  t22_n115: return 0.09792731702327728;
  t22_n116: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t22_n118;
  t22_n117: return 0.1060355007648468;
  t22_n118: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t22_n124;
  t22_n119: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t22_n123;
  t22_n120: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t22_n122;
  t22_n121: return 0.07620657980442047;
  t22_n122: return 0.137957364320755;
  t22_n123: return 0.12857386469841003;
  t22_n124: return 0.11971444636583328;
  t22_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t22_n151;
  t22_n126: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n140;
  t22_n127: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t22_n129;
  t22_n128: return -0.03722847253084183;
  t22_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t22_n135;
  t22_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t22_n132;
  t22_n131: return 0.04914555698633194;
  t22_n132: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t22_n134;
  t22_n133: return 0.13501620292663574;
  t22_n134: return 0.09686993807554245;
  t22_n135: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n137;
  t22_n136: return 0.009274082258343697;
  t22_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t22_n139;
  t22_n138: return 0.09701956808567047;
  t22_n139: return 0.12201515585184097;
  t22_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n142;
  t22_n141: return -0.09809672832489014;
  t22_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t22_n146;
  t22_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n145;
  t22_n144: return 0.04865065589547157;
  t22_n145: return 0.0788327008485794;
  t22_n146: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t22_n150;
  t22_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n149;
  t22_n148: return 0.09272085875272751;
  t22_n149: return 0.0718664601445198;
  t22_n150: return -0.1320115476846695;
  t22_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n153;
  t22_n152: return 0.040096551179885864;
  t22_n153: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t22_n155;
  t22_n154: return 0.04908088594675064;
  t22_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n157;
  t22_n156: return 0.10109912604093552;
  t22_n157: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n161;
  t22_n158: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n160;
  t22_n159: return 0.11371567845344543;
  t22_n160: return 0.10599197447299957;
  t22_n161: return 0.08749158680438995;
  t22_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n168;
  t22_n163: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t22_n167;
  t22_n164: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n166;
  t22_n165: return 0.040991950780153275;
  t22_n166: return 0.09672246128320694;
  t22_n167: return 0.07129731774330139;
  t22_n168: if (E.getNumReferences() >= 3361394368 /*224059.0*/) goto t22_n180;
  t22_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n171;
  t22_n170: return 0.06220857799053192;
  t22_n171: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t22_n173;
  t22_n172: return 0.07652159035205841;
  t22_n173: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t22_n179;
  t22_n174: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t22_n176;
  t22_n175: return 0.10936254262924194;
  t22_n176: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t22_n178;
  t22_n177: return 0.12418550997972488;
  t22_n178: return 0.10870133340358734;
  t22_n179: return 0.08530250936746597;
  t22_n180: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t22_n184;
  t22_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n183;
  t22_n182: return 0.11119940876960754;
  t22_n183: return 0.11250545084476471;
  t22_n184: return 0.08244796097278595;
  t22_n185: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t22_n227;
  t22_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n210;
  t22_n187: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n201;
  t22_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t22_n190;
  t22_n189: return 0.043488435447216034;
  t22_n190: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t22_n200;
  t22_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t22_n193;
  t22_n192: return -0.11391264945268631;
  t22_n193: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t22_n195;
  t22_n194: return 0.05983489751815796;
  t22_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t22_n199;
  t22_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n198;
  t22_n197: return 0.052188217639923096;
  t22_n198: return 0.08017999678850174;
  t22_n199: return 0.09964317828416824;
  t22_n200: return -0.08470036089420319;
  t22_n201: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n203;
  t22_n202: return 0.05481072515249252;
  t22_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n205;
  t22_n204: return 0.08337461203336716;
  t22_n205: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t22_n207;
  t22_n206: return 0.0726684182882309;
  t22_n207: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t22_n209;
  t22_n208: return 0.10822884738445282;
  t22_n209: return 0.12369024753570557;
  t22_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t22_n214;
  t22_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n213;
  t22_n212: return 0.07813972234725952;
  t22_n213: return -0.0462191142141819;
  t22_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n226;
  t22_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n223;
  t22_n216: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t22_n218;
  t22_n217: return 0.06743642687797546;
  t22_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t22_n222;
  t22_n219: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t22_n221;
  t22_n220: return 0.10931980609893799;
  t22_n221: return 0.10747617483139038;
  t22_n222: return 0.07936207950115204;
  t22_n223: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n225;
  t22_n224: return 0.10656165331602097;
  t22_n225: return 0.10781911015510559;
  t22_n226: return 0.05057692527770996;
  t22_n227: return -0.06849317252635956;
  t22_n228: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t22_n242;
  t22_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t22_n233;
  t22_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n232;
  t22_n231: return 0.03649128973484039;
  t22_n232: return 0.07353859394788742;
  t22_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t22_n241;
  t22_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n238;
  t22_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t22_n237;
  t22_n236: return 0.068202443420887;
  t22_n237: return 0.08225443959236145;
  t22_n238: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t22_n240;
  t22_n239: return 0.08868706971406937;
  t22_n240: return 0.08317942172288895;
  t22_n241: return 0.07203096896409988;
  t22_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t22_n252;
  t22_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t22_n247;
  t22_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t22_n246;
  t22_n245: return 0.04501327499747276;
  t22_n246: return 0.09413398057222366;
  t22_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t22_n251;
  t22_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t22_n250;
  t22_n249: return 0.08418097347021103;
  t22_n250: return 0.10141000151634216;
  t22_n251: return 0.1030830591917038;
  t22_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t22_n254;
  t22_n253: return 0.10221869498491287;
  t22_n254: return 0.10103550553321838;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree23(const Example& E) {
  t23_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t23_n232;
  t23_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t23_n107;
  t23_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t23_n104;
  t23_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n93;
  t23_n4: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t23_n86;
  t23_n5: if (E.getNumReferences() >= 3350479168 /*92290.5*/) goto t23_n61;
  t23_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n10;
  t23_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t23_n9;
  t23_n8: return -0.0670025423169136;
  t23_n9: return -0.04367159679532051;
  t23_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n12;
  t23_n11: return -0.007504863664507866;
  t23_n12: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t23_n44;
  t23_n13: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t23_n21;
  t23_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n16;
  t23_n15: return 0.04749932885169983;
  t23_n16: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t23_n18;
  t23_n17: return 0.0729912742972374;
  t23_n18: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t23_n20;
  t23_n19: return 0.07764342427253723;
  t23_n20: return 0.10017454624176025;
  t23_n21: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t23_n41;
  t23_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t23_n34;
  t23_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t23_n25;
  t23_n24: return -0.00810820609331131;
  t23_n25: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t23_n33;
  t23_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t23_n30;
  t23_n27: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t23_n29;
  t23_n28: return 0.07503074407577515;
  t23_n29: return 0.0973166674375534;
  t23_n30: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t23_n32;
  t23_n31: return 0.08736281841993332;
  t23_n32: return 0.10506746917963028;
  t23_n33: return 0.005731381010264158;
  t23_n34: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t23_n36;
  t23_n35: return 0.03968428075313568;
  t23_n36: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t23_n40;
  t23_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t23_n39;
  t23_n38: return 0.06668933480978012;
  t23_n39: return 0.1021733209490776;
  t23_n40: return 0.034502483904361725;
  t23_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n43;
  t23_n42: return 0.11679862439632416;
  t23_n43: return 0.1278681606054306;
  t23_n44: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t23_n58;
  t23_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t23_n47;
  t23_n46: return 0.09067565202713013;
  t23_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t23_n51;
  t23_n48: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t23_n50;
  t23_n49: return 0.10746051371097565;
  t23_n50: return 0.08371025323867798;
  t23_n51: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t23_n57;
  t23_n52: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t23_n56;
  t23_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t23_n55;
  t23_n54: return 0.11729732155799866;
  t23_n55: return 0.14320144057273865;
  t23_n56: return 0.12095954269170761;
  t23_n57: return 0.12725019454956055;
  t23_n58: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t23_n60;
  t23_n59: return 0.03637876361608505;
  t23_n60: return 0.07318583875894547;
  t23_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n63;
  t23_n62: return 0.05078461021184921;
  t23_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t23_n65;
  t23_n64: return 0.0077086882665753365;
  t23_n65: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t23_n83;
  t23_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n72;
  t23_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n69;
  t23_n68: return 0.068008653819561;
  t23_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n71;
  t23_n70: return 0.09798572957515717;
  t23_n71: return -0.007992702536284924;
  t23_n72: if (E.getNumReferences() >= 3354764736 /*125771.5*/) goto t23_n82;
  t23_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t23_n79;
  t23_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t23_n76;
  t23_n75: return 0.14890994131565094;
  t23_n76: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t23_n78;
  t23_n77: return 0.13075588643550873;
  t23_n78: return -0.16752617061138153;
  t23_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t23_n81;
  t23_n80: return 0.1088843047618866;
  t23_n81: return 0.10011031478643417;
  t23_n82: return 0.10065103322267532;
  t23_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t23_n85;
  t23_n84: return 0.09624484181404114;
  t23_n85: return 0.10401970893144608;
  t23_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n88;
  t23_n87: return -0.06536716222763062;
  t23_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n90;
  t23_n89: return -0.04247163236141205;
  t23_n90: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t23_n92;
  t23_n91: return 0.06530530750751495;
  t23_n92: return -0.10781064629554749;
  t23_n93: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t23_n99;
  t23_n94: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t23_n98;
  t23_n95: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n97;
  t23_n96: return 0.030656760558485985;
  t23_n97: return 0.05634601414203644;
  t23_n98: return 0.06095041707158089;
  t23_n99: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t23_n103;
  t23_n100: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t23_n102;
  t23_n101: return 0.0921257734298706;
  t23_n102: return 0.11488429456949234;
  t23_n103: return 0.082788847386837;
  t23_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t23_n106;
  t23_n105: return 0.04653044790029526;
  t23_n106: return 0.09603098034858704;
  t23_n107: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t23_n193;
  t23_n108: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t23_n158;
  t23_n109: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t23_n135;
  t23_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n126;
  t23_n111: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t23_n113;
  t23_n112: return 0.02209080196917057;
  t23_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t23_n115;
  t23_n114: return 0.0642714872956276;
  t23_n115: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t23_n117;
  t23_n116: return 0.0909452959895134;
  t23_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t23_n119;
  t23_n118: return 0.12030066549777985;
  t23_n119: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t23_n121;
  t23_n120: return 0.1302683800458908;
  t23_n121: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t23_n125;
  t23_n122: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t23_n124;
  t23_n123: return 0.07886702567338943;
  t23_n124: return 0.1358511745929718;
  t23_n125: return 0.1718037873506546;
  t23_n126: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t23_n130;
  t23_n127: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t23_n129;
  t23_n128: return 0.09571295231580734;
  t23_n129: return 0.10088285058736801;
  t23_n130: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t23_n132;
  t23_n131: return -0.14675216376781464;
  t23_n132: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t23_n134;
  t23_n133: return 0.12025311589241028;
  t23_n134: return 0.15285837650299072;
  t23_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t23_n147;
  t23_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n138;
  t23_n137: return -0.03379612788558006;
  t23_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n140;
  t23_n139: return -0.09711913764476776;
  t23_n140: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t23_n144;
  t23_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t23_n143;
  t23_n142: return 0.06889687478542328;
  t23_n143: return 0.08142505586147308;
  t23_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t23_n146;
  t23_n145: return -0.12314438074827194;
  t23_n146: return 0.04939870536327362;
  t23_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t23_n149;
  t23_n148: return 0.040415145456790924;
  t23_n149: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t23_n151;
  t23_n150: return 0.04732656851410866;
  t23_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t23_n153;
  t23_n152: return 0.09690593928098679;
  t23_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n157;
  t23_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n156;
  t23_n155: return 0.11192294955253601;
  t23_n156: return 0.10326255857944489;
  t23_n157: return 0.08229685574769974;
  t23_n158: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t23_n178;
  t23_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n163;
  t23_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n162;
  t23_n161: return 0.040678057819604874;
  t23_n162: return 0.10093683004379272;
  t23_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t23_n169;
  t23_n164: if (E.getNumReferences() >= 3342741376 /*48687.5*/) goto t23_n166;
  t23_n165: return 0.08897099643945694;
  t23_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n168;
  t23_n167: return 0.09720822423696518;
  t23_n168: return -0.027462609112262726;
  t23_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n171;
  t23_n170: return 0.061774082481861115;
  t23_n171: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t23_n177;
  t23_n172: if (E.getNumReferences() >= 3281469440 /*302.5*/) goto t23_n176;
  t23_n173: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t23_n175;
  t23_n174: return 0.08478084951639175;
  t23_n175: return 0.1251426339149475;
  t23_n176: return 0.07488584518432617;
  t23_n177: return 0.11764760315418243;
  t23_n178: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t23_n190;
  t23_n179: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n189;
  t23_n180: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t23_n184;
  t23_n181: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t23_n183;
  t23_n182: return 0.021210720762610435;
  t23_n183: return 0.08484400063753128;
  t23_n184: if (E.getNumReferences() >= 3290931200 /*670.5*/) goto t23_n186;
  t23_n185: return 0.10607680678367615;
  t23_n186: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t23_n188;
  t23_n187: return 0.11376242339611053;
  t23_n188: return 0.09373289346694946;
  t23_n189: return 0.09723813831806183;
  t23_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t23_n192;
  t23_n191: return 0.06723029166460037;
  t23_n192: return 0.09830570966005325;
  t23_n193: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n195;
  t23_n194: return -0.11481451988220215;
  t23_n195: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n229;
  t23_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t23_n216;
  t23_n197: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n215;
  t23_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t23_n200;
  t23_n199: return 0.045046061277389526;
  t23_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t23_n202;
  t23_n201: return 0.06082760542631149;
  t23_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n212;
  t23_n203: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t23_n205;
  t23_n204: return 0.06440615653991699;
  t23_n205: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t23_n211;
  t23_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t23_n210;
  t23_n207: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t23_n209;
  t23_n208: return 0.10648705810308456;
  t23_n209: return -0.044152867048978806;
  t23_n210: return 0.10545133054256439;
  t23_n211: return -0.0684368759393692;
  t23_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n214;
  t23_n213: return 0.10332600027322769;
  t23_n214: return 0.10394494235515594;
  t23_n215: return 0.027821049094200134;
  t23_n216: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t23_n222;
  t23_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t23_n219;
  t23_n218: return 0.04733862355351448;
  t23_n219: if (E.getNumReferences() >= 3339137920 /*34611.5*/) goto t23_n221;
  t23_n220: return 0.07448448240756989;
  t23_n221: return 0.10401178896427155;
  t23_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t23_n226;
  t23_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n225;
  t23_n224: return 0.048937972635030746;
  t23_n225: return 0.0768369808793068;
  t23_n226: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t23_n228;
  t23_n227: return 0.10333514213562012;
  t23_n228: return 0.059964071959257126;
  t23_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t23_n231;
  t23_n230: return 0.047398027032613754;
  t23_n231: return 0.07459260523319244;
  t23_n232: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t23_n244;
  t23_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t23_n237;
  t23_n234: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n236;
  t23_n235: return 0.03577946871519089;
  t23_n236: return 0.07023951411247253;
  t23_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t23_n243;
  t23_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n242;
  t23_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t23_n241;
  t23_n240: return 0.06545548141002655;
  t23_n241: return 0.08028707653284073;
  t23_n242: return 0.08669762313365936;
  t23_n243: return 0.06957267224788666;
  t23_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t23_n252;
  t23_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t23_n249;
  t23_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t23_n248;
  t23_n247: return 0.03744826838374138;
  t23_n248: return 0.09255963563919067;
  t23_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t23_n251;
  t23_n250: return 0.10018783807754517;
  t23_n251: return 0.10235167294740677;
  t23_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t23_n254;
  t23_n253: return 0.10150332003831863;
  t23_n254: return 0.10074210911989212;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree24(const Example& E) {
  t24_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t24_n234;
  t24_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t24_n105;
  t24_n2: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t24_n102;
  t24_n3: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t24_n61;
  t24_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t24_n26;
  t24_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n7;
  t24_n6: return -0.08898825943470001;
  t24_n7: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t24_n25;
  t24_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t24_n22;
  t24_n9: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t24_n11;
  t24_n10: return -0.016563281416893005;
  t24_n11: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t24_n13;
  t24_n12: return 0.05841028690338135;
  t24_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n21;
  t24_n14: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t24_n16;
  t24_n15: return 0.10796554386615753;
  t24_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t24_n18;
  t24_n17: return 0.06932752579450607;
  t24_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n20;
  t24_n19: return 0.13711702823638916;
  t24_n20: return 0.12914560735225677;
  t24_n21: return 0.10033559054136276;
  t24_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t24_n24;
  t24_n23: return 0.08828029781579971;
  t24_n24: return 0.10053598135709763;
  t24_n25: return -0.07979728281497955;
  t24_n26: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t24_n60;
  t24_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n29;
  t24_n28: return 0.013146830722689629;
  t24_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t24_n47;
  t24_n30: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t24_n46;
  t24_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t24_n33;
  t24_n32: return 0.03803709149360657;
  t24_n33: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t24_n35;
  t24_n34: return 0.04975070804357529;
  t24_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t24_n45;
  t24_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n38;
  t24_n37: return 0.06198708340525627;
  t24_n38: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n40;
  t24_n39: return 0.014219434931874275;
  t24_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n44;
  t24_n41: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t24_n43;
  t24_n42: return 0.19257663190364838;
  t24_n43: return 0.14516116678714752;
  t24_n44: return -0.050409648567438126;
  t24_n45: return 0.06801265478134155;
  t24_n46: return 0.08109802007675171;
  t24_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t24_n49;
  t24_n48: return 0.04121699184179306;
  t24_n49: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t24_n59;
  t24_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n58;
  t24_n51: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t24_n57;
  t24_n52: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t24_n54;
  t24_n53: return 0.08308743685483932;
  t24_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t24_n56;
  t24_n55: return 0.07489126920700073;
  t24_n56: return 0.09987715631723404;
  t24_n57: return 0.10336194187402725;
  t24_n58: return -0.009202755987644196;
  t24_n59: return 0.051436856389045715;
  t24_n60: return -0.02371092699468136;
  t24_n61: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t24_n85;
  t24_n62: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n82;
  t24_n63: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t24_n77;
  t24_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n66;
  t24_n65: return 0.02700420282781124;
  t24_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n68;
  t24_n67: return 0.0485927052795887;
  t24_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t24_n70;
  t24_n69: return 0.10177362710237503;
  t24_n70: if (E.getNumReferences() >= 3288547328 /*525.0*/) goto t24_n72;
  t24_n71: return 0.11534357070922852;
  t24_n72: if (E.getNumReferences() >= 3289890816 /*607.0*/) goto t24_n76;
  t24_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t24_n75;
  t24_n74: return 0.13508744537830353;
  t24_n75: return 0.13379782438278198;
  t24_n76: return 0.11397166550159454;
  t24_n77: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n79;
  t24_n78: return 0.08018286526203156;
  t24_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n81;
  t24_n80: return 0.10714451223611832;
  t24_n81: return 0.12361838668584824;
  t24_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n84;
  t24_n83: return -0.005363681819289923;
  t24_n84: return 0.05666632205247879;
  t24_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t24_n97;
  t24_n86: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t24_n96;
  t24_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t24_n89;
  t24_n88: return 0.09834462404251099;
  t24_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t24_n93;
  t24_n90: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t24_n92;
  t24_n91: return 0.13782206177711487;
  t24_n92: return 0.11919205635786057;
  t24_n93: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t24_n95;
  t24_n94: return 0.13928453624248505;
  t24_n95: return 0.14540995657444;
  t24_n96: return 0.11259087920188904;
  t24_n97: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t24_n99;
  t24_n98: return 0.06952771544456482;
  t24_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t24_n101;
  t24_n100: return 0.0775487944483757;
  t24_n101: return 0.09234050661325455;
  t24_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n104;
  t24_n103: return 0.04296475276350975;
  t24_n104: return 0.09454330056905746;
  t24_n105: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n199;
  t24_n106: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t24_n170;
  t24_n107: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t24_n159;
  t24_n108: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n110;
  t24_n109: return -0.02048930712044239;
  t24_n110: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t24_n156;
  t24_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t24_n135;
  t24_n112: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t24_n126;
  t24_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t24_n115;
  t24_n114: return 0.03339335322380066;
  t24_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t24_n117;
  t24_n116: return 0.06158693507313728;
  t24_n117: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t24_n119;
  t24_n118: return 0.04026748985052109;
  t24_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t24_n121;
  t24_n120: return 0.09177011251449585;
  t24_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n125;
  t24_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n124;
  t24_n123: return 0.10985642671585083;
  t24_n124: return 0.09988368302583694;
  t24_n125: return 0.07810868322849274;
  t24_n126: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n132;
  t24_n127: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t24_n129;
  t24_n128: return 0.083390973508358;
  t24_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t24_n131;
  t24_n130: return 0.11016308516263962;
  t24_n131: return 0.12278363108634949;
  t24_n132: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t24_n134;
  t24_n133: return -3.087921504629776e-05;
  t24_n134: return 0.09010626375675201;
  t24_n135: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t24_n137;
  t24_n136: return 0.07815537601709366;
  t24_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n139;
  t24_n138: return 0.020399127155542374;
  t24_n139: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t24_n153;
  t24_n140: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t24_n148;
  t24_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t24_n143;
  t24_n142: return 0.09614239633083344;
  t24_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n147;
  t24_n144: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t24_n146;
  t24_n145: return 0.12703804671764374;
  t24_n146: return 0.1265375316143036;
  t24_n147: return 0.09174419194459915;
  t24_n148: if (E.getNumReferences() >= 3275784192 /*192.5*/) goto t24_n152;
  t24_n149: if (E.getNumReferences() >= 3275096064 /*182.0*/) goto t24_n151;
  t24_n150: return 0.12119748443365097;
  t24_n151: return 0.12632471323013306;
  t24_n152: return 0.11633560061454773;
  t24_n153: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n155;
  t24_n154: return 0.12225674837827682;
  t24_n155: return 0.0964503362774849;
  t24_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t24_n158;
  t24_n157: return -0.018611766397953033;
  t24_n158: return 0.04718386381864548;
  t24_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t24_n163;
  t24_n160: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t24_n162;
  t24_n161: return 0.035464879125356674;
  t24_n162: return 0.0640779361128807;
  t24_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n165;
  t24_n164: return 0.03740580752491951;
  t24_n165: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t24_n167;
  t24_n166: return 0.07280068844556808;
  t24_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n169;
  t24_n168: return 0.09452009201049805;
  t24_n169: return -0.0019600028172135353;
  t24_n170: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t24_n198;
  t24_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t24_n181;
  t24_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t24_n174;
  t24_n173: return 0.03610789403319359;
  t24_n174: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t24_n178;
  t24_n175: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n177;
  t24_n176: return -0.053355827927589417;
  t24_n177: return 0.060116298496723175;
  t24_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t24_n180;
  t24_n179: return 0.06453591585159302;
  t24_n180: return 0.09586746245622635;
  t24_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t24_n185;
  t24_n182: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n184;
  t24_n183: return 0.07233692705631256;
  t24_n184: return -0.042264241725206375;
  t24_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n197;
  t24_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n194;
  t24_n187: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t24_n189;
  t24_n188: return 0.05925663560628891;
  t24_n189: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n193;
  t24_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t24_n192;
  t24_n191: return 0.10186795890331268;
  t24_n192: return 0.10303256660699844;
  t24_n193: return 0.07281392812728882;
  t24_n194: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n196;
  t24_n195: return 0.09934757649898529;
  t24_n196: return 0.10123523324728012;
  t24_n197: return 0.0478086955845356;
  t24_n198: return -0.08318805694580078;
  t24_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t24_n227;
  t24_n200: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t24_n220;
  t24_n201: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t24_n217;
  t24_n202: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t24_n204;
  t24_n203: return 0.0953967496752739;
  t24_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t24_n206;
  t24_n205: return 0.08693362772464752;
  t24_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n208;
  t24_n207: return 0.12883447110652924;
  t24_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n210;
  t24_n209: return 0.12550878524780273;
  t24_n210: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t24_n212;
  t24_n211: return 0.08172253519296646;
  t24_n212: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t24_n216;
  t24_n213: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t24_n215;
  t24_n214: return 0.12283647060394287;
  t24_n215: return 0.13682134449481964;
  t24_n216: return 0.11658955365419388;
  t24_n217: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t24_n219;
  t24_n218: return 0.055241625756025314;
  t24_n219: return 0.04951534792780876;
  t24_n220: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t24_n226;
  t24_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t24_n223;
  t24_n222: return 0.08542577177286148;
  t24_n223: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t24_n225;
  t24_n224: return 0.1191733330488205;
  t24_n225: return 0.12775008380413055;
  t24_n226: return 0.09852899610996246;
  t24_n227: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t24_n231;
  t24_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n230;
  t24_n229: return 0.07449112832546234;
  t24_n230: return 0.06461283564567566;
  t24_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t24_n233;
  t24_n232: return -0.14111103117465973;
  t24_n233: return 0.11162705719470978;
  t24_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t24_n244;
  t24_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t24_n239;
  t24_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n238;
  t24_n237: return 0.03161162883043289;
  t24_n238: return 0.06761990487575531;
  t24_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t24_n243;
  t24_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n242;
  t24_n241: return 0.07330860942602158;
  t24_n242: return 0.08467020094394684;
  t24_n243: return 0.06621427834033966;
  t24_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t24_n252;
  t24_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t24_n249;
  t24_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t24_n248;
  t24_n247: return 0.03814175724983215;
  t24_n248: return 0.09134194999933243;
  t24_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t24_n251;
  t24_n250: return 0.09978199005126953;
  t24_n251: return 0.10179370641708374;
  t24_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t24_n254;
  t24_n253: return 0.10085102915763855;
  t24_n254: return 0.09998769313097;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree25(const Example& E) {
  t25_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t25_n236;
  t25_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t25_n139;
  t25_n2: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t25_n98;
  t25_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n93;
  t25_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t25_n82;
  t25_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t25_n7;
  t25_n6: return -0.03690199553966522;
  t25_n7: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t25_n51;
  t25_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t25_n14;
  t25_n9: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t25_n13;
  t25_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t25_n12;
  t25_n11: return 0.0061548990197479725;
  t25_n12: return 0.05696645379066467;
  t25_n13: return -0.027868865057826042;
  t25_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t25_n30;
  t25_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t25_n17;
  t25_n16: return -0.012633911333978176;
  t25_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n19;
  t25_n18: return 0.022943994030356407;
  t25_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t25_n21;
  t25_n20: return 0.058626383543014526;
  t25_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t25_n27;
  t25_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n26;
  t25_n23: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t25_n25;
  t25_n24: return 0.1283687800168991;
  t25_n25: return 0.11855170875787735;
  t25_n26: return 0.08548422157764435;
  t25_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n29;
  t25_n28: return 0.146471306681633;
  t25_n29: return 0.1021866574883461;
  t25_n30: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t25_n34;
  t25_n31: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t25_n33;
  t25_n32: return 0.0749087855219841;
  t25_n33: return -0.14742225408554077;
  t25_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t25_n38;
  t25_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n37;
  t25_n36: return -0.16079933941364288;
  t25_n37: return 0.09328688681125641;
  t25_n38: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t25_n50;
  t25_n39: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n49;
  t25_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t25_n48;
  t25_n41: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t25_n45;
  t25_n42: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n44;
  t25_n43: return 0.12928442656993866;
  t25_n44: return 0.12612298130989075;
  t25_n45: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t25_n47;
  t25_n46: return 0.010157212615013123;
  t25_n47: return 0.12490243464708328;
  t25_n48: return 0.12114982306957245;
  t25_n49: return 0.08714230358600616;
  t25_n50: return -0.10186692327260971;
  t25_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n63;
  t25_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t25_n54;
  t25_n53: return 0.030240565538406372;
  t25_n54: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t25_n56;
  t25_n55: return 0.11595530062913895;
  t25_n56: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t25_n58;
  t25_n57: return 0.1250377595424652;
  t25_n58: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t25_n62;
  t25_n59: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t25_n61;
  t25_n60: return 0.13563720881938934;
  t25_n61: return 0.07475613802671432;
  t25_n62: return 0.14688166975975037;
  t25_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t25_n67;
  t25_n64: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t25_n66;
  t25_n65: return 0.08852090686559677;
  t25_n66: return 0.0983005240559578;
  t25_n67: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t25_n71;
  t25_n68: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t25_n70;
  t25_n69: return 0.11016272753477097;
  t25_n70: return 0.11654260754585266;
  t25_n71: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t25_n79;
  t25_n72: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t25_n74;
  t25_n73: return 0.12736129760742188;
  t25_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t25_n78;
  t25_n75: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t25_n77;
  t25_n76: return 0.13435092568397522;
  t25_n77: return 0.08711062371730804;
  t25_n78: return 0.12021595984697342;
  t25_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t25_n81;
  t25_n80: return 0.09724607318639755;
  t25_n81: return 0.14048387110233307;
  t25_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t25_n88;
  t25_n83: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n85;
  t25_n84: return -0.07258697599172592;
  t25_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t25_n87;
  t25_n86: return 0.02026878297328949;
  t25_n87: return 0.06009600684046745;
  t25_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t25_n90;
  t25_n89: return 0.0026062980759888887;
  t25_n90: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t25_n92;
  t25_n91: return 0.08895762264728546;
  t25_n92: return 0.05852504447102547;
  t25_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n97;
  t25_n94: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t25_n96;
  t25_n95: return 0.032874103635549545;
  t25_n96: return 0.05743447318673134;
  t25_n97: return 0.05575476959347725;
  t25_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t25_n108;
  t25_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t25_n105;
  t25_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n104;
  t25_n101: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n103;
  t25_n102: return 0.04717090353369713;
  t25_n103: return 0.09327362477779388;
  t25_n104: return 0.08898892253637314;
  t25_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n107;
  t25_n106: return -0.010259861126542091;
  t25_n107: return 0.0645832046866417;
  t25_n108: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t25_n136;
  t25_n109: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t25_n135;
  t25_n110: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t25_n134;
  t25_n111: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t25_n125;
  t25_n112: if (E.getNumReferences() >= 3356822208 /*152619.0*/) goto t25_n124;
  t25_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t25_n115;
  t25_n114: return 0.0654779002070427;
  t25_n115: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t25_n121;
  t25_n116: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n120;
  t25_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t25_n119;
  t25_n118: return -0.334852397441864;
  t25_n119: return 0.10761624574661255;
  t25_n120: return 0.09377473592758179;
  t25_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t25_n123;
  t25_n122: return 0.032746024429798126;
  t25_n123: return 0.09606136381626129;
  t25_n124: return -0.07916650176048279;
  t25_n125: if (E.getNumReferences() >= 3360630592 /*212125.0*/) goto t25_n133;
  t25_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t25_n128;
  t25_n127: return 0.10178090631961823;
  t25_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t25_n130;
  t25_n129: return 0.01975713111460209;
  t25_n130: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n132;
  t25_n131: return 0.11206359416246414;
  t25_n132: return 0.11374465376138687;
  t25_n133: return 0.06619451940059662;
  t25_n134: return -0.058774322271347046;
  t25_n135: return 0.09961261600255966;
  t25_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t25_n138;
  t25_n137: return 0.08585544675588608;
  t25_n138: return 0.09133344888687134;
  t25_n139: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n215;
  t25_n140: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t25_n186;
  t25_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n147;
  t25_n142: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t25_n144;
  t25_n143: return -0.020343076437711716;
  t25_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n146;
  t25_n145: return 0.027253063395619392;
  t25_n146: return 0.11778703331947327;
  t25_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t25_n155;
  t25_n148: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t25_n150;
  t25_n149: return 0.0013152218889445066;
  t25_n150: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t25_n152;
  t25_n151: return 0.047136612236499786;
  t25_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n154;
  t25_n153: return 0.021842539310455322;
  t25_n154: return 0.06967971473932266;
  t25_n155: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t25_n185;
  t25_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t25_n170;
  t25_n157: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t25_n161;
  t25_n158: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t25_n160;
  t25_n159: return 0.06722558289766312;
  t25_n160: return 0.0176190584897995;
  t25_n161: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t25_n169;
  t25_n162: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t25_n168;
  t25_n163: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t25_n165;
  t25_n164: return 0.13381488621234894;
  t25_n165: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t25_n167;
  t25_n166: return 0.1665211170911789;
  t25_n167: return 0.1173693835735321;
  t25_n168: return 0.09761855751276016;
  t25_n169: return 0.04609879106283188;
  t25_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t25_n174;
  t25_n171: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t25_n173;
  t25_n172: return 0.05168671905994415;
  t25_n173: return 0.056092433631420135;
  t25_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t25_n176;
  t25_n175: return 0.022372279316186905;
  t25_n176: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t25_n178;
  t25_n177: return 0.07381711900234222;
  t25_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t25_n180;
  t25_n179: return 0.08874266594648361;
  t25_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n184;
  t25_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n183;
  t25_n182: return 0.10851673036813736;
  t25_n183: return 0.09729903936386108;
  t25_n184: return 0.06980862468481064;
  t25_n185: return 0.08450575917959213;
  t25_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n188;
  t25_n187: return -0.1132279559969902;
  t25_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t25_n204;
  t25_n189: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n203;
  t25_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t25_n192;
  t25_n191: return 0.038136012852191925;
  t25_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t25_n194;
  t25_n193: return 0.05465397611260414;
  t25_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n202;
  t25_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t25_n197;
  t25_n196: return 0.05599016696214676;
  t25_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n201;
  t25_n198: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t25_n200;
  t25_n199: return 0.09963186830282211;
  t25_n200: return 0.10133979469537735;
  t25_n201: return -0.0484488382935524;
  t25_n202: return 0.0997401773929596;
  t25_n203: return 0.02270159311592579;
  t25_n204: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t25_n210;
  t25_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t25_n207;
  t25_n206: return 0.041113171726465225;
  t25_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n209;
  t25_n208: return 0.08522047102451324;
  t25_n209: return 0.015087341889739037;
  t25_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t25_n214;
  t25_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n213;
  t25_n212: return 0.029507754370570183;
  t25_n213: return 0.07106882333755493;
  t25_n214: return 0.0926426500082016;
  t25_n215: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t25_n235;
  t25_n216: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t25_n228;
  t25_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t25_n225;
  t25_n218: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t25_n224;
  t25_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t25_n221;
  t25_n220: return 0.056193456053733826;
  t25_n221: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t25_n223;
  t25_n222: return 0.11200492829084396;
  t25_n223: return 0.10369132459163666;
  t25_n224: return 0.10372419655323029;
  t25_n225: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t25_n227;
  t25_n226: return 0.06768085807561874;
  t25_n227: return 0.0493784174323082;
  t25_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n230;
  t25_n229: return 0.07372123003005981;
  t25_n230: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t25_n232;
  t25_n231: return 0.06141049414873123;
  t25_n232: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t25_n234;
  t25_n233: return 0.10208559781312943;
  t25_n234: return 0.0862874761223793;
  t25_n235: return 0.09926255792379379;
  t25_n236: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t25_n246;
  t25_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t25_n241;
  t25_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n240;
  t25_n239: return 0.029646653681993484;
  t25_n240: return 0.06433539092540741;
  t25_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t25_n245;
  t25_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n244;
  t25_n243: return 0.07058992236852646;
  t25_n244: return 0.08285298198461533;
  t25_n245: return 0.0635547786951065;
  t25_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t25_n252;
  t25_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t25_n249;
  t25_n248: return 0.0888437032699585;
  t25_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t25_n251;
  t25_n250: return 0.09870356321334839;
  t25_n251: return 0.10092539340257645;
  t25_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t25_n254;
  t25_n253: return 0.10004948824644089;
  t25_n254: return 0.09932459890842438;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree26(const Example& E) {
  t26_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t26_n234;
  t26_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t26_n89;
  t26_n2: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t26_n54;
  t26_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n47;
  t26_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t26_n20;
  t26_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t26_n17;
  t26_n6: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t26_n16;
  t26_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t26_n9;
  t26_n8: return 0.014405845664441586;
  t26_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t26_n15;
  t26_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n12;
  t26_n11: return 0.08003503084182739;
  t26_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t26_n14;
  t26_n13: return 0.10005635768175125;
  t26_n14: return 0.08272362500429153;
  t26_n15: return 0.09879712760448456;
  t26_n16: return -0.05046782270073891;
  t26_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t26_n19;
  t26_n18: return -0.09682656079530716;
  t26_n19: return -0.07741732895374298;
  t26_n20: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t26_n46;
  t26_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n23;
  t26_n22: return -0.0014361203648149967;
  t26_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t26_n31;
  t26_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n26;
  t26_n25: return 0.02398626320064068;
  t26_n26: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t26_n28;
  t26_n27: return 0.043291885405778885;
  t26_n28: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t26_n30;
  t26_n29: return 0.05907106399536133;
  t26_n30: return 0.08178655058145523;
  t26_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t26_n33;
  t26_n32: return 0.03764462471008301;
  t26_n33: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t26_n43;
  t26_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n42;
  t26_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t26_n41;
  t26_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t26_n38;
  t26_n37: return 0.07390547543764114;
  t26_n38: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t26_n40;
  t26_n39: return 0.08386719971895218;
  t26_n40: return 0.09625855088233948;
  t26_n41: return 0.09843553602695465;
  t26_n42: return -0.007019375450909138;
  t26_n43: if (E.getNumReferences() >= 3337742592 /*30964.5*/) goto t26_n45;
  t26_n44: return 0.03788790851831436;
  t26_n45: return 0.1049976721405983;
  t26_n46: return -0.025165744125843048;
  t26_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n49;
  t26_n48: return 0.024968791753053665;
  t26_n49: if (E.getNumReferences() >= 3301310464 /*1584.0*/) goto t26_n51;
  t26_n50: return 0.048295434564352036;
  t26_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t26_n53;
  t26_n52: return 0.04483024403452873;
  t26_n53: return 0.0833570659160614;
  t26_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t26_n64;
  t26_n55: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t26_n61;
  t26_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n60;
  t26_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n59;
  t26_n58: return 0.04560507833957672;
  t26_n59: return 0.09152285009622574;
  t26_n60: return 0.08583171665668488;
  t26_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n63;
  t26_n62: return -0.011096643283963203;
  t26_n63: return 0.060159213840961456;
  t26_n64: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t26_n86;
  t26_n65: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t26_n85;
  t26_n66: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t26_n84;
  t26_n67: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t26_n81;
  t26_n68: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t26_n80;
  t26_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t26_n71;
  t26_n70: return 0.06546513736248016;
  t26_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t26_n77;
  t26_n72: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t26_n76;
  t26_n73: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t26_n75;
  t26_n74: return -0.29993537068367004;
  t26_n75: return 0.1062079519033432;
  t26_n76: return 0.09719296544790268;
  t26_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t26_n79;
  t26_n78: return 0.08907850831747055;
  t26_n79: return -0.1146119013428688;
  t26_n80: return -0.027773112058639526;
  t26_n81: if (E.getNumReferences() >= 3360630592 /*212125.0*/) goto t26_n83;
  t26_n82: return 0.10290336608886719;
  t26_n83: return 0.05970387160778046;
  t26_n84: return -0.051487091928720474;
  t26_n85: return 0.09774709492921829;
  t26_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t26_n88;
  t26_n87: return 0.08291012793779373;
  t26_n88: return 0.08900907635688782;
  t26_n89: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n205;
  t26_n90: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t26_n174;
  t26_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t26_n101;
  t26_n92: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t26_n94;
  t26_n93: return -0.019237851724028587;
  t26_n94: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n96;
  t26_n95: return 0.028570694848895073;
  t26_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n98;
  t26_n97: return 0.093368761241436;
  t26_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n100;
  t26_n99: return 0.12014514207839966;
  t26_n100: return 0.11002354323863983;
  t26_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t26_n111;
  t26_n102: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t26_n106;
  t26_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t26_n105;
  t26_n104: return 0.049268562346696854;
  t26_n105: return -0.023958448320627213;
  t26_n106: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t26_n108;
  t26_n107: return 0.045336365699768066;
  t26_n108: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n110;
  t26_n109: return 0.016995510086417198;
  t26_n110: return 0.06684443354606628;
  t26_n111: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t26_n155;
  t26_n112: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t26_n128;
  t26_n113: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t26_n117;
  t26_n114: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t26_n116;
  t26_n115: return 0.06801466643810272;
  t26_n116: return 0.028500594198703766;
  t26_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t26_n119;
  t26_n118: return 0.04840678349137306;
  t26_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t26_n121;
  t26_n120: return 0.040820397436618805;
  t26_n121: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t26_n123;
  t26_n122: return 0.07591094076633453;
  t26_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n127;
  t26_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n126;
  t26_n125: return 0.10747081786394119;
  t26_n126: return 0.09468194097280502;
  t26_n127: return 0.061911240220069885;
  t26_n128: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t26_n146;
  t26_n129: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t26_n145;
  t26_n130: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n132;
  t26_n131: return 0.08416491001844406;
  t26_n132: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t26_n142;
  t26_n133: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t26_n135;
  t26_n134: return 0.10643356293439865;
  t26_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t26_n137;
  t26_n136: return 0.11771097034215927;
  t26_n137: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t26_n141;
  t26_n138: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t26_n140;
  t26_n139: return 0.13736295700073242;
  t26_n140: return 0.11816023290157318;
  t26_n141: return 0.1675173044204712;
  t26_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t26_n144;
  t26_n143: return 0.10991781949996948;
  t26_n144: return 0.1226481944322586;
  t26_n145: return 0.08255918323993683;
  t26_n146: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t26_n154;
  t26_n147: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t26_n149;
  t26_n148: return 0.040628112852573395;
  t26_n149: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t26_n151;
  t26_n150: return 0.1299315094947815;
  t26_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t26_n153;
  t26_n152: return 0.09907563030719757;
  t26_n153: return 0.11593476682901382;
  t26_n154: return 0.07608336210250854;
  t26_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n173;
  t26_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t26_n160;
  t26_n157: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t26_n159;
  t26_n158: return 0.05432823300361633;
  t26_n159: return 0.0997917652130127;
  t26_n160: if (E.getNumReferences() >= 3330526208 /*16870.0*/) goto t26_n166;
  t26_n161: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t26_n163;
  t26_n162: return 0.09979181736707687;
  t26_n163: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t26_n165;
  t26_n164: return 0.12174098193645477;
  t26_n165: return 0.10146904736757278;
  t26_n166: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t26_n168;
  t26_n167: return 0.07906590402126312;
  t26_n168: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t26_n172;
  t26_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n171;
  t26_n170: return 0.10819828510284424;
  t26_n171: return 0.11162833869457245;
  t26_n172: return 0.08183406293392181;
  t26_n173: return 0.008491222746670246;
  t26_n174: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t26_n204;
  t26_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t26_n185;
  t26_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t26_n178;
  t26_n177: return 0.032524432986974716;
  t26_n178: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t26_n180;
  t26_n179: return 0.032751958817243576;
  t26_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t26_n182;
  t26_n181: return 0.060417987406253815;
  t26_n182: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t26_n184;
  t26_n183: return 0.09682713449001312;
  t26_n184: return 0.045387327671051025;
  t26_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t26_n193;
  t26_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n192;
  t26_n187: if (E.getNumReferences() >= 3331838976 /*19434.0*/) goto t26_n189;
  t26_n188: return 0.06456196308135986;
  t26_n189: if (E.getNumReferences() >= 3367232976 /*368430.5*/) goto t26_n191;
  t26_n190: return 0.10257193446159363;
  t26_n191: return -0.029642047360539436;
  t26_n192: return -0.03721177205443382;
  t26_n193: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n203;
  t26_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n202;
  t26_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t26_n197;
  t26_n196: return 0.05364245921373367;
  t26_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t26_n201;
  t26_n198: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t26_n200;
  t26_n199: return 0.09765447676181793;
  t26_n200: return 0.09899885952472687;
  t26_n201: return 0.07114715129137039;
  t26_n202: return 0.09499595314264297;
  t26_n203: return 0.0463312529027462;
  t26_n204: return -0.07984188944101334;
  t26_n205: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t26_n227;
  t26_n206: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t26_n220;
  t26_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t26_n215;
  t26_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t26_n210;
  t26_n209: return 0.06798141449689865;
  t26_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t26_n214;
  t26_n211: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t26_n213;
  t26_n212: return 0.1070571169257164;
  t26_n213: return 0.12837938964366913;
  t26_n214: return 0.09846615791320801;
  t26_n215: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t26_n217;
  t26_n216: return 0.057345516979694366;
  t26_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t26_n219;
  t26_n218: return 0.04918431118130684;
  t26_n219: return -0.4464443624019623;
  t26_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n222;
  t26_n221: return 0.07045559585094452;
  t26_n222: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t26_n224;
  t26_n223: return 0.058893147855997086;
  t26_n224: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t26_n226;
  t26_n225: return 0.10119149088859558;
  t26_n226: return 0.060545191168785095;
  t26_n227: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t26_n233;
  t26_n228: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t26_n230;
  t26_n229: return 0.08277919143438339;
  t26_n230: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t26_n232;
  t26_n231: return 0.11774390190839767;
  t26_n232: return 0.12525182962417603;
  t26_n233: return 0.0956396609544754;
  t26_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t26_n246;
  t26_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t26_n239;
  t26_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n238;
  t26_n237: return 0.02691120095551014;
  t26_n238: return 0.06066697835922241;
  t26_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t26_n245;
  t26_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n244;
  t26_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t26_n243;
  t26_n242: return 0.05355618894100189;
  t26_n243: return 0.0720386803150177;
  t26_n244: return 0.0805329978466034;
  t26_n245: return 0.06060732528567314;
  t26_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t26_n252;
  t26_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t26_n249;
  t26_n248: return 0.0865032747387886;
  t26_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t26_n251;
  t26_n250: return 0.09784076362848282;
  t26_n251: return 0.10035522282123566;
  t26_n252: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t26_n254;
  t26_n253: return 0.09916064143180847;
  t26_n254: return 0.09836581349372864;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree27(const Example& E) {
  t27_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t27_n234;
  t27_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t27_n103;
  t27_n2: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t27_n30;
  t27_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t27_n17;
  t27_n4: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t27_n12;
  t27_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t27_n7;
  t27_n6: return -0.002250316319987178;
  t27_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t27_n9;
  t27_n8: return 0.08175423741340637;
  t27_n9: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t27_n11;
  t27_n10: return 0.09260950982570648;
  t27_n11: return 0.10614252090454102;
  t27_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n14;
  t27_n13: return -0.08366627991199493;
  t27_n14: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n16;
  t27_n15: return -0.07547459751367569;
  t27_n16: return 0.031507354229688644;
  t27_n17: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t27_n29;
  t27_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n20;
  t27_n19: return 0.009542238898575306;
  t27_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t27_n24;
  t27_n21: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t27_n23;
  t27_n22: return 0.04284418001770973;
  t27_n23: return 0.06509136408567429;
  t27_n24: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t27_n26;
  t27_n25: return 0.05332379415631294;
  t27_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n28;
  t27_n27: return 0.0935368686914444;
  t27_n28: return 0.053418464958667755;
  t27_n29: return -0.01649182289838791;
  t27_n30: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t27_n46;
  t27_n31: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n45;
  t27_n32: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t27_n42;
  t27_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n35;
  t27_n34: return 0.006141360383480787;
  t27_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n37;
  t27_n36: return 0.04069095849990845;
  t27_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n41;
  t27_n38: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t27_n40;
  t27_n39: return 0.09493308514356613;
  t27_n40: return 0.09985616058111191;
  t27_n41: return -0.007883652113378048;
  t27_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n44;
  t27_n43: return 0.06649854779243469;
  t27_n44: return 0.10591664165258408;
  t27_n45: return -0.02156270295381546;
  t27_n46: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t27_n50;
  t27_n47: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t27_n49;
  t27_n48: return 0.04125131294131279;
  t27_n49: return 0.07967223227024078;
  t27_n50: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t27_n102;
  t27_n51: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t27_n75;
  t27_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t27_n56;
  t27_n53: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n55;
  t27_n54: return 0.05694194510579109;
  t27_n55: return 0.0909416675567627;
  t27_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n58;
  t27_n57: return 0.0712653398513794;
  t27_n58: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t27_n74;
  t27_n59: if (E.getNumReferences() >= 3328529408 /*14677.0*/) goto t27_n61;
  t27_n60: return 0.09078636020421982;
  t27_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t27_n63;
  t27_n62: return 0.10290645807981491;
  t27_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t27_n69;
  t27_n64: if (E.getNumReferences() >= 3331854592 /*19464.5*/) goto t27_n66;
  t27_n65: return 0.13163284957408905;
  t27_n66: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t27_n68;
  t27_n67: return 0.13196611404418945;
  t27_n68: return 0.10339105129241943;
  t27_n69: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t27_n73;
  t27_n70: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t27_n72;
  t27_n71: return 0.12263378500938416;
  t27_n72: return 0.1372125893831253;
  t27_n73: return 0.12189549952745438;
  t27_n74: return 0.07118251174688339;
  t27_n75: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t27_n77;
  t27_n76: return 0.06033502146601677;
  t27_n77: if (E.getNumReferences() >= 3332389376 /*20509.0*/) goto t27_n101;
  t27_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t27_n88;
  t27_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t27_n83;
  t27_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t27_n82;
  t27_n81: return 0.031783781945705414;
  t27_n82: return 0.1019834652543068;
  t27_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n87;
  t27_n84: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t27_n86;
  t27_n85: return 0.11924794316291809;
  t27_n86: return 0.11239280551671982;
  t27_n87: return 0.11285277456045151;
  t27_n88: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t27_n94;
  t27_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t27_n91;
  t27_n90: return 0.10655276477336884;
  t27_n91: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t27_n93;
  t27_n92: return 0.11295586824417114;
  t27_n93: return 0.11289377510547638;
  t27_n94: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t27_n98;
  t27_n95: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t27_n97;
  t27_n96: return 0.11348339170217514;
  t27_n97: return 0.11483943462371826;
  t27_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t27_n100;
  t27_n99: return 0.10529745370149612;
  t27_n100: return 0.11073853820562363;
  t27_n101: return 0.06336667388677597;
  t27_n102: return 0.0836590901017189;
  t27_n103: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n213;
  t27_n104: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n194;
  t27_n105: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t27_n149;
  t27_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n108;
  t27_n107: return -0.10185298323631287;
  t27_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t27_n134;
  t27_n109: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t27_n113;
  t27_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t27_n112;
  t27_n111: return -0.07527177780866623;
  t27_n112: return 0.09749510884284973;
  t27_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t27_n131;
  t27_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t27_n116;
  t27_n115: return 0.020543811842799187;
  t27_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t27_n118;
  t27_n117: return 0.04278431460261345;
  t27_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t27_n124;
  t27_n119: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t27_n123;
  t27_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n122;
  t27_n121: return 0.06817318499088287;
  t27_n122: return -0.12515026330947876;
  t27_n123: return -0.1445506513118744;
  t27_n124: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t27_n126;
  t27_n125: return 0.04412543401122093;
  t27_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t27_n128;
  t27_n127: return 0.08207032829523087;
  t27_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n130;
  t27_n129: return 0.10497482120990753;
  t27_n130: return 0.056964632123708725;
  t27_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n133;
  t27_n132: return -0.1579478234052658;
  t27_n133: return 0.06755433976650238;
  t27_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t27_n138;
  t27_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t27_n137;
  t27_n136: return -0.01960107311606407;
  t27_n137: return 0.038574106991291046;
  t27_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t27_n146;
  t27_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t27_n141;
  t27_n140: return 0.048909012228250504;
  t27_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n143;
  t27_n142: return 0.0763493999838829;
  t27_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n145;
  t27_n144: return 0.11428479850292206;
  t27_n145: return 0.05217314511537552;
  t27_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n148;
  t27_n147: return 0.11336711049079895;
  t27_n148: return 0.09681560844182968;
  t27_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t27_n181;
  t27_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n156;
  t27_n151: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t27_n153;
  t27_n152: return 0.05331927165389061;
  t27_n153: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t27_n155;
  t27_n154: return 0.16469398140907288;
  t27_n155: return -0.11179858446121216;
  t27_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t27_n174;
  t27_n157: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t27_n159;
  t27_n158: return 0.07096464931964874;
  t27_n159: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t27_n165;
  t27_n160: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t27_n162;
  t27_n161: return 0.11626150459051132;
  t27_n162: if (E.getFilterLength() >= 3246653440 /*16.5*/) goto t27_n164;
  t27_n163: return 0.13258449733257294;
  t27_n164: return 0.10530152916908264;
  t27_n165: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t27_n169;
  t27_n166: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t27_n168;
  t27_n167: return 0.18532268702983856;
  t27_n168: return 0.18019329011440277;
  t27_n169: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t27_n173;
  t27_n170: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t27_n172;
  t27_n171: return 0.134942427277565;
  t27_n172: return 0.13207806646823883;
  t27_n173: return 0.12346258014440536;
  t27_n174: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t27_n176;
  t27_n175: return 0.1062602698802948;
  t27_n176: if (E.getNumReferences() >= 3341359232 /*43288.5*/) goto t27_n178;
  t27_n177: return 0.07957826554775238;
  t27_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n180;
  t27_n179: return 0.08813734352588654;
  t27_n180: return -0.05292808264493942;
  t27_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n183;
  t27_n182: return 0.00472661666572094;
  t27_n183: if (E.getNumReferences() >= 3271360512 /*126.5*/) goto t27_n193;
  t27_n184: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t27_n186;
  t27_n185: return 0.10558247566223145;
  t27_n186: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t27_n188;
  t27_n187: return 0.11705932766199112;
  t27_n188: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t27_n190;
  t27_n189: return 0.13552039861679077;
  t27_n190: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t27_n192;
  t27_n191: return 0.11851337552070618;
  t27_n192: return 0.14436441659927368;
  t27_n193: return 0.10974132269620895;
  t27_n194: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t27_n198;
  t27_n195: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t27_n197;
  t27_n196: return -0.02867922931909561;
  t27_n197: return 0.07844355702400208;
  t27_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t27_n202;
  t27_n199: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t27_n201;
  t27_n200: return 0.04181888327002525;
  t27_n201: return -0.11062851548194885;
  t27_n202: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t27_n208;
  t27_n203: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t27_n205;
  t27_n204: return 0.03879576548933983;
  t27_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t27_n207;
  t27_n206: return 0.05773795768618584;
  t27_n207: return 0.09160872548818588;
  t27_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n212;
  t27_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n211;
  t27_n210: return 0.09366068989038467;
  t27_n211: return 0.10056722909212112;
  t27_n212: return 0.07204980403184891;
  t27_n213: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t27_n229;
  t27_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t27_n222;
  t27_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t27_n217;
  t27_n216: return 0.03919835388660431;
  t27_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t27_n221;
  t27_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n220;
  t27_n219: return 0.10484211146831512;
  t27_n220: return 0.09291033446788788;
  t27_n221: return 0.05861171334981918;
  t27_n222: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t27_n226;
  t27_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n225;
  t27_n224: return 0.06753937900066376;
  t27_n225: return 0.056757740676403046;
  t27_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t27_n228;
  t27_n227: return -0.18442082405090332;
  t27_n228: return 0.10957329720258713;
  t27_n229: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t27_n231;
  t27_n230: return 0.10683280974626541;
  t27_n231: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t27_n233;
  t27_n232: return 0.08790922164916992;
  t27_n233: return 0.09217962622642517;
  t27_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t27_n248;
  t27_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t27_n239;
  t27_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n238;
  t27_n237: return 0.02626214176416397;
  t27_n238: return 0.056954458355903625;
  t27_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t27_n247;
  t27_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t27_n244;
  t27_n241: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t27_n243;
  t27_n242: return 0.05560321360826492;
  t27_n243: return 0.09685510396957397;
  t27_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t27_n246;
  t27_n245: return 0.06945163011550903;
  t27_n246: return 0.08205331861972809;
  t27_n247: return 0.05784423649311066;
  t27_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t27_n254;
  t27_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t27_n251;
  t27_n250: return 0.08464425802230835;
  t27_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t27_n253;
  t27_n252: return 0.09648414701223373;
  t27_n253: return 0.09941785782575607;
  t27_n254: return 0.09814776480197906;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree28(const Example& E) {
  t28_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t28_n236;
  t28_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t28_n123;
  t28_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t28_n112;
  t28_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t28_n73;
  t28_n4: if (E.getNumReferences() >= 3350479168 /*92290.5*/) goto t28_n60;
  t28_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t28_n9;
  t28_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t28_n8;
  t28_n7: return -0.07319080829620361;
  t28_n8: return -0.034655600786209106;
  t28_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n11;
  t28_n10: return 0.004125924315303564;
  t28_n11: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t28_n31;
  t28_n12: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t28_n28;
  t28_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t28_n27;
  t28_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t28_n18;
  t28_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t28_n17;
  t28_n16: return 0.02764684334397316;
  t28_n17: return 0.06906145811080933;
  t28_n18: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t28_n20;
  t28_n19: return 0.0007923730299808085;
  t28_n20: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t28_n26;
  t28_n21: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n25;
  t28_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n24;
  t28_n23: return 0.0845867320895195;
  t28_n24: return 0.10380563884973526;
  t28_n25: return -0.01781434379518032;
  t28_n26: return -0.14093796908855438;
  t28_n27: return 0.055923204869031906;
  t28_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t28_n30;
  t28_n29: return 0.11047772318124771;
  t28_n30: return 0.12354728579521179;
  t28_n31: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n57;
  t28_n32: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t28_n40;
  t28_n33: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t28_n35;
  t28_n34: return 0.09117015451192856;
  t28_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t28_n37;
  t28_n36: return 0.09104929864406586;
  t28_n37: if (E.getNumReferences() >= 3288662016 /*532.0*/) goto t28_n39;
  t28_n38: return 0.10903242975473404;
  t28_n39: return 0.11665262281894684;
  t28_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t28_n44;
  t28_n41: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t28_n43;
  t28_n42: return 0.11676470935344696;
  t28_n43: return 0.10730163007974625;
  t28_n44: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t28_n48;
  t28_n45: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t28_n47;
  t28_n46: return 0.11589714139699936;
  t28_n47: return 0.12234698981046677;
  t28_n48: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t28_n54;
  t28_n49: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t28_n53;
  t28_n50: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t28_n52;
  t28_n51: return 0.13078458607196808;
  t28_n52: return 0.14318498969078064;
  t28_n53: return 0.13347768783569336;
  t28_n54: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t28_n56;
  t28_n55: return 0.12436038255691528;
  t28_n56: return 0.11671070754528046;
  t28_n57: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n59;
  t28_n58: return 0.01793665997684002;
  t28_n59: return 0.07287955284118652;
  t28_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n62;
  t28_n61: return 0.036084383726119995;
  t28_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t28_n64;
  t28_n63: return 0.07390078157186508;
  t28_n64: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t28_n72;
  t28_n65: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t28_n71;
  t28_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t28_n68;
  t28_n67: return -0.051693227142095566;
  t28_n68: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t28_n70;
  t28_n69: return 0.1231718435883522;
  t28_n70: return 0.09190519899129868;
  t28_n71: return 0.059616170823574066;
  t28_n72: return 0.12006671726703644;
  t28_n73: if (E.getNumReferences() >= 3302551552 /*1735.5*/) goto t28_n75;
  t28_n74: return -0.07020708173513412;
  t28_n75: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t28_n77;
  t28_n76: return -0.014188935048878193;
  t28_n77: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t28_n83;
  t28_n78: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n80;
  t28_n79: return -0.023351827636361122;
  t28_n80: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t28_n82;
  t28_n81: return 0.031273212283849716;
  t28_n82: return 0.08856521546840668;
  t28_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t28_n87;
  t28_n84: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t28_n86;
  t28_n85: return 0.05735853686928749;
  t28_n86: return 0.08539588004350662;
  t28_n87: if (E.getNumReferences() >= 3322022400 /*8322.5*/) goto t28_n89;
  t28_n88: return 0.08893360942602158;
  t28_n89: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t28_n111;
  t28_n90: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t28_n100;
  t28_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t28_n95;
  t28_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t28_n94;
  t28_n93: return 0.09601203352212906;
  t28_n94: return 0.11779074370861053;
  t28_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t28_n97;
  t28_n96: return 0.09584145247936249;
  t28_n97: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t28_n99;
  t28_n98: return 0.11194667965173721;
  t28_n99: return 0.12073103338479996;
  t28_n100: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t28_n110;
  t28_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t28_n107;
  t28_n102: if (E.getNumReferences() >= 3332280320 /*20296.0*/) goto t28_n106;
  t28_n103: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t28_n105;
  t28_n104: return 0.12021433562040329;
  t28_n105: return 0.054349951446056366;
  t28_n106: return 0.1137055903673172;
  t28_n107: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t28_n109;
  t28_n108: return 0.1125812977552414;
  t28_n109: return 0.10768667608499527;
  t28_n110: return 0.12094046175479889;
  t28_n111: return 0.08027283102273941;
  t28_n112: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t28_n118;
  t28_n113: if (E.getNumReferences() >= 3266772992 /*91.5*/) goto t28_n117;
  t28_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n116;
  t28_n115: return 0.029525483027100563;
  t28_n116: return 0.052279382944107056;
  t28_n117: return 0.05336284637451172;
  t28_n118: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t28_n122;
  t28_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t28_n121;
  t28_n120: return 0.09209723770618439;
  t28_n121: return 0.11341874301433563;
  t28_n122: return 0.07904698699712753;
  t28_n123: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t28_n211;
  t28_n124: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n188;
  t28_n125: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t28_n165;
  t28_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t28_n128;
  t28_n127: return -0.09893183410167694;
  t28_n128: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t28_n150;
  t28_n129: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t28_n133;
  t28_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t28_n132;
  t28_n131: return -0.07029975950717926;
  t28_n132: return 0.09692507982254028;
  t28_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n149;
  t28_n134: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t28_n148;
  t28_n135: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n139;
  t28_n136: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t28_n138;
  t28_n137: return 0.04518013820052147;
  t28_n138: return -0.024235466495156288;
  t28_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t28_n141;
  t28_n140: return 0.04706069082021713;
  t28_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t28_n143;
  t28_n142: return 0.05309688299894333;
  t28_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t28_n145;
  t28_n144: return 0.06559275090694427;
  t28_n145: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t28_n147;
  t28_n146: return 0.0474921390414238;
  t28_n147: return 0.10299462080001831;
  t28_n148: return 0.06512492150068283;
  t28_n149: return 0.01391737349331379;
  t28_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t28_n152;
  t28_n151: return 0.03082091547548771;
  t28_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t28_n162;
  t28_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t28_n155;
  t28_n154: return 0.04736173897981644;
  t28_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n159;
  t28_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n158;
  t28_n157: return 0.08003383129835129;
  t28_n158: return 0.06252841651439667;
  t28_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n161;
  t28_n160: return 0.11143464595079422;
  t28_n161: return 0.05032835528254509;
  t28_n162: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n164;
  t28_n163: return 0.11182516068220139;
  t28_n164: return 0.0966302752494812;
  t28_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n167;
  t28_n166: return 0.05253740772604942;
  t28_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t28_n183;
  t28_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t28_n170;
  t28_n169: return 0.060715384781360626;
  t28_n170: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t28_n178;
  t28_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t28_n173;
  t28_n172: return 0.08585411310195923;
  t28_n173: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t28_n177;
  t28_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n176;
  t28_n175: return 0.11497923731803894;
  t28_n176: return 0.10477931052446365;
  t28_n177: return 0.0887206494808197;
  t28_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t28_n180;
  t28_n179: return 0.11148922890424728;
  t28_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t28_n182;
  t28_n181: return 0.11767596751451492;
  t28_n182: return 0.1345542073249817;
  t28_n183: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t28_n185;
  t28_n184: return 0.1041170284152031;
  t28_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t28_n187;
  t28_n186: return 0.04511601850390434;
  t28_n187: return 0.1129213273525238;
  t28_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t28_n196;
  t28_n189: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t28_n195;
  t28_n190: if (E.getNumReferences() >= 3300749312 /*1515.5*/) goto t28_n192;
  t28_n191: return -0.03517380356788635;
  t28_n192: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t28_n194;
  t28_n193: return 0.03208289295434952;
  t28_n194: return 0.09019894152879715;
  t28_n195: return 0.07574383914470673;
  t28_n196: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t28_n200;
  t28_n197: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t28_n199;
  t28_n198: return 0.04015159234404564;
  t28_n199: return -0.09610975533723831;
  t28_n200: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t28_n206;
  t28_n201: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t28_n203;
  t28_n202: return 0.03590346500277519;
  t28_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t28_n205;
  t28_n204: return 0.055153779685497284;
  t28_n205: return 0.08987389504909515;
  t28_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n210;
  t28_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n209;
  t28_n208: return 0.08958028256893158;
  t28_n209: return 0.09639377146959305;
  t28_n210: return 0.06609519571065903;
  t28_n211: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t28_n231;
  t28_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t28_n222;
  t28_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t28_n217;
  t28_n214: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t28_n216;
  t28_n215: return 0.01606987603008747;
  t28_n216: return 0.059487007558345795;
  t28_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t28_n221;
  t28_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n220;
  t28_n219: return 0.10172253847122192;
  t28_n220: return 0.09002453833818436;
  t28_n221: return 0.05638539791107178;
  t28_n222: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t28_n230;
  t28_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n225;
  t28_n224: return 0.06888460367918015;
  t28_n225: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t28_n227;
  t28_n226: return 0.061818260699510574;
  t28_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t28_n229;
  t28_n228: return 0.10328233987092972;
  t28_n229: return 0.05090958997607231;
  t28_n230: return -0.06752050668001175;
  t28_n231: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t28_n233;
  t28_n232: return 0.10481748729944229;
  t28_n233: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t28_n235;
  t28_n234: return 0.08940485119819641;
  t28_n235: return 0.0902535542845726;
  t28_n236: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t28_n248;
  t28_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t28_n241;
  t28_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n240;
  t28_n239: return 0.023753339424729347;
  t28_n240: return 0.05417478457093239;
  t28_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t28_n247;
  t28_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t28_n244;
  t28_n243: return 0.053186748176813126;
  t28_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n246;
  t28_n245: return 0.0661201924085617;
  t28_n246: return 0.07971949875354767;
  t28_n247: return 0.0549158938229084;
  t28_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t28_n254;
  t28_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t28_n251;
  t28_n250: return 0.08245819061994553;
  t28_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t28_n253;
  t28_n252: return 0.09542493522167206;
  t28_n253: return 0.09814881533384323;
  t28_n254: return 0.09708111733198166;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree29(const Example& E) {
  t29_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t29_n236;
  t29_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t29_n123;
  t29_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t29_n116;
  t29_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t29_n93;
  t29_n4: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n84;
  t29_n5: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t29_n83;
  t29_n6: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t29_n50;
  t29_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t29_n21;
  t29_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t29_n10;
  t29_n9: return -0.046342816203832626;
  t29_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t29_n12;
  t29_n11: return -0.06902772933244705;
  t29_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n20;
  t29_n13: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t29_n15;
  t29_n14: return 0.07261911034584045;
  t29_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n19;
  t29_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n18;
  t29_n17: return 0.11989691853523254;
  t29_n18: return 0.031202232465147972;
  t29_n19: return -0.1987142115831375;
  t29_n20: return -0.06657100468873978;
  t29_n21: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t29_n23;
  t29_n22: return -0.03819447383284569;
  t29_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t29_n35;
  t29_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t29_n26;
  t29_n25: return -0.009936257265508175;
  t29_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n28;
  t29_n27: return 0.10028426349163055;
  t29_n28: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n30;
  t29_n29: return -0.019022764638066292;
  t29_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n34;
  t29_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n33;
  t29_n32: return 0.21282723546028137;
  t29_n33: return 0.08435684442520142;
  t29_n34: return 0.12594260275363922;
  t29_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t29_n41;
  t29_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t29_n38;
  t29_n37: return 0.04876156151294708;
  t29_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n40;
  t29_n39: return -0.15646661818027496;
  t29_n40: return 0.0873827412724495;
  t29_n41: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n45;
  t29_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t29_n44;
  t29_n43: return 0.08962169289588928;
  t29_n44: return 0.1135420873761177;
  t29_n45: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n49;
  t29_n46: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t29_n48;
  t29_n47: return 0.12668254971504211;
  t29_n48: return 0.11957183480262756;
  t29_n49: return 0.08459299057722092;
  t29_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t29_n52;
  t29_n51: return 0.01874445751309395;
  t29_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t29_n70;
  t29_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t29_n61;
  t29_n54: if (E.getNumReferences() >= 3322526208 /*8814.5*/) goto t29_n56;
  t29_n55: return -0.00755287054926157;
  t29_n56: if (E.getNumReferences() >= 3322619392 /*8905.5*/) goto t29_n60;
  t29_n57: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t29_n59;
  t29_n58: return 0.12436193227767944;
  t29_n59: return 0.13846561312675476;
  t29_n60: return 0.07065743207931519;
  t29_n61: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t29_n63;
  t29_n62: return 0.11110251396894455;
  t29_n63: if (E.getNumReferences() >= 3274440704 /*172.0*/) goto t29_n65;
  t29_n64: return 0.11706472933292389;
  t29_n65: if (E.getNumReferences() >= 3283369984 /*360.5*/) goto t29_n69;
  t29_n66: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t29_n68;
  t29_n67: return 0.12824293971061707;
  t29_n68: return 0.13060955703258514;
  t29_n69: return 0.1376085877418518;
  t29_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t29_n76;
  t29_n71: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t29_n73;
  t29_n72: return 0.09456486999988556;
  t29_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t29_n75;
  t29_n74: return 0.09248660504817963;
  t29_n75: return 0.11247477680444717;
  t29_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t29_n78;
  t29_n77: return 0.10990148037672043;
  t29_n78: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t29_n82;
  t29_n79: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t29_n81;
  t29_n80: return 0.11561852693557739;
  t29_n81: return 0.11510325223207474;
  t29_n82: return 0.14070595800876617;
  t29_n83: return 0.06530718505382538;
  t29_n84: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n86;
  t29_n85: return -0.05977655202150345;
  t29_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t29_n92;
  t29_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n89;
  t29_n88: return -0.04638363793492317;
  t29_n89: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t29_n91;
  t29_n90: return 0.11303608864545822;
  t29_n91: return 0.05235430970788002;
  t29_n92: return 0.005024287384003401;
  t29_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n95;
  t29_n94: return 0.003358637448400259;
  t29_n95: if (E.getNumReferences() >= 3345992448 /*61387.0*/) goto t29_n115;
  t29_n96: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t29_n102;
  t29_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t29_n99;
  t29_n98: return 0.06009771302342415;
  t29_n99: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t29_n101;
  t29_n100: return 0.07708510756492615;
  t29_n101: return 0.09892570972442627;
  t29_n102: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t29_n110;
  t29_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t29_n105;
  t29_n104: return -0.009806705638766289;
  t29_n105: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t29_n109;
  t29_n106: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n108;
  t29_n107: return 0.088361956179142;
  t29_n108: return -0.028381850570440292;
  t29_n109: return 0.06623093783855438;
  t29_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t29_n114;
  t29_n111: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t29_n113;
  t29_n112: return 0.050270453095436096;
  t29_n113: return 0.09959348291158676;
  t29_n114: return 0.07924217730760574;
  t29_n115: return 0.05385678634047508;
  t29_n116: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t29_n120;
  t29_n117: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t29_n119;
  t29_n118: return 0.03142070025205612;
  t29_n119: return 0.05258962884545326;
  t29_n120: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t29_n122;
  t29_n121: return 0.10500594973564148;
  t29_n122: return 0.07512295991182327;
  t29_n123: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t29_n219;
  t29_n124: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n186;
  t29_n125: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t29_n155;
  t29_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n128;
  t29_n127: return -0.09745106846094131;
  t29_n128: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n134;
  t29_n129: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t29_n133;
  t29_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t29_n132;
  t29_n131: return -0.06522787362337112;
  t29_n132: return 0.09363895654678345;
  t29_n133: return 0.033611394464969635;
  t29_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t29_n144;
  t29_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t29_n137;
  t29_n136: return -0.02598552405834198;
  t29_n137: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t29_n141;
  t29_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t29_n140;
  t29_n139: return 0.04784100130200386;
  t29_n140: return 0.010532775893807411;
  t29_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t29_n143;
  t29_n142: return -0.08310116082429886;
  t29_n143: return 0.06661106646060944;
  t29_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t29_n152;
  t29_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t29_n147;
  t29_n146: return 0.045855287462472916;
  t29_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n149;
  t29_n148: return 0.07303889840841293;
  t29_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n151;
  t29_n150: return 0.10838281363248825;
  t29_n151: return 0.0472366027534008;
  t29_n152: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n154;
  t29_n153: return 0.11071507632732391;
  t29_n154: return 0.09330449998378754;
  t29_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n157;
  t29_n156: return 0.04641267657279968;
  t29_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t29_n179;
  t29_n158: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t29_n168;
  t29_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n161;
  t29_n160: return 0.05389760807156563;
  t29_n161: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t29_n163;
  t29_n162: return 0.08058474212884903;
  t29_n163: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t29_n165;
  t29_n164: return 0.08672366291284561;
  t29_n165: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t29_n167;
  t29_n166: return 0.1406799554824829;
  t29_n167: return 0.08271614462137222;
  t29_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t29_n170;
  t29_n169: return 0.10054317116737366;
  t29_n170: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t29_n172;
  t29_n171: return 0.1188000962138176;
  t29_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t29_n174;
  t29_n173: return 0.10865415632724762;
  t29_n174: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t29_n178;
  t29_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n177;
  t29_n176: return -0.08888290077447891;
  t29_n177: return 0.1406112015247345;
  t29_n178: return 0.1138056144118309;
  t29_n179: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t29_n181;
  t29_n180: return 0.095346599817276;
  t29_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t29_n183;
  t29_n182: return 0.023462744429707527;
  t29_n183: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t29_n185;
  t29_n184: return 0.10685291141271591;
  t29_n185: return 0.12185629457235336;
  t29_n186: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t29_n192;
  t29_n187: if (E.getNumReferences() >= 3307765760 /*2696.0*/) goto t29_n189;
  t29_n188: return -0.03190362825989723;
  t29_n189: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t29_n191;
  t29_n190: return 0.03504772111773491;
  t29_n191: return 0.08103670924901962;
  t29_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t29_n196;
  t29_n193: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t29_n195;
  t29_n194: return 0.035387247800827026;
  t29_n195: return -0.08757559955120087;
  t29_n196: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t29_n214;
  t29_n197: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t29_n211;
  t29_n198: if (E.getNumReferences() >= 3331066112 /*17924.5*/) goto t29_n210;
  t29_n199: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t29_n201;
  t29_n200: return 0.055910874158144;
  t29_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n203;
  t29_n202: return 0.0831533819437027;
  t29_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n209;
  t29_n204: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t29_n206;
  t29_n205: return 0.07934632152318954;
  t29_n206: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t29_n208;
  t29_n207: return 0.1495693325996399;
  t29_n208: return 0.06411650031805038;
  t29_n209: return 0.16113150119781494;
  t29_n210: return 0.09443002939224243;
  t29_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t29_n213;
  t29_n212: return -0.13370732963085175;
  t29_n213: return 0.03685329481959343;
  t29_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n218;
  t29_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n217;
  t29_n216: return 0.08628179877996445;
  t29_n217: return 0.09292631596326828;
  t29_n218: return 0.05570896714925766;
  t29_n219: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t29_n231;
  t29_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t29_n228;
  t29_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t29_n223;
  t29_n222: return 0.0332760326564312;
  t29_n223: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t29_n227;
  t29_n224: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n226;
  t29_n225: return 0.10125807672739029;
  t29_n226: return 0.09415087103843689;
  t29_n227: return 0.05448073521256447;
  t29_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n230;
  t29_n229: return 0.06359212845563889;
  t29_n230: return 0.05233462527394295;
  t29_n231: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t29_n233;
  t29_n232: return 0.1058979481458664;
  t29_n233: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t29_n235;
  t29_n234: return 0.08542871475219727;
  t29_n235: return 0.08596237748861313;
  t29_n236: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t29_n248;
  t29_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t29_n241;
  t29_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n240;
  t29_n239: return 0.022498339414596558;
  t29_n240: return 0.05123157799243927;
  t29_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t29_n247;
  t29_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t29_n244;
  t29_n243: return 0.0492643378674984;
  t29_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n246;
  t29_n245: return 0.0634249821305275;
  t29_n246: return 0.07778431475162506;
  t29_n247: return 0.053083471953868866;
  t29_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t29_n254;
  t29_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t29_n251;
  t29_n250: return 0.08113537728786469;
  t29_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t29_n253;
  t29_n252: return 0.09383099526166916;
  t29_n253: return 0.09715373814105988;
  t29_n254: return 0.096180759370327;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree30(const Example& E) {
  t30_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t30_n234;
  t30_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t30_n113;
  t30_n2: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t30_n56;
  t30_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n27;
  t30_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n6;
  t30_n5: return -0.07988978922367096;
  t30_n6: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t30_n26;
  t30_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t30_n21;
  t30_n8: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t30_n10;
  t30_n9: return -0.011837724596261978;
  t30_n10: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t30_n12;
  t30_n11: return 0.05911026522517204;
  t30_n12: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t30_n14;
  t30_n13: return 0.09184220433235168;
  t30_n14: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t30_n20;
  t30_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t30_n17;
  t30_n16: return 0.1204136312007904;
  t30_n17: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t30_n19;
  t30_n18: return 0.12008615583181381;
  t30_n19: return 0.12615050375461578;
  t30_n20: return 0.12712682783603668;
  t30_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t30_n23;
  t30_n22: return 0.06711600720882416;
  t30_n23: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t30_n25;
  t30_n24: return 0.08316154032945633;
  t30_n25: return 0.10889960080385208;
  t30_n26: return -0.06890865415334702;
  t30_n27: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t30_n55;
  t30_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n36;
  t30_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t30_n31;
  t30_n30: return 0.009994917549192905;
  t30_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t30_n35;
  t30_n32: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t30_n34;
  t30_n33: return 0.10679509490728378;
  t30_n34: return -0.2426668405532837;
  t30_n35: return -0.019458986818790436;
  t30_n36: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t30_n52;
  t30_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t30_n39;
  t30_n38: return 0.035064976662397385;
  t30_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t30_n41;
  t30_n40: return 0.010810046456754208;
  t30_n41: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n51;
  t30_n42: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t30_n50;
  t30_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t30_n45;
  t30_n44: return 0.05226702243089676;
  t30_n45: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t30_n47;
  t30_n46: return 0.0873592346906662;
  t30_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n49;
  t30_n48: return 0.10537770390510559;
  t30_n49: return 0.09859009832143784;
  t30_n50: return 0.09168054163455963;
  t30_n51: return 0.043188780546188354;
  t30_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t30_n54;
  t30_n53: return 0.06667513400316238;
  t30_n54: return 0.08815333992242813;
  t30_n55: return -0.012444643303751945;
  t30_n56: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t30_n84;
  t30_n57: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n75;
  t30_n58: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t30_n72;
  t30_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n61;
  t30_n60: return 0.024656780064105988;
  t30_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t30_n65;
  t30_n62: if (E.getNumReferences() >= 3317562368 /*6079.5*/) goto t30_n64;
  t30_n63: return -0.0012585445074364543;
  t30_n64: return 0.06809698045253754;
  t30_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t30_n67;
  t30_n66: return 0.08644454926252365;
  t30_n67: if (E.getNumReferences() >= 3281534976 /*304.5*/) goto t30_n69;
  t30_n68: return 0.0885462835431099;
  t30_n69: if (E.getNumReferences() >= 3281829888 /*313.5*/) goto t30_n71;
  t30_n70: return 0.1275576949119568;
  t30_n71: return 0.11204013973474503;
  t30_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t30_n74;
  t30_n73: return 0.060461290180683136;
  t30_n74: return 0.10565366595983505;
  t30_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t30_n77;
  t30_n76: return -0.008197814226150513;
  t30_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n79;
  t30_n78: return 0.018756821751594543;
  t30_n79: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t30_n81;
  t30_n80: return 0.03962288051843643;
  t30_n81: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t30_n83;
  t30_n82: return 0.12694329023361206;
  t30_n83: return 0.0654509961605072;
  t30_n84: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t30_n108;
  t30_n85: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t30_n107;
  t30_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression))) goto t30_n88;
  t30_n87: return 0.09616822749376297;
  t30_n88: if (E.getNumReferences() >= 3289939968 /*610.0*/) goto t30_n106;
  t30_n89: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n105;
  t30_n90: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t30_n92;
  t30_n91: return 0.1150871068239212;
  t30_n92: if (E.getNumReferences() >= 3278077952 /*227.5*/) goto t30_n96;
  t30_n93: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n95;
  t30_n94: return 0.12735208868980408;
  t30_n95: return 0.24654537439346313;
  t30_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t30_n104;
  t30_n97: if (E.getNumReferences() >= 3278864384 /*239.5*/) goto t30_n99;
  t30_n98: return 0.14085908234119415;
  t30_n99: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t30_n103;
  t30_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t30_n102;
  t30_n101: return 0.11776981502771378;
  t30_n102: return 0.11984768509864807;
  t30_n103: return 0.07943981140851974;
  t30_n104: return 0.14028973877429962;
  t30_n105: return 0.09518180042505264;
  t30_n106: return 0.0895916074514389;
  t30_n107: return 0.10031922161579132;
  t30_n108: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t30_n110;
  t30_n109: return 0.06518664956092834;
  t30_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t30_n112;
  t30_n111: return 0.06675998121500015;
  t30_n112: return 0.08457107841968536;
  t30_n113: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t30_n211;
  t30_n114: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n178;
  t30_n115: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t30_n149;
  t30_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t30_n118;
  t30_n117: return -0.09598101675510406;
  t30_n118: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t30_n134;
  t30_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t30_n121;
  t30_n120: return -0.15779836475849152;
  t30_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t30_n133;
  t30_n122: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t30_n132;
  t30_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t30_n127;
  t30_n124: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t30_n126;
  t30_n125: return 0.04070506989955902;
  t30_n126: return -0.021104127168655396;
  t30_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t30_n129;
  t30_n128: return 0.040375713258981705;
  t30_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t30_n131;
  t30_n130: return 0.04531017690896988;
  t30_n131: return 0.07937242835760117;
  t30_n132: return 0.05943911522626877;
  t30_n133: return 0.009574887342751026;
  t30_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t30_n138;
  t30_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t30_n137;
  t30_n136: return 0.013735877349972725;
  t30_n137: return 0.0369424931704998;
  t30_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t30_n146;
  t30_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t30_n141;
  t30_n140: return 0.04621891677379608;
  t30_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n143;
  t30_n142: return 0.06950265914201736;
  t30_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n145;
  t30_n144: return 0.10534540563821793;
  t30_n145: return 0.044251423329114914;
  t30_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n148;
  t30_n147: return 0.10934865474700928;
  t30_n148: return 0.092179074883461;
  t30_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n151;
  t30_n150: return 0.04512152820825577;
  t30_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t30_n171;
  t30_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t30_n154;
  t30_n153: return 0.055864572525024414;
  t30_n154: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t30_n160;
  t30_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t30_n157;
  t30_n156: return 0.07703255861997604;
  t30_n157: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t30_n159;
  t30_n158: return 0.08839262276887894;
  t30_n159: return 0.08814766258001328;
  t30_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t30_n162;
  t30_n161: return 0.10727155208587646;
  t30_n162: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t30_n164;
  t30_n163: return 0.0944567546248436;
  t30_n164: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t30_n168;
  t30_n165: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t30_n167;
  t30_n166: return 0.1304481029510498;
  t30_n167: return 0.12278269976377487;
  t30_n168: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t30_n170;
  t30_n169: return 0.13254466652870178;
  t30_n170: return 0.12339652329683304;
  t30_n171: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t30_n173;
  t30_n172: return 0.09295044094324112;
  t30_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t30_n175;
  t30_n174: return 0.02907082438468933;
  t30_n175: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t30_n177;
  t30_n176: return 0.10415984690189362;
  t30_n177: return 0.11795271188020706;
  t30_n178: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n188;
  t30_n179: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t30_n185;
  t30_n180: if (E.getNumReferences() >= 3300749312 /*1515.5*/) goto t30_n182;
  t30_n181: return -0.030990881845355034;
  t30_n182: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t30_n184;
  t30_n183: return 0.028061307966709137;
  t30_n184: return 0.08609889447689056;
  t30_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t30_n187;
  t30_n186: return 0.05196783319115639;
  t30_n187: return 0.10321398079395294;
  t30_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t30_n192;
  t30_n189: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t30_n191;
  t30_n190: return 0.03004598431289196;
  t30_n191: return -0.08122137188911438;
  t30_n192: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t30_n206;
  t30_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n195;
  t30_n194: return -0.00908403005450964;
  t30_n195: if (E.getNumReferences() >= 3346274176 /*62487.5*/) goto t30_n205;
  t30_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t30_n204;
  t30_n197: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t30_n199;
  t30_n198: return 0.06350743770599365;
  t30_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n201;
  t30_n200: return 0.08375894278287888;
  t30_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t30_n203;
  t30_n202: return 0.09417697042226791;
  t30_n203: return 0.1538955420255661;
  t30_n204: return 0.03191281855106354;
  t30_n205: return 0.07869970053434372;
  t30_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t30_n210;
  t30_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n209;
  t30_n208: return 0.08197664469480515;
  t30_n209: return 0.08672332763671875;
  t30_n210: return 0.055646561086177826;
  t30_n211: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t30_n229;
  t30_n212: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t30_n224;
  t30_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t30_n217;
  t30_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n216;
  t30_n215: return 0.030619410797953606;
  t30_n216: return 0.06381335109472275;
  t30_n217: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t30_n223;
  t30_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n222;
  t30_n219: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t30_n221;
  t30_n220: return 0.10436039417982101;
  t30_n221: return -0.015951581299304962;
  t30_n222: return 0.0831737220287323;
  t30_n223: return 0.050407856702804565;
  t30_n224: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t30_n228;
  t30_n225: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t30_n227;
  t30_n226: return -0.011512279510498047;
  t30_n227: return 0.11691262573003769;
  t30_n228: return 0.06845016777515411;
  t30_n229: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t30_n231;
  t30_n230: return 0.10322204977273941;
  t30_n231: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t30_n233;
  t30_n232: return 0.0819946825504303;
  t30_n233: return 0.08450005948543549;
  t30_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t30_n248;
  t30_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t30_n239;
  t30_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n238;
  t30_n237: return 0.02074565924704075;
  t30_n238: return 0.04723113030195236;
  t30_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t30_n245;
  t30_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t30_n244;
  t30_n241: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t30_n243;
  t30_n242: return 0.04593530669808388;
  t30_n243: return 0.094930000603199;
  t30_n244: return 0.06572984158992767;
  t30_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n247;
  t30_n246: return 0.033618710935115814;
  t30_n247: return 0.06796739995479584;
  t30_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t30_n254;
  t30_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t30_n251;
  t30_n250: return 0.07882481813430786;
  t30_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t30_n253;
  t30_n252: return 0.09273308515548706;
  t30_n253: return 0.09622552245855331;
  t30_n254: return 0.09499520063400269;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree31(const Example& E) {
  t31_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t31_n234;
  t31_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t31_n109;
  t31_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t31_n98;
  t31_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t31_n7;
  t31_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t31_n6;
  t31_n5: return -0.07411451637744904;
  t31_n6: return -0.04307333007454872;
  t31_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t31_n9;
  t31_n8: return -0.019794322550296783;
  t31_n9: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t31_n65;
  t31_n10: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t31_n56;
  t31_n11: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t31_n27;
  t31_n12: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t31_n18;
  t31_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t31_n15;
  t31_n14: return 0.0566537119448185;
  t31_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t31_n17;
  t31_n16: return 0.04594162479043007;
  t31_n17: return 0.10637771338224411;
  t31_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t31_n20;
  t31_n19: return 0.027454162016510963;
  t31_n20: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t31_n22;
  t31_n21: return 0.07249496877193451;
  t31_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n26;
  t31_n23: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t31_n25;
  t31_n24: return 0.10535271465778351;
  t31_n25: return 0.04813031107187271;
  t31_n26: return 0.09252878278493881;
  t31_n27: if (E.getNumReferences() >= 3277619200 /*220.5*/) goto t31_n41;
  t31_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t31_n30;
  t31_n29: return -0.008355220779776573;
  t31_n30: if (E.getFileProximityDistance() >= 3254779904 /*32.0*/) goto t31_n40;
  t31_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t31_n33;
  t31_n32: return 0.0012523445766419172;
  t31_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n39;
  t31_n34: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t31_n36;
  t31_n35: return 0.057008251547813416;
  t31_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Symbol))) goto t31_n38;
  t31_n37: return 0.018205493688583374;
  t31_n38: return 0.09689542651176453;
  t31_n39: return -0.06283459067344666;
  t31_n40: return 0.05421716719865799;
  t31_n41: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t31_n53;
  t31_n42: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n52;
  t31_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n45;
  t31_n44: return 0.029634563252329826;
  t31_n45: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t31_n51;
  t31_n46: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t31_n48;
  t31_n47: return 0.09400828927755356;
  t31_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t31_n50;
  t31_n49: return 0.09707805514335632;
  t31_n50: return 0.11406219750642776;
  t31_n51: return 0.07081660628318787;
  t31_n52: return 0.01956593431532383;
  t31_n53: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t31_n55;
  t31_n54: return 0.10719464719295502;
  t31_n55: return 0.08770495653152466;
  t31_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n58;
  t31_n57: return 0.02456427738070488;
  t31_n58: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t31_n60;
  t31_n59: return 0.0919668897986412;
  t31_n60: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t31_n62;
  t31_n61: return -0.18411147594451904;
  t31_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t31_n64;
  t31_n63: return -0.20275302231311798;
  t31_n64: return 0.0690579041838646;
  t31_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t31_n85;
  t31_n66: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t31_n68;
  t31_n67: return 0.08910321444272995;
  t31_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n70;
  t31_n69: return 0.05979388579726219;
  t31_n70: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t31_n82;
  t31_n71: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t31_n73;
  t31_n72: return 0.03572395071387291;
  t31_n73: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t31_n81;
  t31_n74: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t31_n80;
  t31_n75: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t31_n79;
  t31_n76: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t31_n78;
  t31_n77: return 0.12533311545848846;
  t31_n78: return 0.11479062587022781;
  t31_n79: return 0.09869313985109329;
  t31_n80: return 0.1146898865699768;
  t31_n81: return 0.025061940774321556;
  t31_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n84;
  t31_n83: return 0.11295679956674576;
  t31_n84: return 0.11715521663427353;
  t31_n85: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t31_n95;
  t31_n86: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t31_n88;
  t31_n87: return 0.05382590368390083;
  t31_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n94;
  t31_n89: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n93;
  t31_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n92;
  t31_n91: return 0.11542722582817078;
  t31_n92: return 0.02210078574717045;
  t31_n93: return -0.19121751189231873;
  t31_n94: return -0.22946575284004211;
  t31_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n97;
  t31_n96: return 0.14832377433776855;
  t31_n97: return 0.1858838051557541;
  t31_n98: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t31_n104;
  t31_n99: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t31_n103;
  t31_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n102;
  t31_n101: return 0.026507295668125153;
  t31_n102: return 0.04763495549559593;
  t31_n103: return 0.0511174201965332;
  t31_n104: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t31_n108;
  t31_n105: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t31_n107;
  t31_n106: return 0.08533474802970886;
  t31_n107: return 0.11100007593631744;
  t31_n108: return 0.0723692774772644;
  t31_n109: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t31_n183;
  t31_n110: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n170;
  t31_n111: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t31_n145;
  t31_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t31_n114;
  t31_n113: return -0.09410938620567322;
  t31_n114: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t31_n132;
  t31_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t31_n117;
  t31_n116: return -0.15148615837097168;
  t31_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n131;
  t31_n118: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t31_n130;
  t31_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t31_n123;
  t31_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t31_n122;
  t31_n121: return -0.022946802899241447;
  t31_n122: return 0.04511291906237602;
  t31_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t31_n125;
  t31_n124: return 0.03840666636824608;
  t31_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t31_n127;
  t31_n126: return 0.04200948029756546;
  t31_n127: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n129;
  t31_n128: return 0.0867886170744896;
  t31_n129: return -0.11481592059135437;
  t31_n130: return 0.057327136397361755;
  t31_n131: return 0.009328179061412811;
  t31_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t31_n134;
  t31_n133: return 0.024536680430173874;
  t31_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t31_n142;
  t31_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t31_n137;
  t31_n136: return 0.0336955189704895;
  t31_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n139;
  t31_n138: return 0.06602799892425537;
  t31_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n141;
  t31_n140: return 0.10225320607423782;
  t31_n141: return 0.04154878854751587;
  t31_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n144;
  t31_n143: return 0.10880439728498459;
  t31_n144: return 0.09298846125602722;
  t31_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n147;
  t31_n146: return 0.040481675416231155;
  t31_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t31_n165;
  t31_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t31_n150;
  t31_n149: return 0.05390727519989014;
  t31_n150: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t31_n154;
  t31_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t31_n153;
  t31_n152: return 0.07455972582101822;
  t31_n153: return 0.08534149825572968;
  t31_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t31_n156;
  t31_n155: return 0.10435163974761963;
  t31_n156: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t31_n158;
  t31_n157: return 0.09250275045633316;
  t31_n158: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t31_n162;
  t31_n159: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t31_n161;
  t31_n160: return 0.1259382665157318;
  t31_n161: return 0.12008083611726761;
  t31_n162: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t31_n164;
  t31_n163: return 0.12787263095378876;
  t31_n164: return 0.12167565524578094;
  t31_n165: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t31_n167;
  t31_n166: return 0.08966151624917984;
  t31_n167: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t31_n169;
  t31_n168: return 0.097087562084198;
  t31_n169: return 0.11353477835655212;
  t31_n170: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t31_n174;
  t31_n171: if (E.getNumReferences() >= 3307765760 /*2696.0*/) goto t31_n173;
  t31_n172: return -0.027178598567843437;
  t31_n173: return 0.03448713570833206;
  t31_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t31_n176;
  t31_n175: return -0.027857527136802673;
  t31_n176: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t31_n180;
  t31_n177: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t31_n179;
  t31_n178: return 0.04460880532860756;
  t31_n179: return 0.015473397448658943;
  t31_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t31_n182;
  t31_n181: return 0.0486983060836792;
  t31_n182: return 0.08331289887428284;
  t31_n183: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t31_n197;
  t31_n184: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t31_n196;
  t31_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t31_n189;
  t31_n186: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t31_n188;
  t31_n187: return 0.034080833196640015;
  t31_n188: return 0.059069495648145676;
  t31_n189: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t31_n195;
  t31_n190: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n194;
  t31_n191: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t31_n193;
  t31_n192: return 0.10036890208721161;
  t31_n193: return -0.02507765218615532;
  t31_n194: return 0.07879649847745895;
  t31_n195: return 0.04814474284648895;
  t31_n196: return 0.07219839841127396;
  t31_n197: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t31_n231;
  t31_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t31_n218;
  t31_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t31_n201;
  t31_n200: return 0.1048678383231163;
  t31_n201: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t31_n203;
  t31_n202: return 0.09876088798046112;
  t31_n203: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t31_n217;
  t31_n204: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t31_n208;
  t31_n205: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t31_n207;
  t31_n206: return 0.12210358679294586;
  t31_n207: return 0.13390330970287323;
  t31_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t31_n210;
  t31_n209: return 0.11702311038970947;
  t31_n210: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t31_n216;
  t31_n211: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t31_n215;
  t31_n212: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t31_n214;
  t31_n213: return -0.11049437522888184;
  t31_n214: return 0.14934110641479492;
  t31_n215: return 0.1315069943666458;
  t31_n216: return 0.14992696046829224;
  t31_n217: return 0.12772290408611298;
  t31_n218: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t31_n220;
  t31_n219: return 0.013012549839913845;
  t31_n220: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t31_n230;
  t31_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t31_n223;
  t31_n222: return 0.08851122111082077;
  t31_n223: if (E.getNumReferences() >= 3269459968 /*112.0*/) goto t31_n229;
  t31_n224: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t31_n228;
  t31_n225: if (E.getNumReferences() >= 3255304192 /*34.0*/) goto t31_n227;
  t31_n226: return 0.11316315084695816;
  t31_n227: return 0.17409545183181763;
  t31_n228: return 0.03492238372564316;
  t31_n229: return 0.1178073137998581;
  t31_n230: return 0.08135859668254852;
  t31_n231: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t31_n233;
  t31_n232: return 0.07870391011238098;
  t31_n233: return 0.07998043298721313;
  t31_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t31_n248;
  t31_n235: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t31_n239;
  t31_n236: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t31_n238;
  t31_n237: return 0.02398156188428402;
  t31_n238: return 0.0642051100730896;
  t31_n239: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t31_n245;
  t31_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t31_n244;
  t31_n241: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t31_n243;
  t31_n242: return 0.042972054332494736;
  t31_n243: return 0.09579891711473465;
  t31_n244: return 0.0626397505402565;
  t31_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n247;
  t31_n246: return 0.03134853392839432;
  t31_n247: return 0.06560327112674713;
  t31_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t31_n254;
  t31_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t31_n251;
  t31_n250: return 0.07719690352678299;
  t31_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t31_n253;
  t31_n252: return 0.09079969674348831;
  t31_n253: return 0.09508895874023438;
  t31_n254: return 0.09379677474498749;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree32(const Example& E) {
  t32_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t32_n244;
  t32_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t32_n121;
  t32_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t32_n114;
  t32_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n35;
  t32_n4: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t32_n20;
  t32_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t32_n19;
  t32_n6: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t32_n8;
  t32_n7: return -0.04602367803454399;
  t32_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t32_n10;
  t32_n9: return -0.05131932720541954;
  t32_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n18;
  t32_n11: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t32_n13;
  t32_n12: return 0.058712247759103775;
  t32_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t32_n17;
  t32_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t32_n16;
  t32_n15: return 0.11268454790115356;
  t32_n16: return 0.018008451908826828;
  t32_n17: return -0.1302957385778427;
  t32_n18: return -0.05191807076334953;
  t32_n19: return -0.01255775149911642;
  t32_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t32_n24;
  t32_n21: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t32_n23;
  t32_n22: return 0.024995483458042145;
  t32_n23: return 0.053215205669403076;
  t32_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n26;
  t32_n25: return 0.04508533328771591;
  t32_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t32_n28;
  t32_n27: return 0.0893661379814148;
  t32_n28: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t32_n34;
  t32_n29: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n31;
  t32_n30: return 0.09098424762487411;
  t32_n31: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t32_n33;
  t32_n32: return 0.1129998043179512;
  t32_n33: return 0.12127768993377686;
  t32_n34: return 0.1045694425702095;
  t32_n35: if (E.getNumReferences() >= 3297873920 /*1164.5*/) goto t32_n65;
  t32_n36: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t32_n64;
  t32_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n39;
  t32_n38: return -0.07066159695386887;
  t32_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t32_n41;
  t32_n40: return 0.007132420781999826;
  t32_n41: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t32_n47;
  t32_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t32_n44;
  t32_n43: return 0.020345350727438927;
  t32_n44: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t32_n46;
  t32_n45: return 0.04207784682512283;
  t32_n46: return 0.08316624164581299;
  t32_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n53;
  t32_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n52;
  t32_n49: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t32_n51;
  t32_n50: return 0.1705029159784317;
  t32_n51: return 0.053396329283714294;
  t32_n52: return -0.005190904717892408;
  t32_n53: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n63;
  t32_n54: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t32_n62;
  t32_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t32_n57;
  t32_n56: return 0.1745147705078125;
  t32_n57: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t32_n59;
  t32_n58: return 0.166315495967865;
  t32_n59: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n61;
  t32_n60: return 0.17488929629325867;
  t32_n61: return 0.17180435359477997;
  t32_n62: return 0.05354469642043114;
  t32_n63: return 0.10866813361644745;
  t32_n64: return -0.13024494051933289;
  t32_n65: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t32_n67;
  t32_n66: return -0.006889455020427704;
  t32_n67: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t32_n71;
  t32_n68: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n70;
  t32_n69: return 0.037961069494485855;
  t32_n70: return 0.07622769474983215;
  t32_n71: if (E.getNumReferences() >= 3333896192 /*23452.0*/) goto t32_n107;
  t32_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t32_n74;
  t32_n73: return 0.0605032853782177;
  t32_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t32_n90;
  t32_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t32_n81;
  t32_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t32_n78;
  t32_n77: return 0.07511378824710846;
  t32_n78: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t32_n80;
  t32_n79: return 0.09188303351402283;
  t32_n80: return 0.1027001366019249;
  t32_n81: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t32_n83;
  t32_n82: return 0.10775981843471527;
  t32_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t32_n85;
  t32_n84: return 0.09258915483951569;
  t32_n85: if (E.getNumReferences() >= 3331329792 /*18439.5*/) goto t32_n89;
  t32_n86: if (E.getNumReferences() >= 3331038976 /*17871.5*/) goto t32_n88;
  t32_n87: return 0.11941427737474442;
  t32_n88: return 0.11313833296298981;
  t32_n89: return 0.10395792126655579;
  t32_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t32_n92;
  t32_n91: return 0.10231499373912811;
  t32_n92: if (E.getNumReferences() >= 3331545088 /*18860.0*/) goto t32_n102;
  t32_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t32_n101;
  t32_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t32_n96;
  t32_n95: return 0.0877973884344101;
  t32_n96: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t32_n100;
  t32_n97: if (E.getNumReferences() >= 3325171712 /*11398.0*/) goto t32_n99;
  t32_n98: return 0.10151828080415726;
  t32_n99: return 0.11287166178226471;
  t32_n100: return 0.10811910033226013;
  t32_n101: return 0.11399803310632706;
  t32_n102: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t32_n106;
  t32_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n105;
  t32_n104: return -0.11154328286647797;
  t32_n105: return 0.10750268399715424;
  t32_n106: return 0.11773435771465302;
  t32_n107: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t32_n109;
  t32_n108: return 0.027166256681084633;
  t32_n109: if (E.getNumReferences() >= 3360267424 /*206450.5*/) goto t32_n113;
  t32_n110: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t32_n112;
  t32_n111: return 0.09300626069307327;
  t32_n112: return 0.11289087682962418;
  t32_n113: return 0.05705789849162102;
  t32_n114: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t32_n118;
  t32_n115: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t32_n117;
  t32_n116: return 0.03143789619207382;
  t32_n117: return 0.04844158887863159;
  t32_n118: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t32_n120;
  t32_n119: return 0.10109245032072067;
  t32_n120: return 0.06979764252901077;
  t32_n121: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t32_n191;
  t32_n122: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n174;
  t32_n123: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t32_n149;
  t32_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n126;
  t32_n125: return -0.09165337681770325;
  t32_n126: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t32_n138;
  t32_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t32_n137;
  t32_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n130;
  t32_n129: return -0.06290064007043839;
  t32_n130: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t32_n132;
  t32_n131: return 0.00994063075631857;
  t32_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n134;
  t32_n133: return 0.09769657254219055;
  t32_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t32_n136;
  t32_n135: return -0.06351738423109055;
  t32_n136: return 0.08827611804008484;
  t32_n137: return 0.03258704021573067;
  t32_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t32_n140;
  t32_n139: return 0.021195976063609123;
  t32_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t32_n146;
  t32_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t32_n143;
  t32_n142: return 0.033814575523138046;
  t32_n143: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t32_n145;
  t32_n144: return 0.08152149617671967;
  t32_n145: return 0.03981047123670578;
  t32_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t32_n148;
  t32_n147: return 0.10754305124282837;
  t32_n148: return 0.09091003239154816;
  t32_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n151;
  t32_n150: return 0.03896127641201019;
  t32_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t32_n169;
  t32_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t32_n154;
  t32_n153: return 0.051459841430187225;
  t32_n154: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t32_n158;
  t32_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t32_n157;
  t32_n156: return 0.07138580083847046;
  t32_n157: return 0.08192767202854156;
  t32_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t32_n160;
  t32_n159: return 0.09855083376169205;
  t32_n160: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t32_n162;
  t32_n161: return 0.08927515149116516;
  t32_n162: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t32_n166;
  t32_n163: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t32_n165;
  t32_n164: return 0.12033988535404205;
  t32_n165: return 0.11839272826910019;
  t32_n166: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t32_n168;
  t32_n167: return 0.12431298196315765;
  t32_n168: return 0.12230589985847473;
  t32_n169: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t32_n171;
  t32_n170: return 0.08777765929698944;
  t32_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t32_n173;
  t32_n172: return 0.016477419063448906;
  t32_n173: return 0.1040799617767334;
  t32_n174: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n178;
  t32_n175: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t32_n177;
  t32_n176: return -0.019507434219121933;
  t32_n177: return 0.06416507810354233;
  t32_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t32_n182;
  t32_n179: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t32_n181;
  t32_n180: return 0.004355084616690874;
  t32_n181: return 0.04691008850932121;
  t32_n182: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t32_n186;
  t32_n183: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t32_n185;
  t32_n184: return 0.021839236840605736;
  t32_n185: return 0.049330323934555054;
  t32_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t32_n190;
  t32_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n189;
  t32_n188: return 0.07744351029396057;
  t32_n189: return 0.08434715867042542;
  t32_n190: return 0.04574592784047127;
  t32_n191: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t32_n207;
  t32_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t32_n196;
  t32_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t32_n195;
  t32_n194: return 0.026734961196780205;
  t32_n195: return 0.05505753681063652;
  t32_n196: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t32_n206;
  t32_n197: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t32_n205;
  t32_n198: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n204;
  t32_n199: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n203;
  t32_n200: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t32_n202;
  t32_n201: return 0.11201421171426773;
  t32_n202: return 0.06820883601903915;
  t32_n203: return -0.013675825670361519;
  t32_n204: return 0.07530423998832703;
  t32_n205: return 0.044148705899715424;
  t32_n206: return 0.06914860755205154;
  t32_n207: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t32_n241;
  t32_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t32_n210;
  t32_n209: return 0.09846442937850952;
  t32_n210: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t32_n224;
  t32_n211: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t32_n213;
  t32_n212: return 0.06975579261779785;
  t32_n213: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t32_n215;
  t32_n214: return 0.08125975728034973;
  t32_n215: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t32_n221;
  t32_n216: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t32_n220;
  t32_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t32_n219;
  t32_n218: return 0.11469855159521103;
  t32_n219: return 0.16268904507160187;
  t32_n220: return 0.09036900848150253;
  t32_n221: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t32_n223;
  t32_n222: return 0.1154247596859932;
  t32_n223: return 0.1224432960152626;
  t32_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t32_n226;
  t32_n225: return 0.09800039976835251;
  t32_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t32_n240;
  t32_n227: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t32_n233;
  t32_n228: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t32_n230;
  t32_n229: return 0.0811709463596344;
  t32_n230: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t32_n232;
  t32_n231: return 0.13057731091976166;
  t32_n232: return 0.13365723192691803;
  t32_n233: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t32_n239;
  t32_n234: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t32_n238;
  t32_n235: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t32_n237;
  t32_n236: return -0.16824063658714294;
  t32_n237: return 0.1457187831401825;
  t32_n238: return 0.1266189068555832;
  t32_n239: return 0.14133939146995544;
  t32_n240: return 0.12335138022899628;
  t32_n241: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t32_n243;
  t32_n242: return 0.0759904533624649;
  t32_n243: return 0.08317477256059647;
  t32_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t32_n248;
  t32_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t32_n247;
  t32_n246: return 0.0255378820002079;
  t32_n247: return 0.05114961415529251;
  t32_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t32_n254;
  t32_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t32_n251;
  t32_n250: return 0.07462623715400696;
  t32_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t32_n253;
  t32_n252: return 0.08907203376293182;
  t32_n253: return 0.09381041675806046;
  t32_n254: return 0.09259036183357239;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree33(const Example& E) {
  t33_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t33_n242;
  t33_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t33_n167;
  t33_n2: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t33_n64;
  t33_n3: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t33_n21;
  t33_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n6;
  t33_n5: return -0.07424012571573257;
  t33_n6: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t33_n18;
  t33_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t33_n15;
  t33_n8: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t33_n10;
  t33_n9: return 0.004568946082144976;
  t33_n10: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t33_n12;
  t33_n11: return 0.055402301251888275;
  t33_n12: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t33_n14;
  t33_n13: return 0.08651256561279297;
  t33_n14: return 0.10638370364904404;
  t33_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t33_n17;
  t33_n16: return 0.06880543380975723;
  t33_n17: return 0.08545611053705215;
  t33_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n20;
  t33_n19: return -0.06700631976127625;
  t33_n20: return 0.020558400079607964;
  t33_n21: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t33_n35;
  t33_n22: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n34;
  t33_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n25;
  t33_n24: return 0.026111025363206863;
  t33_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n29;
  t33_n26: if (E.getNumReferences() >= 3317562368 /*6079.5*/) goto t33_n28;
  t33_n27: return 1.3816131286148448e-05;
  t33_n28: return 0.07092804461717606;
  t33_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t33_n31;
  t33_n30: return 0.08442425727844238;
  t33_n31: if (E.getNumReferences() >= 3288662016 /*532.0*/) goto t33_n33;
  t33_n32: return 0.10713803023099899;
  t33_n33: return 0.11418567597866058;
  t33_n34: return -0.009524664841592312;
  t33_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t33_n43;
  t33_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t33_n38;
  t33_n37: return 0.11339371651411057;
  t33_n38: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t33_n40;
  t33_n39: return 0.11434896290302277;
  t33_n40: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t33_n42;
  t33_n41: return 0.1228564903140068;
  t33_n42: return 0.12774993479251862;
  t33_n43: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t33_n61;
  t33_n44: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t33_n60;
  t33_n45: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t33_n59;
  t33_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t33_n48;
  t33_n47: return 0.07014434039592743;
  t33_n48: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t33_n54;
  t33_n49: if (E.getNumReferences() >= 3280257024 /*265.5*/) goto t33_n51;
  t33_n50: return 0.11370737850666046;
  t33_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t33_n53;
  t33_n52: return 0.1099417582154274;
  t33_n53: return 0.13433025777339935;
  t33_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t33_n56;
  t33_n55: return 0.11940054595470428;
  t33_n56: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t33_n58;
  t33_n57: return 0.13003960251808167;
  t33_n58: return 0.11454390734434128;
  t33_n59: return 0.13039498031139374;
  t33_n60: return 0.0628533810377121;
  t33_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t33_n63;
  t33_n62: return 0.061495590955019;
  t33_n63: return 0.08833400905132294;
  t33_n64: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t33_n104;
  t33_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n67;
  t33_n66: return 0.004041620995849371;
  t33_n67: if (E.getNumReferences() >= 3335302144 /*26198.0*/) goto t33_n103;
  t33_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t33_n98;
  t33_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n81;
  t33_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t33_n80;
  t33_n71: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n79;
  t33_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t33_n74;
  t33_n73: return 0.03164295107126236;
  t33_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t33_n76;
  t33_n75: return 0.053082339465618134;
  t33_n76: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t33_n78;
  t33_n77: return 0.09252900630235672;
  t33_n78: return 0.026155253872275352;
  t33_n79: return 0.029090087860822678;
  t33_n80: return 0.005033364985138178;
  t33_n81: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t33_n83;
  t33_n82: return 0.04401484131813049;
  t33_n83: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t33_n97;
  t33_n84: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n86;
  t33_n85: return 0.05068403482437134;
  t33_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t33_n96;
  t33_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n89;
  t33_n88: return 0.01939484104514122;
  t33_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t33_n91;
  t33_n90: return 0.09934631735086441;
  t33_n91: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t33_n93;
  t33_n92: return -0.11727119237184525;
  t33_n93: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t33_n95;
  t33_n94: return 0.12698420882225037;
  t33_n95: return 0.10252104699611664;
  t33_n96: return 0.038346316665410995;
  t33_n97: return 0.08246398717164993;
  t33_n98: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t33_n102;
  t33_n99: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t33_n101;
  t33_n100: return 0.05859338119626045;
  t33_n101: return 0.08106959611177444;
  t33_n102: return 0.009252588264644146;
  t33_n103: return 0.05976543202996254;
  t33_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n106;
  t33_n105: return -0.032753780484199524;
  t33_n106: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t33_n142;
  t33_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t33_n109;
  t33_n108: return -0.013651938177645206;
  t33_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n111;
  t33_n110: return -0.003099750727415085;
  t33_n111: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t33_n113;
  t33_n112: return 0.06533350050449371;
  t33_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t33_n119;
  t33_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t33_n116;
  t33_n115: return 0.08945854008197784;
  t33_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n118;
  t33_n117: return 0.11460621654987335;
  t33_n118: return 0.03149433806538582;
  t33_n119: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t33_n127;
  t33_n120: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t33_n126;
  t33_n121: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n125;
  t33_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n124;
  t33_n123: return 0.10992425680160522;
  t33_n124: return 0.01304571982473135;
  t33_n125: return -0.14846475422382355;
  t33_n126: return -0.13547883927822113;
  t33_n127: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t33_n141;
  t33_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n132;
  t33_n129: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n131;
  t33_n130: return 0.15059779584407806;
  t33_n131: return 0.05925422161817551;
  t33_n132: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n140;
  t33_n133: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n135;
  t33_n134: return 0.15743069350719452;
  t33_n135: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t33_n137;
  t33_n136: return 0.15019486844539642;
  t33_n137: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t33_n139;
  t33_n138: return 0.15655730664730072;
  t33_n139: return 0.15667423605918884;
  t33_n140: return 0.04684830084443092;
  t33_n141: return 0.041480787098407745;
  t33_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t33_n156;
  t33_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t33_n145;
  t33_n144: return -0.024218598380684853;
  t33_n145: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n149;
  t33_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n148;
  t33_n147: return 0.11734188348054886;
  t33_n148: return 0.10816497355699539;
  t33_n149: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t33_n151;
  t33_n150: return 0.11992766708135605;
  t33_n151: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n155;
  t33_n152: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n154;
  t33_n153: return 0.12322815507650375;
  t33_n154: return 0.11613902449607849;
  t33_n155: return 0.08438374847173691;
  t33_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t33_n166;
  t33_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n159;
  t33_n158: return 0.20031362771987915;
  t33_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n165;
  t33_n160: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t33_n164;
  t33_n161: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t33_n163;
  t33_n162: return 0.1454942375421524;
  t33_n163: return 0.12656530737876892;
  t33_n164: return 0.12318436801433563;
  t33_n165: return 0.10555646568536758;
  t33_n166: return -0.08487161993980408;
  t33_n167: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n231;
  t33_n168: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n214;
  t33_n169: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t33_n197;
  t33_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n172;
  t33_n171: return -0.08860339969396591;
  t33_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t33_n186;
  t33_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t33_n185;
  t33_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n176;
  t33_n175: return -0.060534585267305374;
  t33_n176: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t33_n178;
  t33_n177: return 0.0018639143090695143;
  t33_n178: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n184;
  t33_n179: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t33_n181;
  t33_n180: return 0.021751653403043747;
  t33_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n183;
  t33_n182: return 0.09722376614809036;
  t33_n183: return 0.05784930661320686;
  t33_n184: return -0.15091529488563538;
  t33_n185: return 0.031117860227823257;
  t33_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t33_n188;
  t33_n187: return 0.01863723061978817;
  t33_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t33_n190;
  t33_n189: return 0.02839483879506588;
  t33_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t33_n194;
  t33_n191: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t33_n193;
  t33_n192: return 0.0771755650639534;
  t33_n193: return 0.040834613144397736;
  t33_n194: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t33_n196;
  t33_n195: return 0.10678625106811523;
  t33_n196: return 0.0904608890414238;
  t33_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n199;
  t33_n198: return 0.038524314761161804;
  t33_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t33_n209;
  t33_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t33_n202;
  t33_n201: return 0.04926423728466034;
  t33_n202: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t33_n204;
  t33_n203: return 0.07279983907938004;
  t33_n204: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t33_n206;
  t33_n205: return 0.07970425486564636;
  t33_n206: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t33_n208;
  t33_n207: return 0.128156840801239;
  t33_n208: return 0.07702026516199112;
  t33_n209: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t33_n211;
  t33_n210: return 0.08420182019472122;
  t33_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t33_n213;
  t33_n212: return 0.014953520148992538;
  t33_n213: return 0.10166723281145096;
  t33_n214: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t33_n226;
  t33_n215: if (E.getNumReferences() >= 3283697664 /*370.5*/) goto t33_n217;
  t33_n216: return -0.027106957510113716;
  t33_n217: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t33_n219;
  t33_n218: return 0.028075912967324257;
  t33_n219: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t33_n223;
  t33_n220: if (E.getNumReferences() >= 3294248960 /*873.0*/) goto t33_n222;
  t33_n221: return 0.12394590675830841;
  t33_n222: return 0.11242450028657913;
  t33_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t33_n225;
  t33_n224: return 0.075131356716156;
  t33_n225: return 0.09801036864519119;
  t33_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t33_n228;
  t33_n227: return -0.022769948467612267;
  t33_n228: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t33_n230;
  t33_n229: return 0.032823596149683;
  t33_n230: return 0.046517640352249146;
  t33_n231: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t33_n239;
  t33_n232: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t33_n236;
  t33_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t33_n235;
  t33_n234: return 0.07667089998722076;
  t33_n235: return 0.03740975260734558;
  t33_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n238;
  t33_n237: return 0.07089319825172424;
  t33_n238: return 0.05505699664354324;
  t33_n239: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t33_n241;
  t33_n240: return 0.09733989834785461;
  t33_n241: return 0.07461578398942947;
  t33_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t33_n248;
  t33_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t33_n245;
  t33_n244: return 0.024982482194900513;
  t33_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n247;
  t33_n246: return 0.03455371409654617;
  t33_n247: return 0.0645674616098404;
  t33_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t33_n254;
  t33_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t33_n251;
  t33_n250: return 0.07250507920980453;
  t33_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t33_n253;
  t33_n252: return 0.0871359333395958;
  t33_n253: return 0.09327206760644913;
  t33_n254: return 0.09119874238967896;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree34(const Example& E) {
  t34_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t34_n238;
  t34_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t34_n219;
  t34_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t34_n62;
  t34_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t34_n5;
  t34_n4: return -0.06072438508272171;
  t34_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t34_n17;
  t34_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t34_n8;
  t34_n7: return -0.04561784118413925;
  t34_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n10;
  t34_n9: return 0.08932355046272278;
  t34_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t34_n12;
  t34_n11: return -0.15805965662002563;
  t34_n12: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t34_n14;
  t34_n13: return -0.1357860565185547;
  t34_n14: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t34_n16;
  t34_n15: return 0.11533046513795853;
  t34_n16: return -0.13522233068943024;
  t34_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t34_n43;
  t34_n18: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t34_n40;
  t34_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t34_n25;
  t34_n20: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t34_n22;
  t34_n21: return -0.10084602236747742;
  t34_n22: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t34_n24;
  t34_n23: return 0.025621933862566948;
  t34_n24: return 0.1461782306432724;
  t34_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t34_n29;
  t34_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t34_n28;
  t34_n27: return -0.052339423447847366;
  t34_n28: return 0.03269091993570328;
  t34_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t34_n31;
  t34_n30: return 0.010366215370595455;
  t34_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n33;
  t34_n32: return 0.06497256457805634;
  t34_n33: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n39;
  t34_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n36;
  t34_n35: return 0.12601089477539062;
  t34_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n38;
  t34_n37: return 0.13228099048137665;
  t34_n38: return 0.10307640582323074;
  t34_n39: return 0.05546988546848297;
  t34_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t34_n42;
  t34_n41: return -0.10367829352617264;
  t34_n42: return 0.02383127063512802;
  t34_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n45;
  t34_n44: return 0.06204940006136894;
  t34_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t34_n47;
  t34_n46: return -0.11880707740783691;
  t34_n47: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t34_n51;
  t34_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t34_n50;
  t34_n49: return -0.060938913375139236;
  t34_n50: return 0.05072594806551933;
  t34_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t34_n55;
  t34_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n54;
  t34_n53: return 0.06743579357862473;
  t34_n54: return 0.07367101311683655;
  t34_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n61;
  t34_n56: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t34_n58;
  t34_n57: return 0.11575409024953842;
  t34_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n60;
  t34_n59: return 0.12235099822282791;
  t34_n60: return 0.07994335144758224;
  t34_n61: return 0.06648736447095871;
  t34_n62: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t34_n204;
  t34_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t34_n119;
  t34_n64: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t34_n118;
  t34_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n67;
  t34_n66: return -0.017545266076922417;
  t34_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t34_n115;
  t34_n68: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t34_n78;
  t34_n69: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n71;
  t34_n70: return -0.0003260887460783124;
  t34_n71: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t34_n77;
  t34_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n74;
  t34_n73: return 0.11329954117536545;
  t34_n74: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t34_n76;
  t34_n75: return 0.07003100216388702;
  t34_n76: return 0.14750105142593384;
  t34_n77: return -0.13466379046440125;
  t34_n78: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t34_n82;
  t34_n79: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t34_n81;
  t34_n80: return 0.04970945045351982;
  t34_n81: return 0.04503951221704483;
  t34_n82: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t34_n102;
  t34_n83: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n101;
  t34_n84: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t34_n88;
  t34_n85: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t34_n87;
  t34_n86: return 0.0823080837726593;
  t34_n87: return 0.10120455920696259;
  t34_n88: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t34_n92;
  t34_n89: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t34_n91;
  t34_n90: return 0.10362306237220764;
  t34_n91: return 0.11397574841976166;
  t34_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t34_n100;
  t34_n93: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t34_n97;
  t34_n94: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t34_n96;
  t34_n95: return 0.12664389610290527;
  t34_n96: return 0.13343288004398346;
  t34_n97: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t34_n99;
  t34_n98: return 0.14578957855701447;
  t34_n99: return 0.13087734580039978;
  t34_n100: return 0.11400138586759567;
  t34_n101: return 0.08190202713012695;
  t34_n102: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n114;
  t34_n103: if (E.getNumReferences() >= 3285762048 /*433.5*/) goto t34_n109;
  t34_n104: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t34_n106;
  t34_n105: return 0.10021007061004639;
  t34_n106: if (E.getNumReferences() >= 3268345856 /*103.5*/) goto t34_n108;
  t34_n107: return 0.12001911550760269;
  t34_n108: return 0.11440303176641464;
  t34_n109: if (E.getNumReferences() >= 3289915392 /*608.5*/) goto t34_n113;
  t34_n110: if (E.getNumReferences() >= 3289620480 /*590.5*/) goto t34_n112;
  t34_n111: return 0.116281658411026;
  t34_n112: return 0.1393931806087494;
  t34_n113: return 0.09175349771976471;
  t34_n114: return 0.0972106009721756;
  t34_n115: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n117;
  t34_n116: return 0.0544569231569767;
  t34_n117: return 0.09548622369766235;
  t34_n118: return -0.027798667550086975;
  t34_n119: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t34_n191;
  t34_n120: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t34_n144;
  t34_n121: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t34_n123;
  t34_n122: return 0.032519105821847916;
  t34_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n125;
  t34_n124: return 0.0552234873175621;
  t34_n125: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t34_n133;
  t34_n126: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t34_n128;
  t34_n127: return 0.07187572866678238;
  t34_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t34_n130;
  t34_n129: return 0.0995330810546875;
  t34_n130: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t34_n132;
  t34_n131: return 0.11814288049936295;
  t34_n132: return 0.08248146623373032;
  t34_n133: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t34_n135;
  t34_n134: return 0.09665967524051666;
  t34_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t34_n137;
  t34_n136: return 0.09914509207010269;
  t34_n137: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t34_n143;
  t34_n138: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t34_n142;
  t34_n139: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t34_n141;
  t34_n140: return 0.12309408187866211;
  t34_n141: return 0.12831856310367584;
  t34_n142: return 0.08111158013343811;
  t34_n143: return 0.11137493699789047;
  t34_n144: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t34_n174;
  t34_n145: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t34_n149;
  t34_n146: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t34_n148;
  t34_n147: return 0.011271372437477112;
  t34_n148: return -0.05165904387831688;
  t34_n149: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t34_n157;
  t34_n150: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n156;
  t34_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n153;
  t34_n152: return 0.04129946231842041;
  t34_n153: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t34_n155;
  t34_n154: return 0.09419109672307968;
  t34_n155: return 0.06759216636419296;
  t34_n156: return 0.0010564586846157908;
  t34_n157: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t34_n169;
  t34_n158: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t34_n166;
  t34_n159: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t34_n165;
  t34_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n162;
  t34_n161: return -0.12638241052627563;
  t34_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t34_n164;
  t34_n163: return 0.13006635010242462;
  t34_n164: return 0.15906190872192383;
  t34_n165: return 0.12889304757118225;
  t34_n166: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t34_n168;
  t34_n167: return 0.11772385239601135;
  t34_n168: return 0.17561016976833344;
  t34_n169: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t34_n173;
  t34_n170: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n172;
  t34_n171: return 0.11815571784973145;
  t34_n172: return 0.08970800042152405;
  t34_n173: return 0.08937564492225647;
  t34_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t34_n176;
  t34_n175: return 0.0326998196542263;
  t34_n176: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n178;
  t34_n177: return 0.039908308535814285;
  t34_n178: if (E.getFileProximityDistance() >= 3251634176 /*26.0*/) goto t34_n180;
  t34_n179: return 0.019733097404241562;
  t34_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n190;
  t34_n181: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n189;
  t34_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t34_n184;
  t34_n183: return -0.2560510039329529;
  t34_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n188;
  t34_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n187;
  t34_n186: return 0.1073208898305893;
  t34_n187: return 0.03149968758225441;
  t34_n188: return 0.08546414971351624;
  t34_n189: return 0.00284001836553216;
  t34_n190: return -0.10479722917079926;
  t34_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n193;
  t34_n192: return 0.02290164679288864;
  t34_n193: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t34_n201;
  t34_n194: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n198;
  t34_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n197;
  t34_n196: return 0.09268943220376968;
  t34_n197: return -0.0762515589594841;
  t34_n198: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t34_n200;
  t34_n199: return 0.09342075884342194;
  t34_n200: return 0.11266334354877472;
  t34_n201: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t34_n203;
  t34_n202: return -0.16036756336688995;
  t34_n203: return 0.06167878583073616;
  t34_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t34_n206;
  t34_n205: return 0.0746188834309578;
  t34_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t34_n218;
  t34_n207: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t34_n215;
  t34_n208: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t34_n210;
  t34_n209: return 0.11399317532777786;
  t34_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n214;
  t34_n211: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t34_n213;
  t34_n212: return 0.1455492228269577;
  t34_n213: return 0.1443507820367813;
  t34_n214: return 0.09960097819566727;
  t34_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n217;
  t34_n216: return 0.05266613885760307;
  t34_n217: return 0.10946070402860641;
  t34_n218: return 0.027967039495706558;
  t34_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n225;
  t34_n220: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t34_n222;
  t34_n221: return 0.030657898634672165;
  t34_n222: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t34_n224;
  t34_n223: return 0.10104648023843765;
  t34_n224: return 0.06808734685182571;
  t34_n225: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t34_n233;
  t34_n226: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t34_n232;
  t34_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t34_n231;
  t34_n228: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t34_n230;
  t34_n229: return 0.027385499328374863;
  t34_n230: return 0.05310352146625519;
  t34_n231: return 0.04970017448067665;
  t34_n232: return 0.06097070127725601;
  t34_n233: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t34_n235;
  t34_n234: return 0.09378325939178467;
  t34_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t34_n237;
  t34_n236: return 0.06991786509752274;
  t34_n237: return 0.07800981402397156;
  t34_n238: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t34_n248;
  t34_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n245;
  t34_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t34_n242;
  t34_n241: return -0.009995239786803722;
  t34_n242: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t34_n244;
  t34_n243: return 0.043573830276727676;
  t34_n244: return 0.013259083963930607;
  t34_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n247;
  t34_n246: return 0.03091621957719326;
  t34_n247: return 0.06243055313825607;
  t34_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t34_n254;
  t34_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t34_n251;
  t34_n250: return 0.06984447687864304;
  t34_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t34_n253;
  t34_n252: return 0.08598382025957108;
  t34_n253: return 0.09102986007928848;
  t34_n254: return 0.09021837264299393;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree35(const Example& E) {
  t35_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t35_n242;
  t35_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t35_n141;
  t35_n2: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t35_n56;
  t35_n3: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t35_n15;
  t35_n4: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n12;
  t35_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t35_n7;
  t35_n6: return 0.0005403000977821648;
  t35_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t35_n9;
  t35_n8: return 0.057103365659713745;
  t35_n9: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t35_n11;
  t35_n10: return 0.09478605538606644;
  t35_n11: return 0.046963002532720566;
  t35_n12: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t35_n14;
  t35_n13: return -0.0568498857319355;
  t35_n14: return -0.09128273278474808;
  t35_n15: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t35_n25;
  t35_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n24;
  t35_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n19;
  t35_n18: return 0.02614452876150608;
  t35_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n23;
  t35_n20: if (E.getNumReferences() >= 3317562368 /*6079.5*/) goto t35_n22;
  t35_n21: return 0.003475755453109741;
  t35_n22: return 0.07031068205833435;
  t35_n23: return 0.0815412700176239;
  t35_n24: return -0.008712348528206348;
  t35_n25: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n33;
  t35_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t35_n32;
  t35_n27: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t35_n29;
  t35_n28: return 0.109368234872818;
  t35_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t35_n31;
  t35_n30: return 0.04952806979417801;
  t35_n31: return 0.1523677259683609;
  t35_n32: return 0.11988403648138046;
  t35_n33: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t35_n53;
  t35_n34: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t35_n52;
  t35_n35: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t35_n51;
  t35_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n44;
  t35_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t35_n39;
  t35_n38: return 0.018857955932617188;
  t35_n39: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n43;
  t35_n40: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t35_n42;
  t35_n41: return -0.13766707479953766;
  t35_n42: return 0.12092752009630203;
  t35_n43: return 0.10280290246009827;
  t35_n44: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t35_n50;
  t35_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n47;
  t35_n46: return 0.08923901617527008;
  t35_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t35_n49;
  t35_n48: return 0.12473177909851074;
  t35_n49: return 0.12066980451345444;
  t35_n50: return 0.10609123110771179;
  t35_n51: return 0.12750093638896942;
  t35_n52: return 0.06723346561193466;
  t35_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n55;
  t35_n54: return 0.05806070938706398;
  t35_n55: return 0.08615350723266602;
  t35_n56: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t35_n74;
  t35_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n59;
  t35_n58: return 0.0025837267749011517;
  t35_n59: if (E.getNumReferences() >= 3335302144 /*26198.0*/) goto t35_n73;
  t35_n60: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t35_n70;
  t35_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t35_n67;
  t35_n62: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n64;
  t35_n63: return 0.04244096949696541;
  t35_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t35_n66;
  t35_n65: return -0.038483768701553345;
  t35_n66: return 0.11120299249887466;
  t35_n67: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t35_n69;
  t35_n68: return 0.05304295942187309;
  t35_n69: return 0.07668635994195938;
  t35_n70: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t35_n72;
  t35_n71: return 0.006087548099458218;
  t35_n72: return 0.047567933797836304;
  t35_n73: return 0.05561569705605507;
  t35_n74: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t35_n130;
  t35_n75: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t35_n77;
  t35_n76: return -0.035115525126457214;
  t35_n77: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n79;
  t35_n78: return 0.02693898230791092;
  t35_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t35_n117;
  t35_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n102;
  t35_n81: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n83;
  t35_n82: return -0.00499654421582818;
  t35_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t35_n87;
  t35_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t35_n86;
  t35_n85: return -0.12129142135381699;
  t35_n86: return 0.049073509871959686;
  t35_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t35_n97;
  t35_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n90;
  t35_n89: return -0.03729208558797836;
  t35_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n94;
  t35_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t35_n93;
  t35_n92: return 0.11673139780759811;
  t35_n93: return 0.10292956233024597;
  t35_n94: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n96;
  t35_n95: return 0.12334717810153961;
  t35_n96: return 0.07425970584154129;
  t35_n97: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t35_n101;
  t35_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n100;
  t35_n99: return 0.1406496912240982;
  t35_n100: return 0.1056796982884407;
  t35_n101: return -0.1353047788143158;
  t35_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t35_n106;
  t35_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t35_n105;
  t35_n104: return 0.04022014141082764;
  t35_n105: return 0.0989423468708992;
  t35_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t35_n116;
  t35_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n109;
  t35_n108: return 0.1300990730524063;
  t35_n109: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t35_n111;
  t35_n110: return 0.12832678854465485;
  t35_n111: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t35_n115;
  t35_n112: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t35_n114;
  t35_n113: return -0.029461270198225975;
  t35_n114: return 0.13858948647975922;
  t35_n115: return 0.13586854934692383;
  t35_n116: return 0.08711274713277817;
  t35_n117: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t35_n121;
  t35_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n120;
  t35_n119: return -0.0556531623005867;
  t35_n120: return 0.0784774199128151;
  t35_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n123;
  t35_n122: return 0.08106563240289688;
  t35_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t35_n129;
  t35_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n128;
  t35_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n127;
  t35_n126: return -0.13543488085269928;
  t35_n127: return 0.12557676434516907;
  t35_n128: return 0.11762382835149765;
  t35_n129: return 0.11866790801286697;
  t35_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n132;
  t35_n131: return -0.12046516686677933;
  t35_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t35_n138;
  t35_n133: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n135;
  t35_n134: return 0.006312707904726267;
  t35_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n137;
  t35_n136: return 0.07115352898836136;
  t35_n137: return 0.0712336078286171;
  t35_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n140;
  t35_n139: return 0.07944415509700775;
  t35_n140: return 0.09604539722204208;
  t35_n141: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t35_n209;
  t35_n142: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n182;
  t35_n143: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t35_n159;
  t35_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t35_n146;
  t35_n145: return -0.0848437175154686;
  t35_n146: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n150;
  t35_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t35_n149;
  t35_n148: return -0.017220797017216682;
  t35_n149: return 0.027769114822149277;
  t35_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t35_n152;
  t35_n151: return 0.014772085472941399;
  t35_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t35_n154;
  t35_n153: return 0.02825918421149254;
  t35_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t35_n156;
  t35_n155: return 0.06428533792495728;
  t35_n156: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t35_n158;
  t35_n157: return 0.10603015124797821;
  t35_n158: return 0.09006264060735703;
  t35_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n161;
  t35_n160: return 0.026679806411266327;
  t35_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t35_n179;
  t35_n162: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t35_n164;
  t35_n163: return 0.0594630166888237;
  t35_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n166;
  t35_n165: return 0.04214208200573921;
  t35_n166: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t35_n178;
  t35_n167: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t35_n169;
  t35_n168: return 0.07201921194791794;
  t35_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t35_n171;
  t35_n170: return 0.09101509302854538;
  t35_n171: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t35_n175;
  t35_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t35_n174;
  t35_n173: return 0.08845661580562592;
  t35_n174: return 0.11661775410175323;
  t35_n175: if (E.getNumReferences() >= 3290906624 /*669.0*/) goto t35_n177;
  t35_n176: return 0.1357986181974411;
  t35_n177: return 0.0904502123594284;
  t35_n178: return 0.11923275142908096;
  t35_n179: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t35_n181;
  t35_n180: return 0.07549643516540527;
  t35_n181: return 0.09471698850393295;
  t35_n182: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t35_n202;
  t35_n183: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t35_n185;
  t35_n184: return -0.025098390877246857;
  t35_n185: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t35_n187;
  t35_n186: return 0.02712235413491726;
  t35_n187: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n193;
  t35_n188: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t35_n190;
  t35_n189: return 0.13721300661563873;
  t35_n190: if (E.getNumReferences() >= 3294248960 /*873.0*/) goto t35_n192;
  t35_n191: return 0.11614343523979187;
  t35_n192: return 0.11044947803020477;
  t35_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t35_n195;
  t35_n194: return 0.09006503224372864;
  t35_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t35_n197;
  t35_n196: return 0.07253128290176392;
  t35_n197: if (E.getNumReferences() >= 3277520896 /*219.0*/) goto t35_n199;
  t35_n198: return 0.04583655670285225;
  t35_n199: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t35_n201;
  t35_n200: return 0.13375620543956757;
  t35_n201: return 0.10201161354780197;
  t35_n202: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t35_n208;
  t35_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t35_n205;
  t35_n204: return -0.02141510508954525;
  t35_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t35_n207;
  t35_n206: return -0.7123042345046997;
  t35_n207: return 0.03684786334633827;
  t35_n208: return 0.04319540783762932;
  t35_n209: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t35_n221;
  t35_n210: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t35_n220;
  t35_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t35_n213;
  t35_n212: return 0.026365838944911957;
  t35_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t35_n215;
  t35_n214: return 0.008043061941862106;
  t35_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n217;
  t35_n216: return 0.05620558187365532;
  t35_n217: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t35_n219;
  t35_n218: return 0.0796879231929779;
  t35_n219: return -0.36021342873573303;
  t35_n220: return 0.05713682621717453;
  t35_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t35_n239;
  t35_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t35_n224;
  t35_n223: return 0.08968468755483627;
  t35_n224: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t35_n226;
  t35_n225: return 0.07216192036867142;
  t35_n226: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t35_n228;
  t35_n227: return 0.06801736354827881;
  t35_n228: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t35_n238;
  t35_n229: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t35_n237;
  t35_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t35_n232;
  t35_n231: return 0.10697955638170242;
  t35_n232: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t35_n234;
  t35_n233: return 0.10877490788698196;
  t35_n234: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t35_n236;
  t35_n235: return 0.12498417496681213;
  t35_n236: return 0.1296081393957138;
  t35_n237: return 0.11551684141159058;
  t35_n238: return 0.06239255890250206;
  t35_n239: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t35_n241;
  t35_n240: return 0.06646472960710526;
  t35_n241: return 0.0759739875793457;
  t35_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t35_n248;
  t35_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t35_n245;
  t35_n244: return 0.02199104055762291;
  t35_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n247;
  t35_n246: return 0.028515418991446495;
  t35_n247: return 0.059443797916173935;
  t35_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t35_n254;
  t35_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t35_n251;
  t35_n250: return 0.06731114536523819;
  t35_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t35_n253;
  t35_n252: return 0.08334663510322571;
  t35_n253: return 0.08999878168106079;
  t35_n254: return 0.08846521377563477;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree36(const Example& E) {
  t36_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t36_n240;
  t36_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t36_n167;
  t36_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n86;
  t36_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t36_n63;
  t36_n4: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t36_n46;
  t36_n5: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t36_n23;
  t36_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t36_n22;
  t36_n7: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t36_n9;
  t36_n8: return -0.04003366455435753;
  t36_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t36_n11;
  t36_n10: return -0.09768500924110413;
  t36_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n21;
  t36_n12: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t36_n14;
  t36_n13: return 0.042146679013967514;
  t36_n14: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t36_n20;
  t36_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n17;
  t36_n16: return 0.10409099608659744;
  t36_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n19;
  t36_n18: return 0.107083760201931;
  t36_n19: return -0.016811765730381012;
  t36_n20: return -0.15419016778469086;
  t36_n21: return -0.05809102579951286;
  t36_n22: return -0.009814945049583912;
  t36_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t36_n25;
  t36_n24: return 0.017764123156666756;
  t36_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t36_n35;
  t36_n26: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t36_n28;
  t36_n27: return 0.031267859041690826;
  t36_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n30;
  t36_n29: return 0.03793250396847725;
  t36_n30: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t36_n34;
  t36_n31: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t36_n33;
  t36_n32: return 0.08352570980787277;
  t36_n33: return 0.09704339504241943;
  t36_n34: return 0.07078282535076141;
  t36_n35: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t36_n39;
  t36_n36: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t36_n38;
  t36_n37: return 0.07742344588041306;
  t36_n38: return 0.10907206684350967;
  t36_n39: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t36_n41;
  t36_n40: return 0.09391836076974869;
  t36_n41: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t36_n45;
  t36_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t36_n44;
  t36_n43: return 0.11469779163599014;
  t36_n44: return 0.1010948196053505;
  t36_n45: return 0.01936158910393715;
  t36_n46: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t36_n48;
  t36_n47: return 0.10017935931682587;
  t36_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n58;
  t36_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t36_n57;
  t36_n50: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t36_n52;
  t36_n51: return 0.0008779636700637639;
  t36_n52: if (E.getNumReferences() >= 3361088608 /*219281.5*/) goto t36_n56;
  t36_n53: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t36_n55;
  t36_n54: return 0.1197945848107338;
  t36_n55: return 0.1072230264544487;
  t36_n56: return -0.000856966245919466;
  t36_n57: return 0.06927082687616348;
  t36_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t36_n60;
  t36_n59: return -0.25628259778022766;
  t36_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n62;
  t36_n61: return 0.07275813817977905;
  t36_n62: return 0.09346568584442139;
  t36_n63: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t36_n85;
  t36_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t36_n66;
  t36_n65: return -0.049013201147317886;
  t36_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n68;
  t36_n67: return 0.01633325219154358;
  t36_n68: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t36_n82;
  t36_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n71;
  t36_n70: return 0.004305768292397261;
  t36_n71: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t36_n73;
  t36_n72: return 0.01747310161590576;
  t36_n73: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t36_n77;
  t36_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n76;
  t36_n75: return 0.12089144438505173;
  t36_n76: return 0.007378799840807915;
  t36_n77: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t36_n81;
  t36_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n80;
  t36_n79: return 0.13110868632793427;
  t36_n80: return 0.14532828330993652;
  t36_n81: return 0.12902256846427917;
  t36_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t36_n84;
  t36_n83: return 0.03690376505255699;
  t36_n84: return 0.056593332439661026;
  t36_n85: return -0.11925027519464493;
  t36_n86: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t36_n140;
  t36_n87: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t36_n105;
  t36_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n90;
  t36_n89: return -0.08311042189598083;
  t36_n90: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t36_n94;
  t36_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t36_n93;
  t36_n92: return -0.016150884330272675;
  t36_n93: return 0.02648889645934105;
  t36_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t36_n96;
  t36_n95: return 0.013238271698355675;
  t36_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t36_n98;
  t36_n97: return 0.020079735666513443;
  t36_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t36_n102;
  t36_n99: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t36_n101;
  t36_n100: return 0.06919737160205841;
  t36_n101: return 0.03123764880001545;
  t36_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t36_n104;
  t36_n103: return 0.1043151393532753;
  t36_n104: return 0.08592595160007477;
  t36_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n107;
  t36_n106: return 0.024953262880444527;
  t36_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t36_n127;
  t36_n108: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t36_n110;
  t36_n109: return 0.057738423347473145;
  t36_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t36_n112;
  t36_n111: return 0.0405806340277195;
  t36_n112: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t36_n124;
  t36_n113: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t36_n115;
  t36_n114: return 0.06943071633577347;
  t36_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t36_n117;
  t36_n116: return 0.08792875707149506;
  t36_n117: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t36_n121;
  t36_n118: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t36_n120;
  t36_n119: return 0.08607252687215805;
  t36_n120: return 0.11307962238788605;
  t36_n121: if (E.getNumReferences() >= 3290906624 /*669.0*/) goto t36_n123;
  t36_n122: return 0.1323780119419098;
  t36_n123: return 0.08857329189777374;
  t36_n124: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t36_n126;
  t36_n125: return 0.120931476354599;
  t36_n126: return 0.0716942697763443;
  t36_n127: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t36_n137;
  t36_n128: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t36_n130;
  t36_n129: return 0.0719020813703537;
  t36_n130: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t36_n136;
  t36_n131: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t36_n135;
  t36_n132: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t36_n134;
  t36_n133: return 0.1481046825647354;
  t36_n134: return 0.12275762856006622;
  t36_n135: return 0.11527477204799652;
  t36_n136: return 0.10988340526819229;
  t36_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t36_n139;
  t36_n138: return 0.0005074666696600616;
  t36_n139: return 0.0949082002043724;
  t36_n140: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t36_n162;
  t36_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n151;
  t36_n142: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t36_n144;
  t36_n143: return -0.04227167367935181;
  t36_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t36_n146;
  t36_n145: return -0.013816981576383114;
  t36_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n148;
  t36_n147: return 0.15048983693122864;
  t36_n148: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n150;
  t36_n149: return 0.11360283941030502;
  t36_n150: return 0.10865408182144165;
  t36_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t36_n153;
  t36_n152: return -0.003604038618505001;
  t36_n153: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t36_n155;
  t36_n154: return 0.046411849558353424;
  t36_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t36_n159;
  t36_n156: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t36_n158;
  t36_n157: return 0.0997142493724823;
  t36_n158: return 0.04903023689985275;
  t36_n159: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t36_n161;
  t36_n160: return 0.11669991910457611;
  t36_n161: return 0.03223467618227005;
  t36_n162: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t36_n166;
  t36_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t36_n165;
  t36_n164: return -0.03187083080410957;
  t36_n165: return 0.027436653152108192;
  t36_n166: return 0.03935369849205017;
  t36_n167: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t36_n187;
  t36_n168: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t36_n182;
  t36_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n171;
  t36_n170: return 0.026426827535033226;
  t36_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t36_n177;
  t36_n172: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t36_n176;
  t36_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t36_n175;
  t36_n174: return 0.05864677578210831;
  t36_n175: return 0.07970373332500458;
  t36_n176: return 0.07805291563272476;
  t36_n177: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t36_n179;
  t36_n178: return -0.04232951998710632;
  t36_n179: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t36_n181;
  t36_n180: return 0.03124614804983139;
  t36_n181: return -0.044835615903139114;
  t36_n182: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t36_n186;
  t36_n183: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t36_n185;
  t36_n184: return 0.046115338802337646;
  t36_n185: return -0.0774741843342781;
  t36_n186: return 0.08470660448074341;
  t36_n187: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t36_n233;
  t36_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n200;
  t36_n189: if (E.getNumReferences() >= 3357605312 /*164855.0*/) goto t36_n197;
  t36_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t36_n192;
  t36_n191: return 0.045772578567266464;
  t36_n192: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t36_n194;
  t36_n193: return 0.10295326262712479;
  t36_n194: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t36_n196;
  t36_n195: return 0.1150103211402893;
  t36_n196: return 0.14545777440071106;
  t36_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n199;
  t36_n198: return 0.09712152928113937;
  t36_n199: return 0.11236823350191116;
  t36_n200: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t36_n204;
  t36_n201: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t36_n203;
  t36_n202: return 0.09396905452013016;
  t36_n203: return -0.015081488527357578;
  t36_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t36_n206;
  t36_n205: return 0.09065888822078705;
  t36_n206: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t36_n208;
  t36_n207: return 0.06410586088895798;
  t36_n208: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t36_n232;
  t36_n209: if (E.getNumReferences() >= 3266183168 /*87.0*/) goto t36_n227;
  t36_n210: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t36_n226;
  t36_n211: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t36_n213;
  t36_n212: return 0.10640276968479156;
  t36_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t36_n215;
  t36_n214: return 0.11649299412965775;
  t36_n215: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t36_n221;
  t36_n216: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t36_n220;
  t36_n217: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t36_n219;
  t36_n218: return 0.1192951649427414;
  t36_n219: return 0.13384270668029785;
  t36_n220: return 0.10974038392305374;
  t36_n221: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t36_n223;
  t36_n222: return 0.0505368709564209;
  t36_n223: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t36_n225;
  t36_n224: return 0.1217413991689682;
  t36_n225: return 0.14843294024467468;
  t36_n226: return 0.08504316210746765;
  t36_n227: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t36_n229;
  t36_n228: return 0.12022082507610321;
  t36_n229: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t36_n231;
  t36_n230: return 0.14598695933818817;
  t36_n231: return 0.11516200006008148;
  t36_n232: return 0.058394260704517365;
  t36_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t36_n235;
  t36_n234: return 0.03893298655748367;
  t36_n235: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t36_n237;
  t36_n236: return 0.035107582807540894;
  t36_n237: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t36_n239;
  t36_n238: return 0.0034113212022930384;
  t36_n239: return 0.08880053460597992;
  t36_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t36_n248;
  t36_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n245;
  t36_n242: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t36_n244;
  t36_n243: return 0.014625688083469868;
  t36_n244: return 0.058003079146146774;
  t36_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n247;
  t36_n246: return 0.02643650956451893;
  t36_n247: return 0.057225264608860016;
  t36_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t36_n254;
  t36_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t36_n251;
  t36_n250: return 0.0653735026717186;
  t36_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t36_n253;
  t36_n252: return 0.0811953991651535;
  t36_n253: return 0.08844323456287384;
  t36_n254: return 0.08734571933746338;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree37(const Example& E) {
  t37_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t37_n238;
  t37_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t37_n171;
  t37_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n88;
  t37_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n17;
  t37_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t37_n6;
  t37_n5: return -0.06601682305335999;
  t37_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t37_n8;
  t37_n7: return -0.03362270072102547;
  t37_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n10;
  t37_n9: return 0.09672114253044128;
  t37_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t37_n12;
  t37_n11: return -0.12355320155620575;
  t37_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t37_n16;
  t37_n13: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t37_n15;
  t37_n14: return 0.11829108744859695;
  t37_n15: return 0.11799056828022003;
  t37_n16: return 0.09028028696775436;
  t37_n17: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t37_n65;
  t37_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t37_n20;
  t37_n19: return -0.010517753660678864;
  t37_n20: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t37_n54;
  t37_n21: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t37_n43;
  t37_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n42;
  t37_n23: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t37_n41;
  t37_n24: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t37_n34;
  t37_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t37_n27;
  t37_n26: return 0.015923582017421722;
  t37_n27: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t37_n29;
  t37_n28: return 0.04109753295779228;
  t37_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t37_n31;
  t37_n30: return -0.040462691336870193;
  t37_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t37_n33;
  t37_n32: return 0.09551220387220383;
  t37_n33: return -0.0350465327501297;
  t37_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n36;
  t37_n35: return 0.03635455295443535;
  t37_n36: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t37_n40;
  t37_n37: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t37_n39;
  t37_n38: return 0.09648221731185913;
  t37_n39: return 0.1059868186712265;
  t37_n40: return 0.05899734050035477;
  t37_n41: return -0.0043646227568387985;
  t37_n42: return -0.0679435282945633;
  t37_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t37_n45;
  t37_n44: return 0.05254330486059189;
  t37_n45: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t37_n47;
  t37_n46: return 0.018944764509797096;
  t37_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n53;
  t37_n48: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n52;
  t37_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n51;
  t37_n50: return 0.10181516408920288;
  t37_n51: return 0.10279801487922668;
  t37_n52: return -0.14899028837680817;
  t37_n53: return 0.013200398534536362;
  t37_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n56;
  t37_n55: return 0.02390773594379425;
  t37_n56: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t37_n64;
  t37_n57: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t37_n61;
  t37_n58: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n60;
  t37_n59: return 0.09345024079084396;
  t37_n60: return -0.11282998323440552;
  t37_n61: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t37_n63;
  t37_n62: return 0.0834641084074974;
  t37_n63: return 0.11276564002037048;
  t37_n64: return 0.05314528942108154;
  t37_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t37_n67;
  t37_n66: return 0.06405410170555115;
  t37_n67: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n75;
  t37_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n74;
  t37_n69: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n73;
  t37_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t37_n72;
  t37_n71: return 0.12177029997110367;
  t37_n72: return 0.10622769594192505;
  t37_n73: return 0.03877243772149086;
  t37_n74: return -0.010504615493118763;
  t37_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n87;
  t37_n76: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t37_n82;
  t37_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n81;
  t37_n78: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n80;
  t37_n79: return 0.12731562554836273;
  t37_n80: return 0.08495151996612549;
  t37_n81: return 0.1138947606086731;
  t37_n82: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t37_n86;
  t37_n83: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n85;
  t37_n84: return 0.12325309216976166;
  t37_n85: return 0.09859828650951385;
  t37_n86: return 0.12063798308372498;
  t37_n87: return 0.062465403228998184;
  t37_n88: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t37_n134;
  t37_n89: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t37_n109;
  t37_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n92;
  t37_n91: return -0.07967056334018707;
  t37_n92: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t37_n96;
  t37_n93: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t37_n95;
  t37_n94: return -0.05003969371318817;
  t37_n95: return 0.021281683817505836;
  t37_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t37_n98;
  t37_n97: return 0.013220855966210365;
  t37_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t37_n100;
  t37_n99: return 0.025621503591537476;
  t37_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t37_n106;
  t37_n101: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n105;
  t37_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n104;
  t37_n103: return 0.08042588829994202;
  t37_n104: return 0.09020677208900452;
  t37_n105: return 0.028297681361436844;
  t37_n106: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n108;
  t37_n107: return 0.103019118309021;
  t37_n108: return 0.08735395967960358;
  t37_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n111;
  t37_n110: return 0.024991707876324654;
  t37_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t37_n129;
  t37_n112: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t37_n116;
  t37_n113: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t37_n115;
  t37_n114: return 0.05484051629900932;
  t37_n115: return 0.07170293480157852;
  t37_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t37_n118;
  t37_n117: return 0.06748189777135849;
  t37_n118: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t37_n126;
  t37_n119: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t37_n121;
  t37_n120: return 0.08041789382696152;
  t37_n121: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t37_n125;
  t37_n122: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t37_n124;
  t37_n123: return 0.1255449652671814;
  t37_n124: return 0.08502946048974991;
  t37_n125: return 0.10886535048484802;
  t37_n126: if (E.getNumReferences() >= 3290349568 /*635.0*/) goto t37_n128;
  t37_n127: return 0.12839500606060028;
  t37_n128: return 0.09021064639091492;
  t37_n129: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t37_n133;
  t37_n130: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t37_n132;
  t37_n131: return 0.06937918812036514;
  t37_n132: return 0.10326489806175232;
  t37_n133: return 0.08949611335992813;
  t37_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t37_n148;
  t37_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n141;
  t37_n136: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t37_n138;
  t37_n137: return -0.04038208723068237;
  t37_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n140;
  t37_n139: return -0.014226372353732586;
  t37_n140: return 0.10989479720592499;
  t37_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace))) goto t37_n143;
  t37_n142: return 0.004589468240737915;
  t37_n143: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t37_n145;
  t37_n144: return 0.055153727531433105;
  t37_n145: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t37_n147;
  t37_n146: return 0.1035095751285553;
  t37_n147: return 0.002292314311489463;
  t37_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t37_n152;
  t37_n149: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t37_n151;
  t37_n150: return -0.022371206432580948;
  t37_n151: return 0.10924109816551208;
  t37_n152: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t37_n154;
  t37_n153: return -0.02070821262896061;
  t37_n154: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t37_n170;
  t37_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t37_n165;
  t37_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n160;
  t37_n157: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t37_n159;
  t37_n158: return -0.025951936841011047;
  t37_n159: return 0.07115285843610764;
  t37_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t37_n162;
  t37_n161: return 0.017039762809872627;
  t37_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t37_n164;
  t37_n163: return -0.39387333393096924;
  t37_n164: return 0.053098831325769424;
  t37_n165: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t37_n167;
  t37_n166: return 0.015900282189249992;
  t37_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t37_n169;
  t37_n168: return 0.13884690403938293;
  t37_n169: return 0.07717162370681763;
  t37_n170: return 0.044636070728302;
  t37_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n181;
  t37_n172: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t37_n176;
  t37_n173: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t37_n175;
  t37_n174: return 0.026576578617095947;
  t37_n175: return 0.0419827401638031;
  t37_n176: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t37_n180;
  t37_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n179;
  t37_n178: return 0.06067918986082077;
  t37_n179: return 0.10768653452396393;
  t37_n180: return 0.06296804547309875;
  t37_n181: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t37_n189;
  t37_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t37_n186;
  t37_n183: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t37_n185;
  t37_n184: return 0.023681912571191788;
  t37_n185: return 0.04669145494699478;
  t37_n186: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t37_n188;
  t37_n187: return 0.05054144188761711;
  t37_n188: return -0.02258623205125332;
  t37_n189: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t37_n227;
  t37_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t37_n192;
  t37_n191: return 0.08416101336479187;
  t37_n192: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t37_n200;
  t37_n193: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t37_n195;
  t37_n194: return 0.0554574653506279;
  t37_n195: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t37_n197;
  t37_n196: return 0.08973436057567596;
  t37_n197: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t37_n199;
  t37_n198: return 0.13132654130458832;
  t37_n199: return 0.10722631216049194;
  t37_n200: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t37_n202;
  t37_n201: return 0.057782724499702454;
  t37_n202: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t37_n226;
  t37_n203: if (E.getNumReferences() >= 3266183168 /*87.0*/) goto t37_n221;
  t37_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t37_n206;
  t37_n205: return 0.1013164296746254;
  t37_n206: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t37_n208;
  t37_n207: return 0.10148867219686508;
  t37_n208: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t37_n214;
  t37_n209: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t37_n213;
  t37_n210: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t37_n212;
  t37_n211: return 0.1176985576748848;
  t37_n212: return 0.12517954409122467;
  t37_n213: return 0.10856891423463821;
  t37_n214: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t37_n216;
  t37_n215: return 0.039364781230688095;
  t37_n216: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t37_n220;
  t37_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t37_n219;
  t37_n218: return 0.1335185319185257;
  t37_n219: return 0.12161162495613098;
  t37_n220: return 0.0983230248093605;
  t37_n221: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t37_n223;
  t37_n222: return 0.11852573603391647;
  t37_n223: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t37_n225;
  t37_n224: return 0.14712361991405487;
  t37_n225: return 0.11463134735822678;
  t37_n226: return 0.05653750151395798;
  t37_n227: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t37_n237;
  t37_n228: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t37_n230;
  t37_n229: return 0.02769591473042965;
  t37_n230: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t37_n236;
  t37_n231: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t37_n233;
  t37_n232: return 0.10802781581878662;
  t37_n233: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t37_n235;
  t37_n234: return 0.11169829964637756;
  t37_n235: return 0.11697052419185638;
  t37_n236: return 0.07000154256820679;
  t37_n237: return 0.05344792455434799;
  t37_n238: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t37_n248;
  t37_n239: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n245;
  t37_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t37_n242;
  t37_n241: return -0.01174853928387165;
  t37_n242: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t37_n244;
  t37_n243: return 0.037673983722925186;
  t37_n244: return 0.010186895728111267;
  t37_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n247;
  t37_n246: return 0.024413418024778366;
  t37_n247: return 0.055051740258932114;
  t37_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t37_n254;
  t37_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t37_n251;
  t37_n250: return 0.06377891451120377;
  t37_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t37_n253;
  t37_n252: return 0.07976660877466202;
  t37_n253: return 0.086338572204113;
  t37_n254: return 0.08587254583835602;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree38(const Example& E) {
  t38_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t38_n246;
  t38_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t38_n181;
  t38_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t38_n52;
  t38_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t38_n5;
  t38_n4: return -0.055362947285175323;
  t38_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t38_n17;
  t38_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t38_n8;
  t38_n7: return -0.040542684495449066;
  t38_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n10;
  t38_n9: return 0.08478958159685135;
  t38_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n12;
  t38_n11: return 0.07891104370355606;
  t38_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t38_n16;
  t38_n13: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t38_n15;
  t38_n14: return 0.11399515718221664;
  t38_n15: return 0.11826348304748535;
  t38_n16: return 0.09269677847623825;
  t38_n17: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t38_n43;
  t38_n18: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t38_n26;
  t38_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n21;
  t38_n20: return -0.07976806908845901;
  t38_n21: if (E.getNumReferences() >= 3342147712 /*46368.5*/) goto t38_n25;
  t38_n22: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t38_n24;
  t38_n23: return 0.034580428153276443;
  t38_n24: return -0.09270016103982925;
  t38_n25: return 0.1515534222126007;
  t38_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t38_n30;
  t38_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n29;
  t38_n28: return 0.03454923629760742;
  t38_n29: return -0.053083062171936035;
  t38_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t38_n32;
  t38_n31: return 0.0026602400466799736;
  t38_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n34;
  t38_n33: return 0.0766591727733612;
  t38_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n40;
  t38_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n37;
  t38_n36: return 0.11738161742687225;
  t38_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n39;
  t38_n38: return 0.12723644077777863;
  t38_n39: return 0.07128223031759262;
  t38_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n42;
  t38_n41: return 0.08781342953443527;
  t38_n42: return 0.025236565619707108;
  t38_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t38_n45;
  t38_n44: return -0.11059661954641342;
  t38_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t38_n47;
  t38_n46: return 0.021480940282344818;
  t38_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t38_n49;
  t38_n48: return 0.05232878774404526;
  t38_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n51;
  t38_n50: return 0.0932735875248909;
  t38_n51: return 0.03855506330728531;
  t38_n52: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t38_n172;
  t38_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t38_n63;
  t38_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n56;
  t38_n55: return -0.007914107292890549;
  t38_n56: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t38_n62;
  t38_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n59;
  t38_n58: return 0.04661652445793152;
  t38_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n61;
  t38_n60: return 0.07621905952692032;
  t38_n61: return 0.039009444415569305;
  t38_n62: return -0.12866993248462677;
  t38_n63: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t38_n165;
  t38_n64: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t38_n108;
  t38_n65: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t38_n85;
  t38_n66: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n84;
  t38_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t38_n73;
  t38_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t38_n72;
  t38_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t38_n71;
  t38_n70: return -0.03888826072216034;
  t38_n71: return 0.045305147767066956;
  t38_n72: return 0.06348416209220886;
  t38_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag))) goto t38_n75;
  t38_n74: return 0.016516538336873055;
  t38_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n81;
  t38_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n80;
  t38_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t38_n79;
  t38_n78: return 0.0985163152217865;
  t38_n79: return 0.1061035767197609;
  t38_n80: return 0.06286760419607162;
  t38_n81: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t38_n83;
  t38_n82: return 0.06595302373170853;
  t38_n83: return 0.09655164927244186;
  t38_n84: return -0.07888197153806686;
  t38_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n87;
  t38_n86: return 0.05073300004005432;
  t38_n87: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t38_n107;
  t38_n88: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t38_n90;
  t38_n89: return 0.06257568299770355;
  t38_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t38_n92;
  t38_n91: return 0.08747126907110214;
  t38_n92: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t38_n94;
  t38_n93: return 0.10147086530923843;
  t38_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n96;
  t38_n95: return 0.10992804914712906;
  t38_n96: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t38_n106;
  t38_n97: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t38_n99;
  t38_n98: return 0.09783713519573212;
  t38_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t38_n105;
  t38_n100: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t38_n104;
  t38_n101: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t38_n103;
  t38_n102: return 0.10447847098112106;
  t38_n103: return 0.11919760704040527;
  t38_n104: return 0.12259134650230408;
  t38_n105: return 0.11399397253990173;
  t38_n106: return 0.06022940203547478;
  t38_n107: return 0.09473935514688492;
  t38_n108: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t38_n142;
  t38_n109: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t38_n111;
  t38_n110: return -0.0005444589769467711;
  t38_n111: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t38_n119;
  t38_n112: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t38_n118;
  t38_n113: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n115;
  t38_n114: return 0.04169207066297531;
  t38_n115: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t38_n117;
  t38_n116: return 0.09289062023162842;
  t38_n117: return 0.05714264512062073;
  t38_n118: return -0.00037876988062635064;
  t38_n119: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t38_n141;
  t38_n120: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t38_n140;
  t38_n121: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t38_n135;
  t38_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t38_n124;
  t38_n123: return 0.10875468701124191;
  t38_n124: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t38_n132;
  t38_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n131;
  t38_n126: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t38_n130;
  t38_n127: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t38_n129;
  t38_n128: return -0.10220228880643845;
  t38_n129: return 0.15667930245399475;
  t38_n130: return 0.13154517114162445;
  t38_n131: return 0.08624933660030365;
  t38_n132: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t38_n134;
  t38_n133: return 0.11087449640035629;
  t38_n134: return 0.13469839096069336;
  t38_n135: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t38_n137;
  t38_n136: return 0.14768993854522705;
  t38_n137: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t38_n139;
  t38_n138: return -0.10561879724264145;
  t38_n139: return 0.1634504348039627;
  t38_n140: return 0.10752209275960922;
  t38_n141: return 0.08582920581102371;
  t38_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t38_n144;
  t38_n143: return 0.02860788255929947;
  t38_n144: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t38_n154;
  t38_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n153;
  t38_n146: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t38_n152;
  t38_n147: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t38_n149;
  t38_n148: return 0.016714204102754593;
  t38_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n151;
  t38_n150: return 0.10164794325828552;
  t38_n151: return -0.07687459886074066;
  t38_n152: return -0.1266942322254181;
  t38_n153: return -0.010576254688203335;
  t38_n154: if (E.getFileProximityDistance() >= 3251634176 /*26.0*/) goto t38_n156;
  t38_n155: return 0.00435137702152133;
  t38_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n164;
  t38_n157: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n163;
  t38_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n162;
  t38_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n161;
  t38_n160: return 0.10029390454292297;
  t38_n161: return 0.10127801448106766;
  t38_n162: return 0.08141831308603287;
  t38_n163: return -0.0813506543636322;
  t38_n164: return -0.10530773550271988;
  t38_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n167;
  t38_n166: return 0.0154801644384861;
  t38_n167: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t38_n171;
  t38_n168: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t38_n170;
  t38_n169: return 0.08097843825817108;
  t38_n170: return 0.10641394555568695;
  t38_n171: return 0.04996678978204727;
  t38_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t38_n174;
  t38_n173: return 0.06373048573732376;
  t38_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t38_n180;
  t38_n175: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t38_n179;
  t38_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n178;
  t38_n177: return 0.11850982159376144;
  t38_n178: return 0.063189797103405;
  t38_n179: return 0.07099172472953796;
  t38_n180: return 0.010561195202171803;
  t38_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n187;
  t38_n182: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t38_n184;
  t38_n183: return 0.02480582892894745;
  t38_n184: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t38_n186;
  t38_n185: return 0.09586063027381897;
  t38_n186: return 0.05813870579004288;
  t38_n187: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t38_n207;
  t38_n188: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t38_n194;
  t38_n189: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t38_n193;
  t38_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t38_n192;
  t38_n191: return 0.06964738667011261;
  t38_n192: return 0.07125753909349442;
  t38_n193: return 0.01785593293607235;
  t38_n194: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t38_n204;
  t38_n195: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t38_n197;
  t38_n196: return -0.020522328093647957;
  t38_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t38_n203;
  t38_n198: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t38_n200;
  t38_n199: return 0.010042008943855762;
  t38_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t38_n202;
  t38_n201: return -0.7789092063903809;
  t38_n202: return 0.1321599930524826;
  t38_n203: return -0.012016556225717068;
  t38_n204: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t38_n206;
  t38_n205: return 0.05125374719500542;
  t38_n206: return 0.10201740264892578;
  t38_n207: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t38_n239;
  t38_n208: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t38_n210;
  t38_n209: return 0.03288095444440842;
  t38_n210: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t38_n238;
  t38_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t38_n215;
  t38_n212: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t38_n214;
  t38_n213: return 0.020977847278118134;
  t38_n214: return 0.10807675868272781;
  t38_n215: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t38_n217;
  t38_n216: return 0.07281500846147537;
  t38_n217: if (E.getNumReferences() >= 3273981952 /*165.0*/) goto t38_n237;
  t38_n218: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t38_n234;
  t38_n219: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t38_n225;
  t38_n220: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t38_n222;
  t38_n221: return 0.11369062215089798;
  t38_n222: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t38_n224;
  t38_n223: return 0.09088750183582306;
  t38_n224: return 0.12466146051883698;
  t38_n225: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t38_n233;
  t38_n226: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t38_n228;
  t38_n227: return 0.11126900464296341;
  t38_n228: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t38_n232;
  t38_n229: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t38_n231;
  t38_n230: return 0.12415345758199692;
  t38_n231: return 0.12461581826210022;
  t38_n232: return 0.08588235825300217;
  t38_n233: return 0.10983006656169891;
  t38_n234: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t38_n236;
  t38_n235: return 0.11673220992088318;
  t38_n236: return 0.12389625608921051;
  t38_n237: return 0.0897487998008728;
  t38_n238: return 0.08485789597034454;
  t38_n239: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t38_n245;
  t38_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t38_n244;
  t38_n241: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t38_n243;
  t38_n242: return 0.12196191400289536;
  t38_n243: return 0.06323973834514618;
  t38_n244: return 0.08155130594968796;
  t38_n245: return 0.04567473381757736;
  t38_n246: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t38_n250;
  t38_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n249;
  t38_n248: return 0.01733136922121048;
  t38_n249: return 0.036481063812971115;
  t38_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t38_n254;
  t38_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t38_n253;
  t38_n252: return 0.06086074560880661;
  t38_n253: return 0.07914861291646957;
  t38_n254: return 0.08429668843746185;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree39(const Example& E) {
  t39_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t39_n242;
  t39_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t39_n207;
  t39_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n122;
  t39_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n73;
  t39_n4: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t39_n36;
  t39_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t39_n35;
  t39_n6: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t39_n24;
  t39_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t39_n9;
  t39_n8: return -0.05039064958691597;
  t39_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t39_n15;
  t39_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n12;
  t39_n11: return -0.06467871367931366;
  t39_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n14;
  t39_n13: return 0.07771693170070648;
  t39_n14: return -0.03645526245236397;
  t39_n15: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t39_n17;
  t39_n16: return 0.017934339120984077;
  t39_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n19;
  t39_n18: return 0.2047569751739502;
  t39_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n23;
  t39_n20: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t39_n22;
  t39_n21: return 0.13871021568775177;
  t39_n22: return 0.11456659436225891;
  t39_n23: return 0.10615316778421402;
  t39_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t39_n26;
  t39_n25: return -0.061688825488090515;
  t39_n26: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t39_n28;
  t39_n27: return 0.013545054942369461;
  t39_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n34;
  t39_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n33;
  t39_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n32;
  t39_n31: return 0.09847233444452286;
  t39_n32: return 0.10026425123214722;
  t39_n33: return -0.14121858775615692;
  t39_n34: return -0.009746836498379707;
  t39_n35: return -0.005086731631308794;
  t39_n36: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t39_n42;
  t39_n37: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t39_n39;
  t39_n38: return 0.0229460671544075;
  t39_n39: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t39_n41;
  t39_n40: return 0.09361903369426727;
  t39_n41: return 0.03902535140514374;
  t39_n42: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t39_n68;
  t39_n43: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t39_n45;
  t39_n44: return 0.08085227012634277;
  t39_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t39_n47;
  t39_n46: return 0.08599235862493515;
  t39_n47: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t39_n49;
  t39_n48: return 0.09656066447496414;
  t39_n49: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t39_n55;
  t39_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n52;
  t39_n51: return 0.11496216803789139;
  t39_n52: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t39_n54;
  t39_n53: return 0.10764119774103165;
  t39_n54: return 0.1365249902009964;
  t39_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t39_n67;
  t39_n56: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t39_n64;
  t39_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t39_n59;
  t39_n58: return 0.10408973693847656;
  t39_n59: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t39_n61;
  t39_n60: return 0.08043712377548218;
  t39_n61: if (E.getNumReferences() >= 3275096064 /*182.0*/) goto t39_n63;
  t39_n62: return 0.1235751062631607;
  t39_n63: return 0.1075480505824089;
  t39_n64: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t39_n66;
  t39_n65: return 0.11461898684501648;
  t39_n66: return 0.14421340823173523;
  t39_n67: return 0.04627405107021332;
  t39_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n72;
  t39_n69: if (E.getNumReferences() >= 3319035904 /*6799.0*/) goto t39_n71;
  t39_n70: return -0.0031901304610073566;
  t39_n71: return 0.06717132776975632;
  t39_n72: return 0.06722072511911392;
  t39_n73: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t39_n91;
  t39_n74: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t39_n90;
  t39_n75: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t39_n77;
  t39_n76: return -0.055073466151952744;
  t39_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t39_n79;
  t39_n78: return 0.008397926576435566;
  t39_n79: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t39_n85;
  t39_n80: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t39_n84;
  t39_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t39_n83;
  t39_n82: return 0.01639508828520775;
  t39_n83: return 0.054471299052238464;
  t39_n84: return -0.031107665970921516;
  t39_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n89;
  t39_n86: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t39_n88;
  t39_n87: return 0.11197694391012192;
  t39_n88: return 0.018863162025809288;
  t39_n89: return 0.01524604856967926;
  t39_n90: return -0.11146949231624603;
  t39_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t39_n93;
  t39_n92: return -0.003956094849854708;
  t39_n93: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t39_n95;
  t39_n94: return 0.12686580419540405;
  t39_n95: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t39_n107;
  t39_n96: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t39_n106;
  t39_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t39_n99;
  t39_n98: return 0.03819461166858673;
  t39_n99: if (E.getNumReferences() >= 3327319040 /*13495.0*/) goto t39_n105;
  t39_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t39_n102;
  t39_n101: return 0.11162766814231873;
  t39_n102: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t39_n104;
  t39_n103: return 0.11762914061546326;
  t39_n104: return 0.06004536896944046;
  t39_n105: return 0.061402346938848495;
  t39_n106: return 0.09200522303581238;
  t39_n107: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t39_n111;
  t39_n108: if (E.getNumReferences() >= 3327415296 /*13589.0*/) goto t39_n110;
  t39_n109: return 0.12955045700073242;
  t39_n110: return 0.022844398394227028;
  t39_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t39_n113;
  t39_n112: return 0.07890859991312027;
  t39_n113: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t39_n121;
  t39_n114: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t39_n116;
  t39_n115: return -0.10181187093257904;
  t39_n116: if (E.getNumReferences() >= 3331241984 /*18268.0*/) goto t39_n120;
  t39_n117: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t39_n119;
  t39_n118: return 0.11582332104444504;
  t39_n119: return 0.1099347174167633;
  t39_n120: return 0.11461499333381653;
  t39_n121: return 0.07722152024507523;
  t39_n122: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t39_n166;
  t39_n123: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t39_n129;
  t39_n124: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t39_n126;
  t39_n125: return 0.020407017320394516;
  t39_n126: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t39_n128;
  t39_n127: return -0.013935007154941559;
  t39_n128: return -0.09359447658061981;
  t39_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n131;
  t39_n130: return -0.07779011875391006;
  t39_n131: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t39_n133;
  t39_n132: return -0.01882772147655487;
  t39_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t39_n139;
  t39_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n138;
  t39_n135: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t39_n137;
  t39_n136: return 0.010779477655887604;
  t39_n137: return -0.07273266464471817;
  t39_n138: return -0.09089940041303635;
  t39_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t39_n165;
  t39_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n142;
  t39_n141: return 0.014418356120586395;
  t39_n142: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t39_n160;
  t39_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n149;
  t39_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t39_n146;
  t39_n145: return 0.028086410835385323;
  t39_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t39_n148;
  t39_n147: return 0.03394468128681183;
  t39_n148: return 0.05011334642767906;
  t39_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t39_n151;
  t39_n150: return 0.019248899072408676;
  t39_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t39_n153;
  t39_n152: return -0.0605170838534832;
  t39_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n155;
  t39_n154: return 0.08157581090927124;
  t39_n155: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t39_n157;
  t39_n156: return 0.05547713115811348;
  t39_n157: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t39_n159;
  t39_n158: return 0.13411453366279602;
  t39_n159: return 0.06689178198575974;
  t39_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n164;
  t39_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n163;
  t39_n162: return 0.0690985843539238;
  t39_n163: return 0.08400663733482361;
  t39_n164: return 0.020922062918543816;
  t39_n165: return 0.0013434316497296095;
  t39_n166: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n182;
  t39_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n169;
  t39_n168: return 0.01971074938774109;
  t39_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t39_n179;
  t39_n170: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t39_n172;
  t39_n171: return 0.050833795219659805;
  t39_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t39_n174;
  t39_n173: return 0.0375654436647892;
  t39_n174: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t39_n176;
  t39_n175: return 0.06802689284086227;
  t39_n176: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t39_n178;
  t39_n177: return 0.11746593564748764;
  t39_n178: return 0.06939229369163513;
  t39_n179: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t39_n181;
  t39_n180: return 0.06904544681310654;
  t39_n181: return 0.08492900431156158;
  t39_n182: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t39_n206;
  t39_n183: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t39_n205;
  t39_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t39_n186;
  t39_n185: return 0.08043646067380905;
  t39_n186: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t39_n196;
  t39_n187: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t39_n189;
  t39_n188: return 0.10427872836589813;
  t39_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t39_n191;
  t39_n190: return 0.12133914977312088;
  t39_n191: if (E.getNumReferences() >= 3275030528 /*181.0*/) goto t39_n195;
  t39_n192: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t39_n194;
  t39_n193: return 0.13398641347885132;
  t39_n194: return 0.13232986629009247;
  t39_n195: return 0.11004990339279175;
  t39_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t39_n198;
  t39_n197: return 0.08845709264278412;
  t39_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t39_n204;
  t39_n199: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t39_n203;
  t39_n200: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t39_n202;
  t39_n201: return 0.13749602437019348;
  t39_n202: return -0.12267275154590607;
  t39_n203: return 0.14974968135356903;
  t39_n204: return 0.1335352063179016;
  t39_n205: return 0.0038894186727702618;
  t39_n206: return 0.03534897789359093;
  t39_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n217;
  t39_n208: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t39_n212;
  t39_n209: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n211;
  t39_n210: return 0.02573220804333687;
  t39_n211: return 0.0443853922188282;
  t39_n212: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t39_n216;
  t39_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n215;
  t39_n214: return 0.05506022274494171;
  t39_n215: return 0.10306484252214432;
  t39_n216: return 0.055319562554359436;
  t39_n217: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t39_n231;
  t39_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t39_n222;
  t39_n219: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n221;
  t39_n220: return 0.019506175071001053;
  t39_n221: return 0.0426773838698864;
  t39_n222: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t39_n228;
  t39_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n227;
  t39_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t39_n226;
  t39_n225: return 0.05059078335762024;
  t39_n226: return 0.03222066909074783;
  t39_n227: return 0.061337150633335114;
  t39_n228: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t39_n230;
  t39_n229: return -0.04802776873111725;
  t39_n230: return 0.0816223993897438;
  t39_n231: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t39_n233;
  t39_n232: return 0.08179254829883575;
  t39_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t39_n241;
  t39_n234: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t39_n236;
  t39_n235: return 0.022647010162472725;
  t39_n236: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t39_n240;
  t39_n237: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t39_n239;
  t39_n238: return 0.1009841337800026;
  t39_n239: return 0.11278136074542999;
  t39_n240: return 0.06272494047880173;
  t39_n241: return 0.047917064279317856;
  t39_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t39_n250;
  t39_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n247;
  t39_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t39_n246;
  t39_n245: return -0.016376707702875137;
  t39_n246: return 0.02396969497203827;
  t39_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t39_n249;
  t39_n248: return 0.01951061747968197;
  t39_n249: return 0.05110973119735718;
  t39_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t39_n254;
  t39_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t39_n253;
  t39_n252: return 0.05882137641310692;
  t39_n253: return 0.07710695266723633;
  t39_n254: return 0.08236297965049744;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree40(const Example& E) {
  t40_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t40_n242;
  t40_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t40_n181;
  t40_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t40_n86;
  t40_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t40_n39;
  t40_n4: if (E.getNumReferences() >= 3307976704 /*2747.5*/) goto t40_n6;
  t40_n5: return -0.06253829598426819;
  t40_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t40_n8;
  t40_n7: return -0.1420886516571045;
  t40_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n10;
  t40_n9: return 0.025398014113307;
  t40_n10: if (E.getNumReferences() >= 3326629376 /*12821.5*/) goto t40_n14;
  t40_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t40_n13;
  t40_n12: return 0.03718787431716919;
  t40_n13: return 0.1579907387495041;
  t40_n14: if (E.getNumReferences() >= 3327212032 /*13390.5*/) goto t40_n26;
  t40_n15: if (E.getNumReferences() >= 3327019520 /*13202.5*/) goto t40_n21;
  t40_n16: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t40_n20;
  t40_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t40_n19;
  t40_n18: return 0.12108375877141953;
  t40_n19: return 0.13334433734416962;
  t40_n20: return 0.1114792600274086;
  t40_n21: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t40_n23;
  t40_n22: return 0.11964424699544907;
  t40_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t40_n25;
  t40_n24: return 0.1441175490617752;
  t40_n25: return 0.12809112668037415;
  t40_n26: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t40_n30;
  t40_n27: if (E.getNumReferences() >= 3351807168 /*102665.5*/) goto t40_n29;
  t40_n28: return 0.0706353560090065;
  t40_n29: return -0.08894065022468567;
  t40_n30: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t40_n36;
  t40_n31: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t40_n33;
  t40_n32: return 0.11528899520635605;
  t40_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t40_n35;
  t40_n34: return 0.11655684560537338;
  t40_n35: return 0.11592214554548264;
  t40_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n38;
  t40_n37: return 0.028716960921883583;
  t40_n38: return 0.10211734473705292;
  t40_n39: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t40_n49;
  t40_n40: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t40_n42;
  t40_n41: return -0.03778796270489693;
  t40_n42: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t40_n44;
  t40_n43: return 0.030653852969408035;
  t40_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n46;
  t40_n45: return 0.07520285248756409;
  t40_n46: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t40_n48;
  t40_n47: return 0.11891970038414001;
  t40_n48: return -0.13208414614200592;
  t40_n49: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t40_n73;
  t40_n50: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t40_n56;
  t40_n51: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t40_n53;
  t40_n52: return -0.0863112136721611;
  t40_n53: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t40_n55;
  t40_n54: return 0.022299157455563545;
  t40_n55: return 0.1561080366373062;
  t40_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t40_n60;
  t40_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n59;
  t40_n58: return 0.03122168779373169;
  t40_n59: return -0.0510648675262928;
  t40_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t40_n62;
  t40_n61: return 0.003581155091524124;
  t40_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n64;
  t40_n63: return 0.07275665551424026;
  t40_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n70;
  t40_n65: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n67;
  t40_n66: return 0.1151968315243721;
  t40_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n69;
  t40_n68: return 0.12476243078708649;
  t40_n69: return 0.0686759352684021;
  t40_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n72;
  t40_n71: return 0.07914815843105316;
  t40_n72: return 0.02330300584435463;
  t40_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t40_n75;
  t40_n74: return -0.10158964991569519;
  t40_n75: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t40_n81;
  t40_n76: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n78;
  t40_n77: return -0.0012293658219277859;
  t40_n78: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t40_n80;
  t40_n79: return 0.059728264808654785;
  t40_n80: return -0.020622052252292633;
  t40_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t40_n83;
  t40_n82: return 0.04916961118578911;
  t40_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n85;
  t40_n84: return 0.0899810791015625;
  t40_n85: return 0.036340486258268356;
  t40_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t40_n106;
  t40_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n89;
  t40_n88: return -0.011375101283192635;
  t40_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t40_n91;
  t40_n90: return 0.01833478733897209;
  t40_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t40_n93;
  t40_n92: return 0.03230121359229088;
  t40_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n95;
  t40_n94: return 0.07017646729946136;
  t40_n95: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t40_n97;
  t40_n96: return -0.012533650733530521;
  t40_n97: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t40_n105;
  t40_n98: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t40_n104;
  t40_n99: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t40_n103;
  t40_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n102;
  t40_n101: return 0.11240291595458984;
  t40_n102: return 0.07972382009029388;
  t40_n103: return 0.11238057911396027;
  t40_n104: return 0.06756579875946045;
  t40_n105: return 0.10956333577632904;
  t40_n106: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t40_n174;
  t40_n107: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t40_n153;
  t40_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t40_n148;
  t40_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n147;
  t40_n110: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t40_n132;
  t40_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t40_n115;
  t40_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t40_n114;
  t40_n113: return 0.0012945469934493303;
  t40_n114: return 0.05278632417321205;
  t40_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t40_n117;
  t40_n116: return 0.03022637404501438;
  t40_n117: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t40_n119;
  t40_n118: return 0.0076742516830563545;
  t40_n119: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t40_n123;
  t40_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n122;
  t40_n121: return 0.10120075196027756;
  t40_n122: return -0.06791941076517105;
  t40_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n131;
  t40_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n130;
  t40_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n129;
  t40_n126: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t40_n128;
  t40_n127: return -0.03275703266263008;
  t40_n128: return 0.09688959270715714;
  t40_n129: return -0.1100349947810173;
  t40_n130: return 0.07202090322971344;
  t40_n131: return 0.0795731246471405;
  t40_n132: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t40_n146;
  t40_n133: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t40_n141;
  t40_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n136;
  t40_n135: return 0.05436254292726517;
  t40_n136: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t40_n140;
  t40_n137: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t40_n139;
  t40_n138: return 0.06700816750526428;
  t40_n139: return 0.08893360197544098;
  t40_n140: return 0.06864847987890244;
  t40_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t40_n143;
  t40_n142: return 0.08729751408100128;
  t40_n143: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t40_n145;
  t40_n144: return 0.09556038677692413;
  t40_n145: return 0.1035492792725563;
  t40_n146: return 0.03515530005097389;
  t40_n147: return -0.04007861018180847;
  t40_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t40_n152;
  t40_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t40_n151;
  t40_n150: return -0.058478306978940964;
  t40_n151: return 0.09534724801778793;
  t40_n152: return 0.011549596674740314;
  t40_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n161;
  t40_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n160;
  t40_n155: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t40_n159;
  t40_n156: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t40_n158;
  t40_n157: return 0.0371662937104702;
  t40_n158: return 0.05603684484958649;
  t40_n159: return -0.03264615684747696;
  t40_n160: return -0.2599371075630188;
  t40_n161: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t40_n173;
  t40_n162: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t40_n164;
  t40_n163: return 0.0791022777557373;
  t40_n164: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t40_n172;
  t40_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n171;
  t40_n166: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t40_n170;
  t40_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t40_n169;
  t40_n168: return 0.057846713811159134;
  t40_n169: return 0.1174023225903511;
  t40_n170: return 0.11126118898391724;
  t40_n171: return 0.10497210174798965;
  t40_n172: return 0.09633435308933258;
  t40_n173: return 0.053725000470876694;
  t40_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t40_n180;
  t40_n175: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t40_n179;
  t40_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n178;
  t40_n177: return 0.10469035804271698;
  t40_n178: return 0.0569327287375927;
  t40_n179: return 0.06464086472988129;
  t40_n180: return 0.008206715807318687;
  t40_n181: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t40_n201;
  t40_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t40_n196;
  t40_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n185;
  t40_n184: return 0.02260560169816017;
  t40_n185: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t40_n191;
  t40_n186: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t40_n190;
  t40_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t40_n189;
  t40_n188: return 0.08089587092399597;
  t40_n189: return 0.045040279626846313;
  t40_n190: return 0.06985544413328171;
  t40_n191: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t40_n193;
  t40_n192: return -0.05168046057224274;
  t40_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t40_n195;
  t40_n194: return 0.005731320474296808;
  t40_n195: return 0.04234291613101959;
  t40_n196: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t40_n200;
  t40_n197: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t40_n199;
  t40_n198: return 0.04237886518239975;
  t40_n199: return 0.07883884757757187;
  t40_n200: return -0.06827498227357864;
  t40_n201: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t40_n235;
  t40_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t40_n208;
  t40_n203: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t40_n207;
  t40_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n206;
  t40_n205: return 0.03911169618368149;
  t40_n206: return 0.07485467940568924;
  t40_n207: return 0.0867425724864006;
  t40_n208: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t40_n214;
  t40_n209: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t40_n211;
  t40_n210: return 0.07729549705982208;
  t40_n211: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t40_n213;
  t40_n212: return -0.16433751583099365;
  t40_n213: return 0.14039607346057892;
  t40_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n216;
  t40_n215: return 0.041180457919836044;
  t40_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n218;
  t40_n217: return 0.11453207582235336;
  t40_n218: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t40_n220;
  t40_n219: return 0.1422300934791565;
  t40_n220: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t40_n222;
  t40_n221: return 0.09113828837871552;
  t40_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t40_n224;
  t40_n223: return 0.10621506720781326;
  t40_n224: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t40_n228;
  t40_n225: if (E.getNumReferences() >= 3266052096 /*86.0*/) goto t40_n227;
  t40_n226: return 0.11646093428134918;
  t40_n227: return 0.1207704246044159;
  t40_n228: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t40_n234;
  t40_n229: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t40_n233;
  t40_n230: if (E.getNumReferences() >= 3259105280 /*48.5*/) goto t40_n232;
  t40_n231: return 0.1112934798002243;
  t40_n232: return 0.12362509220838547;
  t40_n233: return 0.10609473288059235;
  t40_n234: return 0.08576983213424683;
  t40_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t40_n237;
  t40_n236: return 0.030849061906337738;
  t40_n237: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t40_n239;
  t40_n238: return 0.026993820443749428;
  t40_n239: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t40_n241;
  t40_n240: return 0.0019141919910907745;
  t40_n241: return 0.08259481191635132;
  t40_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t40_n250;
  t40_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n247;
  t40_n244: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t40_n246;
  t40_n245: return 0.010034585371613503;
  t40_n246: return 0.05233573541045189;
  t40_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t40_n249;
  t40_n248: return 0.01844082400202751;
  t40_n249: return 0.049050893634557724;
  t40_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t40_n254;
  t40_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t40_n253;
  t40_n252: return 0.0568239800632;
  t40_n253: return 0.07453007996082306;
  t40_n254: return 0.08068624883890152;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree41(const Example& E) {
  t41_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t41_n240;
  t41_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t41_n203;
  t41_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t41_n114;
  t41_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t41_n75;
  t41_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n6;
  t41_n5: return -0.10520941764116287;
  t41_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t41_n50;
  t41_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t41_n23;
  t41_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t41_n22;
  t41_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t41_n11;
  t41_n10: return -0.030468666926026344;
  t41_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n21;
  t41_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t41_n20;
  t41_n13: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t41_n15;
  t41_n14: return -0.060491617769002914;
  t41_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n17;
  t41_n16: return -0.6709210872650146;
  t41_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n19;
  t41_n18: return 0.09468092769384384;
  t41_n19: return 0.07392194867134094;
  t41_n20: return -0.13242489099502563;
  t41_n21: return -0.0070925746113061905;
  t41_n22: return 0.009462571702897549;
  t41_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t41_n29;
  t41_n24: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t41_n26;
  t41_n25: return 0.02674075961112976;
  t41_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t41_n28;
  t41_n27: return -0.09665833413600922;
  t41_n28: return 0.028370190411806107;
  t41_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t41_n39;
  t41_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t41_n32;
  t41_n31: return 0.004122622776776552;
  t41_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n34;
  t41_n33: return 0.08913730829954147;
  t41_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t41_n36;
  t41_n35: return 0.10283865034580231;
  t41_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n38;
  t41_n37: return 0.1213344931602478;
  t41_n38: return 0.0800972729921341;
  t41_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n41;
  t41_n40: return 0.1509074866771698;
  t41_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n47;
  t41_n42: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t41_n46;
  t41_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n45;
  t41_n44: return 0.1461765617132187;
  t41_n45: return 0.13011759519577026;
  t41_n46: return 0.11241767555475235;
  t41_n47: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t41_n49;
  t41_n48: return 0.1105131059885025;
  t41_n49: return 0.09702363610267639;
  t41_n50: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t41_n74;
  t41_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t41_n53;
  t41_n52: return -0.04433785751461983;
  t41_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t41_n55;
  t41_n54: return 0.026300741359591484;
  t41_n55: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t41_n73;
  t41_n56: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t41_n60;
  t41_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n59;
  t41_n58: return 0.012058736756443977;
  t41_n59: return 0.07541155070066452;
  t41_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n62;
  t41_n61: return 0.07302262634038925;
  t41_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n68;
  t41_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n67;
  t41_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t41_n66;
  t41_n65: return 0.059767719358205795;
  t41_n66: return 0.10328985750675201;
  t41_n67: return 0.016554279252886772;
  t41_n68: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t41_n70;
  t41_n69: return 0.10576734691858292;
  t41_n70: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t41_n72;
  t41_n71: return 0.11429159343242645;
  t41_n72: return -0.1115475744009018;
  t41_n73: return 0.035137709230184555;
  t41_n74: return -0.020996257662773132;
  t41_n75: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n81;
  t41_n76: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t41_n80;
  t41_n77: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t41_n79;
  t41_n78: return 0.022493954747915268;
  t41_n79: return 0.11158695071935654;
  t41_n80: return 0.04244447499513626;
  t41_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t41_n91;
  t41_n82: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t41_n84;
  t41_n83: return 0.04258648306131363;
  t41_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n90;
  t41_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t41_n89;
  t41_n86: if (E.getNumReferences() >= 3308359680 /*2841.0*/) goto t41_n88;
  t41_n87: return -0.017507357522845268;
  t41_n88: return 0.058614425361156464;
  t41_n89: return 0.09827828407287598;
  t41_n90: return 0.07048068195581436;
  t41_n91: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t41_n111;
  t41_n92: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t41_n94;
  t41_n93: return 0.06863448768854141;
  t41_n94: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t41_n96;
  t41_n95: return 0.06130596250295639;
  t41_n96: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t41_n110;
  t41_n97: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t41_n99;
  t41_n98: return 0.10796506702899933;
  t41_n99: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t41_n105;
  t41_n100: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t41_n104;
  t41_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t41_n103;
  t41_n102: return 0.10319153964519501;
  t41_n103: return 0.11869559437036514;
  t41_n104: return 0.03250354155898094;
  t41_n105: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t41_n107;
  t41_n106: return 0.10823696106672287;
  t41_n107: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n109;
  t41_n108: return 0.0938991904258728;
  t41_n109: return 0.12496254593133926;
  t41_n110: return 0.09927182644605637;
  t41_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n113;
  t41_n112: return 0.047033775597810745;
  t41_n113: return 0.0891859158873558;
  t41_n114: if (E.getNumReferences() >= 3283271680 /*357.5*/) goto t41_n122;
  t41_n115: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t41_n117;
  t41_n116: return 0.004602473229169846;
  t41_n117: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t41_n121;
  t41_n118: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t41_n120;
  t41_n119: return -0.033001288771629333;
  t41_n120: return -0.09596039354801178;
  t41_n121: return -0.07815799117088318;
  t41_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t41_n198;
  t41_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t41_n125;
  t41_n124: return -0.026733607053756714;
  t41_n125: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t41_n147;
  t41_n126: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t41_n146;
  t41_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t41_n135;
  t41_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t41_n130;
  t41_n129: return 0.07280541211366653;
  t41_n130: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t41_n134;
  t41_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t41_n133;
  t41_n132: return 0.11155259609222412;
  t41_n133: return 0.1279035061597824;
  t41_n134: return 0.08215364068746567;
  t41_n135: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n145;
  t41_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t41_n138;
  t41_n137: return 0.05462583154439926;
  t41_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t41_n142;
  t41_n139: if (E.getNumReferences() >= 3317627904 /*6111.5*/) goto t41_n141;
  t41_n140: return 0.015329133719205856;
  t41_n141: return 0.12388689815998077;
  t41_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n144;
  t41_n143: return 0.04841525852680206;
  t41_n144: return 0.10519404709339142;
  t41_n145: return 0.028063565492630005;
  t41_n146: return 0.0012252974556759;
  t41_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t41_n149;
  t41_n148: return 0.03382670134305954;
  t41_n149: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t41_n151;
  t41_n150: return 0.12075314670801163;
  t41_n151: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t41_n179;
  t41_n152: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t41_n178;
  t41_n153: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t41_n177;
  t41_n154: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t41_n176;
  t41_n155: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t41_n171;
  t41_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t41_n158;
  t41_n157: return 0.06731346994638443;
  t41_n158: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t41_n160;
  t41_n159: return 0.051796503365039825;
  t41_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n170;
  t41_n161: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t41_n169;
  t41_n162: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t41_n168;
  t41_n163: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t41_n167;
  t41_n164: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t41_n166;
  t41_n165: return 0.06698241829872131;
  t41_n166: return 0.12106805294752121;
  t41_n167: return -0.211131751537323;
  t41_n168: return 0.12095412611961365;
  t41_n169: return 0.11254394799470901;
  t41_n170: return 0.09063549339771271;
  t41_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t41_n173;
  t41_n172: return -0.2839740216732025;
  t41_n173: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t41_n175;
  t41_n174: return 0.111418716609478;
  t41_n175: return 0.09826169162988663;
  t41_n176: return 0.02019410952925682;
  t41_n177: return 0.06618811190128326;
  t41_n178: return 0.08371901512145996;
  t41_n179: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t41_n185;
  t41_n180: if (E.getNumReferences() >= 3327663616 /*13831.5*/) goto t41_n184;
  t41_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t41_n183;
  t41_n182: return 0.1248338595032692;
  t41_n183: return -0.21296149492263794;
  t41_n184: return 0.03210650756955147;
  t41_n185: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t41_n197;
  t41_n186: if (E.getNumReferences() >= 3331599872 /*18967.0*/) goto t41_n190;
  t41_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t41_n189;
  t41_n188: return 0.07344038784503937;
  t41_n189: return 0.11987579613924026;
  t41_n190: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t41_n192;
  t41_n191: return 0.12313918769359589;
  t41_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t41_n194;
  t41_n193: return 0.1057765930891037;
  t41_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t41_n196;
  t41_n195: return -0.10316839069128036;
  t41_n196: return 0.12021303921937943;
  t41_n197: return 0.06958001106977463;
  t41_n198: if (E.getNumReferences() >= 3313614848 /*4152.0*/) goto t41_n200;
  t41_n199: return 0.06341493129730225;
  t41_n200: if (E.getNumReferences() >= 3313630208 /*4159.5*/) goto t41_n202;
  t41_n201: return 0.11983362585306168;
  t41_n202: return 0.07276088744401932;
  t41_n203: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t41_n215;
  t41_n204: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t41_n212;
  t41_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n207;
  t41_n206: return 0.019558515399694443;
  t41_n207: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t41_n211;
  t41_n208: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t41_n210;
  t41_n209: return 0.06750739365816116;
  t41_n210: return 0.06606355309486389;
  t41_n211: return 0.010223177261650562;
  t41_n212: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t41_n214;
  t41_n213: return 0.043015025556087494;
  t41_n214: return -0.06493399292230606;
  t41_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t41_n237;
  t41_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n220;
  t41_n217: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t41_n219;
  t41_n218: return 0.058741677552461624;
  t41_n219: return 0.09335051476955414;
  t41_n220: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t41_n222;
  t41_n221: return 0.05868304893374443;
  t41_n222: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t41_n236;
  t41_n223: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t41_n225;
  t41_n224: return 0.05287448689341545;
  t41_n225: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t41_n235;
  t41_n226: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t41_n234;
  t41_n227: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t41_n229;
  t41_n228: return 0.11201127618551254;
  t41_n229: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t41_n231;
  t41_n230: return 0.11281589418649673;
  t41_n231: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t41_n233;
  t41_n232: return 0.11234300583600998;
  t41_n233: return 0.14828461408615112;
  t41_n234: return 0.07788771390914917;
  t41_n235: return 0.09623021632432938;
  t41_n236: return 0.0770936906337738;
  t41_n237: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t41_n239;
  t41_n238: return 0.017961330711841583;
  t41_n239: return 0.0655328556895256;
  t41_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t41_n250;
  t41_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t41_n247;
  t41_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t41_n244;
  t41_n243: return -0.013487085700035095;
  t41_n244: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t41_n246;
  t41_n245: return 0.027783963829278946;
  t41_n246: return 0.006229615770280361;
  t41_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n249;
  t41_n248: return 0.027997327968478203;
  t41_n249: return 0.046933047473430634;
  t41_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t41_n254;
  t41_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t41_n253;
  t41_n252: return 0.05400834232568741;
  t41_n253: return 0.07239622622728348;
  t41_n254: return 0.07921694964170456;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree42(const Example& E) {
  t42_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t42_n240;
  t42_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t42_n207;
  t42_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t42_n136;
  t42_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t42_n67;
  t42_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t42_n18;
  t42_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n17;
  t42_n6: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t42_n8;
  t42_n7: return -0.037490855902433395;
  t42_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n10;
  t42_n9: return -0.02785281091928482;
  t42_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t42_n16;
  t42_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n15;
  t42_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n14;
  t42_n13: return 0.10603093355894089;
  t42_n14: return 0.03206202760338783;
  t42_n15: return -0.09804033488035202;
  t42_n16: return 0.05455341190099716;
  t42_n17: return -0.005018787458539009;
  t42_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t42_n40;
  t42_n19: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t42_n37;
  t42_n20: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t42_n22;
  t42_n21: return -0.009330053813755512;
  t42_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t42_n24;
  t42_n23: return 0.02008703164756298;
  t42_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t42_n26;
  t42_n25: return 0.002837696811184287;
  t42_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n28;
  t42_n27: return 0.051161471754312515;
  t42_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n34;
  t42_n29: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n31;
  t42_n30: return 0.10466275364160538;
  t42_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n33;
  t42_n32: return 0.11731909960508347;
  t42_n33: return 0.05710399150848389;
  t42_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n36;
  t42_n35: return 0.08058083802461624;
  t42_n36: return 0.013332612812519073;
  t42_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n39;
  t42_n38: return -0.09358767420053482;
  t42_n39: return 0.014707647264003754;
  t42_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n42;
  t42_n41: return 0.04967696592211723;
  t42_n42: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t42_n66;
  t42_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n65;
  t42_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n52;
  t42_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t42_n47;
  t42_n46: return -0.11445857584476471;
  t42_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n49;
  t42_n48: return 0.06143416836857796;
  t42_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n51;
  t42_n50: return -0.13702277839183807;
  t42_n51: return 0.07293903827667236;
  t42_n52: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t42_n58;
  t42_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t42_n55;
  t42_n54: return 0.05544663593173027;
  t42_n55: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t42_n57;
  t42_n56: return 0.08593448251485825;
  t42_n57: return 0.10875973850488663;
  t42_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t42_n60;
  t42_n59: return 0.1030084639787674;
  t42_n60: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t42_n64;
  t42_n61: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t42_n63;
  t42_n62: return 0.1333000510931015;
  t42_n63: return 0.10860288888216019;
  t42_n64: return 0.10424675047397614;
  t42_n65: return 0.018755564466118813;
  t42_n66: return -0.119242824614048;
  t42_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n71;
  t42_n68: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t42_n70;
  t42_n69: return 0.017389623448252678;
  t42_n70: return 0.03817242011427879;
  t42_n71: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t42_n83;
  t42_n72: if (E.getNumReferences() >= 3322313728 /*8607.0*/) goto t42_n82;
  t42_n73: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t42_n81;
  t42_n74: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t42_n76;
  t42_n75: return 0.05080670863389969;
  t42_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t42_n78;
  t42_n77: return 0.06782162934541702;
  t42_n78: if (E.getNumReferences() >= 3316801536 /*5708.0*/) goto t42_n80;
  t42_n79: return 0.08667787164449692;
  t42_n80: return 0.13483598828315735;
  t42_n81: return 0.031153041869401932;
  t42_n82: return 0.0649285838007927;
  t42_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n85;
  t42_n84: return 0.05128517746925354;
  t42_n85: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t42_n111;
  t42_n86: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t42_n88;
  t42_n87: return 0.07762572169303894;
  t42_n88: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t42_n90;
  t42_n89: return 0.05270606279373169;
  t42_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t42_n96;
  t42_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t42_n93;
  t42_n92: return 0.08847479522228241;
  t42_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t42_n95;
  t42_n94: return 0.0;
  t42_n95: return 0.13439396023750305;
  t42_n96: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t42_n104;
  t42_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t42_n99;
  t42_n98: return 0.1027669906616211;
  t42_n99: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t42_n101;
  t42_n100: return 0.10546208918094635;
  t42_n101: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t42_n103;
  t42_n102: return 0.11156207323074341;
  t42_n103: return 0.09655668586492538;
  t42_n104: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t42_n110;
  t42_n105: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t42_n109;
  t42_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t42_n108;
  t42_n107: return 0.11340165138244629;
  t42_n108: return 0.1253156214952469;
  t42_n109: return 0.08541890978813171;
  t42_n110: return 0.10872430354356766;
  t42_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t42_n135;
  t42_n112: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t42_n130;
  t42_n113: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t42_n125;
  t42_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n124;
  t42_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t42_n117;
  t42_n116: return 0.10194632411003113;
  t42_n117: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t42_n119;
  t42_n118: return 0.09446459263563156;
  t42_n119: if (E.getNumReferences() >= 3275292672 /*185.0*/) goto t42_n121;
  t42_n120: return 0.1328074187040329;
  t42_n121: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t42_n123;
  t42_n122: return 0.10952425003051758;
  t42_n123: return 0.10936874151229858;
  t42_n124: return 0.0877019539475441;
  t42_n125: if (E.getNumReferences() >= 3289686016 /*594.5*/) goto t42_n129;
  t42_n126: if (E.getNumReferences() >= 3289554944 /*586.5*/) goto t42_n128;
  t42_n127: return 0.10976188629865646;
  t42_n128: return 0.12180563062429428;
  t42_n129: return 0.09348856657743454;
  t42_n130: if (E.getNumReferences() >= 3288629248 /*530.0*/) goto t42_n134;
  t42_n131: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t42_n133;
  t42_n132: return 0.12286219745874405;
  t42_n133: return 0.11836230754852295;
  t42_n134: return 0.13431866466999054;
  t42_n135: return 0.045828912407159805;
  t42_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t42_n150;
  t42_n137: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t42_n141;
  t42_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t42_n140;
  t42_n139: return -0.07041773945093155;
  t42_n140: return -0.04100750386714935;
  t42_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t42_n143;
  t42_n142: return 0.031666066497564316;
  t42_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t42_n145;
  t42_n144: return 0.06178174167871475;
  t42_n145: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t42_n149;
  t42_n146: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t42_n148;
  t42_n147: return 0.12028663605451584;
  t42_n148: return 0.0878564715385437;
  t42_n149: return -0.13512301445007324;
  t42_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t42_n200;
  t42_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t42_n153;
  t42_n152: return -0.019633334130048752;
  t42_n153: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t42_n171;
  t42_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t42_n156;
  t42_n155: return 0.00911285076290369;
  t42_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t42_n160;
  t42_n157: if (E.getNumReferences() >= 3344570752 /*55833.5*/) goto t42_n159;
  t42_n158: return -0.047385599464178085;
  t42_n159: return -1.6160533428192139;
  t42_n160: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t42_n168;
  t42_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t42_n167;
  t42_n162: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t42_n164;
  t42_n163: return -0.026457034051418304;
  t42_n164: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t42_n166;
  t42_n165: return 0.09324149787425995;
  t42_n166: return 0.06676327437162399;
  t42_n167: return 0.08768998086452484;
  t42_n168: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t42_n170;
  t42_n169: return 0.06881550699472427;
  t42_n170: return 0.008022638969123363;
  t42_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n173;
  t42_n172: return -0.04163543879985809;
  t42_n173: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t42_n199;
  t42_n174: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t42_n192;
  t42_n175: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t42_n191;
  t42_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n178;
  t42_n177: return 0.06310597062110901;
  t42_n178: if (E.getNumReferences() >= 3351357120 /*99149.5*/) goto t42_n180;
  t42_n179: return 0.07562904059886932;
  t42_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t42_n184;
  t42_n181: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t42_n183;
  t42_n182: return 0.11571775376796722;
  t42_n183: return -0.09872382134199142;
  t42_n184: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t42_n190;
  t42_n185: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t42_n189;
  t42_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t42_n188;
  t42_n187: return 0.004338487982749939;
  t42_n188: return 0.11079677194356918;
  t42_n189: return 0.09285352379083633;
  t42_n190: return 0.11346780508756638;
  t42_n191: return 0.02190997824072838;
  t42_n192: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t42_n196;
  t42_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t42_n195;
  t42_n194: return 0.023407146334648132;
  t42_n195: return 0.11092424392700195;
  t42_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t42_n198;
  t42_n197: return 0.059443745762109756;
  t42_n198: return 0.13954001665115356;
  t42_n199: return 0.02061515301465988;
  t42_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t42_n206;
  t42_n201: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t42_n205;
  t42_n202: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n204;
  t42_n203: return 0.10075397789478302;
  t42_n204: return 0.049083106219768524;
  t42_n205: return -0.005070025566965342;
  t42_n206: return 0.006138732191175222;
  t42_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n215;
  t42_n208: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t42_n210;
  t42_n209: return 0.02257363311946392;
  t42_n210: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t42_n214;
  t42_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n213;
  t42_n212: return 0.0469496063888073;
  t42_n213: return 0.10076364874839783;
  t42_n214: return 0.04595816135406494;
  t42_n215: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t42_n221;
  t42_n216: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t42_n220;
  t42_n217: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t42_n219;
  t42_n218: return 0.06146440654993057;
  t42_n219: return 0.01357225701212883;
  t42_n220: return 0.051501110196113586;
  t42_n221: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t42_n237;
  t42_n222: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t42_n224;
  t42_n223: return 0.0283907912671566;
  t42_n224: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t42_n236;
  t42_n225: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t42_n233;
  t42_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t42_n232;
  t42_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t42_n231;
  t42_n228: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t42_n230;
  t42_n229: return 0.11413849145174026;
  t42_n230: return -0.42751097679138184;
  t42_n231: return 0.06262442469596863;
  t42_n232: return 0.10536643862724304;
  t42_n233: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t42_n235;
  t42_n234: return 0.10150540620088577;
  t42_n235: return 0.11348651349544525;
  t42_n236: return 0.06280223280191422;
  t42_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t42_n239;
  t42_n238: return 0.0741322860121727;
  t42_n239: return 0.033270929008722305;
  t42_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t42_n248;
  t42_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t42_n247;
  t42_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t42_n244;
  t42_n243: return -0.009360347874462605;
  t42_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n246;
  t42_n245: return 0.015722405165433884;
  t42_n246: return 0.025051068514585495;
  t42_n247: return 0.053251221776008606;
  t42_n248: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t42_n254;
  t42_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t42_n253;
  t42_n250: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t42_n252;
  t42_n251: return 0.052400365471839905;
  t42_n252: return -1.1818149089813232;
  t42_n253: return 0.07040401548147202;
  t42_n254: return 0.07726709544658661;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree43(const Example& E) {
  t43_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t43_n244;
  t43_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t43_n205;
  t43_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t43_n50;
  t43_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t43_n5;
  t43_n4: return -0.047468893229961395;
  t43_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t43_n17;
  t43_n6: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t43_n8;
  t43_n7: return -0.03401704877614975;
  t43_n8: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t43_n10;
  t43_n9: return 0.02503488026559353;
  t43_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n12;
  t43_n11: return 0.06323012709617615;
  t43_n12: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t43_n16;
  t43_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t43_n15;
  t43_n14: return 0.11596348136663437;
  t43_n15: return 0.08510378748178482;
  t43_n16: return -0.13344962894916534;
  t43_n17: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t43_n41;
  t43_n18: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t43_n24;
  t43_n19: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t43_n21;
  t43_n20: return -0.07709621638059616;
  t43_n21: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t43_n23;
  t43_n22: return 0.019858218729496002;
  t43_n23: return 0.1569412350654602;
  t43_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t43_n28;
  t43_n25: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n27;
  t43_n26: return 0.02586708404123783;
  t43_n27: return -0.044863343238830566;
  t43_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t43_n30;
  t43_n29: return 0.0037555077578872442;
  t43_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n32;
  t43_n31: return 0.06564286351203918;
  t43_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n38;
  t43_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n35;
  t43_n34: return 0.10233079642057419;
  t43_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n37;
  t43_n36: return 0.11678358912467957;
  t43_n37: return 0.05778829753398895;
  t43_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n40;
  t43_n39: return 0.06870138645172119;
  t43_n40: return 0.02060181088745594;
  t43_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t43_n43;
  t43_n42: return -0.0906379371881485;
  t43_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t43_n45;
  t43_n44: return 0.016817495226860046;
  t43_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t43_n47;
  t43_n46: return 0.04150906205177307;
  t43_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n49;
  t43_n48: return 0.08193935453891754;
  t43_n49: return 0.03334878385066986;
  t43_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t43_n122;
  t43_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t43_n101;
  t43_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n74;
  t43_n53: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t43_n73;
  t43_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n72;
  t43_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n57;
  t43_n56: return 0.029866671189665794;
  t43_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t43_n61;
  t43_n58: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t43_n60;
  t43_n59: return -0.0016610396560281515;
  t43_n60: return 0.04609021544456482;
  t43_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n71;
  t43_n62: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t43_n70;
  t43_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n69;
  t43_n64: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t43_n66;
  t43_n65: return 0.09256085008382797;
  t43_n66: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t43_n68;
  t43_n67: return 0.1041339859366417;
  t43_n68: return 0.045266296714544296;
  t43_n69: return 0.05903179571032524;
  t43_n70: return -0.011987753212451935;
  t43_n71: return 0.07302061468362808;
  t43_n72: return -0.02367425709962845;
  t43_n73: return -0.0335930772125721;
  t43_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t43_n100;
  t43_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n77;
  t43_n76: return 0.08939637988805771;
  t43_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t43_n81;
  t43_n78: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t43_n80;
  t43_n79: return -0.2809866666793823;
  t43_n80: return 0.0629500225186348;
  t43_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n93;
  t43_n82: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t43_n92;
  t43_n83: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t43_n89;
  t43_n84: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t43_n86;
  t43_n85: return 0.10059891641139984;
  t43_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n88;
  t43_n87: return 0.11481710523366928;
  t43_n88: return -0.39259129762649536;
  t43_n89: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t43_n91;
  t43_n90: return 0.12458371371030807;
  t43_n91: return 0.10884097218513489;
  t43_n92: return 0.02665458247065544;
  t43_n93: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t43_n95;
  t43_n94: return 0.037609200924634933;
  t43_n95: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t43_n99;
  t43_n96: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t43_n98;
  t43_n97: return 0.04284759238362312;
  t43_n98: return 0.12971840798854828;
  t43_n99: return -0.002188628539443016;
  t43_n100: return -0.12506498396396637;
  t43_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t43_n113;
  t43_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n104;
  t43_n103: return 0.017531948164105415;
  t43_n104: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t43_n110;
  t43_n105: if (E.getNumReferences() >= 3313957888 /*4319.5*/) goto t43_n107;
  t43_n106: return 0.06755475699901581;
  t43_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t43_n109;
  t43_n108: return -0.12873367965221405;
  t43_n109: return 0.1151280403137207;
  t43_n110: if (E.getNumReferences() >= 3350304896 /*90929.0*/) goto t43_n112;
  t43_n111: return 0.004521478433161974;
  t43_n112: return 0.03488617390394211;
  t43_n113: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t43_n117;
  t43_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t43_n116;
  t43_n115: return 0.022266047075390816;
  t43_n116: return -0.08904312551021576;
  t43_n117: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t43_n119;
  t43_n118: return 0.0865335538983345;
  t43_n119: if (E.getNumReferences() >= 3345471616 /*59352.5*/) goto t43_n121;
  t43_n120: return 0.05738483741879463;
  t43_n121: return 0.09534192830324173;
  t43_n122: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t43_n198;
  t43_n123: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t43_n173;
  t43_n124: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n172;
  t43_n125: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t43_n169;
  t43_n126: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t43_n148;
  t43_n127: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t43_n133;
  t43_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t43_n130;
  t43_n129: return 0.003496906952932477;
  t43_n130: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n132;
  t43_n131: return 0.04115966707468033;
  t43_n132: return -0.15925078094005585;
  t43_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t43_n135;
  t43_n134: return 0.03409409523010254;
  t43_n135: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t43_n141;
  t43_n136: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n138;
  t43_n137: return 0.05551021918654442;
  t43_n138: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n140;
  t43_n139: return 0.09374657273292542;
  t43_n140: return -0.09019798040390015;
  t43_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n147;
  t43_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n146;
  t43_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n145;
  t43_n144: return 0.09136015176773071;
  t43_n145: return 0.05027921870350838;
  t43_n146: return 0.06806188821792603;
  t43_n147: return -0.11321104317903519;
  t43_n148: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t43_n168;
  t43_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n151;
  t43_n150: return 0.046049319207668304;
  t43_n151: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t43_n163;
  t43_n152: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t43_n162;
  t43_n153: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t43_n155;
  t43_n154: return 0.06706079840660095;
  t43_n155: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t43_n161;
  t43_n156: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t43_n158;
  t43_n157: return 0.06960850954055786;
  t43_n158: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t43_n160;
  t43_n159: return 0.11081524193286896;
  t43_n160: return 0.12274874746799469;
  t43_n161: return 0.08196306973695755;
  t43_n162: return 0.06274178624153137;
  t43_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t43_n165;
  t43_n164: return 0.08095846325159073;
  t43_n165: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t43_n167;
  t43_n166: return 0.09182743728160858;
  t43_n167: return 0.09877505898475647;
  t43_n168: return 0.031619809567928314;
  t43_n169: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t43_n171;
  t43_n170: return -0.10401492565870285;
  t43_n171: return 0.005989354103803635;
  t43_n172: return -0.04418177902698517;
  t43_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n181;
  t43_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n180;
  t43_n175: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t43_n179;
  t43_n176: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t43_n178;
  t43_n177: return 0.03815910965204239;
  t43_n178: return 0.05118688568472862;
  t43_n179: return -0.02009310945868492;
  t43_n180: return -0.22815470397472382;
  t43_n181: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t43_n195;
  t43_n182: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t43_n194;
  t43_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n193;
  t43_n184: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t43_n190;
  t43_n185: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t43_n189;
  t43_n186: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t43_n188;
  t43_n187: return 0.06824788451194763;
  t43_n188: return 0.09501289576292038;
  t43_n189: return 0.02164395898580551;
  t43_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t43_n192;
  t43_n191: return 0.06637893617153168;
  t43_n192: return 0.1261409968137741;
  t43_n193: return -0.09256494045257568;
  t43_n194: return 0.09235575050115585;
  t43_n195: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t43_n197;
  t43_n196: return -0.14329716563224792;
  t43_n197: return 0.05123712494969368;
  t43_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t43_n204;
  t43_n199: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t43_n203;
  t43_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n202;
  t43_n201: return 0.09682772308588028;
  t43_n202: return 0.04578198865056038;
  t43_n203: return 0.05650106072425842;
  t43_n204: return 0.0003987904929090291;
  t43_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n213;
  t43_n206: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t43_n208;
  t43_n207: return 0.022221341729164124;
  t43_n208: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t43_n212;
  t43_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n211;
  t43_n210: return 0.04750833287835121;
  t43_n211: return 0.09767487645149231;
  t43_n212: return 0.04451904445886612;
  t43_n213: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t43_n225;
  t43_n214: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t43_n220;
  t43_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t43_n219;
  t43_n216: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n218;
  t43_n217: return 0.07800448685884476;
  t43_n218: return 0.00871039554476738;
  t43_n219: return 0.05504220724105835;
  t43_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t43_n222;
  t43_n221: return 0.01676081120967865;
  t43_n222: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t43_n224;
  t43_n223: return 0.03468573838472366;
  t43_n224: return 0.10070764273405075;
  t43_n225: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t43_n243;
  t43_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t43_n238;
  t43_n227: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t43_n229;
  t43_n228: return 0.03757056966423988;
  t43_n229: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t43_n237;
  t43_n230: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t43_n232;
  t43_n231: return 0.10807815194129944;
  t43_n232: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t43_n234;
  t43_n233: return 0.1108432337641716;
  t43_n234: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t43_n236;
  t43_n235: return 0.11203009635210037;
  t43_n236: return 0.15363642573356628;
  t43_n237: return 0.06537214666604996;
  t43_n238: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t43_n240;
  t43_n239: return 0.07382272928953171;
  t43_n240: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t43_n242;
  t43_n241: return 0.10670778900384903;
  t43_n242: return 0.08848480135202408;
  t43_n243: return 0.05793815851211548;
  t43_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t43_n250;
  t43_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n247;
  t43_n246: return 0.012484190985560417;
  t43_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t43_n249;
  t43_n248: return 0.014666415750980377;
  t43_n249: return 0.04296388849616051;
  t43_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t43_n254;
  t43_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t43_n253;
  t43_n252: return 0.05096007138490677;
  t43_n253: return 0.06841588765382767;
  t43_n254: return 0.07612770795822144;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree44(const Example& E) {
  t44_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t44_n242;
  t44_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t44_n133;
  t44_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n110;
  t44_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t44_n49;
  t44_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t44_n6;
  t44_n5: return -0.024293536320328712;
  t44_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t44_n24;
  t44_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t44_n21;
  t44_n8: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t44_n10;
  t44_n9: return -0.011778797954320908;
  t44_n10: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n14;
  t44_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t44_n13;
  t44_n12: return 0.020518586039543152;
  t44_n13: return 0.04299282655119896;
  t44_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t44_n16;
  t44_n15: return 0.035126443952322006;
  t44_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t44_n18;
  t44_n17: return 0.026254205033183098;
  t44_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t44_n20;
  t44_n19: return 0.10384384542703629;
  t44_n20: return 0.09839324653148651;
  t44_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n23;
  t44_n22: return -0.09765972942113876;
  t44_n23: return 0.016834130510687828;
  t44_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n26;
  t44_n25: return 0.06195678561925888;
  t44_n26: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t44_n48;
  t44_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t44_n33;
  t44_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t44_n30;
  t44_n29: return -0.11009704321622849;
  t44_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t44_n32;
  t44_n31: return -0.13598990440368652;
  t44_n32: return 0.06757490336894989;
  t44_n33: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t44_n37;
  t44_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t44_n36;
  t44_n35: return -0.02851085364818573;
  t44_n36: return 0.07464741170406342;
  t44_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t44_n43;
  t44_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t44_n42;
  t44_n39: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t44_n41;
  t44_n40: return 0.1150076687335968;
  t44_n41: return 0.1360168159008026;
  t44_n42: return 0.05542629212141037;
  t44_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t44_n47;
  t44_n44: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t44_n46;
  t44_n45: return 0.1295044720172882;
  t44_n46: return 0.10656126588582993;
  t44_n47: return 0.10404347628355026;
  t44_n48: return -0.13346245884895325;
  t44_n49: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t44_n79;
  t44_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n76;
  t44_n51: if (E.getNumReferences() >= 3354076032 /*120391.0*/) goto t44_n65;
  t44_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n54;
  t44_n53: return 0.008919809944927692;
  t44_n54: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t44_n62;
  t44_n55: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t44_n57;
  t44_n56: return 0.04695183411240578;
  t44_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t44_n59;
  t44_n58: return 0.06456561386585236;
  t44_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t44_n61;
  t44_n60: return 0.07089012116193771;
  t44_n61: return 0.09559787064790726;
  t44_n62: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t44_n64;
  t44_n63: return -0.0015968570951372385;
  t44_n64: return 0.05976584926247597;
  t44_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t44_n67;
  t44_n66: return 0.021609829738736153;
  t44_n67: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t44_n75;
  t44_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t44_n70;
  t44_n69: return -0.1258685439825058;
  t44_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t44_n74;
  t44_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n73;
  t44_n72: return 0.19213242828845978;
  t44_n73: return 0.11959285289049149;
  t44_n74: return 0.09849417209625244;
  t44_n75: return 0.05542486906051636;
  t44_n76: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t44_n78;
  t44_n77: return 0.057353027164936066;
  t44_n78: return 0.08758872747421265;
  t44_n79: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t44_n105;
  t44_n80: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t44_n82;
  t44_n81: return 0.0862971618771553;
  t44_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n84;
  t44_n83: return 0.08606243133544922;
  t44_n84: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t44_n104;
  t44_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t44_n103;
  t44_n86: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t44_n92;
  t44_n87: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t44_n91;
  t44_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t44_n90;
  t44_n89: return 0.10303869843482971;
  t44_n90: return 0.14521700143814087;
  t44_n91: return 0.1063937395811081;
  t44_n92: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t44_n102;
  t44_n93: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t44_n95;
  t44_n94: return 0.1014941856265068;
  t44_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t44_n99;
  t44_n96: if (E.getNumReferences() >= 3278340096 /*231.5*/) goto t44_n98;
  t44_n97: return 0.12005867063999176;
  t44_n98: return 0.10155146569013596;
  t44_n99: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t44_n101;
  t44_n100: return -0.17856334149837494;
  t44_n101: return 0.12699751555919647;
  t44_n102: return 0.13959693908691406;
  t44_n103: return 0.10161413997411728;
  t44_n104: return 0.053550444543361664;
  t44_n105: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t44_n107;
  t44_n106: return 0.0604475662112236;
  t44_n107: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t44_n109;
  t44_n108: return -0.12869277596473694;
  t44_n109: return 0.12870340049266815;
  t44_n110: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t44_n112;
  t44_n111: return -0.037972357124090195;
  t44_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n114;
  t44_n113: return 0.001228130073286593;
  t44_n114: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t44_n130;
  t44_n115: if (E.getNumReferences() >= 3332134144 /*20010.5*/) goto t44_n129;
  t44_n116: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t44_n126;
  t44_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t44_n119;
  t44_n118: return 0.0725105032324791;
  t44_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t44_n125;
  t44_n120: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t44_n124;
  t44_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t44_n123;
  t44_n122: return -0.16863998770713806;
  t44_n123: return 0.123162642121315;
  t44_n124: return 0.11804983764886856;
  t44_n125: return -0.11471951007843018;
  t44_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t44_n128;
  t44_n127: return 0.0081983283162117;
  t44_n128: return 0.12315896898508072;
  t44_n129: return 0.11299879103899002;
  t44_n130: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t44_n132;
  t44_n131: return 0.035231444984674454;
  t44_n132: return 0.08153291791677475;
  t44_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n221;
  t44_n134: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t44_n146;
  t44_n135: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t44_n145;
  t44_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t44_n138;
  t44_n137: return 0.013064312748610973;
  t44_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t44_n144;
  t44_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t44_n141;
  t44_n140: return 0.04656098410487175;
  t44_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t44_n143;
  t44_n142: return -0.36557188630104065;
  t44_n143: return -0.025142816826701164;
  t44_n144: return 0.05496266484260559;
  t44_n145: return -0.01204124465584755;
  t44_n146: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t44_n174;
  t44_n147: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t44_n171;
  t44_n148: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t44_n162;
  t44_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t44_n151;
  t44_n150: return 0.042962681502103806;
  t44_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t44_n153;
  t44_n152: return 0.03757135942578316;
  t44_n153: if (E.getNumReferences() >= 3324333056 /*10579.0*/) goto t44_n161;
  t44_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t44_n160;
  t44_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t44_n157;
  t44_n156: return 0.07114937156438828;
  t44_n157: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t44_n159;
  t44_n158: return 0.07020167261362076;
  t44_n159: return 0.08212114870548248;
  t44_n160: return 0.045522406697273254;
  t44_n161: return 0.06765322387218475;
  t44_n162: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t44_n164;
  t44_n163: return 0.06920038163661957;
  t44_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n166;
  t44_n165: return 0.07005167752504349;
  t44_n166: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t44_n168;
  t44_n167: return 0.09941409528255463;
  t44_n168: if (E.getNumReferences() >= 3290054656 /*617.0*/) goto t44_n170;
  t44_n169: return 0.1207844540476799;
  t44_n170: return 0.09590913355350494;
  t44_n171: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n173;
  t44_n172: return -0.03408896178007126;
  t44_n173: return 0.016319725662469864;
  t44_n174: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t44_n218;
  t44_n175: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t44_n213;
  t44_n176: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t44_n178;
  t44_n177: return 0.07559382915496826;
  t44_n178: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t44_n204;
  t44_n179: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t44_n191;
  t44_n180: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t44_n182;
  t44_n181: return 0.10389962047338486;
  t44_n182: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t44_n190;
  t44_n183: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n185;
  t44_n184: return -0.1762019842863083;
  t44_n185: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t44_n187;
  t44_n186: return -0.14951059222221375;
  t44_n187: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t44_n189;
  t44_n188: return 0.1819792538881302;
  t44_n189: return 0.14863939583301544;
  t44_n190: return 0.032886963337659836;
  t44_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t44_n193;
  t44_n192: return 0.12535598874092102;
  t44_n193: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t44_n199;
  t44_n194: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t44_n196;
  t44_n195: return 0.1414700150489807;
  t44_n196: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t44_n198;
  t44_n197: return 0.10212089121341705;
  t44_n198: return 0.12140429019927979;
  t44_n199: if (E.getNumReferences() >= 3287072768 /*473.5*/) goto t44_n201;
  t44_n200: return 0.12312133610248566;
  t44_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n203;
  t44_n202: return -0.11236371099948883;
  t44_n203: return 0.11701709777116776;
  t44_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t44_n212;
  t44_n205: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n207;
  t44_n206: return 0.08600073307752609;
  t44_n207: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t44_n209;
  t44_n208: return 0.12506987154483795;
  t44_n209: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t44_n211;
  t44_n210: return 0.1431622952222824;
  t44_n211: return 0.11914102733135223;
  t44_n212: return 0.21360664069652557;
  t44_n213: if (E.getNumReferences() >= 3304226816 /*1940.0*/) goto t44_n215;
  t44_n214: return -0.01688382960855961;
  t44_n215: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t44_n217;
  t44_n216: return 0.026220517233014107;
  t44_n217: return 0.07306814193725586;
  t44_n218: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t44_n220;
  t44_n219: return -0.010550318285822868;
  t44_n220: return 0.040736258029937744;
  t44_n221: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t44_n225;
  t44_n222: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n224;
  t44_n223: return 0.03751401603221893;
  t44_n224: return 0.015811672434210777;
  t44_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t44_n227;
  t44_n226: return 0.06772035360336304;
  t44_n227: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t44_n241;
  t44_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n238;
  t44_n229: if (E.getNumReferences() >= 3318290432 /*6435.0*/) goto t44_n237;
  t44_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t44_n234;
  t44_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t44_n233;
  t44_n232: return 0.16837111115455627;
  t44_n233: return 0.11226489394903183;
  t44_n234: if (E.getNumReferences() >= 3291725824 /*719.0*/) goto t44_n236;
  t44_n235: return 0.05654074251651764;
  t44_n236: return 0.11220324784517288;
  t44_n237: return -0.008908032439649105;
  t44_n238: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t44_n240;
  t44_n239: return 0.016976967453956604;
  t44_n240: return 0.06794597953557968;
  t44_n241: return -0.4171523451805115;
  t44_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t44_n250;
  t44_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t44_n249;
  t44_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t44_n246;
  t44_n245: return -0.011124324053525925;
  t44_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t44_n248;
  t44_n247: return 0.026654329150915146;
  t44_n248: return 0.009893125854432583;
  t44_n249: return 0.049071092158555984;
  t44_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t44_n254;
  t44_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t44_n253;
  t44_n252: return 0.04693726822733879;
  t44_n253: return 0.06612439453601837;
  t44_n254: return 0.07333523035049438;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree45(const Example& E) {
  t45_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t45_n242;
  t45_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t45_n205;
  t45_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n140;
  t45_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t45_n85;
  t45_n4: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t45_n10;
  t45_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t45_n7;
  t45_n6: return -0.03878267854452133;
  t45_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n9;
  t45_n8: return -0.01337344478815794;
  t45_n9: return -0.05581933632493019;
  t45_n10: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t45_n22;
  t45_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n21;
  t45_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t45_n14;
  t45_n13: return 0.019077986478805542;
  t45_n14: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t45_n18;
  t45_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t45_n17;
  t45_n16: return 0.07008162140846252;
  t45_n17: return 0.08890661597251892;
  t45_n18: if (E.getNumReferences() >= 3322075136 /*8374.0*/) goto t45_n20;
  t45_n19: return 0.02962479554116726;
  t45_n20: return 0.06446485966444016;
  t45_n21: return -0.0069566648453474045;
  t45_n22: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t45_n68;
  t45_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t45_n25;
  t45_n24: return 0.09693577885627747;
  t45_n25: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t45_n31;
  t45_n26: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t45_n30;
  t45_n27: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t45_n29;
  t45_n28: return 0.15922586619853973;
  t45_n29: return 0.07758715003728867;
  t45_n30: return 0.1022767424583435;
  t45_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n59;
  t45_n32: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t45_n34;
  t45_n33: return 0.15491251647472382;
  t45_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t45_n36;
  t45_n35: return 0.09551940113306046;
  t45_n36: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t45_n48;
  t45_n37: if (E.getNumReferences() >= 3272245248 /*138.5*/) goto t45_n45;
  t45_n38: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t45_n44;
  t45_n39: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t45_n43;
  t45_n40: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t45_n42;
  t45_n41: return 0.12738971412181854;
  t45_n42: return 0.14097119867801666;
  t45_n43: return 0.14542363584041595;
  t45_n44: return 0.08997993916273117;
  t45_n45: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t45_n47;
  t45_n46: return 0.09831365197896957;
  t45_n47: return 0.14865538477897644;
  t45_n48: if (E.getNumReferences() >= 3277455360 /*218.0*/) goto t45_n50;
  t45_n49: return 0.0826878771185875;
  t45_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n56;
  t45_n51: if (E.getNumReferences() >= 3280732160 /*280.0*/) goto t45_n55;
  t45_n52: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t45_n54;
  t45_n53: return 0.10951296985149384;
  t45_n54: return 0.09954026341438293;
  t45_n55: return 0.08836407214403152;
  t45_n56: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t45_n58;
  t45_n57: return 0.4833403527736664;
  t45_n58: return 0.12412381917238235;
  t45_n59: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n67;
  t45_n60: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t45_n64;
  t45_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t45_n63;
  t45_n62: return 0.09927617758512497;
  t45_n63: return 0.117418572306633;
  t45_n64: if (E.getNumReferences() >= 3273064448 /*151.0*/) goto t45_n66;
  t45_n65: return 0.10001974552869797;
  t45_n66: return 0.13324688374996185;
  t45_n67: return 0.08219517767429352;
  t45_n68: if (E.getNumReferences() >= 3309385728 /*3091.5*/) goto t45_n76;
  t45_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t45_n71;
  t45_n70: return 0.040486760437488556;
  t45_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t45_n73;
  t45_n72: return 0.09676642715930939;
  t45_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t45_n75;
  t45_n74: return 0.053833793848752975;
  t45_n75: return 0.09287746250629425;
  t45_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t45_n78;
  t45_n77: return 0.04133662208914757;
  t45_n78: if (E.getNumReferences() >= 3332703232 /*21122.0*/) goto t45_n84;
  t45_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t45_n83;
  t45_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t45_n82;
  t45_n81: return 0.06931572407484055;
  t45_n82: return 0.09536321461200714;
  t45_n83: return 0.09295689314603806;
  t45_n84: return 0.060586024075746536;
  t45_n85: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t45_n107;
  t45_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t45_n88;
  t45_n87: return -0.10673873126506805;
  t45_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t45_n90;
  t45_n89: return 0.011147492565214634;
  t45_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t45_n98;
  t45_n91: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t45_n93;
  t45_n92: return 0.02597849629819393;
  t45_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t45_n95;
  t45_n94: return -0.09082065522670746;
  t45_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n97;
  t45_n96: return 0.02052619308233261;
  t45_n97: return 0.08582962304353714;
  t45_n98: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t45_n100;
  t45_n99: return 0.021511323750019073;
  t45_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n102;
  t45_n101: return 0.07449206709861755;
  t45_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n106;
  t45_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n105;
  t45_n104: return 0.11190628260374069;
  t45_n105: return 0.13856804370880127;
  t45_n106: return 0.04853130131959915;
  t45_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t45_n113;
  t45_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t45_n110;
  t45_n109: return 0.004695583134889603;
  t45_n110: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t45_n112;
  t45_n111: return 0.1033553034067154;
  t45_n112: return -0.017506830394268036;
  t45_n113: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t45_n125;
  t45_n114: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t45_n120;
  t45_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t45_n117;
  t45_n116: return 0.03701140731573105;
  t45_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n119;
  t45_n118: return 0.07165718078613281;
  t45_n119: return 0.0051089623011648655;
  t45_n120: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t45_n122;
  t45_n121: return -0.12756288051605225;
  t45_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t45_n124;
  t45_n123: return 0.007927682250738144;
  t45_n124: return 0.05236465111374855;
  t45_n125: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t45_n131;
  t45_n126: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n128;
  t45_n127: return 0.10187677294015884;
  t45_n128: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t45_n130;
  t45_n129: return 0.14183728396892548;
  t45_n130: return 0.10869599133729935;
  t45_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t45_n133;
  t45_n132: return 0.04168513044714928;
  t45_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t45_n135;
  t45_n134: return 0.07948527485132217;
  t45_n135: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t45_n137;
  t45_n136: return 0.08438087999820709;
  t45_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t45_n139;
  t45_n138: return 0.1729329228401184;
  t45_n139: return 0.1082054078578949;
  t45_n140: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t45_n156;
  t45_n141: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n153;
  t45_n142: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t45_n150;
  t45_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t45_n145;
  t45_n144: return -0.0636780634522438;
  t45_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t45_n149;
  t45_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n148;
  t45_n147: return -0.0006485919002443552;
  t45_n148: return -0.06564050912857056;
  t45_n149: return 0.024252155795693398;
  t45_n150: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t45_n152;
  t45_n151: return 0.05023109167814255;
  t45_n152: return -0.022992076352238655;
  t45_n153: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t45_n155;
  t45_n154: return -0.009619501419365406;
  t45_n155: return 0.0228411927819252;
  t45_n156: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n162;
  t45_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t45_n159;
  t45_n158: return 0.02211480215191841;
  t45_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t45_n161;
  t45_n160: return 0.05214855074882507;
  t45_n161: return 0.0711488351225853;
  t45_n162: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t45_n170;
  t45_n163: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t45_n165;
  t45_n164: return 0.023578010499477386;
  t45_n165: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t45_n169;
  t45_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t45_n168;
  t45_n167: return -0.17271342873573303;
  t45_n168: return 0.10995496064424515;
  t45_n169: return 0.029430394992232323;
  t45_n170: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t45_n172;
  t45_n171: return 0.10972420126199722;
  t45_n172: if (E.getNumReferences() >= 3276963840 /*210.5*/) goto t45_n190;
  t45_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t45_n175;
  t45_n174: return 0.06336010992527008;
  t45_n175: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t45_n177;
  t45_n176: return 0.06906703859567642;
  t45_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t45_n189;
  t45_n178: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t45_n182;
  t45_n179: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t45_n181;
  t45_n180: return 0.15486927330493927;
  t45_n181: return 0.14347843825817108;
  t45_n182: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t45_n188;
  t45_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t45_n185;
  t45_n184: return -0.021088963374495506;
  t45_n185: if (E.getNumReferences() >= 3263692800 /*68.0*/) goto t45_n187;
  t45_n186: return 0.1312038153409958;
  t45_n187: return 0.13446931540966034;
  t45_n188: return 0.1492665857076645;
  t45_n189: return 0.09188620001077652;
  t45_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t45_n196;
  t45_n191: if (E.getNumReferences() >= 3277094912 /*212.5*/) goto t45_n195;
  t45_n192: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t45_n194;
  t45_n193: return -0.10162874311208725;
  t45_n194: return 0.13233321905136108;
  t45_n195: return 0.07762180268764496;
  t45_n196: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t45_n204;
  t45_n197: if (E.getNumReferences() >= 3278012416 /*226.5*/) goto t45_n199;
  t45_n198: return -0.18827524781227112;
  t45_n199: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t45_n203;
  t45_n200: if (E.getNumReferences() >= 3278667776 /*236.5*/) goto t45_n202;
  t45_n201: return 0.12221164256334305;
  t45_n202: return 0.02977663278579712;
  t45_n203: return 0.1368335783481598;
  t45_n204: return 0.07915378361940384;
  t45_n205: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t45_n223;
  t45_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n208;
  t45_n207: return 0.018576303496956825;
  t45_n208: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t45_n222;
  t45_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t45_n215;
  t45_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t45_n214;
  t45_n211: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t45_n213;
  t45_n212: return 0.06871616095304489;
  t45_n213: return 0.02969803288578987;
  t45_n214: return 0.05477425828576088;
  t45_n215: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t45_n217;
  t45_n216: return -0.02044288069009781;
  t45_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Expression))) goto t45_n221;
  t45_n218: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t45_n220;
  t45_n219: return 0.012430910021066666;
  t45_n220: return -0.10691875219345093;
  t45_n221: return 0.0346798412501812;
  t45_n222: return 0.044489651918411255;
  t45_n223: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t45_n239;
  t45_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n228;
  t45_n225: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t45_n227;
  t45_n226: return 0.059422656893730164;
  t45_n227: return 0.08699791878461838;
  t45_n228: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t45_n230;
  t45_n229: return 0.020796215161681175;
  t45_n230: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t45_n238;
  t45_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t45_n235;
  t45_n232: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t45_n234;
  t45_n233: return 0.000983759411610663;
  t45_n234: return 0.09038735926151276;
  t45_n235: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t45_n237;
  t45_n236: return 0.05147552117705345;
  t45_n237: return 0.10151077061891556;
  t45_n238: return 0.0676175132393837;
  t45_n239: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t45_n241;
  t45_n240: return 0.012625953182578087;
  t45_n241: return 0.06771672517061234;
  t45_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t45_n250;
  t45_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n247;
  t45_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t45_n246;
  t45_n245: return -0.01825018785893917;
  t45_n246: return 0.015718890354037285;
  t45_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t45_n249;
  t45_n248: return 0.012398050166666508;
  t45_n249: return 0.039137545973062515;
  t45_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t45_n254;
  t45_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t45_n253;
  t45_n252: return 0.046930912882089615;
  t45_n253: return 0.06347072869539261;
  t45_n254: return 0.07209525257349014;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree46(const Example& E) {
  t46_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t46_n240;
  t46_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t46_n157;
  t46_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t46_n136;
  t46_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t46_n127;
  t46_n4: if (E.getNumReferences() >= 3302477824 /*1726.5*/) goto t46_n58;
  t46_n5: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t46_n55;
  t46_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t46_n48;
  t46_n7: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t46_n9;
  t46_n8: return -0.007959683425724506;
  t46_n9: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t46_n11;
  t46_n10: return 0.044617895036935806;
  t46_n11: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t46_n15;
  t46_n12: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t46_n14;
  t46_n13: return 0.07049542665481567;
  t46_n14: return 0.09853275120258331;
  t46_n15: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t46_n25;
  t46_n16: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t46_n24;
  t46_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n19;
  t46_n18: return 0.06253321468830109;
  t46_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t46_n23;
  t46_n20: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t46_n22;
  t46_n21: return 0.0658816322684288;
  t46_n22: return 0.14533160626888275;
  t46_n23: return 0.11468365043401718;
  t46_n24: return 0.083208367228508;
  t46_n25: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t46_n35;
  t46_n26: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t46_n32;
  t46_n27: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t46_n31;
  t46_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t46_n30;
  t46_n29: return 0.1959695816040039;
  t46_n30: return 0.14690111577510834;
  t46_n31: return 0.09773681312799454;
  t46_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t46_n34;
  t46_n33: return 0.210405170917511;
  t46_n34: return 0.12790364027023315;
  t46_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t46_n37;
  t46_n36: return -0.1023319661617279;
  t46_n37: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t46_n47;
  t46_n38: if (E.getNumReferences() >= 3272245248 /*138.5*/) goto t46_n44;
  t46_n39: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t46_n43;
  t46_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t46_n42;
  t46_n41: return -0.1119351014494896;
  t46_n42: return 0.11413811147212982;
  t46_n43: return 0.14134271442890167;
  t46_n44: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t46_n46;
  t46_n45: return 0.14060662686824799;
  t46_n46: return 0.12811458110809326;
  t46_n47: return 0.10041888058185577;
  t46_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag))) goto t46_n50;
  t46_n49: return 0.030355393886566162;
  t46_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n54;
  t46_n51: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t46_n53;
  t46_n52: return 0.10221845656633377;
  t46_n53: return -0.14968737959861755;
  t46_n54: return 0.07315105944871902;
  t46_n55: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t46_n57;
  t46_n56: return -0.04201190918684006;
  t46_n57: return -0.01669915020465851;
  t46_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t46_n68;
  t46_n59: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t46_n67;
  t46_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n62;
  t46_n61: return 0.015902584418654442;
  t46_n62: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t46_n66;
  t46_n63: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t46_n65;
  t46_n64: return 0.052728552371263504;
  t46_n65: return 0.10803741961717606;
  t46_n66: return 0.06409996747970581;
  t46_n67: return -0.019266163930296898;
  t46_n68: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t46_n74;
  t46_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t46_n71;
  t46_n70: return -0.48632505536079407;
  t46_n71: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t46_n73;
  t46_n72: return 0.032842740416526794;
  t46_n73: return 0.05773879587650299;
  t46_n74: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t46_n88;
  t46_n75: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t46_n87;
  t46_n76: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t46_n86;
  t46_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t46_n79;
  t46_n78: return 0.05442443862557411;
  t46_n79: if (E.getNumReferences() >= 3353598912 /*116663.5*/) goto t46_n81;
  t46_n80: return 0.06010521948337555;
  t46_n81: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t46_n85;
  t46_n82: if (E.getNumReferences() >= 3355447552 /*131140.0*/) goto t46_n84;
  t46_n83: return 0.10142756253480911;
  t46_n84: return 0.0902186706662178;
  t46_n85: return 0.08533700555562973;
  t46_n86: return -0.008874350227415562;
  t46_n87: return 0.06633585691452026;
  t46_n88: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t46_n112;
  t46_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n107;
  t46_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t46_n92;
  t46_n91: return -0.08389978855848312;
  t46_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t46_n94;
  t46_n93: return 0.056193333119153976;
  t46_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t46_n100;
  t46_n95: if (E.getNumReferences() >= 3327959040 /*14120.0*/) goto t46_n99;
  t46_n96: if (E.getNumReferences() >= 3327660032 /*13828.0*/) goto t46_n98;
  t46_n97: return 0.10023672878742218;
  t46_n98: return 0.10775056481361389;
  t46_n99: return 0.04757571592926979;
  t46_n100: if (E.getNumReferences() >= 3331473152 /*18719.5*/) goto t46_n106;
  t46_n101: if (E.getNumReferences() >= 3331038976 /*17871.5*/) goto t46_n103;
  t46_n102: return 0.11143804341554642;
  t46_n103: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t46_n105;
  t46_n104: return 0.10905306041240692;
  t46_n105: return 0.10691864788532257;
  t46_n106: return 0.07935803383588791;
  t46_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t46_n109;
  t46_n108: return 0.04994148388504982;
  t46_n109: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t46_n111;
  t46_n110: return 0.08306130021810532;
  t46_n111: return -0.016047261655330658;
  t46_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t46_n116;
  t46_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t46_n115;
  t46_n114: return 0.07699542492628098;
  t46_n115: return 0.10280206799507141;
  t46_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t46_n118;
  t46_n117: return -0.23771105706691742;
  t46_n118: if (E.getNumReferences() >= 3341127552 /*42383.5*/) goto t46_n126;
  t46_n119: if (E.getNumReferences() >= 3328147968 /*14304.5*/) goto t46_n121;
  t46_n120: return 0.1191849336028099;
  t46_n121: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t46_n125;
  t46_n122: if (E.getNumReferences() >= 3331241984 /*18268.0*/) goto t46_n124;
  t46_n123: return 0.1121678426861763;
  t46_n124: return 0.10910829156637192;
  t46_n125: return 0.10100672394037247;
  t46_n126: return 0.05175783112645149;
  t46_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t46_n135;
  t46_n128: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t46_n134;
  t46_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t46_n131;
  t46_n130: return 0.04916958883404732;
  t46_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t46_n133;
  t46_n132: return 0.049035705626010895;
  t46_n133: return 0.0816156417131424;
  t46_n134: return 0.019725831225514412;
  t46_n135: return 0.09188001602888107;
  t46_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t46_n138;
  t46_n137: return -0.05462833121418953;
  t46_n138: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t46_n156;
  t46_n139: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n141;
  t46_n140: return 0.05611738562583923;
  t46_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n147;
  t46_n142: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t46_n146;
  t46_n143: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t46_n145;
  t46_n144: return 0.03338908404111862;
  t46_n145: return 0.10628322511911392;
  t46_n146: return 0.055573105812072754;
  t46_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t46_n155;
  t46_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t46_n150;
  t46_n149: return 0.01408223807811737;
  t46_n150: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t46_n154;
  t46_n151: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t46_n153;
  t46_n152: return 0.11885558068752289;
  t46_n153: return 0.11284635961055756;
  t46_n154: return 0.03053661808371544;
  t46_n155: return 0.0008501035626977682;
  t46_n156: return -0.08354692906141281;
  t46_n157: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t46_n211;
  t46_n158: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t46_n166;
  t46_n159: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t46_n165;
  t46_n160: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t46_n162;
  t46_n161: return 0.010987053625285625;
  t46_n162: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t46_n164;
  t46_n163: return 0.04845085367560387;
  t46_n164: return -0.021321328356862068;
  t46_n165: return -0.0071618990041315556;
  t46_n166: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t46_n172;
  t46_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n169;
  t46_n168: return 0.018797580152750015;
  t46_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t46_n171;
  t46_n170: return 0.04981033504009247;
  t46_n171: return 0.06886359304189682;
  t46_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t46_n180;
  t46_n173: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t46_n175;
  t46_n174: return 0.024459002539515495;
  t46_n175: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t46_n179;
  t46_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t46_n178;
  t46_n177: return -0.05438021197915077;
  t46_n178: return 0.10936104506254196;
  t46_n179: return 0.027668334543704987;
  t46_n180: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t46_n194;
  t46_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t46_n187;
  t46_n182: if (E.getNumReferences() >= 3294576640 /*893.0*/) goto t46_n184;
  t46_n183: return 0.09344179183244705;
  t46_n184: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t46_n186;
  t46_n185: return 0.0810207724571228;
  t46_n186: return 0.10859508067369461;
  t46_n187: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t46_n191;
  t46_n188: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t46_n190;
  t46_n189: return 0.03037494421005249;
  t46_n190: return 0.14585596323013306;
  t46_n191: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t46_n193;
  t46_n192: return 0.1252736896276474;
  t46_n193: return 0.07796800881624222;
  t46_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t46_n202;
  t46_n195: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t46_n201;
  t46_n196: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t46_n198;
  t46_n197: return 0.09638211131095886;
  t46_n198: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t46_n200;
  t46_n199: return 0.17756541073322296;
  t46_n200: return 0.11225973814725876;
  t46_n201: return 0.07309702783823013;
  t46_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t46_n204;
  t46_n203: return 0.0670749768614769;
  t46_n204: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t46_n206;
  t46_n205: return 0.08196453750133514;
  t46_n206: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t46_n208;
  t46_n207: return 0.14256294071674347;
  t46_n208: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t46_n210;
  t46_n209: return 0.11430492997169495;
  t46_n210: return 0.0725393146276474;
  t46_n211: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t46_n227;
  t46_n212: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t46_n218;
  t46_n213: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t46_n215;
  t46_n214: return 0.052971284836530685;
  t46_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t46_n217;
  t46_n216: return 0.007263694889843464;
  t46_n217: return 0.04154454916715622;
  t46_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t46_n220;
  t46_n219: return 0.0676555186510086;
  t46_n220: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t46_n226;
  t46_n221: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t46_n225;
  t46_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t46_n224;
  t46_n223: return 0.12140152603387833;
  t46_n224: return 0.08621010929346085;
  t46_n225: return 0.05425418168306351;
  t46_n226: return 0.02429996058344841;
  t46_n227: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t46_n237;
  t46_n228: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t46_n230;
  t46_n229: return -0.013770418241620064;
  t46_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t46_n232;
  t46_n231: return -0.045352108776569366;
  t46_n232: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t46_n236;
  t46_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t46_n235;
  t46_n234: return -0.5102289319038391;
  t46_n235: return 0.12910036742687225;
  t46_n236: return -0.07760182023048401;
  t46_n237: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t46_n239;
  t46_n238: return 0.04052695631980896;
  t46_n239: return 0.09927772730588913;
  t46_n240: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t46_n250;
  t46_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t46_n245;
  t46_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t46_n244;
  t46_n243: return -0.019328102469444275;
  t46_n244: return 0.01463851984590292;
  t46_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t46_n249;
  t46_n246: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t46_n248;
  t46_n247: return 0.005481171887367964;
  t46_n248: return 0.09106045216321945;
  t46_n249: return 0.026983633637428284;
  t46_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t46_n254;
  t46_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t46_n253;
  t46_n252: return 0.04511869698762894;
  t46_n253: return 0.061853982508182526;
  t46_n254: return 0.07015928626060486;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree47(const Example& E) {
  t47_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t47_n242;
  t47_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t47_n225;
  t47_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t47_n108;
  t47_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t47_n27;
  t47_n4: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t47_n6;
  t47_n5: return -0.045847706496715546;
  t47_n6: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t47_n18;
  t47_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t47_n13;
  t47_n8: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t47_n12;
  t47_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t47_n11;
  t47_n10: return 0.10240629315376282;
  t47_n11: return -0.12097807228565216;
  t47_n12: return -0.13723382353782654;
  t47_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n15;
  t47_n14: return 0.3271450996398926;
  t47_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t47_n17;
  t47_n16: return 0.1157015711069107;
  t47_n17: return 0.11161697655916214;
  t47_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t47_n24;
  t47_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n21;
  t47_n20: return -0.03486471250653267;
  t47_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n23;
  t47_n22: return 0.03383694589138031;
  t47_n23: return 0.09053122252225876;
  t47_n24: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t47_n26;
  t47_n25: return 0.11802715063095093;
  t47_n26: return 0.09112399071455002;
  t47_n27: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t47_n99;
  t47_n28: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t47_n70;
  t47_n29: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t47_n61;
  t47_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t47_n32;
  t47_n31: return -0.09896514564752579;
  t47_n32: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t47_n38;
  t47_n33: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t47_n35;
  t47_n34: return -0.0798402652144432;
  t47_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n37;
  t47_n36: return -0.00421931641176343;
  t47_n37: return 0.023450279608368874;
  t47_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t47_n46;
  t47_n39: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t47_n41;
  t47_n40: return 0.018842153251171112;
  t47_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t47_n43;
  t47_n42: return -0.05975435674190521;
  t47_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n45;
  t47_n44: return 0.044935014098882675;
  t47_n45: return 0.0688767358660698;
  t47_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t47_n48;
  t47_n47: return 0.002993321744725108;
  t47_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n50;
  t47_n49: return 0.048716578632593155;
  t47_n50: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n58;
  t47_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n57;
  t47_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n56;
  t47_n53: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t47_n55;
  t47_n54: return 0.1302167773246765;
  t47_n55: return 0.10469905287027359;
  t47_n56: return 0.11114340275526047;
  t47_n57: return 0.06417609006166458;
  t47_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n60;
  t47_n59: return 0.047633808106184006;
  t47_n60: return 0.0099726477637887;
  t47_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n63;
  t47_n62: return 0.24871762096881866;
  t47_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t47_n65;
  t47_n64: return -0.06693190336227417;
  t47_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t47_n69;
  t47_n66: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t47_n68;
  t47_n67: return 0.1299591213464737;
  t47_n68: return 0.11656012386083603;
  t47_n69: return 0.09156139940023422;
  t47_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n72;
  t47_n71: return -0.048438750207424164;
  t47_n72: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t47_n96;
  t47_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t47_n75;
  t47_n74: return -0.09685519337654114;
  t47_n75: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t47_n95;
  t47_n76: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t47_n78;
  t47_n77: return 0.04466497525572777;
  t47_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t47_n86;
  t47_n79: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t47_n85;
  t47_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t47_n84;
  t47_n81: if (E.getNumReferences() >= 3338441472 /*32329.5*/) goto t47_n83;
  t47_n82: return 0.05211235210299492;
  t47_n83: return 0.08950281888246536;
  t47_n84: return 0.03151756152510643;
  t47_n85: return 0.10511350631713867;
  t47_n86: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t47_n88;
  t47_n87: return 0.09129566699266434;
  t47_n88: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t47_n94;
  t47_n89: if (E.getNumReferences() >= 3287973888 /*501.0*/) goto t47_n91;
  t47_n90: return 0.04237419739365578;
  t47_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t47_n93;
  t47_n92: return 0.1176171526312828;
  t47_n93: return 0.14930547773838043;
  t47_n94: return 0.1109669879078865;
  t47_n95: return -0.16154879331588745;
  t47_n96: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n98;
  t47_n97: return 0.09704131633043289;
  t47_n98: return 0.12709587812423706;
  t47_n99: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t47_n101;
  t47_n100: return 0.023399552330374718;
  t47_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n103;
  t47_n102: return 0.058761920779943466;
  t47_n103: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t47_n107;
  t47_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t47_n106;
  t47_n105: return 0.11358317732810974;
  t47_n106: return 0.07917433977127075;
  t47_n107: return -0.13207079470157623;
  t47_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t47_n144;
  t47_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n111;
  t47_n110: return -0.008939000777900219;
  t47_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t47_n129;
  t47_n112: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t47_n128;
  t47_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n115;
  t47_n114: return 0.012876151129603386;
  t47_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t47_n117;
  t47_n116: return -0.3514515161514282;
  t47_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n123;
  t47_n118: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t47_n122;
  t47_n119: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t47_n121;
  t47_n120: return 0.045128338038921356;
  t47_n121: return 0.1107548251748085;
  t47_n122: return 0.006431868299841881;
  t47_n123: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t47_n125;
  t47_n124: return 0.04534413293004036;
  t47_n125: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t47_n127;
  t47_n126: return 0.12512412667274475;
  t47_n127: return 0.030039561912417412;
  t47_n128: return -0.1107720285654068;
  t47_n129: if (E.getNumReferences() >= 3347359424 /*67917.5*/) goto t47_n143;
  t47_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t47_n132;
  t47_n131: return 0.026596959680318832;
  t47_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n136;
  t47_n133: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n135;
  t47_n134: return 0.07979274541139603;
  t47_n135: return -0.02128704823553562;
  t47_n136: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t47_n138;
  t47_n137: return -0.02386574074625969;
  t47_n138: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t47_n142;
  t47_n139: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t47_n141;
  t47_n140: return 0.0769573524594307;
  t47_n141: return 0.106548011302948;
  t47_n142: return 0.055953919887542725;
  t47_n143: return 0.062066104263067245;
  t47_n144: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t47_n216;
  t47_n145: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t47_n191;
  t47_n146: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n190;
  t47_n147: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t47_n183;
  t47_n148: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t47_n166;
  t47_n149: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t47_n165;
  t47_n150: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t47_n162;
  t47_n151: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t47_n161;
  t47_n152: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t47_n154;
  t47_n153: return 0.03372858464717865;
  t47_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t47_n156;
  t47_n155: return 0.06563778966665268;
  t47_n156: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t47_n158;
  t47_n157: return -0.004311565775424242;
  t47_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n160;
  t47_n159: return 0.0858621671795845;
  t47_n160: return 0.0612034909427166;
  t47_n161: return -0.01841914653778076;
  t47_n162: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t47_n164;
  t47_n163: return -0.059935230761766434;
  t47_n164: return 0.020282501354813576;
  t47_n165: return -0.1462099403142929;
  t47_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t47_n182;
  t47_n167: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t47_n175;
  t47_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n170;
  t47_n169: return 0.03810138255357742;
  t47_n170: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t47_n174;
  t47_n171: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t47_n173;
  t47_n172: return 0.05744525045156479;
  t47_n173: return 0.07691103219985962;
  t47_n174: return 0.05480698123574257;
  t47_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t47_n177;
  t47_n176: return 0.07393854111433029;
  t47_n177: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t47_n181;
  t47_n178: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t47_n180;
  t47_n179: return 0.07634568214416504;
  t47_n180: return 0.09669946879148483;
  t47_n181: return 0.09420102834701538;
  t47_n182: return 0.026633772999048233;
  t47_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t47_n187;
  t47_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t47_n186;
  t47_n185: return -0.052018627524375916;
  t47_n186: return 0.09479127079248428;
  t47_n187: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t47_n189;
  t47_n188: return -0.07795128971338272;
  t47_n189: return 0.01690850220620632;
  t47_n190: return -0.042088497430086136;
  t47_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t47_n193;
  t47_n192: return 0.016147444024682045;
  t47_n193: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t47_n211;
  t47_n194: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t47_n206;
  t47_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n205;
  t47_n196: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t47_n202;
  t47_n197: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t47_n201;
  t47_n198: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t47_n200;
  t47_n199: return 0.06203779578208923;
  t47_n200: return 0.09004157781600952;
  t47_n201: return 0.012087193317711353;
  t47_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t47_n204;
  t47_n203: return 0.06119203567504883;
  t47_n204: return 0.12356191128492355;
  t47_n205: return -0.09218922257423401;
  t47_n206: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t47_n208;
  t47_n207: return 0.07553490251302719;
  t47_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t47_n210;
  t47_n209: return 0.10723134875297546;
  t47_n210: return 0.09716886281967163;
  t47_n211: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t47_n213;
  t47_n212: return -0.12791045010089874;
  t47_n213: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t47_n215;
  t47_n214: return 0.05825604870915413;
  t47_n215: return -0.0349796824157238;
  t47_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t47_n224;
  t47_n217: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t47_n221;
  t47_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n220;
  t47_n219: return 0.09225229173898697;
  t47_n220: return 0.03939049318432808;
  t47_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n223;
  t47_n222: return 0.012802254408597946;
  t47_n223: return 0.09358344227075577;
  t47_n224: return -0.002525538206100464;
  t47_n225: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t47_n231;
  t47_n226: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n228;
  t47_n227: return 0.019262637943029404;
  t47_n228: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t47_n230;
  t47_n229: return 0.03413253650069237;
  t47_n230: return 0.013267013244330883;
  t47_n231: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t47_n237;
  t47_n232: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t47_n234;
  t47_n233: return 0.07597023248672485;
  t47_n234: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t47_n236;
  t47_n235: return 0.044736847281455994;
  t47_n236: return 0.07936464995145798;
  t47_n237: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t47_n239;
  t47_n238: return 0.012294942513108253;
  t47_n239: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t47_n241;
  t47_n240: return -0.004812796600162983;
  t47_n241: return 0.0780157595872879;
  t47_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t47_n250;
  t47_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t47_n249;
  t47_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t47_n246;
  t47_n245: return -0.006953505799174309;
  t47_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t47_n248;
  t47_n247: return 0.023779602721333504;
  t47_n248: return 0.007769410032778978;
  t47_n249: return 0.04558553174138069;
  t47_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t47_n254;
  t47_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t47_n253;
  t47_n252: return 0.045222219079732895;
  t47_n253: return 0.059219326823949814;
  t47_n254: return 0.06808535009622574;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree48(const Example& E) {
  t48_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t48_n242;
  t48_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t48_n189;
  t48_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t48_n78;
  t48_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t48_n23;
  t48_n4: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t48_n6;
  t48_n5: return -0.04384564980864525;
  t48_n6: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t48_n18;
  t48_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t48_n13;
  t48_n8: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t48_n12;
  t48_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n11;
  t48_n10: return 0.09814662486314774;
  t48_n11: return -0.1028486117720604;
  t48_n12: return -0.11925717443227768;
  t48_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t48_n17;
  t48_n14: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t48_n16;
  t48_n15: return 0.13494610786437988;
  t48_n16: return 0.1250736117362976;
  t48_n17: return 0.10791732370853424;
  t48_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n20;
  t48_n19: return 0.00987265631556511;
  t48_n20: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t48_n22;
  t48_n21: return 0.11670646071434021;
  t48_n22: return 0.08498862385749817;
  t48_n23: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t48_n69;
  t48_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n50;
  t48_n25: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t48_n29;
  t48_n26: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t48_n28;
  t48_n27: return -0.0022802921012043953;
  t48_n28: return 0.04317060858011246;
  t48_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n31;
  t48_n30: return 0.16341367363929749;
  t48_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n33;
  t48_n32: return -0.06175748258829117;
  t48_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t48_n49;
  t48_n34: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t48_n38;
  t48_n35: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t48_n37;
  t48_n36: return 0.06575874984264374;
  t48_n37: return 0.12846626341342926;
  t48_n38: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n46;
  t48_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n41;
  t48_n40: return 0.07895856350660324;
  t48_n41: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t48_n45;
  t48_n42: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t48_n44;
  t48_n43: return 0.12368374317884445;
  t48_n44: return 0.11630748212337494;
  t48_n45: return 0.09990520030260086;
  t48_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n48;
  t48_n47: return 0.12792466580867767;
  t48_n48: return 0.05362152308225632;
  t48_n49: return 0.09078188985586166;
  t48_n50: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t48_n52;
  t48_n51: return -0.04662219062447548;
  t48_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n54;
  t48_n53: return -0.07950426638126373;
  t48_n54: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t48_n68;
  t48_n55: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t48_n67;
  t48_n56: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t48_n66;
  t48_n57: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t48_n61;
  t48_n58: if (E.getNumReferences() >= 3332189440 /*20118.5*/) goto t48_n60;
  t48_n59: return 0.043959807604551315;
  t48_n60: return 0.08219298720359802;
  t48_n61: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t48_n63;
  t48_n62: return 0.03838725388050079;
  t48_n63: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t48_n65;
  t48_n64: return 0.0860578715801239;
  t48_n65: return 0.13692933320999146;
  t48_n66: return 0.0975499153137207;
  t48_n67: return -0.15229997038841248;
  t48_n68: return 0.11163006722927094;
  t48_n69: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t48_n71;
  t48_n70: return 0.027282414957880974;
  t48_n71: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n73;
  t48_n72: return 0.053020499646663666;
  t48_n73: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t48_n77;
  t48_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t48_n76;
  t48_n75: return 0.11068890988826752;
  t48_n76: return 0.07621318101882935;
  t48_n77: return -0.13151895999908447;
  t48_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t48_n104;
  t48_n79: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n81;
  t48_n80: return -0.009189669042825699;
  t48_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t48_n83;
  t48_n82: return 0.015291326679289341;
  t48_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t48_n85;
  t48_n84: return 0.024666404351592064;
  t48_n85: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t48_n95;
  t48_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n88;
  t48_n87: return 0.05316344276070595;
  t48_n88: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t48_n90;
  t48_n89: return -0.023692753165960312;
  t48_n90: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t48_n92;
  t48_n91: return -0.07934925705194473;
  t48_n92: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n94;
  t48_n93: return 0.1165269985795021;
  t48_n94: return 0.08977712690830231;
  t48_n95: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t48_n101;
  t48_n96: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t48_n100;
  t48_n97: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t48_n99;
  t48_n98: return 0.07977869361639023;
  t48_n99: return 0.10750984400510788;
  t48_n100: return 0.05374440550804138;
  t48_n101: if (E.getNumReferences() >= 3351690304 /*101752.5*/) goto t48_n103;
  t48_n102: return 0.11166912317276001;
  t48_n103: return 0.09187794476747513;
  t48_n104: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t48_n180;
  t48_n105: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t48_n149;
  t48_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n148;
  t48_n107: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n141;
  t48_n108: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t48_n126;
  t48_n109: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t48_n123;
  t48_n110: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t48_n122;
  t48_n111: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t48_n121;
  t48_n112: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t48_n114;
  t48_n113: return 0.03231531009078026;
  t48_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t48_n116;
  t48_n115: return 0.05799880251288414;
  t48_n116: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t48_n118;
  t48_n117: return -0.004337986931204796;
  t48_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n120;
  t48_n119: return 0.08355078101158142;
  t48_n120: return 0.0564713180065155;
  t48_n121: return -0.14175626635551453;
  t48_n122: return -0.023703493177890778;
  t48_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n125;
  t48_n124: return -0.05948984622955322;
  t48_n125: return 0.0222018975764513;
  t48_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t48_n140;
  t48_n127: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n129;
  t48_n128: return 0.03137115761637688;
  t48_n129: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t48_n131;
  t48_n130: return 0.05839965492486954;
  t48_n131: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t48_n137;
  t48_n132: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t48_n134;
  t48_n133: return 0.060443200170993805;
  t48_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion))) goto t48_n136;
  t48_n135: return 0.08330818265676498;
  t48_n136: return 0.10898367315530777;
  t48_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t48_n139;
  t48_n138: return 0.06859918683767319;
  t48_n139: return 0.0913970023393631;
  t48_n140: return 0.023177558556199074;
  t48_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t48_n145;
  t48_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t48_n144;
  t48_n143: return -0.04915129765868187;
  t48_n144: return 0.09043075144290924;
  t48_n145: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t48_n147;
  t48_n146: return 0.016475317999720573;
  t48_n147: return -0.1757425218820572;
  t48_n148: return -0.042192600667476654;
  t48_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t48_n155;
  t48_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n154;
  t48_n151: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t48_n153;
  t48_n152: return 0.042957283556461334;
  t48_n153: return -0.021462902426719666;
  t48_n154: return -0.19391462206840515;
  t48_n155: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t48_n177;
  t48_n156: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t48_n172;
  t48_n157: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t48_n161;
  t48_n158: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t48_n160;
  t48_n159: return 0.06416954845190048;
  t48_n160: return 0.011415870860219002;
  t48_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t48_n163;
  t48_n162: return 0.03194235637784004;
  t48_n163: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t48_n171;
  t48_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n170;
  t48_n165: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t48_n169;
  t48_n166: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t48_n168;
  t48_n167: return 0.10362294316291809;
  t48_n168: return 0.11512645334005356;
  t48_n169: return 0.10204895585775375;
  t48_n170: return 0.07562866061925888;
  t48_n171: return 0.12464451044797897;
  t48_n172: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t48_n174;
  t48_n173: return 0.07200933992862701;
  t48_n174: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t48_n176;
  t48_n175: return 0.1063447892665863;
  t48_n176: return 0.09575214982032776;
  t48_n177: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t48_n179;
  t48_n178: return -0.11666768044233322;
  t48_n179: return 0.0423554964363575;
  t48_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t48_n188;
  t48_n181: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t48_n185;
  t48_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n184;
  t48_n183: return 0.08655806630849838;
  t48_n184: return 0.034406114369630814;
  t48_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n187;
  t48_n186: return 0.012664949521422386;
  t48_n187: return 0.09242243319749832;
  t48_n188: return -0.004659170750528574;
  t48_n189: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t48_n225;
  t48_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t48_n216;
  t48_n191: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t48_n215;
  t48_n192: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t48_n212;
  t48_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t48_n195;
  t48_n194: return -0.23240312933921814;
  t48_n195: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t48_n211;
  t48_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n210;
  t48_n197: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n199;
  t48_n198: return 0.03360581025481224;
  t48_n199: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t48_n201;
  t48_n200: return 0.03834622725844383;
  t48_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n209;
  t48_n202: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t48_n204;
  t48_n203: return -0.020636308938264847;
  t48_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t48_n206;
  t48_n205: return 0.12051068991422653;
  t48_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t48_n208;
  t48_n207: return 0.11243531852960587;
  t48_n208: return 0.0260930135846138;
  t48_n209: return 0.06324395537376404;
  t48_n210: return 0.05248526856303215;
  t48_n211: return -0.0038150129839777946;
  t48_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t48_n214;
  t48_n213: return -0.3445795476436615;
  t48_n214: return 0.03277602046728134;
  t48_n215: return -0.05489566922187805;
  t48_n216: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t48_n224;
  t48_n217: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t48_n223;
  t48_n218: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t48_n220;
  t48_n219: return 0.04342828691005707;
  t48_n220: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t48_n222;
  t48_n221: return -0.03262172266840935;
  t48_n222: return 0.057404227554798126;
  t48_n223: return 0.07405927032232285;
  t48_n224: return -0.10923736542463303;
  t48_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t48_n231;
  t48_n226: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t48_n230;
  t48_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n229;
  t48_n228: return 0.052105292677879333;
  t48_n229: return 0.0583263635635376;
  t48_n230: return 0.07582864910364151;
  t48_n231: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t48_n233;
  t48_n232: return 0.008800377137959003;
  t48_n233: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t48_n235;
  t48_n234: return 0.005562382750213146;
  t48_n235: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t48_n241;
  t48_n236: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t48_n240;
  t48_n237: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t48_n239;
  t48_n238: return 0.09486287087202072;
  t48_n239: return 0.15499897301197052;
  t48_n240: return -0.08354710042476654;
  t48_n241: return 0.06999339163303375;
  t48_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t48_n250;
  t48_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t48_n249;
  t48_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t48_n246;
  t48_n245: return -0.011260349303483963;
  t48_n246: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t48_n248;
  t48_n247: return 0.015681782737374306;
  t48_n248: return -0.2677670121192932;
  t48_n249: return 0.04364495724439621;
  t48_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t48_n254;
  t48_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t48_n253;
  t48_n252: return 0.039197325706481934;
  t48_n253: return 0.05754837766289711;
  t48_n254: return 0.06619742512702942;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree49(const Example& E) {
  t49_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t49_n244;
  t49_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t49_n203;
  t49_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t49_n150;
  t49_n3: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t49_n21;
  t49_n4: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t49_n6;
  t49_n5: return -0.0071006654761731625;
  t49_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t49_n8;
  t49_n7: return 0.016056198626756668;
  t49_n8: if (E.getNumReferences() >= 3322075136 /*8374.0*/) goto t49_n20;
  t49_n9: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t49_n19;
  t49_n10: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t49_n14;
  t49_n11: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t49_n13;
  t49_n12: return 0.04005441814661026;
  t49_n13: return 0.06396548449993134;
  t49_n14: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t49_n16;
  t49_n15: return 0.07404827326536179;
  t49_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t49_n18;
  t49_n17: return 0.07894711941480637;
  t49_n18: return 0.09220299124717712;
  t49_n19: return 0.025485316291451454;
  t49_n20: return 0.06034582853317261;
  t49_n21: if (E.getNumReferences() >= 3302477824 /*1726.5*/) goto t49_n23;
  t49_n22: return -0.03828606754541397;
  t49_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n25;
  t49_n24: return -0.013273654505610466;
  t49_n25: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t49_n45;
  t49_n26: if (E.getNumReferences() >= 3302612992 /*1743.0*/) goto t49_n38;
  t49_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t49_n35;
  t49_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t49_n30;
  t49_n29: return -0.06457944214344025;
  t49_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t49_n32;
  t49_n31: return -0.11997425556182861;
  t49_n32: if (E.getNumReferences() >= 3302539264 /*1734.0*/) goto t49_n34;
  t49_n33: return -0.15876121819019318;
  t49_n34: return 0.1284700632095337;
  t49_n35: if (E.getNumReferences() >= 3302567936 /*1737.5*/) goto t49_n37;
  t49_n36: return 0.1210581511259079;
  t49_n37: return 0.11772502958774567;
  t49_n38: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t49_n40;
  t49_n39: return 0.010903328657150269;
  t49_n40: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t49_n44;
  t49_n41: if (E.getNumReferences() >= 3306715136 /*2439.5*/) goto t49_n43;
  t49_n42: return 0.008649859577417374;
  t49_n43: return 0.06551069021224976;
  t49_n44: return -0.9966633319854736;
  t49_n45: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t49_n55;
  t49_n46: if (E.getNumReferences() >= 3350366592 /*91411.0*/) goto t49_n52;
  t49_n47: if (E.getNumReferences() >= 3344779136 /*56647.5*/) goto t49_n49;
  t49_n48: return 0.01582244411110878;
  t49_n49: if (E.getNumReferences() >= 3345992448 /*61387.0*/) goto t49_n51;
  t49_n50: return -0.2695603370666504;
  t49_n51: return -0.011394688859581947;
  t49_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t49_n54;
  t49_n53: return -0.316650927066803;
  t49_n54: return 0.05662946403026581;
  t49_n55: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t49_n111;
  t49_n56: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t49_n108;
  t49_n57: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t49_n71;
  t49_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t49_n60;
  t49_n59: return 0.0417284294962883;
  t49_n60: if (E.getNumReferences() >= 3339274880 /*35146.5*/) goto t49_n62;
  t49_n61: return 0.08221323788166046;
  t49_n62: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t49_n66;
  t49_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t49_n65;
  t49_n64: return 0.09869615733623505;
  t49_n65: return 0.12250382453203201;
  t49_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t49_n70;
  t49_n67: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t49_n69;
  t49_n68: return -0.0845021978020668;
  t49_n69: return 0.09057016670703888;
  t49_n70: return 0.10654788464307785;
  t49_n71: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t49_n95;
  t49_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n74;
  t49_n73: return -0.01306490134447813;
  t49_n74: if (E.getNumReferences() >= 3324975616 /*11206.5*/) goto t49_n92;
  t49_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t49_n91;
  t49_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t49_n86;
  t49_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t49_n79;
  t49_n78: return 0.09161747246980667;
  t49_n79: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t49_n81;
  t49_n80: return 0.11490260809659958;
  t49_n81: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t49_n83;
  t49_n82: return 0.06962916254997253;
  t49_n83: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t49_n85;
  t49_n84: return -0.06388957798480988;
  t49_n85: return 0.11955096572637558;
  t49_n86: if (E.getNumReferences() >= 3322129920 /*8427.5*/) goto t49_n90;
  t49_n87: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t49_n89;
  t49_n88: return 0.11492963880300522;
  t49_n89: return 0.12519164383411407;
  t49_n90: return 0.04900578781962395;
  t49_n91: return 0.0965886190533638;
  t49_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t49_n94;
  t49_n93: return -0.11210517585277557;
  t49_n94: return 0.11321491748094559;
  t49_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t49_n103;
  t49_n96: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t49_n102;
  t49_n97: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t49_n101;
  t49_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t49_n100;
  t49_n99: return 0.061438195407390594;
  t49_n100: return 0.0830722451210022;
  t49_n101: return -0.0651339665055275;
  t49_n102: return 0.07960812747478485;
  t49_n103: if (E.getNumReferences() >= 3331329792 /*18439.5*/) goto t49_n107;
  t49_n104: if (E.getNumReferences() >= 3331157760 /*18103.5*/) goto t49_n106;
  t49_n105: return 0.0637628585100174;
  t49_n106: return 0.10811486840248108;
  t49_n107: return 0.09574811905622482;
  t49_n108: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t49_n110;
  t49_n109: return -0.14152005314826965;
  t49_n110: return 0.013371014036238194;
  t49_n111: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t49_n149;
  t49_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t49_n140;
  t49_n113: if (E.getNumReferences() >= 3329839104 /*15956.0*/) goto t49_n121;
  t49_n114: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t49_n116;
  t49_n115: return 0.051595382392406464;
  t49_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t49_n118;
  t49_n117: return 0.08934242278337479;
  t49_n118: if (E.getNumReferences() >= 3325309440 /*11532.5*/) goto t49_n120;
  t49_n119: return -0.5525740385055542;
  t49_n120: return 0.11077194660902023;
  t49_n121: if (E.getNumReferences() >= 3330013184 /*16126.0*/) goto t49_n123;
  t49_n122: return 0.12585948407649994;
  t49_n123: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t49_n137;
  t49_n124: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t49_n126;
  t49_n125: return 0.08524616062641144;
  t49_n126: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t49_n128;
  t49_n127: return 0.12033101171255112;
  t49_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t49_n130;
  t49_n129: return 0.09863711148500443;
  t49_n130: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t49_n132;
  t49_n131: return 0.11165256798267365;
  t49_n132: if (E.getNumReferences() >= 3332793856 /*21299.0*/) goto t49_n134;
  t49_n133: return -0.021748008206486702;
  t49_n134: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t49_n136;
  t49_n135: return 0.11763385683298111;
  t49_n136: return 0.01464210357517004;
  t49_n137: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t49_n139;
  t49_n138: return 0.06868623197078705;
  t49_n139: return 0.1007356271147728;
  t49_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t49_n142;
  t49_n141: return 0.08579104393720627;
  t49_n142: if (E.getNumReferences() >= 3327026688 /*13209.5*/) goto t49_n144;
  t49_n143: return 0.11479629576206207;
  t49_n144: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t49_n148;
  t49_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t49_n147;
  t49_n146: return 0.11135392636060715;
  t49_n147: return 0.10566720366477966;
  t49_n148: return 0.08902639895677567;
  t49_n149: return 0.027570132166147232;
  t49_n150: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t49_n154;
  t49_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n153;
  t49_n152: return 0.014073965139687061;
  t49_n153: return -0.0035217220429331064;
  t49_n154: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t49_n162;
  t49_n155: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t49_n159;
  t49_n156: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t49_n158;
  t49_n157: return 0.04396215081214905;
  t49_n158: return -0.029263505712151527;
  t49_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t49_n161;
  t49_n160: return 0.03692518547177315;
  t49_n161: return 0.056985363364219666;
  t49_n162: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t49_n180;
  t49_n163: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t49_n179;
  t49_n164: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t49_n166;
  t49_n165: return 0.08570831269025803;
  t49_n166: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t49_n170;
  t49_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t49_n169;
  t49_n168: return -0.1775335669517517;
  t49_n169: return 0.10961410403251648;
  t49_n170: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t49_n172;
  t49_n171: return 0.01992739364504814;
  t49_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t49_n174;
  t49_n173: return 0.03656117990612984;
  t49_n174: if (E.getNumReferences() >= 3294330880 /*878.0*/) goto t49_n176;
  t49_n175: return 0.030974987894296646;
  t49_n176: if (E.getNumReferences() >= 3297783808 /*1153.5*/) goto t49_n178;
  t49_n177: return 0.10512590408325195;
  t49_n178: return -0.03786160796880722;
  t49_n179: return 0.016046438366174698;
  t49_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t49_n182;
  t49_n181: return 0.10182895511388779;
  t49_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t49_n190;
  t49_n183: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t49_n189;
  t49_n184: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t49_n186;
  t49_n185: return 0.08860290050506592;
  t49_n186: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t49_n188;
  t49_n187: return 0.15794207155704498;
  t49_n188: return 0.07388676702976227;
  t49_n189: return 0.07138396799564362;
  t49_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t49_n192;
  t49_n191: return 0.05833430960774422;
  t49_n192: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t49_n194;
  t49_n193: return 0.08090172708034515;
  t49_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t49_n198;
  t49_n195: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t49_n197;
  t49_n196: return 0.13626548647880554;
  t49_n197: return 0.03387799859046936;
  t49_n198: if (E.getNumReferences() >= 3270246400 /*118.0*/) goto t49_n200;
  t49_n199: return 0.10067499428987503;
  t49_n200: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t49_n202;
  t49_n201: return 0.14716176688671112;
  t49_n202: return 0.10025899857282639;
  t49_n203: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t49_n239;
  t49_n204: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t49_n236;
  t49_n205: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t49_n233;
  t49_n206: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t49_n230;
  t49_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n209;
  t49_n208: return -0.2279350310564041;
  t49_n209: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t49_n229;
  t49_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t49_n224;
  t49_n211: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t49_n213;
  t49_n212: return 0.030281545594334602;
  t49_n213: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t49_n215;
  t49_n214: return 0.040441129356622696;
  t49_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t49_n223;
  t49_n216: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t49_n218;
  t49_n217: return 0.005902497563511133;
  t49_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t49_n220;
  t49_n219: return 0.18750415742397308;
  t49_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n222;
  t49_n221: return 0.11178500950336456;
  t49_n222: return 0.02780691534280777;
  t49_n223: return 0.06177663803100586;
  t49_n224: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n228;
  t49_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t49_n227;
  t49_n226: return 0.050442490726709366;
  t49_n227: return 0.07691120356321335;
  t49_n228: return 0.026438813656568527;
  t49_n229: return -0.004177542869001627;
  t49_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t49_n232;
  t49_n231: return -0.19554468989372253;
  t49_n232: return 0.031446799635887146;
  t49_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n235;
  t49_n234: return -0.09656501561403275;
  t49_n235: return 0.02716492861509323;
  t49_n236: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t49_n238;
  t49_n237: return 0.03498346358537674;
  t49_n238: return -0.055831823498010635;
  t49_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t49_n241;
  t49_n240: return 0.05599178746342659;
  t49_n241: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t49_n243;
  t49_n242: return 0.010698794387280941;
  t49_n243: return 0.0620381124317646;
  t49_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t49_n250;
  t49_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t49_n249;
  t49_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t49_n248;
  t49_n247: return -0.010166266933083534;
  t49_n248: return 0.01356172002851963;
  t49_n249: return 0.041744306683540344;
  t49_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t49_n254;
  t49_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t49_n253;
  t49_n252: return 0.0395376980304718;
  t49_n253: return 0.05389593169093132;
  t49_n254: return 0.06438782066106796;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree50(const Example& E) {
  t50_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t50_n242;
  t50_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t50_n205;
  t50_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t50_n46;
  t50_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t50_n5;
  t50_n4: return -0.04134805127978325;
  t50_n5: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t50_n37;
  t50_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t50_n8;
  t50_n7: return -0.026538684964179993;
  t50_n8: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t50_n32;
  t50_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t50_n15;
  t50_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t50_n12;
  t50_n11: return -0.12388809770345688;
  t50_n12: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t50_n14;
  t50_n13: return 0.009273992851376534;
  t50_n14: return 0.1657734364271164;
  t50_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t50_n19;
  t50_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n18;
  t50_n17: return 0.020824279636144638;
  t50_n18: return -0.04737229272723198;
  t50_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t50_n21;
  t50_n20: return 0.0032060735393315554;
  t50_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n23;
  t50_n22: return 0.057568058371543884;
  t50_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n29;
  t50_n24: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n28;
  t50_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n27;
  t50_n26: return 0.12297863513231277;
  t50_n27: return 0.11021848022937775;
  t50_n28: return 0.051185671240091324;
  t50_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n31;
  t50_n30: return 0.062262166291475296;
  t50_n31: return 0.016139905899763107;
  t50_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t50_n34;
  t50_n33: return -0.07762875407934189;
  t50_n34: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t50_n36;
  t50_n35: return 0.011380570940673351;
  t50_n36: return 0.05144425854086876;
  t50_n37: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t50_n39;
  t50_n38: return 0.019228573888540268;
  t50_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n41;
  t50_n40: return 0.04975035414099693;
  t50_n41: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t50_n45;
  t50_n42: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t50_n44;
  t50_n43: return 0.10898903012275696;
  t50_n44: return 0.07228424400091171;
  t50_n45: return -0.12793424725532532;
  t50_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t50_n136;
  t50_n47: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n85;
  t50_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t50_n70;
  t50_n49: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t50_n69;
  t50_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n68;
  t50_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t50_n53;
  t50_n52: return 0.027341162785887718;
  t50_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t50_n57;
  t50_n54: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t50_n56;
  t50_n55: return -0.009783999063074589;
  t50_n56: return 0.03894713893532753;
  t50_n57: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t50_n67;
  t50_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n62;
  t50_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n61;
  t50_n60: return 0.10064518451690674;
  t50_n61: return 0.04000569134950638;
  t50_n62: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t50_n64;
  t50_n63: return 0.06306443363428116;
  t50_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n66;
  t50_n65: return 0.09746736288070679;
  t50_n66: return 0.09049498289823532;
  t50_n67: return -0.0383845716714859;
  t50_n68: return -0.020974550396203995;
  t50_n69: return -0.028728077188134193;
  t50_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t50_n72;
  t50_n71: return 0.02507183700799942;
  t50_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t50_n78;
  t50_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n75;
  t50_n74: return 0.01889736019074917;
  t50_n75: if (E.getNumReferences() >= 3332487680 /*20701.0*/) goto t50_n77;
  t50_n76: return -0.073529914021492;
  t50_n77: return -0.23788972198963165;
  t50_n78: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t50_n80;
  t50_n79: return 0.0789819210767746;
  t50_n80: if (E.getNumReferences() >= 3345471616 /*59352.5*/) goto t50_n84;
  t50_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t50_n83;
  t50_n82: return 0.02278936840593815;
  t50_n83: return 0.061685312539339066;
  t50_n84: return 0.0921202227473259;
  t50_n85: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t50_n135;
  t50_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n88;
  t50_n87: return 0.03869762644171715;
  t50_n88: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t50_n90;
  t50_n89: return -0.04303742200136185;
  t50_n90: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t50_n132;
  t50_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n123;
  t50_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t50_n98;
  t50_n93: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t50_n95;
  t50_n94: return -0.0065425848588347435;
  t50_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n97;
  t50_n96: return 0.1079166904091835;
  t50_n97: return 0.06182792782783508;
  t50_n98: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t50_n116;
  t50_n99: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t50_n105;
  t50_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n102;
  t50_n101: return 0.11343332380056381;
  t50_n102: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t50_n104;
  t50_n103: return 0.13738210499286652;
  t50_n104: return 0.09714511781930923;
  t50_n105: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t50_n107;
  t50_n106: return 0.0997411385178566;
  t50_n107: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t50_n109;
  t50_n108: return 0.1317363828420639;
  t50_n109: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t50_n115;
  t50_n110: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t50_n112;
  t50_n111: return 0.11926400661468506;
  t50_n112: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n114;
  t50_n113: return 0.17992882430553436;
  t50_n114: return 0.1305561363697052;
  t50_n115: return 0.03566669300198555;
  t50_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n120;
  t50_n117: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t50_n119;
  t50_n118: return 0.1044851690530777;
  t50_n119: return 0.11056826263666153;
  t50_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t50_n122;
  t50_n121: return -0.21412676572799683;
  t50_n122: return 0.06948933750391006;
  t50_n123: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t50_n127;
  t50_n124: if (E.getNumReferences() >= 3339920000 /*37666.5*/) goto t50_n126;
  t50_n125: return 0.05030626803636551;
  t50_n126: return 0.09811358153820038;
  t50_n127: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t50_n131;
  t50_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n130;
  t50_n129: return 0.12655505537986755;
  t50_n130: return 0.12201696634292603;
  t50_n131: return 0.07862817496061325;
  t50_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t50_n134;
  t50_n133: return -0.445903480052948;
  t50_n134: return 0.0186452753841877;
  t50_n135: return -0.12699289619922638;
  t50_n136: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t50_n198;
  t50_n137: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t50_n173;
  t50_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n172;
  t50_n139: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n171;
  t50_n140: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t50_n162;
  t50_n141: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t50_n161;
  t50_n142: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t50_n148;
  t50_n143: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n145;
  t50_n144: return -0.012254390865564346;
  t50_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t50_n147;
  t50_n146: return 0.01045322511345148;
  t50_n147: return 0.03542685881257057;
  t50_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t50_n150;
  t50_n149: return 0.026217792183160782;
  t50_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t50_n152;
  t50_n151: return 0.03494812548160553;
  t50_n152: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t50_n156;
  t50_n153: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n155;
  t50_n154: return 0.08516044914722443;
  t50_n155: return -0.056391965597867966;
  t50_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n160;
  t50_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n159;
  t50_n158: return 0.07855089753866196;
  t50_n159: return 0.048486556857824326;
  t50_n160: return 0.06578179448843002;
  t50_n161: return -0.132791206240654;
  t50_n162: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t50_n170;
  t50_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t50_n165;
  t50_n164: return 0.05058204382658005;
  t50_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t50_n167;
  t50_n166: return 0.06653691828250885;
  t50_n167: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t50_n169;
  t50_n168: return 0.07408850640058517;
  t50_n169: return 0.08862550556659698;
  t50_n170: return 0.023115815594792366;
  t50_n171: return 0.00764461187645793;
  t50_n172: return -0.042261358350515366;
  t50_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n175;
  t50_n174: return 0.01381650846451521;
  t50_n175: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t50_n197;
  t50_n176: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t50_n192;
  t50_n177: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t50_n179;
  t50_n178: return 0.05360906571149826;
  t50_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t50_n181;
  t50_n180: return 0.029452955350279808;
  t50_n181: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t50_n191;
  t50_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n190;
  t50_n183: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t50_n189;
  t50_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t50_n186;
  t50_n185: return 0.10107163339853287;
  t50_n186: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t50_n188;
  t50_n187: return 0.10413412749767303;
  t50_n188: return 0.12062022089958191;
  t50_n189: return -0.2855970859527588;
  t50_n190: return 0.07257197797298431;
  t50_n191: return 0.12048619240522385;
  t50_n192: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t50_n194;
  t50_n193: return 0.06880953907966614;
  t50_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t50_n196;
  t50_n195: return 0.10560346394777298;
  t50_n196: return 0.09416430443525314;
  t50_n197: return 0.03192706033587456;
  t50_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t50_n204;
  t50_n199: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t50_n203;
  t50_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n202;
  t50_n201: return 0.08188936114311218;
  t50_n202: return 0.028954869136214256;
  t50_n203: return 0.03227877616882324;
  t50_n204: return -0.005101862829178572;
  t50_n205: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t50_n235;
  t50_n206: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t50_n232;
  t50_n207: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t50_n231;
  t50_n208: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t50_n228;
  t50_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t50_n227;
  t50_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n226;
  t50_n211: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t50_n213;
  t50_n212: return 0.02519003488123417;
  t50_n213: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t50_n215;
  t50_n214: return 0.03199714049696922;
  t50_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t50_n225;
  t50_n216: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t50_n218;
  t50_n217: return 0.05099630355834961;
  t50_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t50_n220;
  t50_n219: return 0.09037555009126663;
  t50_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t50_n224;
  t50_n221: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t50_n223;
  t50_n222: return 0.2917834520339966;
  t50_n223: return 0.10759331285953522;
  t50_n224: return 0.027771135792136192;
  t50_n225: return 0.043648116290569305;
  t50_n226: return 0.048263318836688995;
  t50_n227: return -0.03764214366674423;
  t50_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t50_n230;
  t50_n229: return 0.019585177302360535;
  t50_n230: return 0.06294625997543335;
  t50_n231: return -0.047912854701280594;
  t50_n232: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t50_n234;
  t50_n233: return 0.032482992857694626;
  t50_n234: return -0.09266506880521774;
  t50_n235: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t50_n237;
  t50_n236: return 0.0543208122253418;
  t50_n237: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t50_n239;
  t50_n238: return 0.05184972286224365;
  t50_n239: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t50_n241;
  t50_n240: return 0.00410868227481842;
  t50_n241: return 0.05685129389166832;
  t50_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t50_n250;
  t50_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t50_n247;
  t50_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t50_n246;
  t50_n245: return -0.014628834091126919;
  t50_n246: return 0.008296489715576172;
  t50_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t50_n249;
  t50_n248: return 0.006730273831635714;
  t50_n249: return 0.032410744577646255;
  t50_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t50_n254;
  t50_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t50_n253;
  t50_n252: return 0.03775531426072121;
  t50_n253: return 0.05281894654035568;
  t50_n254: return 0.0633334144949913;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree51(const Example& E) {
  t51_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t51_n242;
  t51_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t51_n181;
  t51_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t51_n132;
  t51_n3: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t51_n97;
  t51_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t51_n6;
  t51_n5: return -0.10008023679256439;
  t51_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n10;
  t51_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n9;
  t51_n8: return -0.028660377487540245;
  t51_n9: return 0.0009207770926877856;
  t51_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t51_n40;
  t51_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n25;
  t51_n12: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n20;
  t51_n13: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n15;
  t51_n14: return -6.07479851169046e-05;
  t51_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t51_n17;
  t51_n16: return 0.019823433831334114;
  t51_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n19;
  t51_n18: return 0.08727134764194489;
  t51_n19: return 0.08624925464391708;
  t51_n20: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t51_n22;
  t51_n21: return -0.04731930047273636;
  t51_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t51_n24;
  t51_n23: return 0.014646998606622219;
  t51_n24: return 0.06068236753344536;
  t51_n25: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t51_n39;
  t51_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t51_n28;
  t51_n27: return 0.02075262926518917;
  t51_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n30;
  t51_n29: return 0.06784842163324356;
  t51_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n32;
  t51_n31: return -0.09729500859975815;
  t51_n32: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n38;
  t51_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n37;
  t51_n34: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t51_n36;
  t51_n35: return 0.09988777339458466;
  t51_n36: return 0.10896018892526627;
  t51_n37: return 0.05765452980995178;
  t51_n38: return 0.05373663082718849;
  t51_n39: return -0.012967594899237156;
  t51_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t51_n96;
  t51_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n83;
  t51_n42: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n82;
  t51_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t51_n53;
  t51_n44: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t51_n46;
  t51_n45: return 0.029533429071307182;
  t51_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n50;
  t51_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n49;
  t51_n48: return 0.09660156071186066;
  t51_n49: return 0.08169213682413101;
  t51_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n52;
  t51_n51: return -0.12639819085597992;
  t51_n52: return 0.07922067493200302;
  t51_n53: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t51_n55;
  t51_n54: return -0.016608865931630135;
  t51_n55: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n81;
  t51_n56: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t51_n80;
  t51_n57: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n73;
  t51_n58: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t51_n68;
  t51_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t51_n65;
  t51_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n62;
  t51_n61: return 0.024267712607979774;
  t51_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n64;
  t51_n63: return 0.10823991149663925;
  t51_n64: return 0.16870132088661194;
  t51_n65: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n67;
  t51_n66: return 0.08685863763093948;
  t51_n67: return 0.06822140514850616;
  t51_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n72;
  t51_n69: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t51_n71;
  t51_n70: return 0.066021628677845;
  t51_n71: return 0.07984019815921783;
  t51_n72: return -0.12042003124952316;
  t51_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n75;
  t51_n74: return 0.08530237525701523;
  t51_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t51_n77;
  t51_n76: return 0.02107425220310688;
  t51_n77: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n79;
  t51_n78: return 0.08761854469776154;
  t51_n79: return 0.17276939749717712;
  t51_n80: return 0.14991039037704468;
  t51_n81: return -0.04158106818795204;
  t51_n82: return -0.1394587755203247;
  t51_n83: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n85;
  t51_n84: return 0.020540708675980568;
  t51_n85: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n95;
  t51_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n88;
  t51_n87: return 0.15503810346126556;
  t51_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n92;
  t51_n89: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t51_n91;
  t51_n90: return 0.1337841898202896;
  t51_n91: return 0.10422546416521072;
  t51_n92: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t51_n94;
  t51_n93: return 0.11333973705768585;
  t51_n94: return 0.09107884764671326;
  t51_n95: return 0.0985180139541626;
  t51_n96: return -0.08237232267856598;
  t51_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n99;
  t51_n98: return 0.01483225543051958;
  t51_n99: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t51_n111;
  t51_n100: if (E.getNumReferences() >= 3322313728 /*8607.0*/) goto t51_n110;
  t51_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t51_n105;
  t51_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t51_n104;
  t51_n103: return -0.0002643891202751547;
  t51_n104: return 0.051075488328933716;
  t51_n105: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t51_n107;
  t51_n106: return 0.03412409871816635;
  t51_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t51_n109;
  t51_n108: return 0.05016158148646355;
  t51_n109: return 0.06977683305740356;
  t51_n110: return 0.05865240842103958;
  t51_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t51_n113;
  t51_n112: return 0.04029959812760353;
  t51_n113: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t51_n119;
  t51_n114: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t51_n116;
  t51_n115: return 0.05640612170100212;
  t51_n116: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t51_n118;
  t51_n117: return 0.03491213917732239;
  t51_n118: return 0.08955834060907364;
  t51_n119: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t51_n131;
  t51_n120: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t51_n124;
  t51_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n123;
  t51_n122: return 0.09029603004455566;
  t51_n123: return 0.027315175160765648;
  t51_n124: if (E.getNumReferences() >= 3289915392 /*608.5*/) goto t51_n130;
  t51_n125: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t51_n129;
  t51_n126: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t51_n128;
  t51_n127: return 0.090761698782444;
  t51_n128: return 0.12894944846630096;
  t51_n129: return 0.11572017520666122;
  t51_n130: return 0.07422088831663132;
  t51_n131: return 0.12760351598262787;
  t51_n132: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t51_n144;
  t51_n133: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n143;
  t51_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n138;
  t51_n135: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t51_n137;
  t51_n136: return 0.0041726985946297646;
  t51_n137: return -0.047311387956142426;
  t51_n138: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n142;
  t51_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n141;
  t51_n140: return -0.06445800513029099;
  t51_n141: return 0.017773283645510674;
  t51_n142: return -0.12040869146585464;
  t51_n143: return -0.08488812297582626;
  t51_n144: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t51_n146;
  t51_n145: return 0.0009405958699062467;
  t51_n146: if (E.getNumReferences() >= 3305330688 /*2101.5*/) goto t51_n180;
  t51_n147: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t51_n153;
  t51_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t51_n150;
  t51_n149: return 0.0954778790473938;
  t51_n150: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t51_n152;
  t51_n151: return 0.12196951359510422;
  t51_n152: return 0.1053016260266304;
  t51_n153: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t51_n161;
  t51_n154: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n156;
  t51_n155: return 0.053942374885082245;
  t51_n156: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t51_n158;
  t51_n157: return 0.05887967720627785;
  t51_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t51_n160;
  t51_n159: return 0.08431582897901535;
  t51_n160: return 0.10805691033601761;
  t51_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t51_n163;
  t51_n162: return 0.05690474435687065;
  t51_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t51_n165;
  t51_n164: return 0.09101638942956924;
  t51_n165: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t51_n179;
  t51_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t51_n168;
  t51_n167: return 0.09666786342859268;
  t51_n168: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t51_n178;
  t51_n169: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t51_n177;
  t51_n170: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t51_n172;
  t51_n171: return -0.23752228915691376;
  t51_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t51_n176;
  t51_n173: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t51_n175;
  t51_n174: return -0.07282708585262299;
  t51_n175: return 0.13471876084804535;
  t51_n176: return 0.13607141375541687;
  t51_n177: return 0.08723253011703491;
  t51_n178: return 0.11431910842657089;
  t51_n179: return 0.09049317240715027;
  t51_n180: return 0.06194601207971573;
  t51_n181: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t51_n211;
  t51_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t51_n208;
  t51_n183: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n205;
  t51_n184: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t51_n202;
  t51_n185: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t51_n201;
  t51_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n200;
  t51_n187: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n189;
  t51_n188: return 0.026585564017295837;
  t51_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t51_n191;
  t51_n190: return 0.036901723593473434;
  t51_n191: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t51_n199;
  t51_n192: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t51_n194;
  t51_n193: return 0.044806744903326035;
  t51_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n196;
  t51_n195: return 0.16821569204330444;
  t51_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t51_n198;
  t51_n197: return 0.10853410512208939;
  t51_n198: return 0.025955818593502045;
  t51_n199: return 0.050318412482738495;
  t51_n200: return 0.045413874089717865;
  t51_n201: return -0.006247398909181356;
  t51_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t51_n204;
  t51_n203: return -0.24469321966171265;
  t51_n204: return 0.02732834219932556;
  t51_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t51_n207;
  t51_n206: return -0.08739649504423141;
  t51_n207: return 0.028588082641363144;
  t51_n208: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t51_n210;
  t51_n209: return 0.02335643768310547;
  t51_n210: return 0.06940221786499023;
  t51_n211: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t51_n239;
  t51_n212: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t51_n214;
  t51_n213: return 0.07605765014886856;
  t51_n214: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t51_n232;
  t51_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n221;
  t51_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t51_n218;
  t51_n217: return -0.011795085854828358;
  t51_n218: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t51_n220;
  t51_n219: return 0.08917725831270218;
  t51_n220: return 0.13676831126213074;
  t51_n221: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t51_n231;
  t51_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n230;
  t51_n223: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t51_n227;
  t51_n224: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t51_n226;
  t51_n225: return 0.13366715610027313;
  t51_n226: return -0.06363644450902939;
  t51_n227: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t51_n229;
  t51_n228: return -0.0859861671924591;
  t51_n229: return 0.13724838197231293;
  t51_n230: return 0.06553714722394943;
  t51_n231: return 0.05068916454911232;
  t51_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t51_n236;
  t51_n233: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t51_n235;
  t51_n234: return 0.12179490178823471;
  t51_n235: return 0.05919289216399193;
  t51_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n238;
  t51_n237: return 0.11769304424524307;
  t51_n238: return 0.08528245240449905;
  t51_n239: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t51_n241;
  t51_n240: return 0.01918763294816017;
  t51_n241: return 0.04876163601875305;
  t51_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t51_n248;
  t51_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n245;
  t51_n244: return 0.003121410496532917;
  t51_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t51_n247;
  t51_n246: return 0.013019402511417866;
  t51_n247: return 0.03146563842892647;
  t51_n248: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t51_n252;
  t51_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t51_n251;
  t51_n250: return 0.043255515396595;
  t51_n251: return 0.06133098527789116;
  t51_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t51_n254;
  t51_n253: return 0.09447713196277618;
  t51_n254: return -0.05863041430711746;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree52(const Example& E) {
  t52_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t52_n248;
  t52_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t52_n229;
  t52_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t52_n122;
  t52_n3: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t52_n91;
  t52_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t52_n42;
  t52_n5: if (E.getFileProximityDistance() >= 3253993472 /*30.5*/) goto t52_n7;
  t52_n6: return -0.028378136456012726;
  t52_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t52_n19;
  t52_n8: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n18;
  t52_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t52_n15;
  t52_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n12;
  t52_n11: return 0.04299920052289963;
  t52_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t52_n14;
  t52_n13: return 0.0930233746767044;
  t52_n14: return 0.15866044163703918;
  t52_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n17;
  t52_n16: return 0.1394285261631012;
  t52_n17: return -0.1026780754327774;
  t52_n18: return -0.12375067174434662;
  t52_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n31;
  t52_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n30;
  t52_n21: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t52_n29;
  t52_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n28;
  t52_n23: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t52_n27;
  t52_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n26;
  t52_n25: return 0.09354108572006226;
  t52_n26: return 0.08712858706712723;
  t52_n27: return 0.07187109440565109;
  t52_n28: return -0.09735995531082153;
  t52_n29: return 0.05862484127283096;
  t52_n30: return 0.01897485740482807;
  t52_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n39;
  t52_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n34;
  t52_n33: return 0.15244701504707336;
  t52_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n38;
  t52_n35: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t52_n37;
  t52_n36: return 0.1314072459936142;
  t52_n37: return 0.10142859816551208;
  t52_n38: return 0.10374916344881058;
  t52_n39: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n41;
  t52_n40: return 0.10275956243276596;
  t52_n41: return 0.08674181252717972;
  t52_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t52_n44;
  t52_n43: return -0.09604907780885696;
  t52_n44: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n78;
  t52_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n47;
  t52_n46: return -0.0022822695318609476;
  t52_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t52_n77;
  t52_n48: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n58;
  t52_n49: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t52_n57;
  t52_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t52_n56;
  t52_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n55;
  t52_n52: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t52_n54;
  t52_n53: return 0.021031904965639114;
  t52_n54: return 0.05259525403380394;
  t52_n55: return 0.0497216135263443;
  t52_n56: return 0.0022051515989005566;
  t52_n57: return -0.04130452871322632;
  t52_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t52_n66;
  t52_n59: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t52_n65;
  t52_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n62;
  t52_n61: return 0.03232536092400551;
  t52_n62: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t52_n64;
  t52_n63: return -8.442633406957611e-05;
  t52_n64: return -0.13689470291137695;
  t52_n65: return -0.06391794234514236;
  t52_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t52_n72;
  t52_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t52_n69;
  t52_n68: return 0.02729213796555996;
  t52_n69: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t52_n71;
  t52_n70: return 0.08777285367250443;
  t52_n71: return 0.03795889392495155;
  t52_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n76;
  t52_n73: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t52_n75;
  t52_n74: return 0.11242359131574631;
  t52_n75: return 0.10573946684598923;
  t52_n76: return 0.058043222874403;
  t52_n77: return 0.05399106815457344;
  t52_n78: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t52_n90;
  t52_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t52_n83;
  t52_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n82;
  t52_n81: return -0.004594679921865463;
  t52_n82: return -0.08119597285985947;
  t52_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t52_n85;
  t52_n84: return 0.018645592033863068;
  t52_n85: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t52_n87;
  t52_n86: return 0.07804474979639053;
  t52_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t52_n89;
  t52_n88: return 0.07378573715686798;
  t52_n89: return 0.04875962808728218;
  t52_n90: return -0.01335485465824604;
  t52_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t52_n95;
  t52_n92: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t52_n94;
  t52_n93: return 0.0134520148858428;
  t52_n94: return 0.10304031521081924;
  t52_n95: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t52_n105;
  t52_n96: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t52_n104;
  t52_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t52_n99;
  t52_n98: return 0.0183434896171093;
  t52_n99: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t52_n101;
  t52_n100: return 0.03243129700422287;
  t52_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t52_n103;
  t52_n102: return 0.04611947759985924;
  t52_n103: return 0.06412260234355927;
  t52_n104: return 0.05763658881187439;
  t52_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t52_n107;
  t52_n106: return 0.04038873687386513;
  t52_n107: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t52_n111;
  t52_n108: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t52_n110;
  t52_n109: return 0.05612390488386154;
  t52_n110: return 0.07466696202754974;
  t52_n111: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t52_n121;
  t52_n112: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t52_n114;
  t52_n113: return 0.07972965389490128;
  t52_n114: if (E.getNumReferences() >= 3289915392 /*608.5*/) goto t52_n120;
  t52_n115: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t52_n119;
  t52_n116: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t52_n118;
  t52_n117: return 0.08881927281618118;
  t52_n118: return 0.12557657063007355;
  t52_n119: return 0.11417718231678009;
  t52_n120: return 0.07160821557044983;
  t52_n121: return 0.1251259297132492;
  t52_n122: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t52_n162;
  t52_n123: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t52_n125;
  t52_n124: return -0.00792151689529419;
  t52_n125: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t52_n127;
  t52_n126: return 0.036507006734609604;
  t52_n127: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t52_n129;
  t52_n128: return 0.07897599786520004;
  t52_n129: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t52_n137;
  t52_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t52_n132;
  t52_n131: return 0.09076914936304092;
  t52_n132: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t52_n136;
  t52_n133: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t52_n135;
  t52_n134: return 0.11921140551567078;
  t52_n135: return 0.17296388745307922;
  t52_n136: return 0.10721610486507416;
  t52_n137: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t52_n139;
  t52_n138: return 0.0957835465669632;
  t52_n139: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t52_n157;
  t52_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t52_n142;
  t52_n141: return 0.07707501202821732;
  t52_n142: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t52_n144;
  t52_n143: return 0.14610522985458374;
  t52_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t52_n146;
  t52_n145: return 0.09277653694152832;
  t52_n146: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t52_n154;
  t52_n147: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t52_n153;
  t52_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t52_n150;
  t52_n149: return 0.15936768054962158;
  t52_n150: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t52_n152;
  t52_n151: return 0.17408387362957;
  t52_n152: return 0.12924019992351532;
  t52_n153: return 0.15099135041236877;
  t52_n154: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t52_n156;
  t52_n155: return 0.1290314793586731;
  t52_n156: return 0.12046767771244049;
  t52_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t52_n159;
  t52_n158: return 0.10075583308935165;
  t52_n159: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t52_n161;
  t52_n160: return 0.15523257851600647;
  t52_n161: return 0.11913907527923584;
  t52_n162: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n228;
  t52_n163: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t52_n167;
  t52_n164: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t52_n166;
  t52_n165: return -0.06887055188417435;
  t52_n166: return -0.03189649060368538;
  t52_n167: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t52_n169;
  t52_n168: return 0.001671694335527718;
  t52_n169: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t52_n171;
  t52_n170: return 0.11599329859018326;
  t52_n171: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t52_n205;
  t52_n172: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t52_n200;
  t52_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t52_n183;
  t52_n174: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t52_n176;
  t52_n175: return 0.059763625264167786;
  t52_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t52_n178;
  t52_n177: return 0.043315060436725616;
  t52_n178: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t52_n180;
  t52_n179: return 0.03556403890252113;
  t52_n180: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t52_n182;
  t52_n181: return 0.12051813304424286;
  t52_n182: return 0.10993154346942902;
  t52_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t52_n185;
  t52_n184: return 0.08681832998991013;
  t52_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t52_n187;
  t52_n186: return 0.06171135976910591;
  t52_n187: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t52_n195;
  t52_n188: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t52_n194;
  t52_n189: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t52_n191;
  t52_n190: return -0.24531316757202148;
  t52_n191: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t52_n193;
  t52_n192: return 0.12176381796598434;
  t52_n193: return 0.11065977066755295;
  t52_n194: return 0.09905698895454407;
  t52_n195: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t52_n197;
  t52_n196: return 0.10667841881513596;
  t52_n197: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t52_n199;
  t52_n198: return 0.11309338361024857;
  t52_n199: return 0.10824301093816757;
  t52_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t52_n202;
  t52_n201: return -0.3290286958217621;
  t52_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t52_n204;
  t52_n203: return 0.10903338342905045;
  t52_n204: return 0.09662605077028275;
  t52_n205: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t52_n227;
  t52_n206: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t52_n226;
  t52_n207: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t52_n223;
  t52_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t52_n210;
  t52_n209: return -0.051660675555467606;
  t52_n210: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t52_n218;
  t52_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t52_n213;
  t52_n212: return -0.027487220242619514;
  t52_n213: if (E.getNumReferences() >= 3348532032 /*77078.5*/) goto t52_n215;
  t52_n214: return -0.27939271926879883;
  t52_n215: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t52_n217;
  t52_n216: return 0.09919018298387527;
  t52_n217: return 0.08779013156890869;
  t52_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t52_n222;
  t52_n219: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t52_n221;
  t52_n220: return 0.10364067554473877;
  t52_n221: return 0.055245235562324524;
  t52_n222: return 0.1143907979130745;
  t52_n223: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t52_n225;
  t52_n224: return 0.008769764564931393;
  t52_n225: return 0.05349496752023697;
  t52_n226: return 0.05436914786696434;
  t52_n227: return 0.07662377506494522;
  t52_n228: return 0.023646216839551926;
  t52_n229: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t52_n243;
  t52_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t52_n238;
  t52_n231: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t52_n237;
  t52_n232: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t52_n236;
  t52_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t52_n235;
  t52_n234: return -0.21049700677394867;
  t52_n235: return 0.02030525915324688;
  t52_n236: return 0.026184551417827606;
  t52_n237: return -0.043974585831165314;
  t52_n238: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t52_n242;
  t52_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t52_n241;
  t52_n240: return -0.012704744935035706;
  t52_n241: return 0.03869209811091423;
  t52_n242: return 0.0461750254034996;
  t52_n243: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t52_n245;
  t52_n244: return 0.05303353816270828;
  t52_n245: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t52_n247;
  t52_n246: return 0.018993176519870758;
  t52_n247: return 0.04736955463886261;
  t52_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t52_n254;
  t52_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t52_n253;
  t52_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t52_n252;
  t52_n251: return -0.010401153936982155;
  t52_n252: return 0.011326550506055355;
  t52_n253: return 0.03763800114393234;
  t52_n254: return 0.04616343230009079;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree53(const Example& E) {
  t53_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t53_n244;
  t53_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t53_n187;
  t53_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n112;
  t53_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t53_n23;
  t53_n4: if (E.getNumReferences() >= 3307976704 /*2747.5*/) goto t53_n16;
  t53_n5: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t53_n7;
  t53_n6: return -0.06692574173212051;
  t53_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t53_n9;
  t53_n8: return 0.02192174643278122;
  t53_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n11;
  t53_n10: return -0.09703777730464935;
  t53_n11: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t53_n15;
  t53_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n14;
  t53_n13: return 0.13158933818340302;
  t53_n14: return 0.097732774913311;
  t53_n15: return -0.0797831192612648;
  t53_n16: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t53_n22;
  t53_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n19;
  t53_n18: return 0.013686539605259895;
  t53_n19: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t53_n21;
  t53_n20: return 0.06078856810927391;
  t53_n21: return 0.08992575109004974;
  t53_n22: return -0.13666671514511108;
  t53_n23: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t53_n103;
  t53_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n50;
  t53_n25: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t53_n29;
  t53_n26: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t53_n28;
  t53_n27: return -0.0014712034026160836;
  t53_n28: return 0.037848252803087234;
  t53_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n31;
  t53_n30: return 0.12655532360076904;
  t53_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n33;
  t53_n32: return -0.09044033288955688;
  t53_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t53_n49;
  t53_n34: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t53_n38;
  t53_n35: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t53_n37;
  t53_n36: return 0.05742073804140091;
  t53_n37: return 0.12563742697238922;
  t53_n38: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t53_n46;
  t53_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n41;
  t53_n40: return 0.0811174139380455;
  t53_n41: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t53_n45;
  t53_n42: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t53_n44;
  t53_n43: return 0.12142620980739594;
  t53_n44: return 0.11233923584222794;
  t53_n45: return 0.09406829625368118;
  t53_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n48;
  t53_n47: return 0.12586012482643127;
  t53_n48: return 0.04237079620361328;
  t53_n49: return 0.08632025867700577;
  t53_n50: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t53_n52;
  t53_n51: return -0.04071420803666115;
  t53_n52: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t53_n74;
  t53_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t53_n57;
  t53_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n56;
  t53_n55: return -0.06430169939994812;
  t53_n56: return 0.03644204139709473;
  t53_n57: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t53_n59;
  t53_n58: return 0.031398478895425797;
  t53_n59: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t53_n61;
  t53_n60: return 0.06437842547893524;
  t53_n61: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t53_n73;
  t53_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t53_n64;
  t53_n63: return 0.08309860527515411;
  t53_n64: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t53_n66;
  t53_n65: return -0.10762985050678253;
  t53_n66: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t53_n72;
  t53_n67: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t53_n71;
  t53_n68: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t53_n70;
  t53_n69: return 0.11262725293636322;
  t53_n70: return 0.08936849981546402;
  t53_n71: return 0.1090352013707161;
  t53_n72: return 0.11696723848581314;
  t53_n73: return 0.06583115458488464;
  t53_n74: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t53_n88;
  t53_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t53_n87;
  t53_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n78;
  t53_n77: return -0.10250687599182129;
  t53_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n84;
  t53_n79: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t53_n83;
  t53_n80: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n82;
  t53_n81: return 0.13286982476711273;
  t53_n82: return 0.1034792810678482;
  t53_n83: return -0.08452804386615753;
  t53_n84: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t53_n86;
  t53_n85: return 0.11501934379339218;
  t53_n86: return 0.11322396248579025;
  t53_n87: return 0.09190214425325394;
  t53_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n90;
  t53_n89: return -0.2039903849363327;
  t53_n90: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t53_n94;
  t53_n91: if (E.getNumReferences() >= 3338441472 /*32329.5*/) goto t53_n93;
  t53_n92: return 0.04225044697523117;
  t53_n93: return 0.08674310147762299;
  t53_n94: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t53_n102;
  t53_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n97;
  t53_n96: return -0.007449064403772354;
  t53_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n101;
  t53_n98: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t53_n100;
  t53_n99: return 0.11082323640584946;
  t53_n100: return 0.14386503398418427;
  t53_n101: return -0.056547582149505615;
  t53_n102: return 0.10661908984184265;
  t53_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t53_n105;
  t53_n104: return 0.009446686133742332;
  t53_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n107;
  t53_n106: return -0.25866755843162537;
  t53_n107: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t53_n111;
  t53_n108: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t53_n110;
  t53_n109: return 0.10450591892004013;
  t53_n110: return 0.05755152925848961;
  t53_n111: return -0.13234569132328033;
  t53_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n114;
  t53_n113: return -0.009445993229746819;
  t53_n114: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t53_n182;
  t53_n115: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t53_n179;
  t53_n116: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t53_n150;
  t53_n117: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t53_n131;
  t53_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n120;
  t53_n119: return 0.003395016072317958;
  t53_n120: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t53_n128;
  t53_n121: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t53_n127;
  t53_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Type))) goto t53_n124;
  t53_n123: return 0.016081025823950768;
  t53_n124: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n126;
  t53_n125: return 0.06157607212662697;
  t53_n126: return 0.024039238691329956;
  t53_n127: return 0.021717360243201256;
  t53_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t53_n130;
  t53_n129: return 0.05465981736779213;
  t53_n130: return 0.08713045716285706;
  t53_n131: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t53_n149;
  t53_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t53_n134;
  t53_n133: return 0.010135279037058353;
  t53_n134: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t53_n138;
  t53_n135: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n137;
  t53_n136: return 0.01489149872213602;
  t53_n137: return 0.04482150077819824;
  t53_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t53_n140;
  t53_n139: return 0.04232081398367882;
  t53_n140: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t53_n148;
  t53_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n147;
  t53_n142: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t53_n146;
  t53_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n145;
  t53_n144: return 0.07775154709815979;
  t53_n145: return 0.003860082710161805;
  t53_n146: return 0.06951897591352463;
  t53_n147: return -0.06286740303039551;
  t53_n148: return -0.16438767313957214;
  t53_n149: return -0.14647820591926575;
  t53_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n154;
  t53_n151: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t53_n153;
  t53_n152: return 0.03862074017524719;
  t53_n153: return -0.04423801228404045;
  t53_n154: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t53_n168;
  t53_n155: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t53_n163;
  t53_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t53_n158;
  t53_n157: return 0.062373485416173935;
  t53_n158: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t53_n160;
  t53_n159: return 0.04269137606024742;
  t53_n160: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t53_n162;
  t53_n161: return 0.1063528060913086;
  t53_n162: return 0.13821353018283844;
  t53_n163: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t53_n165;
  t53_n164: return 0.07379163056612015;
  t53_n165: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t53_n167;
  t53_n166: return 0.12141172587871552;
  t53_n167: return 0.07001359760761261;
  t53_n168: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t53_n170;
  t53_n169: return -0.14040598273277283;
  t53_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n178;
  t53_n171: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t53_n173;
  t53_n172: return -0.3227871060371399;
  t53_n173: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n177;
  t53_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n176;
  t53_n175: return 0.0726749524474144;
  t53_n176: return 0.11593247950077057;
  t53_n177: return 0.022665346041321754;
  t53_n178: return 0.03759416937828064;
  t53_n179: if (E.getNumReferences() >= 3354069824 /*120342.5*/) goto t53_n181;
  t53_n180: return -0.04313991591334343;
  t53_n181: return -0.13889269530773163;
  t53_n182: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t53_n186;
  t53_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t53_n185;
  t53_n184: return 0.06335221230983734;
  t53_n185: return -0.006355036050081253;
  t53_n186: return 0.02067609876394272;
  t53_n187: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t53_n221;
  t53_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t53_n212;
  t53_n189: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t53_n207;
  t53_n190: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t53_n200;
  t53_n191: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t53_n199;
  t53_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t53_n194;
  t53_n193: return 0.023319916799664497;
  t53_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n198;
  t53_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n197;
  t53_n196: return 0.0457376167178154;
  t53_n197: return 0.07033480703830719;
  t53_n198: return 0.02188863232731819;
  t53_n199: return -0.038320038467645645;
  t53_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t53_n202;
  t53_n201: return 0.017372701317071915;
  t53_n202: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t53_n204;
  t53_n203: return 0.01818196102976799;
  t53_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t53_n206;
  t53_n205: return 0.03508342429995537;
  t53_n206: return 0.07924194633960724;
  t53_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t53_n209;
  t53_n208: return -0.08599089831113815;
  t53_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n211;
  t53_n210: return -0.010396979749202728;
  t53_n211: return 0.054484471678733826;
  t53_n212: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t53_n220;
  t53_n213: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t53_n219;
  t53_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t53_n218;
  t53_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n217;
  t53_n216: return -0.024118565022945404;
  t53_n217: return 0.06975599378347397;
  t53_n218: return 0.0319049209356308;
  t53_n219: return 0.04393422231078148;
  t53_n220: return 0.06724686920642853;
  t53_n221: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t53_n235;
  t53_n222: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t53_n224;
  t53_n223: return 0.06506972759962082;
  t53_n224: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t53_n226;
  t53_n225: return 0.020453866571187973;
  t53_n226: if (E.getNumReferences() >= 3318682624 /*6626.5*/) goto t53_n234;
  t53_n227: if (E.getNumReferences() >= 3318517760 /*6546.0*/) goto t53_n231;
  t53_n228: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t53_n230;
  t53_n229: return 0.12461809813976288;
  t53_n230: return -0.11714226752519608;
  t53_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n233;
  t53_n232: return 0.11134513467550278;
  t53_n233: return 0.10123241692781448;
  t53_n234: return 0.05584186315536499;
  t53_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t53_n243;
  t53_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t53_n240;
  t53_n237: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t53_n239;
  t53_n238: return 0.11295196413993835;
  t53_n239: return -0.1546712964773178;
  t53_n240: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t53_n242;
  t53_n241: return 0.010489128530025482;
  t53_n242: return 0.06585469096899033;
  t53_n243: return 0.05750352516770363;
  t53_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t53_n250;
  t53_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t53_n249;
  t53_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t53_n248;
  t53_n247: return -0.012059112079441547;
  t53_n248: return 0.009939678013324738;
  t53_n249: return 0.03632717579603195;
  t53_n250: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t53_n254;
  t53_n251: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t53_n253;
  t53_n252: return 0.04098358750343323;
  t53_n253: return 0.058229777961969376;
  t53_n254: return -0.7989847660064697;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree54(const Example& E) {
  t54_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t54_n248;
  t54_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t54_n165;
  t54_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t54_n134;
  t54_n3: if (E.getNumReferences() >= 3304886272 /*2020.5*/) goto t54_n43;
  t54_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Namespace))) goto t54_n40;
  t54_n5: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t54_n27;
  t54_n6: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t54_n8;
  t54_n7: return -0.004043603781610727;
  t54_n8: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t54_n10;
  t54_n9: return 0.03234751150012016;
  t54_n10: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t54_n12;
  t54_n11: return 0.038089025765657425;
  t54_n12: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t54_n14;
  t54_n13: return 0.07774387300014496;
  t54_n14: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t54_n16;
  t54_n15: return 0.0919678583741188;
  t54_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t54_n18;
  t54_n17: return 0.09092561155557632;
  t54_n18: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t54_n20;
  t54_n19: return 0.12867088615894318;
  t54_n20: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t54_n26;
  t54_n21: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t54_n25;
  t54_n22: if (E.getNumReferences() >= 3271426048 /*127.0*/) goto t54_n24;
  t54_n23: return 0.03943594917654991;
  t54_n24: return 0.12672226130962372;
  t54_n25: return 0.10372014343738556;
  t54_n26: return -0.1632649451494217;
  t54_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n29;
  t54_n28: return -0.04482576996088028;
  t54_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n31;
  t54_n30: return -0.03810261934995651;
  t54_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t54_n33;
  t54_n32: return -0.033190369606018066;
  t54_n33: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n39;
  t54_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n36;
  t54_n35: return 0.05901749059557915;
  t54_n36: if (E.getNumReferences() >= 3296428032 /*1006.0*/) goto t54_n38;
  t54_n37: return 0.011628005653619766;
  t54_n38: return 0.09428676217794418;
  t54_n39: return -0.1359575390815735;
  t54_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t54_n42;
  t54_n41: return 0.01621297001838684;
  t54_n42: return 0.08895114064216614;
  t54_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t54_n49;
  t54_n44: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t54_n48;
  t54_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n47;
  t54_n46: return 0.017338335514068604;
  t54_n47: return 0.05569792911410332;
  t54_n48: return -0.013615616597235203;
  t54_n49: if (E.getNumReferences() >= 3316521984 /*5571.5*/) goto t54_n51;
  t54_n50: return 0.027042511850595474;
  t54_n51: if (E.getNumReferences() >= 3334350336 /*24339.0*/) goto t54_n133;
  t54_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t54_n74;
  t54_n53: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t54_n57;
  t54_n54: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t54_n56;
  t54_n55: return 0.056389741599559784;
  t54_n56: return 0.09335660934448242;
  t54_n57: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t54_n59;
  t54_n58: return 0.12458930909633636;
  t54_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t54_n65;
  t54_n60: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t54_n62;
  t54_n61: return 0.05149953067302704;
  t54_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t54_n64;
  t54_n63: return 0.06878671795129776;
  t54_n64: return 0.10778716206550598;
  t54_n65: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t54_n71;
  t54_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n70;
  t54_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t54_n69;
  t54_n68: return 0.1236315593123436;
  t54_n69: return 0.11038236320018768;
  t54_n70: return -0.10365977883338928;
  t54_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t54_n73;
  t54_n72: return 0.07902926951646805;
  t54_n73: return 0.11290470510721207;
  t54_n74: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t54_n76;
  t54_n75: return 0.05539710819721222;
  t54_n76: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t54_n116;
  t54_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t54_n79;
  t54_n78: return 0.013714050874114037;
  t54_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t54_n81;
  t54_n80: return 0.06895851343870163;
  t54_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t54_n111;
  t54_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t54_n84;
  t54_n83: return 0.07479062676429749;
  t54_n84: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t54_n86;
  t54_n85: return 0.09149014949798584;
  t54_n86: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t54_n90;
  t54_n87: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t54_n89;
  t54_n88: return 0.10933281481266022;
  t54_n89: return 0.09403278678655624;
  t54_n90: if (E.getNumReferences() >= 3325492736 /*11711.5*/) goto t54_n110;
  t54_n91: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t54_n107;
  t54_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t54_n94;
  t54_n93: return 0.09071861952543259;
  t54_n94: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t54_n102;
  t54_n95: if (E.getNumReferences() >= 3320114176 /*7325.5*/) goto t54_n97;
  t54_n96: return 0.11647003144025803;
  t54_n97: if (E.getNumReferences() >= 3321433088 /*7969.5*/) goto t54_n99;
  t54_n98: return 0.05781690031290054;
  t54_n99: if (E.getNumReferences() >= 3322399744 /*8691.0*/) goto t54_n101;
  t54_n100: return 0.11537521332502365;
  t54_n101: return 0.11342838406562805;
  t54_n102: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t54_n104;
  t54_n103: return 0.07361665368080139;
  t54_n104: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t54_n106;
  t54_n105: return -0.254279226064682;
  t54_n106: return 0.11887724697589874;
  t54_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n109;
  t54_n108: return 0.11461954563856125;
  t54_n109: return 0.09359626471996307;
  t54_n110: return 0.07602909207344055;
  t54_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t54_n115;
  t54_n112: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t54_n114;
  t54_n113: return 0.10421483963727951;
  t54_n114: return 0.10658140480518341;
  t54_n115: return 0.09166561812162399;
  t54_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t54_n130;
  t54_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t54_n123;
  t54_n118: if (E.getNumReferences() >= 3323042816 /*9319.0*/) goto t54_n120;
  t54_n119: return 0.06294715404510498;
  t54_n120: if (E.getNumReferences() >= 3323761664 /*10021.0*/) goto t54_n122;
  t54_n121: return 0.10628610104322433;
  t54_n122: return 0.09417130798101425;
  t54_n123: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t54_n129;
  t54_n124: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t54_n128;
  t54_n125: if (E.getNumReferences() >= 3325171712 /*11398.0*/) goto t54_n127;
  t54_n126: return 0.10144303739070892;
  t54_n127: return 0.10770926624536514;
  t54_n128: return 0.10549898445606232;
  t54_n129: return 0.09716591238975525;
  t54_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t54_n132;
  t54_n131: return 0.07972411066293716;
  t54_n132: return 0.11280640214681625;
  t54_n133: return 0.01947798766195774;
  t54_n134: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t54_n162;
  t54_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n137;
  t54_n136: return 0.02121984027326107;
  t54_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t54_n141;
  t54_n138: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n140;
  t54_n139: return 0.02530048042535782;
  t54_n140: return -0.11290370672941208;
  t54_n141: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t54_n155;
  t54_n142: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t54_n148;
  t54_n143: if (E.getNumReferences() >= 3318422528 /*6499.5*/) goto t54_n147;
  t54_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t54_n146;
  t54_n145: return -0.05302947759628296;
  t54_n146: return 0.04115046188235283;
  t54_n147: return -0.20506104826927185;
  t54_n148: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t54_n154;
  t54_n149: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t54_n151;
  t54_n150: return 0.08383271098136902;
  t54_n151: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t54_n153;
  t54_n152: return 0.1201913133263588;
  t54_n153: return 0.055800314992666245;
  t54_n154: return 0.02745695970952511;
  t54_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t54_n157;
  t54_n156: return 0.05987654998898506;
  t54_n157: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n161;
  t54_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t54_n160;
  t54_n159: return 0.10629049688577652;
  t54_n160: return 0.10792804509401321;
  t54_n161: return 0.03826398402452469;
  t54_n162: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n164;
  t54_n163: return -0.05362619459629059;
  t54_n164: return 0.048034414649009705;
  t54_n165: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t54_n235;
  t54_n166: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t54_n170;
  t54_n167: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t54_n169;
  t54_n168: return 0.012989888899028301;
  t54_n169: return -0.002927703084424138;
  t54_n170: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t54_n184;
  t54_n171: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t54_n183;
  t54_n172: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t54_n178;
  t54_n173: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t54_n175;
  t54_n174: return 0.04598940908908844;
  t54_n175: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t54_n177;
  t54_n176: return 0.1123078241944313;
  t54_n177: return -0.10423526167869568;
  t54_n178: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n182;
  t54_n179: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t54_n181;
  t54_n180: return -0.02053767256438732;
  t54_n181: return 0.09131718426942825;
  t54_n182: return 0.1321694701910019;
  t54_n183: return 0.017220662906765938;
  t54_n184: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t54_n190;
  t54_n185: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t54_n187;
  t54_n186: return 0.07465335726737976;
  t54_n187: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t54_n189;
  t54_n188: return 0.11337003856897354;
  t54_n189: return 0.0679202601313591;
  t54_n190: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t54_n230;
  t54_n191: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t54_n193;
  t54_n192: return 0.039669204503297806;
  t54_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t54_n215;
  t54_n194: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t54_n208;
  t54_n195: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t54_n197;
  t54_n196: return 0.09174210578203201;
  t54_n197: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t54_n199;
  t54_n198: return 0.0710831955075264;
  t54_n199: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t54_n207;
  t54_n200: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t54_n206;
  t54_n201: if (E.getNumReferences() >= 3288743936 /*537.0*/) goto t54_n205;
  t54_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t54_n204;
  t54_n203: return 0.11670421063899994;
  t54_n204: return 0.11991678178310394;
  t54_n205: return 0.11956088244915009;
  t54_n206: return 0.07784068584442139;
  t54_n207: return 0.0846572071313858;
  t54_n208: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t54_n214;
  t54_n209: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t54_n213;
  t54_n210: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t54_n212;
  t54_n211: return -0.14544430375099182;
  t54_n212: return 0.13894224166870117;
  t54_n213: return 0.16630621254444122;
  t54_n214: return 0.10274066030979156;
  t54_n215: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t54_n217;
  t54_n216: return 0.12040441483259201;
  t54_n217: if (E.getNumReferences() >= 3277488128 /*218.5*/) goto t54_n219;
  t54_n218: return 0.06486739963293076;
  t54_n219: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t54_n227;
  t54_n220: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t54_n224;
  t54_n221: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t54_n223;
  t54_n222: return 0.10981435328722;
  t54_n223: return 0.11789770424365997;
  t54_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t54_n226;
  t54_n225: return 0.0020303400233387947;
  t54_n226: return 0.09185721725225449;
  t54_n227: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t54_n229;
  t54_n228: return 0.13049019873142242;
  t54_n229: return -0.3266313076019287;
  t54_n230: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t54_n234;
  t54_n231: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t54_n233;
  t54_n232: return 0.09925307333469391;
  t54_n233: return 0.1834123134613037;
  t54_n234: return 0.09052475541830063;
  t54_n235: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t54_n243;
  t54_n236: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t54_n238;
  t54_n237: return 0.03828210011124611;
  t54_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t54_n240;
  t54_n239: return 0.0029668547213077545;
  t54_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t54_n242;
  t54_n241: return -0.9418485164642334;
  t54_n242: return 0.02741936780512333;
  t54_n243: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t54_n247;
  t54_n244: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t54_n246;
  t54_n245: return 0.08478087931871414;
  t54_n246: return 0.06191844493150711;
  t54_n247: return 0.041287846863269806;
  t54_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t54_n254;
  t54_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t54_n251;
  t54_n250: return 0.0016432598931714892;
  t54_n251: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t54_n253;
  t54_n252: return 0.009760385379195213;
  t54_n253: return 0.028340382501482964;
  t54_n254: return 0.04236803203821182;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree55(const Example& E) {
  t55_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t55_n244;
  t55_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t55_n209;
  t55_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t55_n94;
  t55_n3: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t55_n53;
  t55_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t55_n52;
  t55_n5: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t55_n13;
  t55_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t55_n8;
  t55_n7: return -0.02618253417313099;
  t55_n8: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t55_n10;
  t55_n9: return -0.043867286294698715;
  t55_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t55_n12;
  t55_n11: return -0.30092155933380127;
  t55_n12: return 0.022116094827651978;
  t55_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t55_n31;
  t55_n14: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n30;
  t55_n15: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t55_n27;
  t55_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n18;
  t55_n17: return 0.047979604452848434;
  t55_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t55_n20;
  t55_n19: return 0.0625975951552391;
  t55_n20: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t55_n26;
  t55_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n23;
  t55_n22: return 0.20342470705509186;
  t55_n23: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t55_n25;
  t55_n24: return 0.16038107872009277;
  t55_n25: return 0.10314429551362991;
  t55_n26: return 0.10631828010082245;
  t55_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n29;
  t55_n28: return 0.13000018894672394;
  t55_n29: return -0.10304326564073563;
  t55_n30: return -0.12002936750650406;
  t55_n31: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n39;
  t55_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n38;
  t55_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t55_n37;
  t55_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n36;
  t55_n35: return 0.07772191613912582;
  t55_n36: return -0.07995694875717163;
  t55_n37: return 0.0480717271566391;
  t55_n38: return 0.005483776330947876;
  t55_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n49;
  t55_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n42;
  t55_n41: return 0.1382446438074112;
  t55_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n48;
  t55_n43: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t55_n45;
  t55_n44: return 0.12904059886932373;
  t55_n45: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t55_n47;
  t55_n46: return 0.1315823644399643;
  t55_n47: return 0.11529511958360672;
  t55_n48: return 0.10232257843017578;
  t55_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n51;
  t55_n50: return 0.10088439285755157;
  t55_n51: return 0.08303450793027878;
  t55_n52: return 0.0040911114774644375;
  t55_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t55_n55;
  t55_n54: return 0.01186628919094801;
  t55_n55: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t55_n79;
  t55_n56: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t55_n78;
  t55_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t55_n61;
  t55_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t55_n60;
  t55_n59: return 0.014144793152809143;
  t55_n60: return 0.08714856207370758;
  t55_n61: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t55_n63;
  t55_n62: return 0.028210405260324478;
  t55_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t55_n77;
  t55_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t55_n66;
  t55_n65: return 0.03799925744533539;
  t55_n66: if (E.getNumReferences() >= 3301523456 /*1610.0*/) goto t55_n74;
  t55_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t55_n69;
  t55_n68: return 0.029009219259023666;
  t55_n69: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t55_n71;
  t55_n70: return 0.08809152990579605;
  t55_n71: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t55_n73;
  t55_n72: return 0.12699681520462036;
  t55_n73: return 0.24628785252571106;
  t55_n74: if (E.getNumReferences() >= 3303129088 /*1806.0*/) goto t55_n76;
  t55_n75: return 0.11470681428909302;
  t55_n76: return 0.10216522216796875;
  t55_n77: return 0.05903928354382515;
  t55_n78: return 0.05295789986848831;
  t55_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t55_n81;
  t55_n80: return 0.03655308857560158;
  t55_n81: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t55_n83;
  t55_n82: return 0.055298812687397;
  t55_n83: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t55_n93;
  t55_n84: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t55_n92;
  t55_n85: if (E.getNumReferences() >= 3286450176 /*454.5*/) goto t55_n87;
  t55_n86: return 0.0824919044971466;
  t55_n87: if (E.getNumReferences() >= 3289686016 /*594.5*/) goto t55_n91;
  t55_n88: if (E.getNumReferences() >= 3289554944 /*586.5*/) goto t55_n90;
  t55_n89: return 0.10703763365745544;
  t55_n90: return 0.1102779358625412;
  t55_n91: return 0.08188609778881073;
  t55_n92: return 0.019277848303318024;
  t55_n93: return 0.12387661635875702;
  t55_n94: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t55_n136;
  t55_n95: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t55_n97;
  t55_n96: return -0.007465111091732979;
  t55_n97: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t55_n99;
  t55_n98: return 0.03471221402287483;
  t55_n99: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t55_n115;
  t55_n100: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t55_n102;
  t55_n101: return 0.07116418331861496;
  t55_n102: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t55_n104;
  t55_n103: return 0.08153471350669861;
  t55_n104: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t55_n110;
  t55_n105: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t55_n109;
  t55_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t55_n108;
  t55_n107: return -0.12243428081274033;
  t55_n108: return 0.15306301414966583;
  t55_n109: return -0.12565480172634125;
  t55_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t55_n112;
  t55_n111: return 0.0803140178322792;
  t55_n112: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t55_n114;
  t55_n113: return -0.10223569720983505;
  t55_n114: return 0.15618360042572021;
  t55_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t55_n117;
  t55_n116: return 0.09212552756071091;
  t55_n117: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t55_n125;
  t55_n118: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t55_n124;
  t55_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t55_n121;
  t55_n120: return 0.13975657522678375;
  t55_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t55_n123;
  t55_n122: return -0.2999022603034973;
  t55_n123: return 0.1165139228105545;
  t55_n124: return 0.10321028530597687;
  t55_n125: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t55_n127;
  t55_n126: return 0.09810017794370651;
  t55_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t55_n129;
  t55_n128: return 0.07189474254846573;
  t55_n129: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t55_n131;
  t55_n130: return 0.16269803047180176;
  t55_n131: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t55_n135;
  t55_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t55_n134;
  t55_n133: return 0.11665543913841248;
  t55_n134: return 0.12334485352039337;
  t55_n135: return 0.0979657769203186;
  t55_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n206;
  t55_n137: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t55_n139;
  t55_n138: return -0.046585921198129654;
  t55_n139: if (E.getNumReferences() >= 3283271680 /*357.5*/) goto t55_n161;
  t55_n140: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t55_n158;
  t55_n141: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n157;
  t55_n142: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t55_n144;
  t55_n143: return -0.01385625172406435;
  t55_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t55_n146;
  t55_n145: return 0.02649054490029812;
  t55_n146: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t55_n156;
  t55_n147: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t55_n155;
  t55_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t55_n150;
  t55_n149: return 0.07210898399353027;
  t55_n150: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t55_n152;
  t55_n151: return 0.0030792062170803547;
  t55_n152: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t55_n154;
  t55_n153: return 0.10227359086275101;
  t55_n154: return 0.03800854831933975;
  t55_n155: return -0.042414698749780655;
  t55_n156: return -0.016151169314980507;
  t55_n157: return -0.0828913152217865;
  t55_n158: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t55_n160;
  t55_n159: return -0.06845709681510925;
  t55_n160: return 0.09075707197189331;
  t55_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t55_n195;
  t55_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t55_n164;
  t55_n163: return -0.005301549099385738;
  t55_n164: if (E.getNumReferences() >= 3316905984 /*5759.0*/) goto t55_n166;
  t55_n165: return 0.01489268895238638;
  t55_n166: if (E.getNumReferences() >= 3316937728 /*5774.5*/) goto t55_n170;
  t55_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t55_n169;
  t55_n168: return -0.11037790030241013;
  t55_n169: return 0.11421182006597519;
  t55_n170: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t55_n178;
  t55_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t55_n177;
  t55_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t55_n176;
  t55_n173: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t55_n175;
  t55_n174: return -0.332120418548584;
  t55_n175: return -0.007095750421285629;
  t55_n176: return 0.04365735501050949;
  t55_n177: return 0.050327517092227936;
  t55_n178: if (E.getNumReferences() >= 3329839104 /*15956.0*/) goto t55_n180;
  t55_n179: return 0.07464227080345154;
  t55_n180: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t55_n194;
  t55_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t55_n185;
  t55_n182: if (E.getNumReferences() >= 3329918464 /*16033.5*/) goto t55_n184;
  t55_n183: return 0.11969279497861862;
  t55_n184: return 0.09910733252763748;
  t55_n185: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t55_n191;
  t55_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t55_n188;
  t55_n187: return 0.0650075152516365;
  t55_n188: if (E.getNumReferences() >= 3331962112 /*19674.5*/) goto t55_n190;
  t55_n189: return 0.09397447854280472;
  t55_n190: return 0.1042194589972496;
  t55_n191: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t55_n193;
  t55_n192: return 0.05667433515191078;
  t55_n193: return 0.11759112030267715;
  t55_n194: return 0.048473961651325226;
  t55_n195: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t55_n199;
  t55_n196: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t55_n198;
  t55_n197: return 0.043594617396593094;
  t55_n198: return 0.07330428063869476;
  t55_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t55_n201;
  t55_n200: return 0.054445549845695496;
  t55_n201: if (E.getNumReferences() >= 3283501056 /*364.5*/) goto t55_n205;
  t55_n202: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t55_n204;
  t55_n203: return -0.10439988970756531;
  t55_n204: return 0.12940481305122375;
  t55_n205: return 0.08461374789476395;
  t55_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t55_n208;
  t55_n207: return -0.10716474801301956;
  t55_n208: return 0.02313307859003544;
  t55_n209: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t55_n225;
  t55_n210: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t55_n222;
  t55_n211: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t55_n219;
  t55_n212: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t55_n214;
  t55_n213: return 0.017272360622882843;
  t55_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t55_n216;
  t55_n215: return 0.015551174990832806;
  t55_n216: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t55_n218;
  t55_n217: return 0.0014325595693662763;
  t55_n218: return 0.056890860199928284;
  t55_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t55_n221;
  t55_n220: return -0.08382689952850342;
  t55_n221: return 0.0314466767013073;
  t55_n222: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t55_n224;
  t55_n223: return 0.028685329481959343;
  t55_n224: return -0.07331707328557968;
  t55_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t55_n227;
  t55_n226: return 0.04606683924794197;
  t55_n227: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t55_n229;
  t55_n228: return 0.004946296568959951;
  t55_n229: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t55_n231;
  t55_n230: return -0.003083112183958292;
  t55_n231: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t55_n243;
  t55_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t55_n234;
  t55_n233: return -0.04841690510511398;
  t55_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t55_n240;
  t55_n235: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t55_n237;
  t55_n236: return 0.08375070244073868;
  t55_n237: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t55_n239;
  t55_n238: return 0.06983144581317902;
  t55_n239: return 0.1344091147184372;
  t55_n240: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t55_n242;
  t55_n241: return 0.12260536104440689;
  t55_n242: return 0.14644229412078857;
  t55_n243: return 0.05417695268988609;
  t55_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t55_n250;
  t55_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t55_n249;
  t55_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t55_n248;
  t55_n247: return -0.013725814409554005;
  t55_n248: return 0.008792513981461525;
  t55_n249: return 0.03315022587776184;
  t55_n250: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t55_n252;
  t55_n251: return 0.040615327656269073;
  t55_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t55_n254;
  t55_n253: return 0.09258484840393066;
  t55_n254: return -0.06301511824131012;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree56(const Example& E) {
  t56_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t56_n246;
  t56_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t56_n117;
  t56_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t56_n36;
  t56_n3: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t56_n5;
  t56_n4: return -0.028395865112543106;
  t56_n5: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t56_n19;
  t56_n6: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t56_n18;
  t56_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t56_n9;
  t56_n8: return 0.01715143583714962;
  t56_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t56_n17;
  t56_n10: if (E.getNumReferences() >= 3317558272 /*6077.5*/) goto t56_n14;
  t56_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t56_n13;
  t56_n12: return 0.010789885185658932;
  t56_n13: return 0.045269742608070374;
  t56_n14: if (E.getNumReferences() >= 3317673984 /*6134.0*/) goto t56_n16;
  t56_n15: return 0.1208549439907074;
  t56_n16: return 0.05191534757614136;
  t56_n17: return 0.06462010741233826;
  t56_n18: return -0.005505191162228584;
  t56_n19: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t56_n35;
  t56_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t56_n22;
  t56_n21: return 0.09102446585893631;
  t56_n22: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t56_n24;
  t56_n23: return 0.07866226136684418;
  t56_n24: if (E.getNumReferences() >= 3268149248 /*102.0*/) goto t56_n26;
  t56_n25: return 0.1214124858379364;
  t56_n26: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t56_n34;
  t56_n27: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t56_n31;
  t56_n28: if (E.getNumReferences() >= 3271557120 /*128.0*/) goto t56_n30;
  t56_n29: return 0.017710542306303978;
  t56_n30: return 0.12324868142604828;
  t56_n31: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t56_n33;
  t56_n32: return 0.11067543923854828;
  t56_n33: return 0.018648948520421982;
  t56_n34: return -0.023633569478988647;
  t56_n35: return 0.06373438239097595;
  t56_n36: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t56_n84;
  t56_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t56_n39;
  t56_n38: return -0.027206474915146828;
  t56_n39: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t56_n75;
  t56_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n46;
  t56_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t56_n45;
  t56_n42: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n44;
  t56_n43: return 0.020887691527605057;
  t56_n44: return 0.04870140925049782;
  t56_n45: return 0.1313479095697403;
  t56_n46: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n74;
  t56_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n63;
  t56_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t56_n62;
  t56_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n51;
  t56_n50: return -0.06705496460199356;
  t56_n51: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t56_n53;
  t56_n52: return 0.004908725619316101;
  t56_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t56_n61;
  t56_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n60;
  t56_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t56_n57;
  t56_n56: return 0.12592290341854095;
  t56_n57: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t56_n59;
  t56_n58: return 0.13101987540721893;
  t56_n59: return 0.11452649533748627;
  t56_n60: return 0.10085144639015198;
  t56_n61: return -0.11891677975654602;
  t56_n62: return 0.02507016435265541;
  t56_n63: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t56_n67;
  t56_n64: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t56_n66;
  t56_n65: return 0.028608912602066994;
  t56_n66: return -0.09607906639575958;
  t56_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t56_n71;
  t56_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t56_n70;
  t56_n69: return -0.013636451214551926;
  t56_n70: return 0.06110746040940285;
  t56_n71: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n73;
  t56_n72: return 0.10059826076030731;
  t56_n73: return 0.0451757088303566;
  t56_n74: return -0.04965496063232422;
  t56_n75: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n83;
  t56_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n78;
  t56_n77: return -0.08320450037717819;
  t56_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t56_n80;
  t56_n79: return 0.0045302086509764194;
  t56_n80: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n82;
  t56_n81: return 0.05933540314435959;
  t56_n82: return 0.09980198740959167;
  t56_n83: return 0.04951826483011246;
  t56_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n90;
  t56_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t56_n87;
  t56_n86: return 0.005393452476710081;
  t56_n87: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t56_n89;
  t56_n88: return 0.0980093851685524;
  t56_n89: return -0.03159739822149277;
  t56_n90: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t56_n102;
  t56_n91: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t56_n97;
  t56_n92: if (E.getNumReferences() >= 3318775808 /*6672.0*/) goto t56_n94;
  t56_n93: return 0.029269210994243622;
  t56_n94: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t56_n96;
  t56_n95: return 0.10710415244102478;
  t56_n96: return -0.138566792011261;
  t56_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t56_n101;
  t56_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t56_n100;
  t56_n99: return -0.01066665817052126;
  t56_n100: return 0.02806418016552925;
  t56_n101: return 0.04582575336098671;
  t56_n102: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t56_n108;
  t56_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t56_n105;
  t56_n104: return 0.09871810674667358;
  t56_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t56_n107;
  t56_n106: return 0.129996657371521;
  t56_n107: return 0.10522422939538956;
  t56_n108: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t56_n110;
  t56_n109: return 0.047497935593128204;
  t56_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t56_n112;
  t56_n111: return -0.12793193757534027;
  t56_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t56_n116;
  t56_n113: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t56_n115;
  t56_n114: return -0.04861535131931305;
  t56_n115: return 0.04222072660923004;
  t56_n116: return -0.08246210217475891;
  t56_n117: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n209;
  t56_n118: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t56_n122;
  t56_n119: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t56_n121;
  t56_n120: return 0.010042550042271614;
  t56_n121: return -0.005443733651190996;
  t56_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t56_n148;
  t56_n123: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t56_n143;
  t56_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t56_n138;
  t56_n125: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t56_n135;
  t56_n126: if (E.getNumReferences() >= 3350349056 /*91274.0*/) goto t56_n128;
  t56_n127: return 0.041053950786590576;
  t56_n128: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t56_n134;
  t56_n129: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t56_n131;
  t56_n130: return 0.0647038072347641;
  t56_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n133;
  t56_n132: return 0.09801509976387024;
  t56_n133: return 0.10711853206157684;
  t56_n134: return -0.016608918085694313;
  t56_n135: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t56_n137;
  t56_n136: return 0.10988640785217285;
  t56_n137: return -0.10387194156646729;
  t56_n138: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n142;
  t56_n139: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t56_n141;
  t56_n140: return -0.02030392922461033;
  t56_n141: return 0.08604293316602707;
  t56_n142: return 0.13393129408359528;
  t56_n143: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t56_n145;
  t56_n144: return 0.04445578530430794;
  t56_n145: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t56_n147;
  t56_n146: return 0.07027552276849747;
  t56_n147: return 0.00357452011667192;
  t56_n148: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t56_n154;
  t56_n149: if (E.getNumReferences() >= 3289653248 /*592.5*/) goto t56_n151;
  t56_n150: return 0.06883924454450607;
  t56_n151: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t56_n153;
  t56_n152: return 0.11140549182891846;
  t56_n153: return 0.06280160695314407;
  t56_n154: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t56_n180;
  t56_n155: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n175;
  t56_n156: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t56_n158;
  t56_n157: return 0.030418654903769493;
  t56_n158: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t56_n160;
  t56_n159: return 0.08484512567520142;
  t56_n160: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t56_n162;
  t56_n161: return 0.06626735627651215;
  t56_n162: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t56_n174;
  t56_n163: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t56_n173;
  t56_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t56_n166;
  t56_n165: return 0.07950937002897263;
  t56_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t56_n172;
  t56_n167: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t56_n171;
  t56_n168: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t56_n170;
  t56_n169: return 0.12006192654371262;
  t56_n170: return 0.11541525274515152;
  t56_n171: return 0.11798924952745438;
  t56_n172: return 0.16988405585289001;
  t56_n173: return 0.07683926075696945;
  t56_n174: return 0.0855187401175499;
  t56_n175: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t56_n179;
  t56_n176: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t56_n178;
  t56_n177: return 0.09634869545698166;
  t56_n178: return 0.16912654042243958;
  t56_n179: return 0.08615800738334656;
  t56_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t56_n194;
  t56_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t56_n183;
  t56_n182: return 0.0470280647277832;
  t56_n183: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t56_n185;
  t56_n184: return 0.09005807340145111;
  t56_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t56_n191;
  t56_n186: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t56_n188;
  t56_n187: return 0.1048746258020401;
  t56_n188: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t56_n190;
  t56_n189: return 0.1439269632101059;
  t56_n190: return -0.16173399984836578;
  t56_n191: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t56_n193;
  t56_n192: return 0.148658886551857;
  t56_n193: return 0.10932236164808273;
  t56_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t56_n200;
  t56_n195: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t56_n199;
  t56_n196: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t56_n198;
  t56_n197: return 0.11352526396512985;
  t56_n198: return 0.12485138326883316;
  t56_n199: return 0.04812386631965637;
  t56_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t56_n202;
  t56_n201: return 0.05823812633752823;
  t56_n202: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t56_n204;
  t56_n203: return 0.09244706481695175;
  t56_n204: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t56_n208;
  t56_n205: if (E.getNumReferences() >= 3279028224 /*242.0*/) goto t56_n207;
  t56_n206: return 0.12180452793836594;
  t56_n207: return 0.08644383400678635;
  t56_n208: return 0.08118460327386856;
  t56_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t56_n241;
  t56_n210: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t56_n216;
  t56_n211: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t56_n215;
  t56_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n214;
  t56_n213: return 0.03510567545890808;
  t56_n214: return 0.06005130708217621;
  t56_n215: return 0.018875770270824432;
  t56_n216: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t56_n240;
  t56_n217: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t56_n219;
  t56_n218: return 0.06810932606458664;
  t56_n219: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t56_n231;
  t56_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t56_n222;
  t56_n221: return -0.07146089524030685;
  t56_n222: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t56_n230;
  t56_n223: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t56_n225;
  t56_n224: return 0.11136108636856079;
  t56_n225: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t56_n227;
  t56_n226: return -0.06838732212781906;
  t56_n227: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t56_n229;
  t56_n228: return 0.1154981255531311;
  t56_n229: return 0.11764450371265411;
  t56_n230: return -0.009000002406537533;
  t56_n231: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t56_n233;
  t56_n232: return -0.004317325074225664;
  t56_n233: if (E.getNumReferences() >= 3267362816 /*96.0*/) goto t56_n235;
  t56_n234: return 0.1106829047203064;
  t56_n235: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t56_n239;
  t56_n236: if (E.getNumReferences() >= 3269984256 /*116.0*/) goto t56_n238;
  t56_n237: return -0.0016672967467457056;
  t56_n238: return 0.12054001539945602;
  t56_n239: return 0.060497842729091644;
  t56_n240: return 0.03979995846748352;
  t56_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t56_n245;
  t56_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t56_n244;
  t56_n243: return -0.004180398769676685;
  t56_n244: return 0.029623497277498245;
  t56_n245: return 0.022709328681230545;
  t56_n246: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t56_n254;
  t56_n247: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t56_n253;
  t56_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t56_n250;
  t56_n249: return -0.005689495243132114;
  t56_n250: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t56_n252;
  t56_n251: return 0.0066826920956373215;
  t56_n252: return 0.025346772745251656;
  t56_n253: return -0.2514071762561798;
  t56_n254: return 0.03902595490217209;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree57(const Example& E) {
  t57_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t57_n248;
  t57_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t57_n207;
  t57_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t57_n54;
  t57_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t57_n5;
  t57_n4: return -0.03601117804646492;
  t57_n5: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t57_n45;
  t57_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t57_n10;
  t57_n7: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t57_n9;
  t57_n8: return 0.018970850855112076;
  t57_n9: return -0.04390953853726387;
  t57_n10: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t57_n16;
  t57_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t57_n13;
  t57_n12: return -0.0920642539858818;
  t57_n13: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t57_n15;
  t57_n14: return 0.014566046185791492;
  t57_n15: return -0.01867746375501156;
  t57_n16: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t57_n20;
  t57_n17: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t57_n19;
  t57_n18: return 0.11764746904373169;
  t57_n19: return 0.0028511302080005407;
  t57_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n22;
  t57_n21: return 0.0023553213104605675;
  t57_n22: if (E.getNumReferences() >= 3361127968 /*219896.5*/) goto t57_n44;
  t57_n23: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t57_n43;
  t57_n24: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t57_n42;
  t57_n25: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t57_n27;
  t57_n26: return 0.04386430233716965;
  t57_n27: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t57_n35;
  t57_n28: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t57_n30;
  t57_n29: return 0.09392116963863373;
  t57_n30: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t57_n32;
  t57_n31: return 0.12194361537694931;
  t57_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n34;
  t57_n33: return 0.09844647347927094;
  t57_n34: return 0.11017860472202301;
  t57_n35: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t57_n41;
  t57_n36: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t57_n40;
  t57_n37: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t57_n39;
  t57_n38: return 0.07622881978750229;
  t57_n39: return -0.031209522858262062;
  t57_n40: return 0.08673743158578873;
  t57_n41: return 0.15919621288776398;
  t57_n42: return -0.14982178807258606;
  t57_n43: return 0.09309288114309311;
  t57_n44: return 0.12211702018976212;
  t57_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t57_n47;
  t57_n46: return 0.013541446067392826;
  t57_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t57_n49;
  t57_n48: return 0.04217858612537384;
  t57_n49: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t57_n53;
  t57_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t57_n52;
  t57_n51: return 0.10409177839756012;
  t57_n52: return 0.06521057337522507;
  t57_n53: return -0.11373437196016312;
  t57_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n56;
  t57_n55: return -0.008731350302696228;
  t57_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t57_n206;
  t57_n57: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t57_n197;
  t57_n58: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t57_n146;
  t57_n59: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t57_n145;
  t57_n60: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t57_n144;
  t57_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n127;
  t57_n62: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t57_n66;
  t57_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n65;
  t57_n64: return 0.01891287788748741;
  t57_n65: return 0.023664014413952827;
  t57_n66: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t57_n68;
  t57_n67: return -0.029191656038165092;
  t57_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t57_n70;
  t57_n69: return -0.0011171776568517089;
  t57_n70: if (E.getNumReferences() >= 3316685824 /*5651.5*/) goto t57_n96;
  t57_n71: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t57_n73;
  t57_n72: return 0.011972908861935139;
  t57_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t57_n83;
  t57_n74: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t57_n76;
  t57_n75: return 0.09553514420986176;
  t57_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t57_n80;
  t57_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t57_n79;
  t57_n78: return -0.023492278531193733;
  t57_n79: return 0.08144426345825195;
  t57_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t57_n82;
  t57_n81: return -0.19521740078926086;
  t57_n82: return 0.21832291781902313;
  t57_n83: if (E.getNumReferences() >= 3280060416 /*259.5*/) goto t57_n85;
  t57_n84: return -0.07427753508090973;
  t57_n85: if (E.getNumReferences() >= 3280093184 /*260.5*/) goto t57_n87;
  t57_n86: return 0.12282276153564453;
  t57_n87: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t57_n95;
  t57_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t57_n90;
  t57_n89: return 0.09554644674062729;
  t57_n90: if (E.getNumReferences() >= 3299962880 /*1419.5*/) goto t57_n94;
  t57_n91: if (E.getNumReferences() >= 3290324992 /*633.5*/) goto t57_n93;
  t57_n92: return -0.14711898565292358;
  t57_n93: return 0.12200018018484116;
  t57_n94: return 0.041434019804000854;
  t57_n95: return 0.04387602582573891;
  t57_n96: if (E.getNumReferences() >= 3332719104 /*21153.0*/) goto t57_n126;
  t57_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t57_n103;
  t57_n98: if (E.getNumReferences() >= 3317223424 /*5914.0*/) goto t57_n102;
  t57_n99: if (E.getNumReferences() >= 3316872192 /*5742.5*/) goto t57_n101;
  t57_n100: return -1.8568289279937744;
  t57_n101: return 0.11567310243844986;
  t57_n102: return 0.007152167614549398;
  t57_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t57_n105;
  t57_n104: return -0.006938971113413572;
  t57_n105: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t57_n107;
  t57_n106: return 0.1030222550034523;
  t57_n107: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t57_n113;
  t57_n108: if (E.getNumReferences() >= 3320056832 /*7297.5*/) goto t57_n112;
  t57_n109: if (E.getNumReferences() >= 3319805952 /*7175.0*/) goto t57_n111;
  t57_n110: return 0.08747990429401398;
  t57_n111: return 0.1176200807094574;
  t57_n112: return 0.1078438088297844;
  t57_n113: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t57_n115;
  t57_n114: return 0.10982216894626617;
  t57_n115: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t57_n123;
  t57_n116: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t57_n122;
  t57_n117: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t57_n121;
  t57_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t57_n120;
  t57_n119: return 0.05788784101605415;
  t57_n120: return 0.12877611815929413;
  t57_n121: return 0.015894288197159767;
  t57_n122: return 0.09801942110061646;
  t57_n123: if (E.getNumReferences() >= 3321857024 /*8176.5*/) goto t57_n125;
  t57_n124: return -0.04209703952074051;
  t57_n125: return 0.10140670090913773;
  t57_n126: return 0.022784437984228134;
  t57_n127: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t57_n133;
  t57_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n130;
  t57_n129: return -0.1277177482843399;
  t57_n130: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t57_n132;
  t57_n131: return -0.021714717149734497;
  t57_n132: return 0.0994676724076271;
  t57_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t57_n135;
  t57_n134: return 0.020832741633057594;
  t57_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t57_n143;
  t57_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t57_n140;
  t57_n137: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t57_n139;
  t57_n138: return -0.04300206899642944;
  t57_n139: return -0.44097089767456055;
  t57_n140: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t57_n142;
  t57_n141: return 0.028585389256477356;
  t57_n142: return 0.10850002616643906;
  t57_n143: return 0.05162881687283516;
  t57_n144: return -0.11273659765720367;
  t57_n145: return -0.13544166088104248;
  t57_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n150;
  t57_n147: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t57_n149;
  t57_n148: return 0.03711828961968422;
  t57_n149: return -0.04368000477552414;
  t57_n150: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t57_n186;
  t57_n151: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t57_n169;
  t57_n152: if (E.getNumReferences() >= 3356390976 /*145881.0*/) goto t57_n168;
  t57_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t57_n155;
  t57_n154: return 0.047712136059999466;
  t57_n155: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t57_n167;
  t57_n156: if (E.getNumReferences() >= 3351357120 /*99149.5*/) goto t57_n160;
  t57_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t57_n159;
  t57_n158: return 0.06302326172590256;
  t57_n159: return 0.08544263243675232;
  t57_n160: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t57_n162;
  t57_n161: return 0.07813819497823715;
  t57_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n164;
  t57_n163: return -0.6979694962501526;
  t57_n164: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t57_n166;
  t57_n165: return 0.10616399347782135;
  t57_n166: return 0.11478207260370255;
  t57_n167: return 0.04573431611061096;
  t57_n168: return -0.22960692644119263;
  t57_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t57_n175;
  t57_n170: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t57_n172;
  t57_n171: return 0.04691813141107559;
  t57_n172: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t57_n174;
  t57_n173: return 0.12711626291275024;
  t57_n174: return -0.24834848940372467;
  t57_n175: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t57_n185;
  t57_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t57_n184;
  t57_n177: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t57_n183;
  t57_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t57_n182;
  t57_n179: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t57_n181;
  t57_n180: return 0.103073351085186;
  t57_n181: return 0.1083160787820816;
  t57_n182: return 0.11628159880638123;
  t57_n183: return -0.2905237674713135;
  t57_n184: return 0.08653702586889267;
  t57_n185: return 0.11084402352571487;
  t57_n186: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t57_n188;
  t57_n187: return -0.15295575559139252;
  t57_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t57_n196;
  t57_n189: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t57_n191;
  t57_n190: return -0.23072127997875214;
  t57_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n193;
  t57_n192: return -0.0027285171672701836;
  t57_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t57_n195;
  t57_n194: return 0.11717559397220612;
  t57_n195: return 0.0729503482580185;
  t57_n196: return 0.03436581417918205;
  t57_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n199;
  t57_n198: return 0.032783228904008865;
  t57_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t57_n205;
  t57_n200: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t57_n204;
  t57_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t57_n203;
  t57_n202: return 0.077858567237854;
  t57_n203: return 0.039654359221458435;
  t57_n204: return -0.031966980546712875;
  t57_n205: return 0.08889190107584;
  t57_n206: return -0.04518652707338333;
  t57_n207: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t57_n231;
  t57_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t57_n224;
  t57_n209: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t57_n213;
  t57_n210: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t57_n212;
  t57_n211: return 0.038254015147686005;
  t57_n212: return 0.04960792511701584;
  t57_n213: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t57_n221;
  t57_n214: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t57_n216;
  t57_n215: return 0.009055497124791145;
  t57_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t57_n218;
  t57_n217: return 0.013970781117677689;
  t57_n218: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t57_n220;
  t57_n219: return 0.02153218723833561;
  t57_n220: return 0.05531010776758194;
  t57_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t57_n223;
  t57_n222: return -0.07813636213541031;
  t57_n223: return 0.029568171128630638;
  t57_n224: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t57_n228;
  t57_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t57_n227;
  t57_n226: return -0.01153387688100338;
  t57_n227: return 0.03300582617521286;
  t57_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n230;
  t57_n229: return 0.0512324720621109;
  t57_n230: return 0.02882315218448639;
  t57_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t57_n243;
  t57_n232: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t57_n238;
  t57_n233: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t57_n237;
  t57_n234: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t57_n236;
  t57_n235: return 0.03372114151716232;
  t57_n236: return 0.08032214641571045;
  t57_n237: return -0.027748089283704758;
  t57_n238: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t57_n242;
  t57_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t57_n241;
  t57_n240: return 0.04312559589743614;
  t57_n241: return 0.09221307933330536;
  t57_n242: return -0.0025013049598783255;
  t57_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t57_n245;
  t57_n244: return 0.032458145171403885;
  t57_n245: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t57_n247;
  t57_n246: return 0.09903321415185928;
  t57_n247: return 0.07515005767345428;
  t57_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t57_n254;
  t57_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t57_n253;
  t57_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t57_n252;
  t57_n251: return -0.00852471124380827;
  t57_n252: return 0.008561967872083187;
  t57_n253: return 0.030439266934990883;
  t57_n254: return 0.03814397379755974;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree58(const Example& E) {
  t58_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t58_n242;
  t58_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t58_n207;
  t58_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t58_n16;
  t58_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t58_n5;
  t58_n4: return -0.03507724776864052;
  t58_n5: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t58_n7;
  t58_n6: return -0.0065452540293335915;
  t58_n7: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t58_n9;
  t58_n8: return 0.014411908574402332;
  t58_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n11;
  t58_n10: return -0.22793163359165192;
  t58_n11: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t58_n15;
  t58_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t58_n14;
  t58_n13: return 0.10025568306446075;
  t58_n14: return 0.04393937811255455;
  t58_n15: return -0.13194122910499573;
  t58_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n18;
  t58_n17: return -0.008191397413611412;
  t58_n18: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t58_n198;
  t58_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t58_n197;
  t58_n20: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t58_n148;
  t58_n21: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t58_n77;
  t58_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n24;
  t58_n23: return 0.001183574553579092;
  t58_n24: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t58_n26;
  t58_n25: return 0.019321879372000694;
  t58_n26: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t58_n28;
  t58_n27: return 0.04385947808623314;
  t58_n28: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t58_n60;
  t58_n29: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t58_n31;
  t58_n30: return 0.05418954789638519;
  t58_n31: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t58_n59;
  t58_n32: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t58_n38;
  t58_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n35;
  t58_n34: return -0.13767355680465698;
  t58_n35: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n37;
  t58_n36: return 0.14104238152503967;
  t58_n37: return -0.13787490129470825;
  t58_n38: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t58_n42;
  t58_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t58_n41;
  t58_n40: return 0.01361524686217308;
  t58_n41: return 0.09459508955478668;
  t58_n42: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t58_n44;
  t58_n43: return 0.09489434957504272;
  t58_n44: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t58_n46;
  t58_n45: return 0.11792459338903427;
  t58_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t58_n56;
  t58_n47: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t58_n51;
  t58_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t58_n50;
  t58_n49: return 0.12502361834049225;
  t58_n50: return 0.13896444439888;
  t58_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t58_n53;
  t58_n52: return 0.10827797651290894;
  t58_n53: if (E.getNumReferences() >= 3285434368 /*423.5*/) goto t58_n55;
  t58_n54: return 0.12428557127714157;
  t58_n55: return 0.10041698813438416;
  t58_n56: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n58;
  t58_n57: return 0.11601947247982025;
  t58_n58: return 0.11609695851802826;
  t58_n59: return 0.02196270413696766;
  t58_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t58_n62;
  t58_n61: return 0.06205722689628601;
  t58_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t58_n68;
  t58_n63: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t58_n67;
  t58_n64: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n66;
  t58_n65: return 0.07101740688085556;
  t58_n66: return 0.15049685537815094;
  t58_n67: return 0.0770079493522644;
  t58_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n70;
  t58_n69: return 0.09867080301046371;
  t58_n70: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t58_n74;
  t58_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n73;
  t58_n72: return 0.06970725208520889;
  t58_n73: return 0.12154272943735123;
  t58_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n76;
  t58_n75: return 0.09206676483154297;
  t58_n76: return 0.1357317715883255;
  t58_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t58_n103;
  t58_n78: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t58_n102;
  t58_n79: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t58_n81;
  t58_n80: return 0.016095157712697983;
  t58_n81: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t58_n83;
  t58_n82: return 0.01058509573340416;
  t58_n83: if (E.getFileProximityDistance() >= 3255435264 /*34.5*/) goto t58_n101;
  t58_n84: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t58_n86;
  t58_n85: return 0.05518040806055069;
  t58_n86: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n88;
  t58_n87: return 0.02833366021513939;
  t58_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t58_n92;
  t58_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t58_n91;
  t58_n90: return -0.026291390880942345;
  t58_n91: return 0.07480942457914352;
  t58_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t58_n96;
  t58_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t58_n95;
  t58_n94: return -0.10842353105545044;
  t58_n95: return 0.13253633677959442;
  t58_n96: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t58_n98;
  t58_n97: return 0.16105398535728455;
  t58_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n100;
  t58_n99: return 0.17631489038467407;
  t58_n100: return 0.12071259319782257;
  t58_n101: return -0.025658272206783295;
  t58_n102: return -0.13746561110019684;
  t58_n103: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t58_n105;
  t58_n104: return -0.0988907516002655;
  t58_n105: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t58_n109;
  t58_n106: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n108;
  t58_n107: return 0.010241303592920303;
  t58_n108: return 0.03843256086111069;
  t58_n109: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t58_n111;
  t58_n110: return -0.015939801931381226;
  t58_n111: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t58_n113;
  t58_n112: return -0.03383716568350792;
  t58_n113: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t58_n133;
  t58_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t58_n116;
  t58_n115: return 0.0941232368350029;
  t58_n116: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t58_n132;
  t58_n117: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t58_n131;
  t58_n118: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t58_n128;
  t58_n119: if (E.getFilterLength() >= 3241148416 /*11.0*/) goto t58_n127;
  t58_n120: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t58_n122;
  t58_n121: return 0.15633444488048553;
  t58_n122: if (E.getNumReferences() >= 3266445312 /*89.0*/) goto t58_n126;
  t58_n123: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t58_n125;
  t58_n124: return 0.134489506483078;
  t58_n125: return 0.12876802682876587;
  t58_n126: return -0.1251208484172821;
  t58_n127: return 0.12538185715675354;
  t58_n128: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t58_n130;
  t58_n129: return 0.15600800514221191;
  t58_n130: return 0.1281343698501587;
  t58_n131: return 0.07572410255670547;
  t58_n132: return 0.09030641615390778;
  t58_n133: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t58_n135;
  t58_n134: return 0.061687178909778595;
  t58_n135: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t58_n147;
  t58_n136: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t58_n140;
  t58_n137: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t58_n139;
  t58_n138: return 0.14410504698753357;
  t58_n139: return -0.10200608521699905;
  t58_n140: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n144;
  t58_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t58_n143;
  t58_n142: return 0.10915616899728775;
  t58_n143: return 0.1233077421784401;
  t58_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t58_n146;
  t58_n145: return 0.09365689754486084;
  t58_n146: return 0.12211688607931137;
  t58_n147: return 0.0748870000243187;
  t58_n148: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n152;
  t58_n149: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t58_n151;
  t58_n150: return 0.033976949751377106;
  t58_n151: return -0.029644612222909927;
  t58_n152: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t58_n190;
  t58_n153: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t58_n173;
  t58_n154: if (E.getNumReferences() >= 3357271616 /*159641.0*/) goto t58_n172;
  t58_n155: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n157;
  t58_n156: return 0.04398266598582268;
  t58_n157: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t58_n171;
  t58_n158: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t58_n162;
  t58_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t58_n161;
  t58_n160: return 0.05291805416345596;
  t58_n161: return 0.08002932369709015;
  t58_n162: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n164;
  t58_n163: return 0.07505594193935394;
  t58_n164: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t58_n168;
  t58_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t58_n167;
  t58_n166: return 0.043938636779785156;
  t58_n167: return 0.10787079483270645;
  t58_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t58_n170;
  t58_n169: return 0.053585171699523926;
  t58_n170: return 0.11406859755516052;
  t58_n171: return 0.04003770649433136;
  t58_n172: return -0.3964356482028961;
  t58_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t58_n179;
  t58_n174: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t58_n176;
  t58_n175: return 0.044570159167051315;
  t58_n176: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t58_n178;
  t58_n177: return 0.12292042374610901;
  t58_n178: return -0.2066422402858734;
  t58_n179: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t58_n189;
  t58_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n188;
  t58_n181: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t58_n187;
  t58_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t58_n184;
  t58_n183: return 0.09508128464221954;
  t58_n184: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t58_n186;
  t58_n185: return 0.09877237677574158;
  t58_n186: return 0.11919255554676056;
  t58_n187: return -0.2405826598405838;
  t58_n188: return 0.08375641703605652;
  t58_n189: return 0.10682514309883118;
  t58_n190: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t58_n192;
  t58_n191: return -0.1432967633008957;
  t58_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t58_n194;
  t58_n193: return -0.029465477913618088;
  t58_n194: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t58_n196;
  t58_n195: return 0.050000958144664764;
  t58_n196: return -0.019488830119371414;
  t58_n197: return -0.04733634740114212;
  t58_n198: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t58_n206;
  t58_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t58_n205;
  t58_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n204;
  t58_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t58_n203;
  t58_n202: return 0.1048400029540062;
  t58_n203: return 0.06765785813331604;
  t58_n204: return 0.019994208589196205;
  t58_n205: return -0.008247138932347298;
  t58_n206: return 0.018031716346740723;
  t58_n207: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t58_n221;
  t58_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t58_n214;
  t58_n209: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t58_n213;
  t58_n210: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t58_n212;
  t58_n211: return 0.03527610003948212;
  t58_n212: return 0.047442857176065445;
  t58_n213: return 0.008656452409923077;
  t58_n214: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t58_n218;
  t58_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t58_n217;
  t58_n216: return -0.008014943450689316;
  t58_n217: return 0.03142165392637253;
  t58_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n220;
  t58_n219: return 0.05187510699033737;
  t58_n220: return 0.02738073095679283;
  t58_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t58_n235;
  t58_n222: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t58_n234;
  t58_n223: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t58_n227;
  t58_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t58_n226;
  t58_n225: return 0.09098463505506516;
  t58_n226: return 0.002955822739750147;
  t58_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t58_n231;
  t58_n228: if (E.getNumReferences() >= 3319676928 /*7112.0*/) goto t58_n230;
  t58_n229: return 0.10081290453672409;
  t58_n230: return 0.04893730580806732;
  t58_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t58_n233;
  t58_n232: return 0.11851964145898819;
  t58_n233: return -0.006772007793188095;
  t58_n234: return 0.013781111687421799;
  t58_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t58_n237;
  t58_n236: return 0.031814251095056534;
  t58_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t58_n239;
  t58_n238: return 0.08926472067832947;
  t58_n239: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t58_n241;
  t58_n240: return 0.0678781121969223;
  t58_n241: return 0.107761912047863;
  t58_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t58_n248;
  t58_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t58_n245;
  t58_n244: return -0.007338813506066799;
  t58_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n247;
  t58_n246: return 0.005029075313359499;
  t58_n247: return 0.023271599784493446;
  t58_n248: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t58_n252;
  t58_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t58_n251;
  t58_n250: return 0.022818025201559067;
  t58_n251: return 0.04517855495214462;
  t58_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t58_n254;
  t58_n253: return 0.0914125144481659;
  t58_n254: return -0.06916659325361252;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree59(const Example& E) {
  t59_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t59_n248;
  t59_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t59_n185;
  t59_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t59_n144;
  t59_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t59_n41;
  t59_n4: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t59_n6;
  t59_n5: return -0.03043026477098465;
  t59_n6: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t59_n20;
  t59_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t59_n19;
  t59_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n10;
  t59_n9: return 0.015493226237595081;
  t59_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t59_n16;
  t59_n11: if (E.getNumReferences() >= 3320417280 /*7473.5*/) goto t59_n13;
  t59_n12: return 0.02774951420724392;
  t59_n13: if (E.getNumReferences() >= 3320443904 /*7486.5*/) goto t59_n15;
  t59_n14: return 0.12180066108703613;
  t59_n15: return 0.05086171627044678;
  t59_n16: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t59_n18;
  t59_n17: return 0.0698990449309349;
  t59_n18: return 0.08096829801797867;
  t59_n19: return -0.005249600391834974;
  t59_n20: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t59_n34;
  t59_n21: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t59_n23;
  t59_n22: return 0.08724913746118546;
  t59_n23: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t59_n25;
  t59_n24: return 0.05805863440036774;
  t59_n25: if (E.getNumReferences() >= 3268149248 /*102.0*/) goto t59_n27;
  t59_n26: return 0.11779167503118515;
  t59_n27: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t59_n33;
  t59_n28: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t59_n32;
  t59_n29: if (E.getNumReferences() >= 3272245248 /*138.5*/) goto t59_n31;
  t59_n30: return 0.09995192289352417;
  t59_n31: return 0.11957811564207077;
  t59_n32: return 0.09956876933574677;
  t59_n33: return -0.04394328221678734;
  t59_n34: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t59_n36;
  t59_n35: return 0.04663391038775444;
  t59_n36: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t59_n38;
  t59_n37: return 0.06843870133161545;
  t59_n38: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t59_n40;
  t59_n39: return 0.10812054574489594;
  t59_n40: return -0.11600537598133087;
  t59_n41: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t59_n111;
  t59_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t59_n60;
  t59_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t59_n45;
  t59_n44: return -0.0430549755692482;
  t59_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t59_n47;
  t59_n46: return -0.11306784301996231;
  t59_n47: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t59_n55;
  t59_n48: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t59_n54;
  t59_n49: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t59_n51;
  t59_n50: return 0.03783860802650452;
  t59_n51: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n53;
  t59_n52: return 0.10014761984348297;
  t59_n53: return 0.06569910049438477;
  t59_n54: return 0.02508256584405899;
  t59_n55: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t59_n59;
  t59_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n58;
  t59_n57: return 0.0635298490524292;
  t59_n58: return 0.026469821110367775;
  t59_n59: return 0.0006109342211857438;
  t59_n60: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t59_n108;
  t59_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n63;
  t59_n62: return 0.02104356698691845;
  t59_n63: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t59_n107;
  t59_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n90;
  t59_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t59_n89;
  t59_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n68;
  t59_n67: return -0.06194634735584259;
  t59_n68: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t59_n78;
  t59_n69: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t59_n73;
  t59_n70: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n72;
  t59_n71: return -0.2693660259246826;
  t59_n72: return 0.07462586462497711;
  t59_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t59_n75;
  t59_n74: return 0.014499283395707607;
  t59_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n77;
  t59_n76: return 0.09158748388290405;
  t59_n77: return -0.04360635578632355;
  t59_n78: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t59_n88;
  t59_n79: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n87;
  t59_n80: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t59_n84;
  t59_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n83;
  t59_n82: return 0.1255514919757843;
  t59_n83: return 0.12999236583709717;
  t59_n84: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t59_n86;
  t59_n85: return 0.11576598137617111;
  t59_n86: return 0.09093362092971802;
  t59_n87: return 0.10095775127410889;
  t59_n88: return -0.0987502932548523;
  t59_n89: return 0.026002898812294006;
  t59_n90: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t59_n98;
  t59_n91: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t59_n95;
  t59_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t59_n94;
  t59_n93: return -0.026555292308330536;
  t59_n94: return 0.047669194638729095;
  t59_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t59_n97;
  t59_n96: return 0.02210824191570282;
  t59_n97: return 0.04340921342372894;
  t59_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t59_n102;
  t59_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t59_n101;
  t59_n100: return -0.036774616688489914;
  t59_n101: return 0.056324951350688934;
  t59_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n106;
  t59_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n105;
  t59_n104: return 0.10065712034702301;
  t59_n105: return 0.09733164310455322;
  t59_n106: return 0.03818165510892868;
  t59_n107: return -0.05151715502142906;
  t59_n108: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n110;
  t59_n109: return -0.04959558695554733;
  t59_n110: return 0.044928550720214844;
  t59_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n113;
  t59_n112: return 0.00747439730912447;
  t59_n113: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t59_n127;
  t59_n114: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t59_n116;
  t59_n115: return 0.025509728118777275;
  t59_n116: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t59_n118;
  t59_n117: return -0.01768270507454872;
  t59_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t59_n120;
  t59_n119: return 0.031802888959646225;
  t59_n120: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t59_n126;
  t59_n121: if (E.getNumReferences() >= 3290988544 /*674.0*/) goto t59_n123;
  t59_n122: return 0.05743851512670517;
  t59_n123: if (E.getNumReferences() >= 3302379520 /*1714.5*/) goto t59_n125;
  t59_n124: return 0.11154046654701233;
  t59_n125: return 0.0523095466196537;
  t59_n126: return 0.04912682995200157;
  t59_n127: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t59_n133;
  t59_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n130;
  t59_n129: return 0.09731828421354294;
  t59_n130: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n132;
  t59_n131: return 0.1251310557126999;
  t59_n132: return 0.10334423184394836;
  t59_n133: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t59_n137;
  t59_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t59_n136;
  t59_n135: return 0.07387450337409973;
  t59_n136: return 0.10284655541181564;
  t59_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t59_n139;
  t59_n138: return 0.024327026680111885;
  t59_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n141;
  t59_n140: return 0.08040785789489746;
  t59_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n143;
  t59_n142: return 0.1632184088230133;
  t59_n143: return 0.10698967427015305;
  t59_n144: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t59_n148;
  t59_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t59_n147;
  t59_n146: return 0.008855876512825489;
  t59_n147: return -0.004813947714865208;
  t59_n148: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t59_n174;
  t59_n149: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t59_n161;
  t59_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t59_n156;
  t59_n151: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t59_n153;
  t59_n152: return 0.0421241857111454;
  t59_n153: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t59_n155;
  t59_n154: return 0.10878458619117737;
  t59_n155: return -0.10261866450309753;
  t59_n156: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t59_n160;
  t59_n157: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t59_n159;
  t59_n158: return -0.019769420847296715;
  t59_n159: return 0.08307718485593796;
  t59_n160: return 0.13568681478500366;
  t59_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t59_n163;
  t59_n162: return 0.046924393624067307;
  t59_n163: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n173;
  t59_n164: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t59_n170;
  t59_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t59_n167;
  t59_n166: return 0.056099530309438705;
  t59_n167: if (E.getNumReferences() >= 3260416000 /*53.5*/) goto t59_n169;
  t59_n168: return 0.12718546390533447;
  t59_n169: return 0.09343980252742767;
  t59_n170: if (E.getNumReferences() >= 3269853184 /*115.0*/) goto t59_n172;
  t59_n171: return -0.1176443099975586;
  t59_n172: return 0.11401204019784927;
  t59_n173: return 0.007484785746783018;
  t59_n174: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t59_n184;
  t59_n175: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t59_n183;
  t59_n176: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t59_n178;
  t59_n177: return 0.09508075565099716;
  t59_n178: if (E.getNumReferences() >= 3297103872 /*1070.5*/) goto t59_n182;
  t59_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t59_n181;
  t59_n180: return 0.11613381654024124;
  t59_n181: return 0.09638731181621552;
  t59_n182: return 0.09145185351371765;
  t59_n183: return 0.0139005733653903;
  t59_n184: return 0.07074028998613358;
  t59_n185: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t59_n223;
  t59_n186: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t59_n222;
  t59_n187: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t59_n219;
  t59_n188: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t59_n216;
  t59_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n191;
  t59_n190: return -0.21217229962348938;
  t59_n191: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t59_n215;
  t59_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t59_n210;
  t59_n193: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t59_n195;
  t59_n194: return 0.023489654064178467;
  t59_n195: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t59_n197;
  t59_n196: return 0.03336751088500023;
  t59_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t59_n209;
  t59_n198: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t59_n200;
  t59_n199: return 0.08425962924957275;
  t59_n200: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n202;
  t59_n201: return 0.01667575165629387;
  t59_n202: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t59_n208;
  t59_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t59_n205;
  t59_n204: return -0.8038914799690247;
  t59_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n207;
  t59_n206: return 0.10745241492986679;
  t59_n207: return 0.0355253703892231;
  t59_n208: return 0.07370508462190628;
  t59_n209: return -0.03816882520914078;
  t59_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n214;
  t59_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n213;
  t59_n212: return 0.03428839147090912;
  t59_n213: return 0.054996591061353683;
  t59_n214: return 0.014646204188466072;
  t59_n215: return -0.00501621887087822;
  t59_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t59_n218;
  t59_n217: return -0.22803011536598206;
  t59_n218: return 0.020241212099790573;
  t59_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t59_n221;
  t59_n220: return -0.07180842012166977;
  t59_n221: return 0.028505578637123108;
  t59_n222: return 0.021962668746709824;
  t59_n223: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t59_n225;
  t59_n224: return 0.044248782098293304;
  t59_n225: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t59_n241;
  t59_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n228;
  t59_n227: return -0.0012423215666785836;
  t59_n228: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t59_n230;
  t59_n229: return 0.055163558572530746;
  t59_n230: if (E.getNumReferences() >= 3318789120 /*6678.5*/) goto t59_n232;
  t59_n231: return 0.11633841693401337;
  t59_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t59_n240;
  t59_n233: if (E.getNumReferences() >= 3322049024 /*8348.5*/) goto t59_n235;
  t59_n234: return 0.0543094240128994;
  t59_n235: if (E.getNumReferences() >= 3331291648 /*18365.0*/) goto t59_n239;
  t59_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t59_n238;
  t59_n237: return 0.11729241907596588;
  t59_n238: return 0.08539179712533951;
  t59_n239: return 0.08474057912826538;
  t59_n240: return 0.07004372775554657;
  t59_n241: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t59_n243;
  t59_n242: return 0.001951553043909371;
  t59_n243: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t59_n247;
  t59_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t59_n246;
  t59_n245: return 0.02603313885629177;
  t59_n246: return 0.09260714054107666;
  t59_n247: return -0.02911706455051899;
  t59_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t59_n254;
  t59_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t59_n253;
  t59_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t59_n252;
  t59_n251: return -0.00788121111690998;
  t59_n252: return 0.006310129072517157;
  t59_n253: return 0.02808763086795807;
  t59_n254: return 0.034822434186935425;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree60(const Example& E) {
  t60_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t60_n246;
  t60_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t60_n235;
  t60_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t60_n130;
  t60_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t60_n97;
  t60_n4: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t60_n14;
  t60_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t60_n9;
  t60_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t60_n8;
  t60_n7: return -0.05631787329912186;
  t60_n8: return -0.04235048592090607;
  t60_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t60_n11;
  t60_n10: return -0.02224130742251873;
  t60_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n13;
  t60_n12: return 0.01286856085062027;
  t60_n13: return -0.06060114502906799;
  t60_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t60_n16;
  t60_n15: return 0.002462713746353984;
  t60_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n40;
  t60_n17: if (E.getNumReferences() >= 3327408128 /*13582.0*/) goto t60_n23;
  t60_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t60_n20;
  t60_n19: return 0.09657931327819824;
  t60_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t60_n22;
  t60_n21: return -0.10462412983179092;
  t60_n22: return 0.11122963577508926;
  t60_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t60_n25;
  t60_n24: return 0.040202733129262924;
  t60_n25: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t60_n27;
  t60_n26: return -0.03671230748295784;
  t60_n27: if (E.getNumReferences() >= 3350807040 /*94852.0*/) goto t60_n31;
  t60_n28: if (E.getNumReferences() >= 3328604672 /*14750.5*/) goto t60_n30;
  t60_n29: return 0.1340457946062088;
  t60_n30: return 0.09071008861064911;
  t60_n31: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t60_n39;
  t60_n32: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t60_n38;
  t60_n33: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n37;
  t60_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t60_n36;
  t60_n35: return 0.13217195868492126;
  t60_n36: return 0.09474249184131622;
  t60_n37: return 0.06394568830728531;
  t60_n38: return 0.06458675861358643;
  t60_n39: return 0.08873936533927917;
  t60_n40: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t60_n42;
  t60_n41: return -0.015393906272947788;
  t60_n42: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t60_n44;
  t60_n43: return 0.033584266901016235;
  t60_n44: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t60_n96;
  t60_n45: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t60_n47;
  t60_n46: return 0.11353379487991333;
  t60_n47: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t60_n75;
  t60_n48: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t60_n64;
  t60_n49: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t60_n63;
  t60_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t60_n52;
  t60_n51: return 0.054002806544303894;
  t60_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t60_n54;
  t60_n53: return 0.07380134612321854;
  t60_n54: if (E.getNumReferences() >= 3326979584 /*13163.5*/) goto t60_n56;
  t60_n55: return 0.12798672914505005;
  t60_n56: if (E.getNumReferences() >= 3331808000 /*19373.5*/) goto t60_n58;
  t60_n57: return 0.09176182746887207;
  t60_n58: if (E.getNumReferences() >= 3332440064 /*20608.0*/) goto t60_n62;
  t60_n59: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t60_n61;
  t60_n60: return 0.11046604812145233;
  t60_n61: return 0.08555535972118378;
  t60_n62: return -0.3849108815193176;
  t60_n63: return -0.008188370615243912;
  t60_n64: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t60_n70;
  t60_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t60_n67;
  t60_n66: return -0.22298219799995422;
  t60_n67: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t60_n69;
  t60_n68: return 0.11216237396001816;
  t60_n69: return 0.11431744694709778;
  t60_n70: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t60_n72;
  t60_n71: return 0.059654105454683304;
  t60_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t60_n74;
  t60_n73: return 0.0723109170794487;
  t60_n74: return 0.11220204085111618;
  t60_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t60_n89;
  t60_n76: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t60_n78;
  t60_n77: return 0.06580409407615662;
  t60_n78: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t60_n86;
  t60_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t60_n81;
  t60_n80: return 0.04755913093686104;
  t60_n81: if (E.getNumReferences() >= 3332023808 /*19795.0*/) goto t60_n85;
  t60_n82: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t60_n84;
  t60_n83: return 0.0431520901620388;
  t60_n84: return 0.11625411361455917;
  t60_n85: return -0.0007792871329002082;
  t60_n86: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n88;
  t60_n87: return 0.05975800380110741;
  t60_n88: return 0.12481998652219772;
  t60_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t60_n91;
  t60_n90: return -0.7609343528747559;
  t60_n91: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t60_n95;
  t60_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t60_n94;
  t60_n93: return 0.10710237175226212;
  t60_n94: return 0.10394173115491867;
  t60_n95: return 0.09090090543031693;
  t60_n96: return 0.0010811637621372938;
  t60_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t60_n101;
  t60_n98: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t60_n100;
  t60_n99: return 0.014291294850409031;
  t60_n100: return -0.04532682150602341;
  t60_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n103;
  t60_n102: return 0.05599929764866829;
  t60_n103: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n129;
  t60_n104: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t60_n122;
  t60_n105: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t60_n111;
  t60_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t60_n108;
  t60_n107: return -0.00344191025942564;
  t60_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n110;
  t60_n109: return 0.05617876350879669;
  t60_n110: return -0.032825179398059845;
  t60_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t60_n113;
  t60_n112: return 0.051988475024700165;
  t60_n113: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t60_n117;
  t60_n114: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t60_n116;
  t60_n115: return 0.07324790209531784;
  t60_n116: return 0.031770795583724976;
  t60_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t60_n121;
  t60_n118: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t60_n120;
  t60_n119: return 0.1291067749261856;
  t60_n120: return 0.14483290910720825;
  t60_n121: return -0.028615526854991913;
  t60_n122: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t60_n128;
  t60_n123: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t60_n125;
  t60_n124: return 0.07464428246021271;
  t60_n125: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t60_n127;
  t60_n126: return 0.11110544949769974;
  t60_n127: return 0.050598349422216415;
  t60_n128: return 0.03960830345749855;
  t60_n129: return -0.1280868798494339;
  t60_n130: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t60_n168;
  t60_n131: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t60_n161;
  t60_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t60_n134;
  t60_n133: return 0.0015788371674716473;
  t60_n134: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n160;
  t60_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t60_n155;
  t60_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t60_n142;
  t60_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t60_n139;
  t60_n138: return 0.014166762121021748;
  t60_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t60_n141;
  t60_n140: return 0.022863101214170456;
  t60_n141: return 0.04387182369828224;
  t60_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t60_n144;
  t60_n143: return -0.07638002932071686;
  t60_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t60_n146;
  t60_n145: return -0.03806503862142563;
  t60_n146: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t60_n150;
  t60_n147: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t60_n149;
  t60_n148: return 0.009622116573154926;
  t60_n149: return 0.07078113406896591;
  t60_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n152;
  t60_n151: return 0.06872764974832535;
  t60_n152: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t60_n154;
  t60_n153: return 0.12067794054746628;
  t60_n154: return 0.05371250584721565;
  t60_n155: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t60_n159;
  t60_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t60_n158;
  t60_n157: return -0.12095515429973602;
  t60_n158: return 0.008608156815171242;
  t60_n159: return 0.048249028623104095;
  t60_n160: return -0.10917449742555618;
  t60_n161: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t60_n165;
  t60_n162: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n164;
  t60_n163: return -0.0754142701625824;
  t60_n164: return -0.10792076587677002;
  t60_n165: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t60_n167;
  t60_n166: return 0.02110866643488407;
  t60_n167: return -0.03313973918557167;
  t60_n168: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t60_n212;
  t60_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n177;
  t60_n170: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n174;
  t60_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t60_n173;
  t60_n172: return -0.021449686959385872;
  t60_n173: return 0.05627036839723587;
  t60_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t60_n176;
  t60_n175: return -0.24280261993408203;
  t60_n176: return -0.036495987325906754;
  t60_n177: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t60_n183;
  t60_n178: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t60_n182;
  t60_n179: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n181;
  t60_n180: return 0.03640257194638252;
  t60_n181: return 0.07550405710935593;
  t60_n182: return 0.04547599330544472;
  t60_n183: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t60_n211;
  t60_n184: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t60_n186;
  t60_n185: return 0.05236944183707237;
  t60_n186: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t60_n202;
  t60_n187: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t60_n189;
  t60_n188: return 0.07427399605512619;
  t60_n189: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t60_n193;
  t60_n190: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t60_n192;
  t60_n191: return 0.1438719630241394;
  t60_n192: return 0.05685099586844444;
  t60_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t60_n201;
  t60_n194: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t60_n196;
  t60_n195: return 0.06818115711212158;
  t60_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n198;
  t60_n197: return 0.07604147493839264;
  t60_n198: if (E.getNumReferences() >= 3280158720 /*262.5*/) goto t60_n200;
  t60_n199: return 0.1268640160560608;
  t60_n200: return 0.18133918941020966;
  t60_n201: return 0.12830959260463715;
  t60_n202: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t60_n204;
  t60_n203: return 0.08314311504364014;
  t60_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n210;
  t60_n205: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t60_n209;
  t60_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t60_n208;
  t60_n207: return 0.12404906749725342;
  t60_n208: return 0.13209721446037292;
  t60_n209: return 0.08591880649328232;
  t60_n210: return -0.022107305005192757;
  t60_n211: return 0.06590757519006729;
  t60_n212: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t60_n232;
  t60_n213: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t60_n223;
  t60_n214: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t60_n216;
  t60_n215: return 0.03237684443593025;
  t60_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t60_n218;
  t60_n217: return -0.05507660284638405;
  t60_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t60_n220;
  t60_n219: return 0.01901942677795887;
  t60_n220: if (E.getNumReferences() >= 3304472576 /*1970.0*/) goto t60_n222;
  t60_n221: return 0.08980867266654968;
  t60_n222: return 0.09019015729427338;
  t60_n223: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t60_n229;
  t60_n224: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t60_n228;
  t60_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n227;
  t60_n226: return 0.12102415412664413;
  t60_n227: return 0.13946186006069183;
  t60_n228: return -0.5730909705162048;
  t60_n229: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t60_n231;
  t60_n230: return 0.0002330445422558114;
  t60_n231: return 0.05648306384682655;
  t60_n232: if (E.getNumReferences() >= 3307765760 /*2696.0*/) goto t60_n234;
  t60_n233: return -0.02189508266746998;
  t60_n234: return 0.017946740612387657;
  t60_n235: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t60_n243;
  t60_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t60_n242;
  t60_n237: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t60_n241;
  t60_n238: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t60_n240;
  t60_n239: return 0.048310648649930954;
  t60_n240: return 0.0300438292324543;
  t60_n241: return 0.0078104776330292225;
  t60_n242: return 0.021170342341065407;
  t60_n243: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t60_n245;
  t60_n244: return 0.023792345076799393;
  t60_n245: return 0.06291677057743073;
  t60_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t60_n250;
  t60_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t60_n249;
  t60_n248: return -0.016890840604901314;
  t60_n249: return 0.007367019075900316;
  t60_n250: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t60_n254;
  t60_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t60_n253;
  t60_n252: return 0.003450787393376231;
  t60_n253: return 0.022402344271540642;
  t60_n254: return 0.041175514459609985;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree61(const Example& E) {
  t61_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t61_n234;
  t61_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t61_n59;
  t61_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t61_n40;
  t61_n3: if (E.getNumReferences() >= 3317190656 /*5898.0*/) goto t61_n35;
  t61_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t61_n6;
  t61_n5: return -0.002688474953174591;
  t61_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n34;
  t61_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t61_n11;
  t61_n8: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t61_n10;
  t61_n9: return 0.04169640690088272;
  t61_n10: return -0.020323986187577248;
  t61_n11: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t61_n25;
  t61_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n22;
  t61_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n15;
  t61_n14: return 0.03903903812170029;
  t61_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t61_n17;
  t61_n16: return 0.009758579544723034;
  t61_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t61_n21;
  t61_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t61_n20;
  t61_n19: return -0.0078056282363832;
  t61_n20: return 0.09727604687213898;
  t61_n21: return 0.008263950236141682;
  t61_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n24;
  t61_n23: return 0.07697572559118271;
  t61_n24: return 0.020888613536953926;
  t61_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t61_n31;
  t61_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n28;
  t61_n27: return 0.04597935080528259;
  t61_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t61_n30;
  t61_n29: return -0.015829036012291908;
  t61_n30: return 0.07852741330862045;
  t61_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n33;
  t61_n32: return 0.1063232347369194;
  t61_n33: return 0.09550962597131729;
  t61_n34: return -0.07893868535757065;
  t61_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n37;
  t61_n36: return 0.018427683040499687;
  t61_n37: if (E.getNumReferences() >= 3317207040 /*5906.0*/) goto t61_n39;
  t61_n38: return 0.11418096721172333;
  t61_n39: return 0.054638225585222244;
  t61_n40: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t61_n58;
  t61_n41: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t61_n57;
  t61_n42: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t61_n44;
  t61_n43: return -0.019901754334568977;
  t61_n44: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t61_n46;
  t61_n45: return 0.022051164880394936;
  t61_n46: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t61_n54;
  t61_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t61_n49;
  t61_n48: return 0.07629828155040741;
  t61_n49: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t61_n51;
  t61_n50: return 0.08644882589578629;
  t61_n51: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t61_n53;
  t61_n52: return 0.12055447697639465;
  t61_n53: return 0.09805988520383835;
  t61_n54: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t61_n56;
  t61_n55: return 0.05989977344870567;
  t61_n56: return 0.07214871793985367;
  t61_n57: return -0.05379561707377434;
  t61_n58: return -0.007837734185159206;
  t61_n59: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n189;
  t61_n60: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t61_n70;
  t61_n61: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t61_n69;
  t61_n62: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n64;
  t61_n63: return 0.008888653479516506;
  t61_n64: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t61_n66;
  t61_n65: return -0.005769222974777222;
  t61_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t61_n68;
  t61_n67: return 0.029972977936267853;
  t61_n68: return 0.11482084542512894;
  t61_n69: return -0.09369645267724991;
  t61_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t61_n102;
  t61_n71: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t61_n87;
  t61_n72: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t61_n74;
  t61_n73: return 0.036313071846961975;
  t61_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n86;
  t61_n75: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t61_n85;
  t61_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n82;
  t61_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t61_n81;
  t61_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n80;
  t61_n79: return -1.2646253108978271;
  t61_n80: return -0.032868947833776474;
  t61_n81: return -0.020635036751627922;
  t61_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t61_n84;
  t61_n83: return 0.0005253305425867438;
  t61_n84: return 0.058422401547431946;
  t61_n85: return 0.07955671846866608;
  t61_n86: return 0.13692334294319153;
  t61_n87: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t61_n89;
  t61_n88: return 0.037726372480392456;
  t61_n89: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n101;
  t61_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t61_n96;
  t61_n91: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t61_n93;
  t61_n92: return 0.0495709553360939;
  t61_n93: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t61_n95;
  t61_n94: return -0.11376836150884628;
  t61_n95: return 0.11328643560409546;
  t61_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t61_n100;
  t61_n97: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t61_n99;
  t61_n98: return -0.27687013149261475;
  t61_n99: return 0.10849657654762268;
  t61_n100: return 0.1204078197479248;
  t61_n101: return 0.0004890883574262261;
  t61_n102: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t61_n116;
  t61_n103: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n113;
  t61_n104: if (E.getNumReferences() >= 3289055232 /*556.0*/) goto t61_n108;
  t61_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t61_n107;
  t61_n106: return 0.048806775361299515;
  t61_n107: return 0.07506565004587173;
  t61_n108: if (E.getNumReferences() >= 3289702400 /*595.5*/) goto t61_n112;
  t61_n109: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n111;
  t61_n110: return 0.10502558201551437;
  t61_n111: return 0.17893637716770172;
  t61_n112: return 0.053672462701797485;
  t61_n113: if (E.getNumReferences() >= 3258449920 /*46.0*/) goto t61_n115;
  t61_n114: return 0.1228170096874237;
  t61_n115: return 0.12319090962409973;
  t61_n116: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n184;
  t61_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t61_n125;
  t61_n118: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n120;
  t61_n119: return 0.050032489001750946;
  t61_n120: if (E.getNumReferences() >= 3364747568 /*290761.5*/) goto t61_n122;
  t61_n121: return 0.015030228532850742;
  t61_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t61_n124;
  t61_n123: return 0.10159795731306076;
  t61_n124: return 0.10863190144300461;
  t61_n125: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t61_n145;
  t61_n126: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t61_n144;
  t61_n127: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t61_n143;
  t61_n128: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t61_n140;
  t61_n129: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t61_n139;
  t61_n130: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t61_n138;
  t61_n131: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t61_n137;
  t61_n132: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t61_n136;
  t61_n133: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t61_n135;
  t61_n134: return 0.1322612464427948;
  t61_n135: return 0.7578839063644409;
  t61_n136: return 0.1287287473678589;
  t61_n137: return -0.12451189011335373;
  t61_n138: return -0.10627590864896774;
  t61_n139: return 0.11298331618309021;
  t61_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t61_n142;
  t61_n141: return 0.13345971703529358;
  t61_n142: return 0.11776729673147202;
  t61_n143: return 0.07949875295162201;
  t61_n144: return 0.12992428243160248;
  t61_n145: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t61_n149;
  t61_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t61_n148;
  t61_n147: return 0.0596432127058506;
  t61_n148: return 0.07255249470472336;
  t61_n149: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t61_n167;
  t61_n150: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t61_n152;
  t61_n151: return 0.10946575552225113;
  t61_n152: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t61_n166;
  t61_n153: if (E.getNumReferences() >= 3288825856 /*542.0*/) goto t61_n165;
  t61_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t61_n160;
  t61_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t61_n157;
  t61_n156: return 0.09601285308599472;
  t61_n157: if (E.getNumReferences() >= 3283124224 /*353.0*/) goto t61_n159;
  t61_n158: return -0.12552593648433685;
  t61_n159: return 0.11896578967571259;
  t61_n160: if (E.getNumReferences() >= 3278569472 /*235.0*/) goto t61_n162;
  t61_n161: return 0.12447575479745865;
  t61_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t61_n164;
  t61_n163: return -0.19613017141819;
  t61_n164: return 0.11275612562894821;
  t61_n165: return 0.116266168653965;
  t61_n166: return 0.06831816583871841;
  t61_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t61_n169;
  t61_n168: return 0.0715729221701622;
  t61_n169: if (E.getNumReferences() >= 3278077952 /*227.5*/) goto t61_n171;
  t61_n170: return -0.10752568393945694;
  t61_n171: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t61_n181;
  t61_n172: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t61_n180;
  t61_n173: if (E.getNumReferences() >= 3306014720 /*2268.5*/) goto t61_n179;
  t61_n174: if (E.getNumReferences() >= 3292626944 /*774.0*/) goto t61_n176;
  t61_n175: return 0.09414530545473099;
  t61_n176: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t61_n178;
  t61_n177: return 0.11186406761407852;
  t61_n178: return 0.0977545753121376;
  t61_n179: return 0.0658622682094574;
  t61_n180: return 0.05958600714802742;
  t61_n181: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t61_n183;
  t61_n182: return 0.12410902231931686;
  t61_n183: return -0.021171918138861656;
  t61_n184: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t61_n188;
  t61_n185: if (E.getNumReferences() >= 3261857792 /*59.0*/) goto t61_n187;
  t61_n186: return 0.14672920107841492;
  t61_n187: return 0.10187336057424545;
  t61_n188: return 0.08818325400352478;
  t61_n189: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t61_n215;
  t61_n190: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t61_n200;
  t61_n191: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t61_n197;
  t61_n192: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t61_n196;
  t61_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t61_n195;
  t61_n194: return 0.02975280210375786;
  t61_n195: return 0.05303137004375458;
  t61_n196: return 0.015888717025518417;
  t61_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t61_n199;
  t61_n198: return -0.00499187596142292;
  t61_n199: return 0.028774067759513855;
  t61_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t61_n210;
  t61_n201: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t61_n203;
  t61_n202: return -0.050620969384908676;
  t61_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t61_n205;
  t61_n204: return 0.025668948888778687;
  t61_n205: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n209;
  t61_n206: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t61_n208;
  t61_n207: return -0.0008961393614299595;
  t61_n208: return 0.1275956928730011;
  t61_n209: return 0.001083776936866343;
  t61_n210: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t61_n212;
  t61_n211: return 0.021579047664999962;
  t61_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n214;
  t61_n213: return 0.09180894494056702;
  t61_n214: return 0.01763906143605709;
  t61_n215: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t61_n225;
  t61_n216: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t61_n222;
  t61_n217: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t61_n219;
  t61_n218: return -0.012368135154247284;
  t61_n219: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t61_n221;
  t61_n220: return 0.10645473003387451;
  t61_n221: return 0.07627753913402557;
  t61_n222: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t61_n224;
  t61_n223: return 0.018539641052484512;
  t61_n224: return 0.070647232234478;
  t61_n225: if (E.getNumReferences() >= 3335803904 /*27178.0*/) goto t61_n233;
  t61_n226: if (E.getNumReferences() >= 3315746816 /*5193.0*/) goto t61_n228;
  t61_n227: return 0.031953420490026474;
  t61_n228: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t61_n232;
  t61_n229: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t61_n231;
  t61_n230: return 0.048473652452230453;
  t61_n231: return 0.11262958496809006;
  t61_n232: return 0.05313548073172569;
  t61_n233: return -0.08172745257616043;
  t61_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t61_n252;
  t61_n235: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t61_n243;
  t61_n236: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n242;
  t61_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t61_n239;
  t61_n238: return -0.007230739574879408;
  t61_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown))) goto t61_n241;
  t61_n240: return -0.153207466006279;
  t61_n241: return 0.006546650547534227;
  t61_n242: return -0.23377101123332977;
  t61_n243: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t61_n245;
  t61_n244: return 0.025960542261600494;
  t61_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t61_n247;
  t61_n246: return 0.0873272493481636;
  t61_n247: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t61_n249;
  t61_n248: return -0.0907054990530014;
  t61_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t61_n251;
  t61_n250: return 0.10119717568159103;
  t61_n251: return -0.010043847374618053;
  t61_n252: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t61_n254;
  t61_n253: return 0.032954584807157516;
  t61_n254: return -0.6991387605667114;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree62(const Example& E) {
  t62_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t62_n248;
  t62_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t62_n239;
  t62_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t62_n106;
  t62_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t62_n5;
  t62_n4: return -0.11910229921340942;
  t62_n5: if (E.getNumReferences() >= 3301474304 /*1604.0*/) goto t62_n63;
  t62_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t62_n12;
  t62_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t62_n11;
  t62_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n10;
  t62_n9: return 0.01652831770479679;
  t62_n10: return 0.043927207589149475;
  t62_n11: return -0.0424213632941246;
  t62_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t62_n14;
  t62_n13: return -0.003630460938438773;
  t62_n14: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t62_n30;
  t62_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t62_n17;
  t62_n16: return -0.0777616798877716;
  t62_n17: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t62_n19;
  t62_n18: return 0.004328985698521137;
  t62_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t62_n29;
  t62_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n26;
  t62_n21: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t62_n23;
  t62_n22: return 0.03399229794740677;
  t62_n23: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t62_n25;
  t62_n24: return 0.11660578846931458;
  t62_n25: return 0.022402655333280563;
  t62_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n28;
  t62_n27: return 0.13387563824653625;
  t62_n28: return 0.0332576259970665;
  t62_n29: return 0.0028056923765689135;
  t62_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t62_n48;
  t62_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t62_n33;
  t62_n32: return 0.004617501050233841;
  t62_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n35;
  t62_n34: return 0.03449399024248123;
  t62_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n47;
  t62_n36: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n38;
  t62_n37: return 0.06824631243944168;
  t62_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n46;
  t62_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t62_n41;
  t62_n40: return 0.0924854725599289;
  t62_n41: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t62_n43;
  t62_n42: return 0.04965367913246155;
  t62_n43: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t62_n45;
  t62_n44: return 0.12507595121860504;
  t62_n45: return 0.12103359401226044;
  t62_n46: return 0.06209895759820938;
  t62_n47: return 0.014065111055970192;
  t62_n48: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n62;
  t62_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n59;
  t62_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n52;
  t62_n51: return 0.14178341627120972;
  t62_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n58;
  t62_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t62_n55;
  t62_n54: return 0.12498944997787476;
  t62_n55: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t62_n57;
  t62_n56: return 0.12990520894527435;
  t62_n57: return 0.11423948407173157;
  t62_n58: return 0.09548838436603546;
  t62_n59: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n61;
  t62_n60: return 0.09989149123430252;
  t62_n61: return 0.08362066000699997;
  t62_n62: return -0.07602657377719879;
  t62_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t62_n105;
  t62_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t62_n66;
  t62_n65: return 0.011322420090436935;
  t62_n66: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t62_n98;
  t62_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t62_n75;
  t62_n68: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t62_n70;
  t62_n69: return 0.03270870819687843;
  t62_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n72;
  t62_n71: return -0.1820523589849472;
  t62_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n74;
  t62_n73: return 0.11488620936870575;
  t62_n74: return 0.09266892075538635;
  t62_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n97;
  t62_n76: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t62_n90;
  t62_n77: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t62_n79;
  t62_n78: return 0.10776535421609879;
  t62_n79: if (E.getNumReferences() >= 3320205312 /*7370.0*/) goto t62_n81;
  t62_n80: return 0.03906910866498947;
  t62_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n85;
  t62_n82: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t62_n84;
  t62_n83: return 0.12530717253684998;
  t62_n84: return 0.1493035852909088;
  t62_n85: if (E.getNumReferences() >= 3348038400 /*73222.0*/) goto t62_n89;
  t62_n86: if (E.getNumReferences() >= 3331855104 /*19465.5*/) goto t62_n88;
  t62_n87: return -0.24254107475280762;
  t62_n88: return 0.15630397200584412;
  t62_n89: return 0.0018753298791125417;
  t62_n90: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t62_n92;
  t62_n91: return -0.1998811960220337;
  t62_n92: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t62_n96;
  t62_n93: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t62_n95;
  t62_n94: return 0.12128446251153946;
  t62_n95: return 0.11609316617250443;
  t62_n96: return 0.10900365561246872;
  t62_n97: return 0.037162598222494125;
  t62_n98: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t62_n100;
  t62_n99: return 0.00827123410999775;
  t62_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t62_n102;
  t62_n101: return -0.23015335202217102;
  t62_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n104;
  t62_n103: return 0.06376876682043076;
  t62_n104: return 0.1101238876581192;
  t62_n105: return 0.04291210696101189;
  t62_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t62_n108;
  t62_n107: return -0.007092191372066736;
  t62_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t62_n238;
  t62_n109: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t62_n233;
  t62_n110: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t62_n194;
  t62_n111: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t62_n161;
  t62_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n114;
  t62_n113: return 0.0006546808290295303;
  t62_n114: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t62_n116;
  t62_n115: return 0.018081214278936386;
  t62_n116: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t62_n118;
  t62_n117: return 0.038946911692619324;
  t62_n118: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t62_n152;
  t62_n119: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t62_n123;
  t62_n120: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t62_n122;
  t62_n121: return 0.023653985932469368;
  t62_n122: return 0.07976188510656357;
  t62_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t62_n151;
  t62_n124: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t62_n130;
  t62_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t62_n127;
  t62_n126: return 0.04283050820231438;
  t62_n127: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t62_n129;
  t62_n128: return 0.11266927421092987;
  t62_n129: return 0.10206324607133865;
  t62_n130: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t62_n150;
  t62_n131: if (E.getNumReferences() >= 3301101568 /*1558.5*/) goto t62_n149;
  t62_n132: if (E.getNumReferences() >= 3289096192 /*558.5*/) goto t62_n144;
  t62_n133: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t62_n143;
  t62_n134: if (E.getNumReferences() >= 3283894272 /*376.5*/) goto t62_n142;
  t62_n135: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t62_n141;
  t62_n136: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t62_n140;
  t62_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t62_n139;
  t62_n138: return 0.11428509652614594;
  t62_n139: return 0.12509790062904358;
  t62_n140: return -0.10402829945087433;
  t62_n141: return 0.13814778625965118;
  t62_n142: return 0.08530663698911667;
  t62_n143: return 0.09001000970602036;
  t62_n144: if (E.getNumReferences() >= 3291480064 /*704.0*/) goto t62_n146;
  t62_n145: return 0.13960784673690796;
  t62_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t62_n148;
  t62_n147: return 0.11492361128330231;
  t62_n148: return 0.12272553890943527;
  t62_n149: return 0.08490412682294846;
  t62_n150: return 0.09028047323226929;
  t62_n151: return 0.0228284802287817;
  t62_n152: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t62_n154;
  t62_n153: return 0.05710701644420624;
  t62_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t62_n160;
  t62_n155: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t62_n159;
  t62_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n158;
  t62_n157: return 0.012671458534896374;
  t62_n158: return 0.13898177444934845;
  t62_n159: return 0.07008057087659836;
  t62_n160: return 0.10040083527565002;
  t62_n161: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t62_n183;
  t62_n162: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t62_n182;
  t62_n163: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t62_n165;
  t62_n164: return 0.013152171857655048;
  t62_n165: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t62_n167;
  t62_n166: return 0.0061471350491046906;
  t62_n167: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n171;
  t62_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Symbol))) goto t62_n170;
  t62_n169: return -0.031028112396597862;
  t62_n170: return 0.038136959075927734;
  t62_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t62_n173;
  t62_n172: return 0.07181185483932495;
  t62_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n179;
  t62_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t62_n178;
  t62_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t62_n177;
  t62_n176: return -0.02574349008500576;
  t62_n177: return 0.07266063988208771;
  t62_n178: return 0.1353096067905426;
  t62_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t62_n181;
  t62_n180: return -0.11153765022754669;
  t62_n181: return 0.14969614148139954;
  t62_n182: return -0.13167212903499603;
  t62_n183: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t62_n185;
  t62_n184: return -0.0946994200348854;
  t62_n185: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t62_n189;
  t62_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n188;
  t62_n187: return 0.007587837520986795;
  t62_n188: return 0.035135142505168915;
  t62_n189: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t62_n191;
  t62_n190: return -0.016243215650320053;
  t62_n191: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t62_n193;
  t62_n192: return -0.023419920355081558;
  t62_n193: return 0.07121126353740692;
  t62_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n198;
  t62_n195: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t62_n197;
  t62_n196: return 0.03199189156293869;
  t62_n197: return -0.027957599610090256;
  t62_n198: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t62_n230;
  t62_n199: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t62_n217;
  t62_n200: if (E.getNumReferences() >= 3357271616 /*159641.0*/) goto t62_n216;
  t62_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n203;
  t62_n202: return 0.04082849621772766;
  t62_n203: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t62_n215;
  t62_n204: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t62_n206;
  t62_n205: return 0.05322428047657013;
  t62_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n208;
  t62_n207: return 0.07276217639446259;
  t62_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n210;
  t62_n209: return 0.0406542643904686;
  t62_n210: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t62_n212;
  t62_n211: return 0.10391473770141602;
  t62_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n214;
  t62_n213: return 0.11465714871883392;
  t62_n214: return 0.1153777539730072;
  t62_n215: return 0.037165023386478424;
  t62_n216: return -0.33891257643699646;
  t62_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t62_n223;
  t62_n218: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t62_n220;
  t62_n219: return 0.04136281833052635;
  t62_n220: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t62_n222;
  t62_n221: return 0.11836188286542892;
  t62_n222: return -0.17109569907188416;
  t62_n223: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t62_n229;
  t62_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t62_n228;
  t62_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t62_n227;
  t62_n226: return 0.09518096596002579;
  t62_n227: return 0.111060231924057;
  t62_n228: return 0.08195760846138;
  t62_n229: return 0.10361205786466599;
  t62_n230: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t62_n232;
  t62_n231: return -0.12635259330272675;
  t62_n232: return 0.024838123470544815;
  t62_n233: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t62_n237;
  t62_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n236;
  t62_n235: return 0.061910469084978104;
  t62_n236: return 0.017036184668540955;
  t62_n237: return 0.02409341186285019;
  t62_n238: return -0.04369986429810524;
  t62_n239: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t62_n245;
  t62_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t62_n244;
  t62_n241: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t62_n243;
  t62_n242: return 0.015338650904595852;
  t62_n243: return -0.03537432476878166;
  t62_n244: return 0.019526425749063492;
  t62_n245: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t62_n247;
  t62_n246: return 0.022495562210679054;
  t62_n247: return 0.060240842401981354;
  t62_n248: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t62_n250;
  t62_n249: return 0.0013547015842050314;
  t62_n250: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t62_n254;
  t62_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t62_n253;
  t62_n252: return 0.0032222727313637733;
  t62_n253: return 0.021199572831392288;
  t62_n254: return 0.03910352289676666;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree63(const Example& E) {
  t63_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t63_n248;
  t63_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t63_n223;
  t63_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t63_n40;
  t63_n3: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t63_n5;
  t63_n4: return 0.0007447571842931211;
  t63_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t63_n7;
  t63_n6: return 0.0113283796235919;
  t63_n7: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t63_n9;
  t63_n8: return 0.02094602771103382;
  t63_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t63_n23;
  t63_n10: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t63_n16;
  t63_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t63_n13;
  t63_n12: return -0.0099408570677042;
  t63_n13: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t63_n15;
  t63_n14: return 0.04074479267001152;
  t63_n15: return -0.0324704572558403;
  t63_n16: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t63_n20;
  t63_n17: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t63_n19;
  t63_n18: return 0.044752128422260284;
  t63_n19: return 0.11421708762645721;
  t63_n20: if (E.getNumReferences() >= 3314900992 /*4780.0*/) goto t63_n22;
  t63_n21: return 0.13111642003059387;
  t63_n22: return -0.04850918799638748;
  t63_n23: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t63_n25;
  t63_n24: return 0.04647286981344223;
  t63_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n27;
  t63_n26: return 0.04308740049600601;
  t63_n27: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t63_n29;
  t63_n28: return 0.0689612552523613;
  t63_n29: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t63_n31;
  t63_n30: return 0.12836581468582153;
  t63_n31: if (E.getNumReferences() >= 3280142336 /*262.0*/) goto t63_n33;
  t63_n32: return 0.06265280395746231;
  t63_n33: if (E.getNumReferences() >= 3281092608 /*291.0*/) goto t63_n35;
  t63_n34: return 0.1174449548125267;
  t63_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t63_n37;
  t63_n36: return 0.08132028579711914;
  t63_n37: if (E.getNumReferences() >= 3289153536 /*562.0*/) goto t63_n39;
  t63_n38: return 0.09752271324396133;
  t63_n39: return 0.12709374725818634;
  t63_n40: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t63_n100;
  t63_n41: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t63_n43;
  t63_n42: return -0.007808484602719545;
  t63_n43: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t63_n69;
  t63_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t63_n46;
  t63_n45: return -0.004790439270436764;
  t63_n46: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t63_n58;
  t63_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t63_n49;
  t63_n48: return 0.04036032781004906;
  t63_n49: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t63_n57;
  t63_n50: if (E.getNumReferences() >= 3280977920 /*287.5*/) goto t63_n52;
  t63_n51: return 0.05743573606014252;
  t63_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t63_n54;
  t63_n53: return 0.10068926960229874;
  t63_n54: if (E.getNumReferences() >= 3293446144 /*824.0*/) goto t63_n56;
  t63_n55: return 0.13360269367694855;
  t63_n56: return 0.09850990772247314;
  t63_n57: return 0.033065810799598694;
  t63_n58: if (E.getNumReferences() >= 3294625792 /*896.0*/) goto t63_n62;
  t63_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t63_n61;
  t63_n60: return -0.020835064351558685;
  t63_n61: return 0.02942359633743763;
  t63_n62: if (E.getNumReferences() >= 3294732288 /*902.5*/) goto t63_n64;
  t63_n63: return 0.10402513295412064;
  t63_n64: if (E.getNumReferences() >= 3337586944 /*30660.5*/) goto t63_n66;
  t63_n65: return 0.016173774376511574;
  t63_n66: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t63_n68;
  t63_n67: return 0.10886112600564957;
  t63_n68: return 0.05429811030626297;
  t63_n69: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t63_n91;
  t63_n70: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t63_n74;
  t63_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t63_n73;
  t63_n72: return 0.062272872775793076;
  t63_n73: return 0.08659258484840393;
  t63_n74: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t63_n76;
  t63_n75: return 0.0722891241312027;
  t63_n76: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t63_n90;
  t63_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t63_n85;
  t63_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t63_n80;
  t63_n79: return 0.06823477894067764;
  t63_n80: if (E.getNumReferences() >= 3289284608 /*570.0*/) goto t63_n82;
  t63_n81: return 0.10697054862976074;
  t63_n82: if (E.getNumReferences() >= 3296874496 /*1042.5*/) goto t63_n84;
  t63_n83: return 0.11500608175992966;
  t63_n84: return 0.1015983298420906;
  t63_n85: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t63_n89;
  t63_n86: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t63_n88;
  t63_n87: return 0.10268504172563553;
  t63_n88: return 0.12175045162439346;
  t63_n89: return 0.10780651122331619;
  t63_n90: return 0.030830416828393936;
  t63_n91: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t63_n93;
  t63_n92: return 0.0743471011519432;
  t63_n93: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t63_n99;
  t63_n94: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t63_n98;
  t63_n95: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t63_n97;
  t63_n96: return 0.09705880284309387;
  t63_n97: return 0.13587133586406708;
  t63_n98: return 0.08937767893075943;
  t63_n99: return 0.10446525365114212;
  t63_n100: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t63_n102;
  t63_n101: return -0.040894437581300735;
  t63_n102: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t63_n134;
  t63_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t63_n109;
  t63_n104: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t63_n108;
  t63_n105: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t63_n107;
  t63_n106: return -0.006937433034181595;
  t63_n107: return 0.018998360261321068;
  t63_n108: return -0.07100225985050201;
  t63_n109: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t63_n111;
  t63_n110: return -0.09767231345176697;
  t63_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t63_n113;
  t63_n112: return -0.04092225059866905;
  t63_n113: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t63_n115;
  t63_n114: return 0.057492226362228394;
  t63_n115: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t63_n127;
  t63_n116: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t63_n118;
  t63_n117: return 0.05360598862171173;
  t63_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t63_n120;
  t63_n119: return 0.0863308236002922;
  t63_n120: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t63_n126;
  t63_n121: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t63_n125;
  t63_n122: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t63_n124;
  t63_n123: return 0.12502773106098175;
  t63_n124: return 0.11587391048669815;
  t63_n125: return -0.18643465638160706;
  t63_n126: return 0.07628177106380463;
  t63_n127: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t63_n131;
  t63_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t63_n130;
  t63_n129: return -0.10258322954177856;
  t63_n130: return 0.14371179044246674;
  t63_n131: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t63_n133;
  t63_n132: return 0.068174347281456;
  t63_n133: return 0.08748720586299896;
  t63_n134: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t63_n136;
  t63_n135: return -0.0031219685915857553;
  t63_n136: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t63_n182;
  t63_n137: if (E.getNumReferences() >= 3313728512 /*4207.5*/) goto t63_n139;
  t63_n138: return 0.012720564380288124;
  t63_n139: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t63_n153;
  t63_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t63_n148;
  t63_n141: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t63_n145;
  t63_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t63_n144;
  t63_n143: return -0.32402926683425903;
  t63_n144: return 0.045374590903520584;
  t63_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t63_n147;
  t63_n146: return -0.03592067211866379;
  t63_n147: return 0.10044491291046143;
  t63_n148: if (E.getNumReferences() >= 3313753088 /*4219.5*/) goto t63_n150;
  t63_n149: return 0.1035466194152832;
  t63_n150: if (E.getNumReferences() >= 3319138304 /*6849.0*/) goto t63_n152;
  t63_n151: return 0.06400834769010544;
  t63_n152: return 0.07005418092012405;
  t63_n153: if (E.getNumReferences() >= 3347118592 /*66036.0*/) goto t63_n161;
  t63_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t63_n160;
  t63_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n157;
  t63_n156: return -0.23394614458084106;
  t63_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t63_n159;
  t63_n158: return -1.8256585597991943;
  t63_n159: return -0.2291814684867859;
  t63_n160: return -0.021160556003451347;
  t63_n161: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t63_n177;
  t63_n162: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t63_n166;
  t63_n163: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t63_n165;
  t63_n164: return 0.021040402352809906;
  t63_n165: return -0.20569559931755066;
  t63_n166: if (E.getNumReferences() >= 3360228064 /*205835.5*/) goto t63_n174;
  t63_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t63_n169;
  t63_n168: return -0.1231517642736435;
  t63_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t63_n171;
  t63_n170: return 0.10540192574262619;
  t63_n171: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t63_n173;
  t63_n172: return 0.09994592517614365;
  t63_n173: return 0.13689520955085754;
  t63_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t63_n176;
  t63_n175: return -0.08152545243501663;
  t63_n176: return 0.06487927585840225;
  t63_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n181;
  t63_n178: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t63_n180;
  t63_n179: return -0.2817407548427582;
  t63_n180: return 0.061266928911209106;
  t63_n181: return -0.13484859466552734;
  t63_n182: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t63_n204;
  t63_n183: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t63_n185;
  t63_n184: return 0.050951190292835236;
  t63_n185: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t63_n187;
  t63_n186: return 0.11991261690855026;
  t63_n187: if (E.getNumReferences() >= 3334377216 /*24391.5*/) goto t63_n203;
  t63_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t63_n198;
  t63_n189: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t63_n197;
  t63_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t63_n192;
  t63_n191: return -0.008353037759661674;
  t63_n192: if (E.getNumReferences() >= 3332719104 /*21153.0*/) goto t63_n194;
  t63_n193: return -0.12222342938184738;
  t63_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t63_n196;
  t63_n195: return 0.11854426562786102;
  t63_n196: return 0.1180325374007225;
  t63_n197: return 0.09821303188800812;
  t63_n198: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t63_n202;
  t63_n199: if (E.getNumReferences() >= 3332878080 /*21463.5*/) goto t63_n201;
  t63_n200: return 0.08401595801115036;
  t63_n201: return 0.10483069717884064;
  t63_n202: return 0.11419687420129776;
  t63_n203: return 0.04077260568737984;
  t63_n204: if (E.getNumReferences() >= 3297198080 /*1082.0*/) goto t63_n208;
  t63_n205: if (E.getNumReferences() >= 3297153024 /*1076.5*/) goto t63_n207;
  t63_n206: return 0.09803646802902222;
  t63_n207: return 0.11916948109865189;
  t63_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t63_n210;
  t63_n209: return 0.06551878154277802;
  t63_n210: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t63_n214;
  t63_n211: if (E.getNumReferences() >= 3302932480 /*1782.0*/) goto t63_n213;
  t63_n212: return 0.1172180026769638;
  t63_n213: return 0.05466178432106972;
  t63_n214: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t63_n220;
  t63_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t63_n219;
  t63_n216: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t63_n218;
  t63_n217: return 0.059932004660367966;
  t63_n218: return 0.12282747775316238;
  t63_n219: return 0.11154378205537796;
  t63_n220: if (E.getNumReferences() >= 3306420224 /*2367.5*/) goto t63_n222;
  t63_n221: return 0.11383315920829773;
  t63_n222: return 0.06141388416290283;
  t63_n223: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t63_n231;
  t63_n224: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t63_n230;
  t63_n225: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t63_n229;
  t63_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t63_n228;
  t63_n227: return 0.046275608241558075;
  t63_n228: return 0.027195684611797333;
  t63_n229: return 0.007354373577982187;
  t63_n230: return 0.01817762665450573;
  t63_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t63_n243;
  t63_n232: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t63_n238;
  t63_n233: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t63_n237;
  t63_n234: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t63_n236;
  t63_n235: return 0.027653485536575317;
  t63_n236: return 0.07645416259765625;
  t63_n237: return -0.02901928313076496;
  t63_n238: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t63_n242;
  t63_n239: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t63_n241;
  t63_n240: return 0.04458116367459297;
  t63_n241: return 0.09025359153747559;
  t63_n242: return -0.000820386572740972;
  t63_n243: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t63_n245;
  t63_n244: return 0.05629705637693405;
  t63_n245: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t63_n247;
  t63_n246: return 0.11339908838272095;
  t63_n247: return 0.08640097081661224;
  t63_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t63_n254;
  t63_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t63_n251;
  t63_n250: return -0.0016391681274399161;
  t63_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t63_n253;
  t63_n252: return 0.0025910327676683664;
  t63_n253: return 0.019565949216485023;
  t63_n254: return 0.030125197023153305;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree64(const Example& E) {
  t64_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t64_n248;
  t64_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t64_n157;
  t64_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t64_n120;
  t64_n3: if (E.getNumReferences() >= 3305242624 /*2080.0*/) goto t64_n5;
  t64_n4: return -0.015650469809770584;
  t64_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t64_n17;
  t64_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t64_n16;
  t64_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t64_n9;
  t64_n8: return 0.01510203629732132;
  t64_n9: if (E.getNumReferences() >= 3317228544 /*5916.5*/) goto t64_n11;
  t64_n10: return 0.01952078379690647;
  t64_n11: if (E.getNumReferences() >= 3317296128 /*5949.5*/) goto t64_n15;
  t64_n12: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t64_n14;
  t64_n13: return -0.35022637248039246;
  t64_n14: return 0.11193179339170456;
  t64_n15: return 0.05653587728738785;
  t64_n16: return -0.010409989394247532;
  t64_n17: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n119;
  t64_n18: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t64_n38;
  t64_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t64_n29;
  t64_n20: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t64_n26;
  t64_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t64_n23;
  t64_n22: return 0.03693248704075813;
  t64_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t64_n25;
  t64_n24: return 0.008617357350885868;
  t64_n25: return 0.10135617852210999;
  t64_n26: if (E.getNumReferences() >= 3318874112 /*6720.0*/) goto t64_n28;
  t64_n27: return 0.11961625516414642;
  t64_n28: return 0.2094815969467163;
  t64_n29: if (E.getNumReferences() >= 3367213520 /*367822.5*/) goto t64_n33;
  t64_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t64_n32;
  t64_n31: return -0.07458770275115967;
  t64_n32: return -0.01327170804142952;
  t64_n33: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t64_n37;
  t64_n34: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t64_n36;
  t64_n35: return 0.11106342822313309;
  t64_n36: return 0.07492045313119888;
  t64_n37: return 0.04428272694349289;
  t64_n38: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t64_n94;
  t64_n39: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t64_n93;
  t64_n40: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t64_n76;
  t64_n41: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t64_n43;
  t64_n42: return 0.03357803821563721;
  t64_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t64_n45;
  t64_n44: return -0.004673770163208246;
  t64_n45: if (E.getNumReferences() >= 3318883328 /*6724.5*/) goto t64_n47;
  t64_n46: return 0.05133851245045662;
  t64_n47: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t64_n69;
  t64_n48: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t64_n68;
  t64_n49: if (E.getNumReferences() >= 3324699136 /*10936.5*/) goto t64_n65;
  t64_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t64_n58;
  t64_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t64_n53;
  t64_n52: return 0.07192136347293854;
  t64_n53: if (E.getNumReferences() >= 3319440384 /*6996.5*/) goto t64_n55;
  t64_n54: return 0.0617440827190876;
  t64_n55: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t64_n57;
  t64_n56: return 0.11156341433525085;
  t64_n57: return 0.08630163967609406;
  t64_n58: if (E.getNumReferences() >= 3322129920 /*8427.5*/) goto t64_n64;
  t64_n59: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t64_n63;
  t64_n60: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t64_n62;
  t64_n61: return 0.10298074036836624;
  t64_n62: return 0.1360694020986557;
  t64_n63: return 0.1268225461244583;
  t64_n64: return 0.01764564774930477;
  t64_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t64_n67;
  t64_n66: return -0.1112494096159935;
  t64_n67: return 0.1071305125951767;
  t64_n68: return 0.0796777755022049;
  t64_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t64_n71;
  t64_n70: return 0.03607213497161865;
  t64_n71: if (E.getNumReferences() >= 3331329792 /*18439.5*/) goto t64_n75;
  t64_n72: if (E.getNumReferences() >= 3331157760 /*18103.5*/) goto t64_n74;
  t64_n73: return 0.019610291346907616;
  t64_n74: return 0.10466224700212479;
  t64_n75: return 0.08185446262359619;
  t64_n76: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t64_n88;
  t64_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t64_n79;
  t64_n78: return -0.24048803746700287;
  t64_n79: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t64_n85;
  t64_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t64_n82;
  t64_n81: return 0.10708088427782059;
  t64_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n84;
  t64_n83: return 0.11103545129299164;
  t64_n84: return 0.09615489095449448;
  t64_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t64_n87;
  t64_n86: return 0.11561645567417145;
  t64_n87: return 0.0984160378575325;
  t64_n88: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t64_n90;
  t64_n89: return 0.048064667731523514;
  t64_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t64_n92;
  t64_n91: return 0.06870903819799423;
  t64_n92: return 0.10507741570472717;
  t64_n93: return -0.012510381639003754;
  t64_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t64_n112;
  t64_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t64_n99;
  t64_n96: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n98;
  t64_n97: return 0.040057651698589325;
  t64_n98: return 0.06098034232854843;
  t64_n99: if (E.getNumReferences() >= 3350280192 /*90736.0*/) goto t64_n111;
  t64_n100: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t64_n102;
  t64_n101: return 0.07540962100028992;
  t64_n102: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t64_n104;
  t64_n103: return 0.10608634352684021;
  t64_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n110;
  t64_n105: if (E.getNumReferences() >= 3334486784 /*24605.5*/) goto t64_n109;
  t64_n106: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t64_n108;
  t64_n107: return 0.09320776164531708;
  t64_n108: return 0.10702026635408401;
  t64_n109: return 0.0689849853515625;
  t64_n110: return 0.04317961633205414;
  t64_n111: return -0.023771122097969055;
  t64_n112: if (E.getNumReferences() >= 3306094592 /*2288.0*/) goto t64_n114;
  t64_n113: return 0.12401192635297775;
  t64_n114: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t64_n116;
  t64_n115: return 0.08579037338495255;
  t64_n116: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t64_n118;
  t64_n117: return 0.12239048629999161;
  t64_n118: return 0.09845999628305435;
  t64_n119: return 0.06019754707813263;
  t64_n120: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t64_n148;
  t64_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t64_n123;
  t64_n122: return 0.014814074151217937;
  t64_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t64_n125;
  t64_n124: return 0.05027838051319122;
  t64_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t64_n147;
  t64_n126: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t64_n134;
  t64_n127: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t64_n129;
  t64_n128: return 0.02608424611389637;
  t64_n129: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t64_n133;
  t64_n130: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t64_n132;
  t64_n131: return 0.0768139660358429;
  t64_n132: return 0.1011427491903305;
  t64_n133: return 0.03797631338238716;
  t64_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t64_n140;
  t64_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t64_n137;
  t64_n136: return 0.07635113596916199;
  t64_n137: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t64_n139;
  t64_n138: return -0.11095718294382095;
  t64_n139: return 0.08144692331552505;
  t64_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t64_n142;
  t64_n141: return 0.0979367196559906;
  t64_n142: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t64_n146;
  t64_n143: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t64_n145;
  t64_n144: return 0.17299604415893555;
  t64_n145: return 0.15530087053775787;
  t64_n146: return -0.10150470584630966;
  t64_n147: return 0.004438433330506086;
  t64_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t64_n150;
  t64_n149: return -0.07145600020885468;
  t64_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t64_n152;
  t64_n151: return 0.0022665977012366056;
  t64_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t64_n156;
  t64_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t64_n155;
  t64_n154: return 0.029187016189098358;
  t64_n155: return 0.08714766800403595;
  t64_n156: return 0.06918095052242279;
  t64_n157: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t64_n179;
  t64_n158: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n174;
  t64_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t64_n165;
  t64_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t64_n162;
  t64_n161: return -0.0035827995743602514;
  t64_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t64_n164;
  t64_n163: return -0.07360649853944778;
  t64_n164: return -0.0188454482704401;
  t64_n165: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t64_n169;
  t64_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t64_n168;
  t64_n167: return -0.024988757446408272;
  t64_n168: return 0.013878131285309792;
  t64_n169: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t64_n171;
  t64_n170: return 0.04068358987569809;
  t64_n171: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t64_n173;
  t64_n172: return -0.09092620760202408;
  t64_n173: return -0.0071328734047710896;
  t64_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t64_n176;
  t64_n175: return -0.009482506662607193;
  t64_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t64_n178;
  t64_n177: return 0.025495463982224464;
  t64_n178: return 0.0004686205356847495;
  t64_n179: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t64_n207;
  t64_n180: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t64_n186;
  t64_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t64_n183;
  t64_n182: return 0.027688592672348022;
  t64_n183: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t64_n185;
  t64_n184: return -0.039729032665491104;
  t64_n185: return 0.028255118057131767;
  t64_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t64_n192;
  t64_n187: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t64_n189;
  t64_n188: return 0.03458377346396446;
  t64_n189: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t64_n191;
  t64_n190: return 0.10842622816562653;
  t64_n191: return 0.12370363622903824;
  t64_n192: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t64_n200;
  t64_n193: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n195;
  t64_n194: return 0.052328240126371384;
  t64_n195: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t64_n199;
  t64_n196: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t64_n198;
  t64_n197: return -0.1493755728006363;
  t64_n198: return 0.12404794245958328;
  t64_n199: return 0.07402962446212769;
  t64_n200: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t64_n202;
  t64_n201: return 0.10936228930950165;
  t64_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t64_n206;
  t64_n203: if (E.getNumReferences() >= 3282075648 /*321.0*/) goto t64_n205;
  t64_n204: return 0.11748813837766647;
  t64_n205: return 0.11620476841926575;
  t64_n206: return 0.04086945578455925;
  t64_n207: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t64_n219;
  t64_n208: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t64_n210;
  t64_n209: return 0.03553832322359085;
  t64_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t64_n218;
  t64_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t64_n217;
  t64_n212: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t64_n214;
  t64_n213: return 0.048836857080459595;
  t64_n214: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t64_n216;
  t64_n215: return -0.11207370460033417;
  t64_n216: return 0.11305306851863861;
  t64_n217: return 0.10521330684423447;
  t64_n218: return 0.0008481668191961944;
  t64_n219: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t64_n237;
  t64_n220: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t64_n222;
  t64_n221: return 0.06916981190443039;
  t64_n222: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t64_n228;
  t64_n223: if (E.getNumReferences() >= 3364747568 /*290761.5*/) goto t64_n225;
  t64_n224: return 0.018041646108031273;
  t64_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t64_n227;
  t64_n226: return 0.10143215954303741;
  t64_n227: return 0.10973773151636124;
  t64_n228: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t64_n230;
  t64_n229: return 0.07672259956598282;
  t64_n230: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t64_n236;
  t64_n231: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n233;
  t64_n232: return 0.054659366607666016;
  t64_n233: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t64_n235;
  t64_n234: return 0.11243365705013275;
  t64_n235: return 0.0828460156917572;
  t64_n236: return 0.07781333476305008;
  t64_n237: if (E.getNumReferences() >= 3263692800 /*68.0*/) goto t64_n247;
  t64_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t64_n246;
  t64_n239: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t64_n243;
  t64_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t64_n242;
  t64_n241: return 0.10490712523460388;
  t64_n242: return 0.1520596295595169;
  t64_n243: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t64_n245;
  t64_n244: return -0.10040918737649918;
  t64_n245: return 0.12808799743652344;
  t64_n246: return -0.19436940550804138;
  t64_n247: return 0.0777873545885086;
  t64_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t64_n250;
  t64_n249: return -0.005219256039708853;
  t64_n250: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t64_n254;
  t64_n251: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t64_n253;
  t64_n252: return 0.004042814951390028;
  t64_n253: return 0.024084853008389473;
  t64_n254: return 0.029685167595744133;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree65(const Example& E) {
  t65_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t65_n226;
  t65_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t65_n131;
  t65_n2: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t65_n98;
  t65_n3: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t65_n67;
  t65_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t65_n6;
  t65_n5: return -0.01834535412490368;
  t65_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t65_n66;
  t65_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t65_n57;
  t65_n8: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t65_n52;
  t65_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t65_n13;
  t65_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t65_n12;
  t65_n11: return -0.1248989999294281;
  t65_n12: return -0.032169684767723083;
  t65_n13: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t65_n23;
  t65_n14: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n22;
  t65_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t65_n21;
  t65_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t65_n20;
  t65_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t65_n19;
  t65_n18: return 0.06657944619655609;
  t65_n19: return 0.08379063755273819;
  t65_n20: return 0.11389318853616714;
  t65_n21: return 0.04432129114866257;
  t65_n22: return -0.018720533698797226;
  t65_n23: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t65_n35;
  t65_n24: if (E.getNumReferences() >= 3328830976 /*14971.5*/) goto t65_n34;
  t65_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n27;
  t65_n26: return -0.01682526245713234;
  t65_n27: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t65_n33;
  t65_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t65_n32;
  t65_n29: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n31;
  t65_n30: return -0.13796746730804443;
  t65_n31: return -0.37000998854637146;
  t65_n32: return 0.10431923717260361;
  t65_n33: return -0.002061940962448716;
  t65_n34: return 0.08060920983552933;
  t65_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n37;
  t65_n36: return -0.013337423093616962;
  t65_n37: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t65_n47;
  t65_n38: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n46;
  t65_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n41;
  t65_n40: return 0.028336089104413986;
  t65_n41: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n43;
  t65_n42: return 0.07120483368635178;
  t65_n43: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t65_n45;
  t65_n44: return 0.09381303191184998;
  t65_n45: return -0.14064271748065948;
  t65_n46: return -0.09779283404350281;
  t65_n47: if (E.getNumReferences() >= 3310286848 /*3311.5*/) goto t65_n49;
  t65_n48: return -0.04116370901465416;
  t65_n49: if (E.getNumReferences() >= 3311257600 /*3548.5*/) goto t65_n51;
  t65_n50: return 0.12097527831792831;
  t65_n51: return 0.062277767807245255;
  t65_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n54;
  t65_n53: return 0.058804310858249664;
  t65_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t65_n56;
  t65_n55: return 0.04473995789885521;
  t65_n56: return 0.052860382944345474;
  t65_n57: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t65_n59;
  t65_n58: return -0.02222730964422226;
  t65_n59: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t65_n61;
  t65_n60: return 0.06608603149652481;
  t65_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n63;
  t65_n62: return -0.015503346920013428;
  t65_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n65;
  t65_n64: return 0.022833826020359993;
  t65_n65: return 0.06102503091096878;
  t65_n66: return 0.08392838388681412;
  t65_n67: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n69;
  t65_n68: return -0.015233042649924755;
  t65_n69: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n97;
  t65_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t65_n74;
  t65_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t65_n73;
  t65_n72: return -0.03896204009652138;
  t65_n73: return 0.045022912323474884;
  t65_n74: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t65_n76;
  t65_n75: return -0.05986245721578598;
  t65_n76: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t65_n94;
  t65_n77: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t65_n85;
  t65_n78: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t65_n84;
  t65_n79: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t65_n81;
  t65_n80: return 0.1271180361509323;
  t65_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n83;
  t65_n82: return 0.14449086785316467;
  t65_n83: return 0.13546694815158844;
  t65_n84: return 0.12186844646930695;
  t65_n85: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n91;
  t65_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n88;
  t65_n87: return 0.13285496830940247;
  t65_n88: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t65_n90;
  t65_n89: return 0.11944764852523804;
  t65_n90: return 0.11730841547250748;
  t65_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n93;
  t65_n92: return 0.12142549455165863;
  t65_n93: return 0.02002578042447567;
  t65_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t65_n96;
  t65_n95: return 0.08824627846479416;
  t65_n96: return 0.08851653337478638;
  t65_n97: return 0.02225440926849842;
  t65_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t65_n102;
  t65_n99: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t65_n101;
  t65_n100: return 0.012532896362245083;
  t65_n101: return -0.04207745939493179;
  t65_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t65_n104;
  t65_n103: return 0.04307427257299423;
  t65_n104: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t65_n130;
  t65_n105: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t65_n109;
  t65_n106: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t65_n108;
  t65_n107: return 0.21937048435211182;
  t65_n108: return 0.12788791954517365;
  t65_n109: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t65_n123;
  t65_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t65_n112;
  t65_n111: return -0.04938111826777458;
  t65_n112: if (E.getFileProximityDistance() >= 3254255616 /*31.0*/) goto t65_n122;
  t65_n113: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t65_n115;
  t65_n114: return -2.6403826268506236e-05;
  t65_n115: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t65_n121;
  t65_n116: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n118;
  t65_n117: return -0.00994004774838686;
  t65_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t65_n120;
  t65_n119: return 0.09655483812093735;
  t65_n120: return 0.07238021492958069;
  t65_n121: return 0.028426405042409897;
  t65_n122: return 0.08717422187328339;
  t65_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t65_n125;
  t65_n124: return 0.06361331790685654;
  t65_n125: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t65_n127;
  t65_n126: return 0.0760316327214241;
  t65_n127: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t65_n129;
  t65_n128: return 0.12253823131322861;
  t65_n129: return 0.11715424805879593;
  t65_n130: return 0.0056626093573868275;
  t65_n131: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t65_n223;
  t65_n132: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t65_n142;
  t65_n133: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t65_n141;
  t65_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t65_n140;
  t65_n135: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t65_n137;
  t65_n136: return -0.004807045683264732;
  t65_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n139;
  t65_n138: return -0.06637326627969742;
  t65_n139: return -0.016405219212174416;
  t65_n140: return 0.010238813236355782;
  t65_n141: return -0.02927108108997345;
  t65_n142: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t65_n216;
  t65_n143: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t65_n175;
  t65_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n152;
  t65_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n149;
  t65_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t65_n148;
  t65_n147: return -0.018985873088240623;
  t65_n148: return 0.05122999846935272;
  t65_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n151;
  t65_n150: return -0.19654276967048645;
  t65_n151: return -0.04118020087480545;
  t65_n152: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t65_n154;
  t65_n153: return 0.03103025071322918;
  t65_n154: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t65_n156;
  t65_n155: return 0.04514029622077942;
  t65_n156: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t65_n158;
  t65_n157: return 0.0445169061422348;
  t65_n158: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t65_n160;
  t65_n159: return 0.07754278928041458;
  t65_n160: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t65_n166;
  t65_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t65_n163;
  t65_n162: return 0.0933670848608017;
  t65_n163: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t65_n165;
  t65_n164: return 0.12194278091192245;
  t65_n165: return -0.03668301925063133;
  t65_n166: if (E.getNumReferences() >= 3271360512 /*126.5*/) goto t65_n168;
  t65_n167: return 0.1229807436466217;
  t65_n168: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t65_n174;
  t65_n169: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n173;
  t65_n170: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t65_n172;
  t65_n171: return -0.12309914827346802;
  t65_n172: return 0.11089044064283371;
  t65_n173: return 0.12740188837051392;
  t65_n174: return 0.10391107201576233;
  t65_n175: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t65_n211;
  t65_n176: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t65_n196;
  t65_n177: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t65_n179;
  t65_n178: return 0.026458794251084328;
  t65_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t65_n183;
  t65_n180: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t65_n182;
  t65_n181: return -0.1367088407278061;
  t65_n182: return -0.020558379590511322;
  t65_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t65_n185;
  t65_n184: return 0.003483752952888608;
  t65_n185: if (E.getNumReferences() >= 3304472576 /*1970.0*/) goto t65_n195;
  t65_n186: if (E.getNumReferences() >= 3273555968 /*158.5*/) goto t65_n194;
  t65_n187: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t65_n189;
  t65_n188: return 0.06893852353096008;
  t65_n189: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n191;
  t65_n190: return 0.10518111288547516;
  t65_n191: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t65_n193;
  t65_n192: return 0.11338888108730316;
  t65_n193: return 0.09977762401103973;
  t65_n194: return -0.011484429240226746;
  t65_n195: return 0.08865810185670853;
  t65_n196: if (E.getNumReferences() >= 3342400384 /*47355.5*/) goto t65_n200;
  t65_n197: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t65_n199;
  t65_n198: return -0.12718261778354645;
  t65_n199: return 0.12448772042989731;
  t65_n200: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t65_n210;
  t65_n201: if (E.getNumReferences() >= 3343995264 /*53585.5*/) goto t65_n203;
  t65_n202: return 0.11714880168437958;
  t65_n203: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t65_n209;
  t65_n204: if (E.getNumReferences() >= 3345907328 /*61054.5*/) goto t65_n208;
  t65_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n207;
  t65_n206: return 0.10536844283342361;
  t65_n207: return 0.08858092129230499;
  t65_n208: return -0.017686134204268456;
  t65_n209: return 0.05843604728579521;
  t65_n210: return -0.027631811797618866;
  t65_n211: if (E.getNumReferences() >= 3320657920 /*7591.0*/) goto t65_n215;
  t65_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t65_n214;
  t65_n213: return -0.19564083218574524;
  t65_n214: return -0.018543360754847527;
  t65_n215: return 0.017672158777713776;
  t65_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t65_n218;
  t65_n217: return -0.0805223286151886;
  t65_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t65_n220;
  t65_n219: return 0.0726984515786171;
  t65_n220: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t65_n222;
  t65_n221: return 0.001973107224330306;
  t65_n222: return 0.18564501404762268;
  t65_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t65_n225;
  t65_n224: return 0.0018229072447866201;
  t65_n225: return 0.01843740977346897;
  t65_n226: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t65_n246;
  t65_n227: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t65_n229;
  t65_n228: return 0.010475614108145237;
  t65_n229: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n235;
  t65_n230: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t65_n232;
  t65_n231: return 0.05222548916935921;
  t65_n232: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t65_n234;
  t65_n233: return 0.018112080171704292;
  t65_n234: return 0.0674857348203659;
  t65_n235: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t65_n237;
  t65_n236: return 0.0007083556265570223;
  t65_n237: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t65_n239;
  t65_n238: return -0.05567193403840065;
  t65_n239: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t65_n245;
  t65_n240: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t65_n244;
  t65_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t65_n243;
  t65_n242: return 0.13909722864627838;
  t65_n243: return 0.12334182858467102;
  t65_n244: return -0.09540338814258575;
  t65_n245: return 0.04827047139406204;
  t65_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t65_n252;
  t65_n247: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t65_n251;
  t65_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t65_n250;
  t65_n249: return -0.019413067027926445;
  t65_n250: return 0.056212443858385086;
  t65_n251: return 0.028848571702837944;
  t65_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t65_n254;
  t65_n253: return -0.0361565463244915;
  t65_n254: return 0.030102472752332687;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree66(const Example& E) {
  t66_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t66_n246;
  t66_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t66_n219;
  t66_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t66_n54;
  t66_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t66_n5;
  t66_n4: return -0.11749647557735443;
  t66_n5: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t66_n7;
  t66_n6: return -0.006548475474119186;
  t66_n7: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t66_n37;
  t66_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t66_n20;
  t66_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n11;
  t66_n10: return 0.14938980340957642;
  t66_n11: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t66_n13;
  t66_n12: return -0.20491832494735718;
  t66_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t66_n15;
  t66_n14: return -0.038697369396686554;
  t66_n15: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t66_n17;
  t66_n16: return 0.1082383245229721;
  t66_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n19;
  t66_n18: return 0.10128773748874664;
  t66_n19: return 0.13744063675403595;
  t66_n20: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t66_n32;
  t66_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t66_n27;
  t66_n22: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t66_n26;
  t66_n23: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t66_n25;
  t66_n24: return 0.025848103687167168;
  t66_n25: return 0.09775490313768387;
  t66_n26: return -0.08685760945081711;
  t66_n27: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t66_n31;
  t66_n28: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t66_n30;
  t66_n29: return 0.13490204513072968;
  t66_n30: return 0.12302614748477936;
  t66_n31: return 0.10456787049770355;
  t66_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t66_n36;
  t66_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n35;
  t66_n34: return 0.056079380214214325;
  t66_n35: return 0.09601928293704987;
  t66_n36: return 0.08895443379878998;
  t66_n37: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t66_n41;
  t66_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t66_n40;
  t66_n39: return -0.10115362703800201;
  t66_n40: return 0.11796797811985016;
  t66_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n47;
  t66_n42: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t66_n44;
  t66_n43: return -0.09427766501903534;
  t66_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n46;
  t66_n45: return -0.16443845629692078;
  t66_n46: return 0.1180739477276802;
  t66_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n49;
  t66_n48: return 0.028523679822683334;
  t66_n49: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t66_n53;
  t66_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n52;
  t66_n51: return 0.09343649446964264;
  t66_n52: return 0.038096822798252106;
  t66_n53: return -0.13087837398052216;
  t66_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t66_n104;
  t66_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t66_n81;
  t66_n56: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t66_n58;
  t66_n57: return -0.017538875341415405;
  t66_n58: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t66_n80;
  t66_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t66_n63;
  t66_n60: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t66_n62;
  t66_n61: return -0.1042635515332222;
  t66_n62: return -0.5235981941223145;
  t66_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n65;
  t66_n64: return 0.05678054690361023;
  t66_n65: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t66_n77;
  t66_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n72;
  t66_n67: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t66_n71;
  t66_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t66_n70;
  t66_n69: return 0.09298224002122879;
  t66_n70: return 0.05289963632822037;
  t66_n71: return 0.12552925944328308;
  t66_n72: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t66_n74;
  t66_n73: return 0.05896072834730148;
  t66_n74: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t66_n76;
  t66_n75: return 0.11733075231313705;
  t66_n76: return 0.04896078631281853;
  t66_n77: if (E.getNumReferences() >= 3348976000 /*80547.0*/) goto t66_n79;
  t66_n78: return 0.008963296189904213;
  t66_n79: return -0.30585771799087524;
  t66_n80: return -0.1218060553073883;
  t66_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t66_n83;
  t66_n82: return 0.018118536099791527;
  t66_n83: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t66_n85;
  t66_n84: return -0.016465406864881516;
  t66_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t66_n87;
  t66_n86: return 0.06580720841884613;
  t66_n87: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t66_n99;
  t66_n88: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t66_n90;
  t66_n89: return 0.01657169498503208;
  t66_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t66_n92;
  t66_n91: return -0.015738381072878838;
  t66_n92: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t66_n98;
  t66_n93: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n97;
  t66_n94: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t66_n96;
  t66_n95: return 0.10685066133737564;
  t66_n96: return 0.1292070597410202;
  t66_n97: return 0.05766758695244789;
  t66_n98: return 0.015241788700222969;
  t66_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t66_n101;
  t66_n100: return 0.06852275133132935;
  t66_n101: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t66_n103;
  t66_n102: return 0.10783430933952332;
  t66_n103: return 0.08059168606996536;
  t66_n104: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t66_n216;
  t66_n105: if (E.getNumReferences() >= 3347329664 /*67685.0*/) goto t66_n189;
  t66_n106: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t66_n184;
  t66_n107: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t66_n183;
  t66_n108: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t66_n182;
  t66_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t66_n137;
  t66_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n112;
  t66_n111: return 0.015041018836200237;
  t66_n112: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t66_n126;
  t66_n113: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t66_n123;
  t66_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t66_n116;
  t66_n115: return 0.026719655841588974;
  t66_n116: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t66_n122;
  t66_n117: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t66_n121;
  t66_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t66_n120;
  t66_n119: return -0.14771457016468048;
  t66_n120: return -0.034178294241428375;
  t66_n121: return 0.02551785297691822;
  t66_n122: return 0.008792242966592312;
  t66_n123: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t66_n125;
  t66_n124: return -0.04521724954247475;
  t66_n125: return 0.01573498547077179;
  t66_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t66_n136;
  t66_n127: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t66_n129;
  t66_n128: return 0.11126060783863068;
  t66_n129: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t66_n135;
  t66_n130: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t66_n134;
  t66_n131: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t66_n133;
  t66_n132: return 0.045604851096868515;
  t66_n133: return 0.06324257701635361;
  t66_n134: return 0.04431990534067154;
  t66_n135: return -0.0033913259394466877;
  t66_n136: return 0.01712394505739212;
  t66_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t66_n159;
  t66_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t66_n142;
  t66_n139: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t66_n141;
  t66_n140: return -0.035788826644420624;
  t66_n141: return -0.3209773004055023;
  t66_n142: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t66_n150;
  t66_n143: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t66_n145;
  t66_n144: return 0.05448324978351593;
  t66_n145: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t66_n149;
  t66_n146: if (E.getNumReferences() >= 3288686592 /*533.5*/) goto t66_n148;
  t66_n147: return 0.09760706126689911;
  t66_n148: return 0.10917531698942184;
  t66_n149: return 0.06487594544887543;
  t66_n150: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n152;
  t66_n151: return -0.19444134831428528;
  t66_n152: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t66_n158;
  t66_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n155;
  t66_n154: return 0.1309516578912735;
  t66_n155: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t66_n157;
  t66_n156: return 0.09561850875616074;
  t66_n157: return 0.1521230936050415;
  t66_n158: return 0.10997404158115387;
  t66_n159: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t66_n177;
  t66_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t66_n162;
  t66_n161: return -0.0011018242221325636;
  t66_n162: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t66_n166;
  t66_n163: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t66_n165;
  t66_n164: return 0.012131360359489918;
  t66_n165: return 0.0903579592704773;
  t66_n166: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n168;
  t66_n167: return -0.08425764739513397;
  t66_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t66_n172;
  t66_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t66_n171;
  t66_n170: return 0.1150236427783966;
  t66_n171: return 0.14500924944877625;
  t66_n172: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t66_n176;
  t66_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t66_n175;
  t66_n174: return 0.18616430461406708;
  t66_n175: return 0.1498935967683792;
  t66_n176: return 0.04728851467370987;
  t66_n177: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t66_n179;
  t66_n178: return -0.05371614173054695;
  t66_n179: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t66_n181;
  t66_n180: return 0.007559794932603836;
  t66_n181: return 0.0706649199128151;
  t66_n182: return -0.1176450178027153;
  t66_n183: return -0.10551843047142029;
  t66_n184: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t66_n186;
  t66_n185: return 0.02619863860309124;
  t66_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t66_n188;
  t66_n187: return 0.04607498645782471;
  t66_n188: return 0.0905148833990097;
  t66_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n193;
  t66_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t66_n192;
  t66_n191: return 0.028348784893751144;
  t66_n192: return -0.019709071144461632;
  t66_n193: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t66_n213;
  t66_n194: if (E.getNumReferences() >= 3359752544 /*198405.5*/) goto t66_n206;
  t66_n195: if (E.getNumReferences() >= 3354069824 /*120342.5*/) goto t66_n205;
  t66_n196: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t66_n198;
  t66_n197: return 0.03638699650764465;
  t66_n198: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t66_n200;
  t66_n199: return 0.058627624064683914;
  t66_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t66_n202;
  t66_n201: return 0.06327999383211136;
  t66_n202: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t66_n204;
  t66_n203: return 0.09836070984601974;
  t66_n204: return 0.10772162675857544;
  t66_n205: return -0.020845597609877586;
  t66_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t66_n212;
  t66_n207: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t66_n209;
  t66_n208: return 0.04963737726211548;
  t66_n209: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t66_n211;
  t66_n210: return 0.10723704844713211;
  t66_n211: return -0.17972122132778168;
  t66_n212: return 0.09913966059684753;
  t66_n213: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t66_n215;
  t66_n214: return -0.10378751158714294;
  t66_n215: return 0.026712151244282722;
  t66_n216: if (E.getNumReferences() >= 3354069824 /*120342.5*/) goto t66_n218;
  t66_n217: return -0.039203446358442307;
  t66_n218: return -0.12158408015966415;
  t66_n219: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t66_n225;
  t66_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t66_n222;
  t66_n221: return 0.011048514395952225;
  t66_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t66_n224;
  t66_n223: return 0.006641191430389881;
  t66_n224: return 0.03022889420390129;
  t66_n225: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t66_n229;
  t66_n226: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t66_n228;
  t66_n227: return 0.08323679864406586;
  t66_n228: return -0.08843325823545456;
  t66_n229: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t66_n241;
  t66_n230: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t66_n240;
  t66_n231: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t66_n235;
  t66_n232: if (E.getNumReferences() >= 3354001600 /*119809.5*/) goto t66_n234;
  t66_n233: return 0.018805790692567825;
  t66_n234: return -2.654709577560425;
  t66_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n239;
  t66_n236: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t66_n238;
  t66_n237: return 0.11708507686853409;
  t66_n238: return 0.09068281948566437;
  t66_n239: return 0.10787360370159149;
  t66_n240: return -0.27176523208618164;
  t66_n241: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t66_n245;
  t66_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n244;
  t66_n243: return 0.03307950496673584;
  t66_n244: return 0.08522992581129074;
  t66_n245: return -0.01038298662751913;
  t66_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t66_n248;
  t66_n247: return 0.0016488278051838279;
  t66_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t66_n254;
  t66_n249: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t66_n251;
  t66_n250: return -0.0006187302060425282;
  t66_n251: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t66_n253;
  t66_n252: return 0.08667685836553574;
  t66_n253: return 0.012421585619449615;
  t66_n254: return 0.02232012152671814;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree67(const Example& E) {
  t67_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t67_n248;
  t67_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t67_n119;
  t67_n2: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t67_n72;
  t67_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t67_n71;
  t67_n4: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t67_n18;
  t67_n5: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t67_n7;
  t67_n6: return -0.005166045390069485;
  t67_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n17;
  t67_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t67_n10;
  t67_n9: return 0.0163692869246006;
  t67_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t67_n12;
  t67_n11: return 0.035363126546144485;
  t67_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t67_n14;
  t67_n13: return 0.04185652732849121;
  t67_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n16;
  t67_n15: return 0.09703364968299866;
  t67_n16: return 0.0966697707772255;
  t67_n17: return -0.07345451414585114;
  t67_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n36;
  t67_n19: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n21;
  t67_n20: return 0.011517041362822056;
  t67_n21: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t67_n35;
  t67_n22: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t67_n30;
  t67_n23: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t67_n29;
  t67_n24: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t67_n26;
  t67_n25: return 0.09969880431890488;
  t67_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n28;
  t67_n27: return 0.12089645862579346;
  t67_n28: return -0.11811241507530212;
  t67_n29: return 0.09598399698734283;
  t67_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t67_n32;
  t67_n31: return -0.03865477815270424;
  t67_n32: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t67_n34;
  t67_n33: return 0.13631458580493927;
  t67_n34: return 0.007129849400371313;
  t67_n35: return 0.026663780212402344;
  t67_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t67_n52;
  t67_n37: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t67_n43;
  t67_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t67_n40;
  t67_n39: return -0.020692946389317513;
  t67_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t67_n42;
  t67_n41: return -0.07657191902399063;
  t67_n42: return 0.03567282110452652;
  t67_n43: if (E.getFileProximityDistance() >= 3252682752 /*28.0*/) goto t67_n51;
  t67_n44: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t67_n50;
  t67_n45: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t67_n49;
  t67_n46: if (E.getNumReferences() >= 3308064768 /*2769.0*/) goto t67_n48;
  t67_n47: return 0.4499160945415497;
  t67_n48: return 0.04811074212193489;
  t67_n49: return 0.11136644333600998;
  t67_n50: return -0.07923044264316559;
  t67_n51: return 0.11621426790952682;
  t67_n52: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t67_n54;
  t67_n53: return 0.034643713384866714;
  t67_n54: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t67_n56;
  t67_n55: return 0.05268236994743347;
  t67_n56: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t67_n58;
  t67_n57: return 0.062459975481033325;
  t67_n58: if (E.getNumReferences() >= 3275587584 /*189.5*/) goto t67_n70;
  t67_n59: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t67_n65;
  t67_n60: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t67_n62;
  t67_n61: return 0.08290256559848785;
  t67_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t67_n64;
  t67_n63: return 0.08220699429512024;
  t67_n64: return 0.1085018739104271;
  t67_n65: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t67_n69;
  t67_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t67_n68;
  t67_n67: return 0.008421097882091999;
  t67_n68: return 0.11113648861646652;
  t67_n69: return 0.021165786311030388;
  t67_n70: return 0.046010758727788925;
  t67_n71: return -0.017132315784692764;
  t67_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n74;
  t67_n73: return -0.01071810070425272;
  t67_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t67_n108;
  t67_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t67_n77;
  t67_n76: return 0.03751387819647789;
  t67_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t67_n85;
  t67_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t67_n80;
  t67_n79: return -0.047588370740413666;
  t67_n80: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t67_n84;
  t67_n81: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t67_n83;
  t67_n82: return -0.14807723462581635;
  t67_n83: return 0.10902814567089081;
  t67_n84: return 0.0594976544380188;
  t67_n85: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n105;
  t67_n86: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t67_n96;
  t67_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t67_n89;
  t67_n88: return -0.10485631972551346;
  t67_n89: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t67_n95;
  t67_n90: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t67_n92;
  t67_n91: return 0.1243896484375;
  t67_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n94;
  t67_n93: return 0.14163093268871307;
  t67_n94: return 0.13496699929237366;
  t67_n95: return 0.12013469636440277;
  t67_n96: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t67_n102;
  t67_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n99;
  t67_n98: return 0.14182718098163605;
  t67_n99: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t67_n101;
  t67_n100: return 0.12153052538633347;
  t67_n101: return 0.09193392097949982;
  t67_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t67_n104;
  t67_n103: return 0.12077051401138306;
  t67_n104: return 0.018772177398204803;
  t67_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t67_n107;
  t67_n106: return 0.08782532066106796;
  t67_n107: return 0.08170706778764725;
  t67_n108: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n110;
  t67_n109: return 0.022977396845817566;
  t67_n110: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t67_n118;
  t67_n111: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t67_n115;
  t67_n112: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t67_n114;
  t67_n113: return 0.08706554025411606;
  t67_n114: return -0.02031710185110569;
  t67_n115: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t67_n117;
  t67_n116: return 0.08103953301906586;
  t67_n117: return 0.10367194563150406;
  t67_n118: return -0.3576662242412567;
  t67_n119: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t67_n199;
  t67_n120: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t67_n196;
  t67_n121: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n191;
  t67_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t67_n128;
  t67_n123: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t67_n125;
  t67_n124: return 0.008369600400328636;
  t67_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t67_n127;
  t67_n126: return -0.020130710676312447;
  t67_n127: return 0.10882770270109177;
  t67_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t67_n168;
  t67_n129: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t67_n167;
  t67_n130: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t67_n132;
  t67_n131: return -0.0023860647343099117;
  t67_n132: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t67_n154;
  t67_n133: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n141;
  t67_n134: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t67_n136;
  t67_n135: return 0.044651683419942856;
  t67_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t67_n138;
  t67_n137: return 0.06313769519329071;
  t67_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t67_n140;
  t67_n139: return 0.007315473631024361;
  t67_n140: return 0.0900426134467125;
  t67_n141: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t67_n153;
  t67_n142: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t67_n144;
  t67_n143: return 0.08902759850025177;
  t67_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t67_n146;
  t67_n145: return 0.12232035398483276;
  t67_n146: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t67_n152;
  t67_n147: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t67_n149;
  t67_n148: return 0.21589675545692444;
  t67_n149: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t67_n151;
  t67_n150: return 0.12003444880247116;
  t67_n151: return 0.137354776263237;
  t67_n152: return -0.10158539563417435;
  t67_n153: return 0.10908053815364838;
  t67_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t67_n156;
  t67_n155: return -0.10950176417827606;
  t67_n156: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t67_n164;
  t67_n157: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t67_n161;
  t67_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t67_n160;
  t67_n159: return -0.04713987559080124;
  t67_n160: return 0.10012225806713104;
  t67_n161: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t67_n163;
  t67_n162: return 0.12958543002605438;
  t67_n163: return 0.15641790628433228;
  t67_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t67_n166;
  t67_n165: return 0.11389359086751938;
  t67_n166: return 0.12464550137519836;
  t67_n167: return -0.034434426575899124;
  t67_n168: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t67_n184;
  t67_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t67_n171;
  t67_n170: return -0.055301204323768616;
  t67_n171: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t67_n173;
  t67_n172: return -0.015765829011797905;
  t67_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t67_n175;
  t67_n174: return 0.0016754899406805634;
  t67_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n177;
  t67_n176: return 0.006111158523708582;
  t67_n177: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t67_n179;
  t67_n178: return 0.02913856692612171;
  t67_n179: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t67_n181;
  t67_n180: return 0.027897372841835022;
  t67_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t67_n183;
  t67_n182: return 0.12689617276191711;
  t67_n183: return 0.04372962936758995;
  t67_n184: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t67_n186;
  t67_n185: return 0.029515095055103302;
  t67_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t67_n188;
  t67_n187: return 0.051933713257312775;
  t67_n188: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t67_n190;
  t67_n189: return 0.14096103608608246;
  t67_n190: return 0.12712721526622772;
  t67_n191: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n195;
  t67_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n194;
  t67_n193: return -0.008596131578087807;
  t67_n194: return 0.026463842019438744;
  t67_n195: return 0.001998779596760869;
  t67_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n198;
  t67_n197: return -0.11607865989208221;
  t67_n198: return -0.05848148837685585;
  t67_n199: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t67_n231;
  t67_n200: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t67_n226;
  t67_n201: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n203;
  t67_n202: return 0.012747850269079208;
  t67_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t67_n211;
  t67_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t67_n206;
  t67_n205: return 0.025067737326025963;
  t67_n206: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t67_n208;
  t67_n207: return 0.06364329159259796;
  t67_n208: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t67_n210;
  t67_n209: return -0.08331967145204544;
  t67_n210: return 0.12799899280071259;
  t67_n211: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t67_n213;
  t67_n212: return 0.04635084047913551;
  t67_n213: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t67_n215;
  t67_n214: return 0.0577244758605957;
  t67_n215: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t67_n225;
  t67_n216: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t67_n224;
  t67_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t67_n219;
  t67_n218: return 0.11240410804748535;
  t67_n219: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t67_n223;
  t67_n220: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t67_n222;
  t67_n221: return 0.12577706575393677;
  t67_n222: return 0.16796688735485077;
  t67_n223: return 0.12004683166742325;
  t67_n224: return -0.1562257707118988;
  t67_n225: return -0.0007054847665131092;
  t67_n226: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t67_n230;
  t67_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t67_n229;
  t67_n228: return 0.11018694192171097;
  t67_n229: return 0.09571418166160583;
  t67_n230: return 0.0318695530295372;
  t67_n231: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t67_n233;
  t67_n232: return 0.013318215496838093;
  t67_n233: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t67_n247;
  t67_n234: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n242;
  t67_n235: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t67_n237;
  t67_n236: return 0.0662451982498169;
  t67_n237: if (E.getNumReferences() >= 3305310208 /*2096.5*/) goto t67_n239;
  t67_n238: return 0.04646610468626022;
  t67_n239: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n241;
  t67_n240: return 0.04449908062815666;
  t67_n241: return 0.09425174444913864;
  t67_n242: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t67_n246;
  t67_n243: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t67_n245;
  t67_n244: return 0.08063844591379166;
  t67_n245: return 0.1394778937101364;
  t67_n246: return 0.08212748169898987;
  t67_n247: return 0.07392704486846924;
  t67_n248: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t67_n254;
  t67_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t67_n253;
  t67_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t67_n252;
  t67_n251: return 0.0025754442904144526;
  t67_n252: return 0.022154033184051514;
  t67_n253: return 0.025756968185305595;
  t67_n254: return -0.23959071934223175;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree68(const Example& E) {
  t68_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t68_n248;
  t68_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t68_n91;
  t68_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t68_n32;
  t68_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t68_n31;
  t68_n4: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t68_n6;
  t68_n5: return -0.0020145257003605366;
  t68_n6: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n8;
  t68_n7: return 0.01500996295362711;
  t68_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t68_n10;
  t68_n9: return 0.0298269372433424;
  t68_n10: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t68_n14;
  t68_n11: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t68_n13;
  t68_n12: return 0.03600062057375908;
  t68_n13: return 0.06277875602245331;
  t68_n14: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t68_n16;
  t68_n15: return 0.052683450281620026;
  t68_n16: if (E.getNumReferences() >= 3275587584 /*189.5*/) goto t68_n30;
  t68_n17: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t68_n23;
  t68_n18: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t68_n20;
  t68_n19: return 0.08169077336788177;
  t68_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t68_n22;
  t68_n21: return 0.07977677881717682;
  t68_n22: return 0.10723293572664261;
  t68_n23: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t68_n29;
  t68_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t68_n26;
  t68_n25: return 0.006517632864415646;
  t68_n26: if (E.getNumReferences() >= 3272146944 /*137.0*/) goto t68_n28;
  t68_n27: return 0.10958486050367355;
  t68_n28: return 0.10841625183820724;
  t68_n29: return 0.020605482161045074;
  t68_n30: return 0.044069111347198486;
  t68_n31: return -0.0167688075453043;
  t68_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t68_n34;
  t68_n33: return -0.014454500749707222;
  t68_n34: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t68_n72;
  t68_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t68_n47;
  t68_n36: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t68_n46;
  t68_n37: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n39;
  t68_n38: return 0.1358901411294937;
  t68_n39: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t68_n41;
  t68_n40: return -0.034369152039289474;
  t68_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n43;
  t68_n42: return 0.11978143453598022;
  t68_n43: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n45;
  t68_n44: return 0.11303748190402985;
  t68_n45: return 0.13804137706756592;
  t68_n46: return 0.032467588782310486;
  t68_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t68_n49;
  t68_n48: return -0.04295014962553978;
  t68_n49: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n69;
  t68_n50: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t68_n60;
  t68_n51: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t68_n59;
  t68_n52: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t68_n56;
  t68_n53: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t68_n55;
  t68_n54: return 0.11728635430335999;
  t68_n55: return 0.1272069364786148;
  t68_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n58;
  t68_n57: return 0.12874849140644073;
  t68_n58: return 0.13138364255428314;
  t68_n59: return 0.11707079410552979;
  t68_n60: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n66;
  t68_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n63;
  t68_n62: return 0.06378869712352753;
  t68_n63: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t68_n65;
  t68_n64: return 0.11539120227098465;
  t68_n65: return 0.11159248650074005;
  t68_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n68;
  t68_n67: return 0.11450060456991196;
  t68_n68: return 0.016993671655654907;
  t68_n69: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n71;
  t68_n70: return 0.08575695753097534;
  t68_n71: return 0.07965527474880219;
  t68_n72: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t68_n74;
  t68_n73: return 0.020015807822346687;
  t68_n74: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t68_n90;
  t68_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t68_n89;
  t68_n76: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n88;
  t68_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t68_n87;
  t68_n78: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t68_n80;
  t68_n79: return 0.07411079853773117;
  t68_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t68_n86;
  t68_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t68_n85;
  t68_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t68_n84;
  t68_n83: return 0.12258957326412201;
  t68_n84: return -0.007292285095900297;
  t68_n85: return 0.0810539647936821;
  t68_n86: return 0.1066562756896019;
  t68_n87: return -0.5175366997718811;
  t68_n88: return -0.05384524166584015;
  t68_n89: return 0.1653703898191452;
  t68_n90: return 0.0025908525567501783;
  t68_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t68_n191;
  t68_n92: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t68_n102;
  t68_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n99;
  t68_n94: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t68_n96;
  t68_n95: return 0.01011196244508028;
  t68_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t68_n98;
  t68_n97: return -0.02397749572992325;
  t68_n98: return 0.09569049626588821;
  t68_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t68_n101;
  t68_n100: return -0.007826769724488258;
  t68_n101: return 0.006734339985996485;
  t68_n102: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t68_n168;
  t68_n103: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n135;
  t68_n104: if (E.getNumReferences() >= 3340847232 /*41288.5*/) goto t68_n110;
  t68_n105: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n107;
  t68_n106: return 0.01664680987596512;
  t68_n107: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t68_n109;
  t68_n108: return -0.02954082004725933;
  t68_n109: return 0.1888871192932129;
  t68_n110: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t68_n112;
  t68_n111: return 0.002787626115605235;
  t68_n112: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t68_n134;
  t68_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t68_n129;
  t68_n114: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n128;
  t68_n115: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t68_n121;
  t68_n116: if (E.getNumReferences() >= 3349201152 /*82306.0*/) goto t68_n118;
  t68_n117: return 0.07073832303285599;
  t68_n118: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t68_n120;
  t68_n119: return 0.09613853693008423;
  t68_n120: return 0.05098113790154457;
  t68_n121: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t68_n123;
  t68_n122: return -0.22378501296043396;
  t68_n123: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t68_n127;
  t68_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t68_n126;
  t68_n125: return 0.09981808811426163;
  t68_n126: return 0.09663739055395126;
  t68_n127: return 0.043120790272951126;
  t68_n128: return -0.05336586385965347;
  t68_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n131;
  t68_n130: return -0.09416690468788147;
  t68_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t68_n133;
  t68_n132: return 0.12235146760940552;
  t68_n133: return -0.007233771029859781;
  t68_n134: return -0.038146745413541794;
  t68_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t68_n141;
  t68_n136: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t68_n138;
  t68_n137: return 0.031826939433813095;
  t68_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t68_n140;
  t68_n139: return 0.10671888291835785;
  t68_n140: return 0.12375158816576004;
  t68_n141: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t68_n143;
  t68_n142: return 0.03809057176113129;
  t68_n143: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t68_n157;
  t68_n144: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t68_n156;
  t68_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n153;
  t68_n146: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t68_n152;
  t68_n147: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t68_n151;
  t68_n148: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t68_n150;
  t68_n149: return 0.12838122248649597;
  t68_n150: return 0.11331497132778168;
  t68_n151: return -0.18465907871723175;
  t68_n152: return 0.12081503868103027;
  t68_n153: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t68_n155;
  t68_n154: return -0.08041463047266006;
  t68_n155: return 0.1165381595492363;
  t68_n156: return 0.046753931790590286;
  t68_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t68_n167;
  t68_n158: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t68_n166;
  t68_n159: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n161;
  t68_n160: return 0.11042331904172897;
  t68_n161: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t68_n165;
  t68_n162: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t68_n164;
  t68_n163: return 0.12394537031650543;
  t68_n164: return 0.16934902966022491;
  t68_n165: return 0.11837195605039597;
  t68_n166: return -0.12137780338525772;
  t68_n167: return 0.01024016086012125;
  t68_n168: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t68_n170;
  t68_n169: return 0.011776783503592014;
  t68_n170: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t68_n180;
  t68_n171: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t68_n179;
  t68_n172: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t68_n174;
  t68_n173: return 0.05621746927499771;
  t68_n174: if (E.getNumReferences() >= 3364747568 /*290761.5*/) goto t68_n176;
  t68_n175: return -0.00878042820841074;
  t68_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t68_n178;
  t68_n177: return 0.10131554305553436;
  t68_n178: return 0.11074429005384445;
  t68_n179: return 0.06374325603246689;
  t68_n180: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t68_n190;
  t68_n181: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t68_n189;
  t68_n182: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t68_n186;
  t68_n183: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t68_n185;
  t68_n184: return 0.11387677490711212;
  t68_n185: return 0.07365266978740692;
  t68_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t68_n188;
  t68_n187: return 0.08971330523490906;
  t68_n188: return 0.12909723818302155;
  t68_n189: return -0.1555570811033249;
  t68_n190: return 0.0658809170126915;
  t68_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t68_n231;
  t68_n192: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t68_n228;
  t68_n193: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t68_n197;
  t68_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n196;
  t68_n195: return 0.03894732519984245;
  t68_n196: return 0.012082746252417564;
  t68_n197: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t68_n221;
  t68_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t68_n200;
  t68_n199: return 0.055730726569890976;
  t68_n200: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t68_n212;
  t68_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t68_n209;
  t68_n202: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t68_n208;
  t68_n203: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t68_n207;
  t68_n204: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t68_n206;
  t68_n205: return 0.11539093405008316;
  t68_n206: return -0.2334531843662262;
  t68_n207: return -0.10386870056390762;
  t68_n208: return 0.11889412999153137;
  t68_n209: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t68_n211;
  t68_n210: return 0.050038132816553116;
  t68_n211: return 0.11191999912261963;
  t68_n212: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t68_n214;
  t68_n213: return -0.0015543807530775666;
  t68_n214: if (E.getNumReferences() >= 3272015872 /*135.0*/) goto t68_n220;
  t68_n215: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t68_n219;
  t68_n216: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t68_n218;
  t68_n217: return -0.40477117896080017;
  t68_n218: return 0.10543566942214966;
  t68_n219: return 0.12859974801540375;
  t68_n220: return 0.028195302933454514;
  t68_n221: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t68_n227;
  t68_n222: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t68_n224;
  t68_n223: return 0.03240234777331352;
  t68_n224: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t68_n226;
  t68_n225: return 0.11099480837583542;
  t68_n226: return 0.058351870626211166;
  t68_n227: return -0.057366643100976944;
  t68_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t68_n230;
  t68_n229: return -0.0036178368609398603;
  t68_n230: return 0.023398438468575478;
  t68_n231: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t68_n243;
  t68_n232: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t68_n234;
  t68_n233: return -0.023281170055270195;
  t68_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n236;
  t68_n235: return -0.018865074962377548;
  t68_n236: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n240;
  t68_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t68_n239;
  t68_n238: return -0.4377630054950714;
  t68_n239: return 0.12402839213609695;
  t68_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t68_n242;
  t68_n241: return -0.1092768982052803;
  t68_n242: return 0.15977884829044342;
  t68_n243: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t68_n245;
  t68_n244: return 0.017906438559293747;
  t68_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t68_n247;
  t68_n246: return 0.08959035575389862;
  t68_n247: return 0.019849667325615883;
  t68_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t68_n254;
  t68_n249: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t68_n253;
  t68_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t68_n252;
  t68_n251: return 0.0028531907591968775;
  t68_n252: return 0.020819077268242836;
  t68_n253: return -0.20470532774925232;
  t68_n254: return 0.02444259077310562;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree69(const Example& E) {
  t69_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t69_n202;
  t69_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t69_n75;
  t69_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t69_n4;
  t69_n3: return -0.015544342808425426;
  t69_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t69_n24;
  t69_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t69_n7;
  t69_n6: return -0.024449076503515244;
  t69_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t69_n21;
  t69_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n10;
  t69_n9: return 0.012174037285149097;
  t69_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t69_n14;
  t69_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t69_n13;
  t69_n12: return -0.023337550461292267;
  t69_n13: return 0.019014600664377213;
  t69_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t69_n18;
  t69_n15: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t69_n17;
  t69_n16: return 0.024934133514761925;
  t69_n17: return -0.19417835772037506;
  t69_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t69_n20;
  t69_n19: return 0.04017289727926254;
  t69_n20: return 0.06071893498301506;
  t69_n21: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t69_n23;
  t69_n22: return -0.039346348494291306;
  t69_n23: return 0.03863472864031792;
  t69_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n32;
  t69_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t69_n27;
  t69_n26: return 0.00724259065464139;
  t69_n27: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t69_n31;
  t69_n28: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t69_n30;
  t69_n29: return 0.09443435817956924;
  t69_n30: return -0.12026329338550568;
  t69_n31: return -0.1209329217672348;
  t69_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t69_n34;
  t69_n33: return 0.013683815486729145;
  t69_n34: if (E.getNumReferences() >= 3292643328 /*775.0*/) goto t69_n38;
  t69_n35: if (E.getNumReferences() >= 3291799552 /*723.5*/) goto t69_n37;
  t69_n36: return 0.02155354805290699;
  t69_n37: return -0.14349070191383362;
  t69_n38: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t69_n40;
  t69_n39: return 0.10801546275615692;
  t69_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t69_n70;
  t69_n41: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t69_n57;
  t69_n42: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t69_n54;
  t69_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n45;
  t69_n44: return -0.13923320174217224;
  t69_n45: if (E.getNumReferences() >= 3317871616 /*6230.5*/) goto t69_n47;
  t69_n46: return -0.13479682803153992;
  t69_n47: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t69_n49;
  t69_n48: return 0.11531852930784225;
  t69_n49: if (E.getNumReferences() >= 3320366080 /*7448.5*/) goto t69_n53;
  t69_n50: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t69_n52;
  t69_n51: return 0.11418786644935608;
  t69_n52: return 0.12181486934423447;
  t69_n53: return 0.024196133017539978;
  t69_n54: if (E.getNumReferences() >= 3308169216 /*2794.5*/) goto t69_n56;
  t69_n55: return -0.14476528763771057;
  t69_n56: return 0.13535234332084656;
  t69_n57: if (E.getNumReferences() >= 3334006272 /*23667.0*/) goto t69_n59;
  t69_n58: return 0.14434629678726196;
  t69_n59: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t69_n65;
  t69_n60: if (E.getNumReferences() >= 3338301440 /*32056.0*/) goto t69_n64;
  t69_n61: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t69_n63;
  t69_n62: return 0.1192256510257721;
  t69_n63: return 0.09571520239114761;
  t69_n64: return 0.12055348604917526;
  t69_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n67;
  t69_n66: return -0.2883565127849579;
  t69_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t69_n69;
  t69_n68: return 0.08981603384017944;
  t69_n69: return 0.06422528624534607;
  t69_n70: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t69_n72;
  t69_n71: return 0.02705262415111065;
  t69_n72: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t69_n74;
  t69_n73: return 0.0873253121972084;
  t69_n74: return 0.10517210513353348;
  t69_n75: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t69_n199;
  t69_n76: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t69_n122;
  t69_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t69_n119;
  t69_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t69_n82;
  t69_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t69_n81;
  t69_n80: return -0.02119724079966545;
  t69_n81: return 0.003244561143219471;
  t69_n82: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t69_n118;
  t69_n83: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t69_n89;
  t69_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n86;
  t69_n85: return -0.10121028125286102;
  t69_n86: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t69_n88;
  t69_n87: return -0.0738721638917923;
  t69_n88: return 0.0004659640835598111;
  t69_n89: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t69_n95;
  t69_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t69_n92;
  t69_n91: return 0.014401696622371674;
  t69_n92: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t69_n94;
  t69_n93: return 0.022489653900265694;
  t69_n94: return 0.06562147289514542;
  t69_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t69_n97;
  t69_n96: return -0.039746761322021484;
  t69_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t69_n111;
  t69_n98: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t69_n100;
  t69_n99: return -0.21001489460468292;
  t69_n100: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t69_n110;
  t69_n101: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t69_n103;
  t69_n102: return -0.1617063581943512;
  t69_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n105;
  t69_n104: return 0.015985073521733284;
  t69_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t69_n107;
  t69_n106: return 0.04053780809044838;
  t69_n107: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t69_n109;
  t69_n108: return 0.119108647108078;
  t69_n109: return 0.10935937613248825;
  t69_n110: return 0.10712576657533646;
  t69_n111: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t69_n113;
  t69_n112: return 0.05723436921834946;
  t69_n113: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t69_n117;
  t69_n114: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t69_n116;
  t69_n115: return 0.14048679172992706;
  t69_n116: return 0.11434081941843033;
  t69_n117: return 0.03581104055047035;
  t69_n118: return -0.10020574182271957;
  t69_n119: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t69_n121;
  t69_n120: return -0.02940702624619007;
  t69_n121: return 0.046753812581300735;
  t69_n122: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t69_n186;
  t69_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n127;
  t69_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t69_n126;
  t69_n125: return -0.031097490340471268;
  t69_n126: return 0.03352880850434303;
  t69_n127: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t69_n153;
  t69_n128: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t69_n130;
  t69_n129: return 0.027775418013334274;
  t69_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t69_n132;
  t69_n131: return 0.03760238364338875;
  t69_n132: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t69_n136;
  t69_n133: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t69_n135;
  t69_n134: return 0.0343426875770092;
  t69_n135: return 0.07331434637308121;
  t69_n136: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t69_n152;
  t69_n137: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t69_n139;
  t69_n138: return 0.06361561268568039;
  t69_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t69_n149;
  t69_n140: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t69_n142;
  t69_n141: return 0.11945488303899765;
  t69_n142: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t69_n144;
  t69_n143: return -0.09277991205453873;
  t69_n144: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t69_n146;
  t69_n145: return 0.12394702434539795;
  t69_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t69_n148;
  t69_n147: return 0.0591760016977787;
  t69_n148: return 0.10589127242565155;
  t69_n149: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t69_n151;
  t69_n150: return 0.14429406821727753;
  t69_n151: return 0.10297191143035889;
  t69_n152: return 0.07154969871044159;
  t69_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t69_n185;
  t69_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t69_n156;
  t69_n155: return -0.023147333413362503;
  t69_n156: if (E.getNumReferences() >= 3332634624 /*20988.0*/) goto t69_n184;
  t69_n157: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t69_n179;
  t69_n158: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t69_n160;
  t69_n159: return 0.07304459065198898;
  t69_n160: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t69_n166;
  t69_n161: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t69_n165;
  t69_n162: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t69_n164;
  t69_n163: return 0.0829138532280922;
  t69_n164: return -0.08565860241651535;
  t69_n165: return 0.021680733188986778;
  t69_n166: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t69_n178;
  t69_n167: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t69_n173;
  t69_n168: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t69_n170;
  t69_n169: return 0.08045249432325363;
  t69_n170: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t69_n172;
  t69_n171: return 0.1259634643793106;
  t69_n172: return 0.14283542335033417;
  t69_n173: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t69_n177;
  t69_n174: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t69_n176;
  t69_n175: return 0.10620424151420593;
  t69_n176: return 0.12684877216815948;
  t69_n177: return -0.15904909372329712;
  t69_n178: return 0.1786331832408905;
  t69_n179: if (E.getNumReferences() >= 3285991424 /*440.5*/) goto t69_n183;
  t69_n180: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t69_n182;
  t69_n181: return 0.1540772169828415;
  t69_n182: return -0.18208588659763336;
  t69_n183: return 0.12885071337223053;
  t69_n184: return 0.11773129552602768;
  t69_n185: return -0.09996062517166138;
  t69_n186: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t69_n198;
  t69_n187: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t69_n189;
  t69_n188: return 0.016802683472633362;
  t69_n189: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t69_n197;
  t69_n190: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t69_n194;
  t69_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t69_n193;
  t69_n192: return -0.22249038517475128;
  t69_n193: return 0.10637980699539185;
  t69_n194: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t69_n196;
  t69_n195: return 0.11896109580993652;
  t69_n196: return 0.17372801899909973;
  t69_n197: return 0.030504964292049408;
  t69_n198: return -0.005267179571092129;
  t69_n199: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n201;
  t69_n200: return 0.0004981762613169849;
  t69_n201: return 0.014840417541563511;
  t69_n202: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t69_n250;
  t69_n203: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t69_n207;
  t69_n204: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t69_n206;
  t69_n205: return 0.013844478875398636;
  t69_n206: return -0.030674273148179054;
  t69_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t69_n211;
  t69_n208: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t69_n210;
  t69_n209: return 0.0812092125415802;
  t69_n210: return -0.07231363654136658;
  t69_n211: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t69_n245;
  t69_n212: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t69_n244;
  t69_n213: if (E.getNumReferences() >= 3349739392 /*86511.0*/) goto t69_n243;
  t69_n214: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t69_n242;
  t69_n215: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t69_n217;
  t69_n216: return 0.0073492564260959625;
  t69_n217: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t69_n225;
  t69_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t69_n222;
  t69_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t69_n221;
  t69_n220: return 0.07450775057077408;
  t69_n221: return 0.10822183638811111;
  t69_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t69_n224;
  t69_n223: return 0.12345010042190552;
  t69_n224: return 0.1145351380109787;
  t69_n225: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t69_n233;
  t69_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t69_n232;
  t69_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t69_n229;
  t69_n228: return 0.04781106859445572;
  t69_n229: if (E.getNumReferences() >= 3328774656 /*14916.5*/) goto t69_n231;
  t69_n230: return 0.11811117082834244;
  t69_n231: return 0.08887248486280441;
  t69_n232: return -0.018858255818486214;
  t69_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t69_n239;
  t69_n234: if (E.getNumReferences() >= 3340675072 /*40616.0*/) goto t69_n236;
  t69_n235: return 0.030212854966521263;
  t69_n236: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t69_n238;
  t69_n237: return 0.12234195321798325;
  t69_n238: return 0.047480542212724686;
  t69_n239: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t69_n241;
  t69_n240: return 0.08750468492507935;
  t69_n241: return 0.05908535420894623;
  t69_n242: return -0.10799582302570343;
  t69_n243: return 0.06492332369089127;
  t69_n244: return -0.2588992118835449;
  t69_n245: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t69_n249;
  t69_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t69_n248;
  t69_n247: return 0.03714810684323311;
  t69_n248: return 0.08337713778018951;
  t69_n249: return -0.004713030532002449;
  t69_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t69_n254;
  t69_n251: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t69_n253;
  t69_n252: return -0.013078194111585617;
  t69_n253: return 0.028148211538791656;
  t69_n254: return 0.024932047352194786;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree70(const Example& E) {
  t70_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t70_n198;
  t70_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t70_n155;
  t70_n2: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t70_n114;
  t70_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n51;
  t70_n4: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t70_n22;
  t70_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t70_n11;
  t70_n6: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t70_n10;
  t70_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t70_n9;
  t70_n8: return -0.06393836438655853;
  t70_n9: return -0.2769813537597656;
  t70_n10: return 0.025071797892451286;
  t70_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t70_n21;
  t70_n12: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t70_n16;
  t70_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n15;
  t70_n14: return 0.10513582825660706;
  t70_n15: return 0.03727031871676445;
  t70_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n18;
  t70_n17: return 0.01906544342637062;
  t70_n18: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t70_n20;
  t70_n19: return 0.05453125387430191;
  t70_n20: return -0.14930739998817444;
  t70_n21: return -0.01830182410776615;
  t70_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n32;
  t70_n23: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t70_n31;
  t70_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n26;
  t70_n25: return -0.024630950763821602;
  t70_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n30;
  t70_n27: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t70_n29;
  t70_n28: return 0.05623319000005722;
  t70_n29: return 0.1377417892217636;
  t70_n30: return -0.048747718334198;
  t70_n31: return -0.11888182908296585;
  t70_n32: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t70_n34;
  t70_n33: return 0.0037025443743914366;
  t70_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t70_n44;
  t70_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n37;
  t70_n36: return 0.14131785929203033;
  t70_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n43;
  t70_n38: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t70_n40;
  t70_n39: return 0.125909686088562;
  t70_n40: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t70_n42;
  t70_n41: return 0.12965866923332214;
  t70_n42: return 0.11375121772289276;
  t70_n43: return 0.09418949484825134;
  t70_n44: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n50;
  t70_n45: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t70_n49;
  t70_n46: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t70_n48;
  t70_n47: return 0.09829194843769073;
  t70_n48: return 0.11408577859401703;
  t70_n49: return 0.08111788332462311;
  t70_n50: return 0.08441198617219925;
  t70_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n53;
  t70_n52: return -0.09004230797290802;
  t70_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n91;
  t70_n54: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t70_n64;
  t70_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t70_n57;
  t70_n56: return -0.11771337687969208;
  t70_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t70_n59;
  t70_n58: return -0.003041570307686925;
  t70_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n63;
  t70_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t70_n62;
  t70_n61: return 0.05273665487766266;
  t70_n62: return 0.10905246436595917;
  t70_n63: return 0.04070732370018959;
  t70_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n74;
  t70_n65: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t70_n71;
  t70_n66: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t70_n70;
  t70_n67: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t70_n69;
  t70_n68: return 0.014699332416057587;
  t70_n69: return -0.07581270486116409;
  t70_n70: return -0.16283321380615234;
  t70_n71: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t70_n73;
  t70_n72: return -0.033651094883680344;
  t70_n73: return 0.04221935570240021;
  t70_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t70_n76;
  t70_n75: return 0.004875708371400833;
  t70_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n78;
  t70_n77: return 0.06244855746626854;
  t70_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n80;
  t70_n79: return 0.06262879073619843;
  t70_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t70_n90;
  t70_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t70_n83;
  t70_n82: return 0.0840410590171814;
  t70_n83: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t70_n85;
  t70_n84: return 0.034009356051683426;
  t70_n85: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t70_n87;
  t70_n86: return 0.11890413612127304;
  t70_n87: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t70_n89;
  t70_n88: return 0.11353887617588043;
  t70_n89: return 0.11748731136322021;
  t70_n90: return 0.05953654646873474;
  t70_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n95;
  t70_n92: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t70_n94;
  t70_n93: return 0.10905759036540985;
  t70_n94: return -0.06586934626102448;
  t70_n95: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t70_n101;
  t70_n96: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t70_n100;
  t70_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t70_n99;
  t70_n98: return -0.047443047165870667;
  t70_n99: return 0.00563888531178236;
  t70_n100: return -0.10860873013734818;
  t70_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t70_n105;
  t70_n102: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t70_n104;
  t70_n103: return -0.10809887945652008;
  t70_n104: return 0.11018995940685272;
  t70_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t70_n111;
  t70_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n108;
  t70_n107: return -0.00615696469321847;
  t70_n108: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t70_n110;
  t70_n109: return 0.06737449765205383;
  t70_n110: return -0.13489142060279846;
  t70_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t70_n113;
  t70_n112: return 0.02489509806036949;
  t70_n113: return 0.005357701797038317;
  t70_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n122;
  t70_n115: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t70_n117;
  t70_n116: return 0.010357639752328396;
  t70_n117: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t70_n119;
  t70_n118: return 0.034748468548059464;
  t70_n119: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n121;
  t70_n120: return 0.1083119586110115;
  t70_n121: return 0.0489652119576931;
  t70_n122: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t70_n124;
  t70_n123: return 0.014650074765086174;
  t70_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t70_n138;
  t70_n125: if (E.getNumReferences() >= 3319035904 /*6799.0*/) goto t70_n133;
  t70_n126: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t70_n132;
  t70_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n129;
  t70_n128: return 0.014695430174469948;
  t70_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n131;
  t70_n130: return -0.1366117298603058;
  t70_n131: return 0.04063120856881142;
  t70_n132: return -0.03012598305940628;
  t70_n133: if (E.getNumReferences() >= 3319090176 /*6825.5*/) goto t70_n135;
  t70_n134: return 0.11659260094165802;
  t70_n135: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t70_n137;
  t70_n136: return 0.040470946580171585;
  t70_n137: return 0.11269339174032211;
  t70_n138: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t70_n142;
  t70_n139: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t70_n141;
  t70_n140: return -0.010308235883712769;
  t70_n141: return 0.05221347138285637;
  t70_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t70_n144;
  t70_n143: return 0.03795795142650604;
  t70_n144: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t70_n154;
  t70_n145: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t70_n151;
  t70_n146: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t70_n148;
  t70_n147: return 0.07916240394115448;
  t70_n148: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t70_n150;
  t70_n149: return 0.12110298126935959;
  t70_n150: return 0.09691213071346283;
  t70_n151: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t70_n153;
  t70_n152: return 0.029391996562480927;
  t70_n153: return 0.058081552386283875;
  t70_n154: return 0.08302424848079681;
  t70_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n159;
  t70_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t70_n158;
  t70_n157: return -0.0981256514787674;
  t70_n158: return -0.021154211834073067;
  t70_n159: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t70_n161;
  t70_n160: return 0.009758093394339085;
  t70_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t70_n163;
  t70_n162: return -0.026531832292675972;
  t70_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t70_n165;
  t70_n164: return -0.008384274318814278;
  t70_n165: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t70_n167;
  t70_n166: return -0.021777698770165443;
  t70_n167: if (E.getNumReferences() >= 3328274432 /*14428.0*/) goto t70_n193;
  t70_n168: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t70_n170;
  t70_n169: return 0.005263220984488726;
  t70_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t70_n172;
  t70_n171: return -0.0025292886421084404;
  t70_n172: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t70_n186;
  t70_n173: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t70_n185;
  t70_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t70_n180;
  t70_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t70_n177;
  t70_n176: return 0.010880619287490845;
  t70_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t70_n179;
  t70_n178: return 0.05877949297428131;
  t70_n179: return 0.11024724692106247;
  t70_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t70_n182;
  t70_n181: return -0.10780923068523407;
  t70_n182: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t70_n184;
  t70_n183: return 0.10818133503198624;
  t70_n184: return 0.1201925054192543;
  t70_n185: return -0.13213950395584106;
  t70_n186: if (E.getNumReferences() >= 3307763712 /*2695.5*/) goto t70_n188;
  t70_n187: return -0.025603123009204865;
  t70_n188: if (E.getNumReferences() >= 3308333056 /*2834.5*/) goto t70_n192;
  t70_n189: if (E.getNumReferences() >= 3308244992 /*2813.0*/) goto t70_n191;
  t70_n190: return 0.09034326672554016;
  t70_n191: return 0.11743861436843872;
  t70_n192: return 0.07359103113412857;
  t70_n193: if (E.getNumReferences() >= 3328853504 /*14993.5*/) goto t70_n197;
  t70_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n196;
  t70_n195: return -0.029311276972293854;
  t70_n196: return 0.1153416857123375;
  t70_n197: return 0.03924862667918205;
  t70_n198: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t70_n246;
  t70_n199: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t70_n245;
  t70_n200: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t70_n222;
  t70_n201: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t70_n213;
  t70_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t70_n204;
  t70_n203: return -0.253995805978775;
  t70_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t70_n208;
  t70_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t70_n207;
  t70_n206: return 0.019093185663223267;
  t70_n207: return -0.06069076061248779;
  t70_n208: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t70_n210;
  t70_n209: return 0.05025263875722885;
  t70_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t70_n212;
  t70_n211: return -0.05528486147522926;
  t70_n212: return 0.08311339467763901;
  t70_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n219;
  t70_n214: if (E.getNumReferences() >= 3319784448 /*7164.5*/) goto t70_n216;
  t70_n215: return 0.08792520314455032;
  t70_n216: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t70_n218;
  t70_n217: return 0.023995770141482353;
  t70_n218: return 0.07465754449367523;
  t70_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t70_n221;
  t70_n220: return 0.11514711380004883;
  t70_n221: return -0.01215172279626131;
  t70_n222: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t70_n224;
  t70_n223: return 0.018043527379631996;
  t70_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t70_n230;
  t70_n225: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t70_n227;
  t70_n226: return -0.043908242136240005;
  t70_n227: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t70_n229;
  t70_n228: return 0.035363949835300446;
  t70_n229: return 0.05633464455604553;
  t70_n230: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t70_n240;
  t70_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t70_n239;
  t70_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n234;
  t70_n233: return 0.05207102373242378;
  t70_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t70_n238;
  t70_n235: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t70_n237;
  t70_n236: return 0.10757286846637726;
  t70_n237: return 0.10584382712841034;
  t70_n238: return 0.08393877744674683;
  t70_n239: return 0.036318182945251465;
  t70_n240: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t70_n242;
  t70_n241: return 0.059091079980134964;
  t70_n242: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t70_n244;
  t70_n243: return 0.09826172888278961;
  t70_n244: return 0.052359405905008316;
  t70_n245: return -0.00023903977125883102;
  t70_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t70_n252;
  t70_n247: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t70_n251;
  t70_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t70_n250;
  t70_n249: return -0.021166905760765076;
  t70_n250: return 0.05560905486345291;
  t70_n251: return 0.025796886533498764;
  t70_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t70_n254;
  t70_n253: return -0.046842310577631;
  t70_n254: return 0.025598300620913506;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree71(const Example& E) {
  t71_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t71_n236;
  t71_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t71_n129;
  t71_n2: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t71_n76;
  t71_n3: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t71_n25;
  t71_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t71_n16;
  t71_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n7;
  t71_n6: return -0.024788713082671165;
  t71_n7: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t71_n9;
  t71_n8: return -0.03742305934429169;
  t71_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n11;
  t71_n10: return 0.006377519574016333;
  t71_n11: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t71_n13;
  t71_n12: return 0.031871650367975235;
  t71_n13: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t71_n15;
  t71_n14: return 0.11959243565797806;
  t71_n15: return 0.04609619453549385;
  t71_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t71_n18;
  t71_n17: return -0.016104796901345253;
  t71_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n20;
  t71_n19: return 0.011657556518912315;
  t71_n20: if (E.getNumReferences() >= 3340461952 /*39783.5*/) goto t71_n22;
  t71_n21: return -0.05409432202577591;
  t71_n22: if (E.getNumReferences() >= 3340710656 /*40755.0*/) goto t71_n24;
  t71_n23: return 0.12041553109884262;
  t71_n24: return -0.10135450959205627;
  t71_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n27;
  t71_n26: return -0.009753072634339333;
  t71_n27: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t71_n61;
  t71_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t71_n38;
  t71_n29: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t71_n37;
  t71_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n32;
  t71_n31: return 0.14600452780723572;
  t71_n32: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t71_n34;
  t71_n33: return -0.031003408133983612;
  t71_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n36;
  t71_n35: return 0.11836861819028854;
  t71_n36: return 0.11377279460430145;
  t71_n37: return 0.030413158237934113;
  t71_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t71_n40;
  t71_n39: return -0.037628334015607834;
  t71_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n60;
  t71_n41: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t71_n51;
  t71_n42: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n50;
  t71_n43: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t71_n47;
  t71_n44: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t71_n46;
  t71_n45: return 0.11390656977891922;
  t71_n46: return 0.14339077472686768;
  t71_n47: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t71_n49;
  t71_n48: return 0.1268949955701828;
  t71_n49: return 0.1157807931303978;
  t71_n50: return 0.11875981092453003;
  t71_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n57;
  t71_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n54;
  t71_n53: return 0.03436379134654999;
  t71_n54: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t71_n56;
  t71_n55: return 0.11414231359958649;
  t71_n56: return 0.11086170375347137;
  t71_n57: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n59;
  t71_n58: return 0.11113474518060684;
  t71_n59: return 0.0109631372615695;
  t71_n60: return 0.08171099424362183;
  t71_n61: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t71_n63;
  t71_n62: return 0.0183603186160326;
  t71_n63: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t71_n75;
  t71_n64: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n74;
  t71_n65: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t71_n67;
  t71_n66: return 0.07230564951896667;
  t71_n67: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t71_n73;
  t71_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n72;
  t71_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t71_n71;
  t71_n70: return 0.11932650208473206;
  t71_n71: return 0.13078798353672028;
  t71_n72: return 0.06601675599813461;
  t71_n73: return 0.08826518803834915;
  t71_n74: return 0.02906121499836445;
  t71_n75: return 0.0020279965829104185;
  t71_n76: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t71_n126;
  t71_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t71_n115;
  t71_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t71_n110;
  t71_n79: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n81;
  t71_n80: return 0.004455329850316048;
  t71_n81: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n85;
  t71_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t71_n84;
  t71_n83: return -0.12386781722307205;
  t71_n84: return 0.02124555967748165;
  t71_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t71_n91;
  t71_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t71_n88;
  t71_n87: return -0.0572894923388958;
  t71_n88: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t71_n90;
  t71_n89: return 0.027612388134002686;
  t71_n90: return -0.18022732436656952;
  t71_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t71_n99;
  t71_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t71_n94;
  t71_n93: return -0.012002633884549141;
  t71_n94: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n98;
  t71_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n97;
  t71_n96: return 0.0805961936712265;
  t71_n97: return 0.08329617232084274;
  t71_n98: return 0.0175457876175642;
  t71_n99: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t71_n109;
  t71_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n108;
  t71_n101: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n105;
  t71_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n104;
  t71_n103: return 0.11906526237726212;
  t71_n104: return 0.13948683440685272;
  t71_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t71_n107;
  t71_n106: return 0.1284082531929016;
  t71_n107: return 0.11395497620105743;
  t71_n108: return 0.09122718125581741;
  t71_n109: return -0.08568167686462402;
  t71_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t71_n112;
  t71_n111: return 0.02706010639667511;
  t71_n112: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n114;
  t71_n113: return -0.03982410207390785;
  t71_n114: return 0.07837499678134918;
  t71_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n119;
  t71_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t71_n118;
  t71_n117: return 0.03912839666008949;
  t71_n118: return 0.07490584999322891;
  t71_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t71_n121;
  t71_n120: return 0.06800539791584015;
  t71_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n125;
  t71_n122: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t71_n124;
  t71_n123: return 0.17750845849514008;
  t71_n124: return 0.19549372792243958;
  t71_n125: return -0.10518208891153336;
  t71_n126: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n128;
  t71_n127: return -0.0349697582423687;
  t71_n128: return 0.03188036382198334;
  t71_n129: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t71_n235;
  t71_n130: if (E.getNumReferences() >= 3306424320 /*2368.5*/) goto t71_n228;
  t71_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t71_n157;
  t71_n132: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t71_n142;
  t71_n133: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n137;
  t71_n134: if (E.getNumReferences() >= 3290472448 /*642.5*/) goto t71_n136;
  t71_n135: return -0.026269210502505302;
  t71_n136: return 0.11676861345767975;
  t71_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t71_n139;
  t71_n138: return -0.286746621131897;
  t71_n139: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t71_n141;
  t71_n140: return -0.10727464407682419;
  t71_n141: return 0.013095499947667122;
  t71_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t71_n146;
  t71_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n145;
  t71_n144: return -0.015538513660430908;
  t71_n145: return 0.008450224995613098;
  t71_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n154;
  t71_n147: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t71_n153;
  t71_n148: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t71_n150;
  t71_n149: return 0.048384372144937515;
  t71_n150: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t71_n152;
  t71_n151: return 0.12886157631874084;
  t71_n152: return 0.039975449442863464;
  t71_n153: return 0.012619270011782646;
  t71_n154: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t71_n156;
  t71_n155: return -0.15206214785575867;
  t71_n156: return -0.012818785384297371;
  t71_n157: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t71_n209;
  t71_n158: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t71_n172;
  t71_n159: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t71_n171;
  t71_n160: if (E.getNumReferences() >= 3293822976 /*847.0*/) goto t71_n168;
  t71_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t71_n163;
  t71_n162: return -0.03913263976573944;
  t71_n163: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t71_n165;
  t71_n164: return 0.04420272633433342;
  t71_n165: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t71_n167;
  t71_n166: return 0.09802037477493286;
  t71_n167: return 0.11237724125385284;
  t71_n168: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t71_n170;
  t71_n169: return 0.10167111456394196;
  t71_n170: return 0.06991651654243469;
  t71_n171: return -0.1371055394411087;
  t71_n172: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t71_n180;
  t71_n173: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t71_n179;
  t71_n174: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n176;
  t71_n175: return -0.00958522129803896;
  t71_n176: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t71_n178;
  t71_n177: return 0.04209195077419281;
  t71_n178: return 0.014762339182198048;
  t71_n179: return 0.0026591450441628695;
  t71_n180: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t71_n184;
  t71_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t71_n183;
  t71_n182: return 0.008033058606088161;
  t71_n183: return -0.04337010905146599;
  t71_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t71_n186;
  t71_n185: return 0.040926430374383926;
  t71_n186: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t71_n202;
  t71_n187: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t71_n189;
  t71_n188: return 0.06841433793306351;
  t71_n189: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t71_n197;
  t71_n190: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t71_n194;
  t71_n191: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t71_n193;
  t71_n192: return 0.12053702771663666;
  t71_n193: return -0.10048949718475342;
  t71_n194: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t71_n196;
  t71_n195: return 0.08318018913269043;
  t71_n196: return 0.14366912841796875;
  t71_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t71_n199;
  t71_n198: return 0.06903650611639023;
  t71_n199: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t71_n201;
  t71_n200: return -0.08626771718263626;
  t71_n201: return 0.11745902895927429;
  t71_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t71_n208;
  t71_n203: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t71_n207;
  t71_n204: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t71_n206;
  t71_n205: return 0.19516704976558685;
  t71_n206: return 0.11492402106523514;
  t71_n207: return 0.0834699496626854;
  t71_n208: return 0.12686562538146973;
  t71_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t71_n217;
  t71_n210: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n216;
  t71_n211: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n213;
  t71_n212: return 0.017947712913155556;
  t71_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t71_n215;
  t71_n214: return 0.025970231741666794;
  t71_n215: return 0.05614982172846794;
  t71_n216: return -0.0003852247609756887;
  t71_n217: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t71_n227;
  t71_n218: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t71_n226;
  t71_n219: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t71_n223;
  t71_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t71_n222;
  t71_n221: return -0.2111499309539795;
  t71_n222: return -0.08509495854377747;
  t71_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t71_n225;
  t71_n224: return 0.0724131315946579;
  t71_n225: return 0.10395810753107071;
  t71_n226: return -0.020591989159584045;
  t71_n227: return -0.0004031365388073027;
  t71_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t71_n230;
  t71_n229: return 0.01145070232450962;
  t71_n230: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t71_n234;
  t71_n231: if (E.getNumReferences() >= 3311878144 /*3700.0*/) goto t71_n233;
  t71_n232: return 0.11831936985254288;
  t71_n233: return 0.05520329996943474;
  t71_n234: return 0.026131825521588326;
  t71_n235: return 0.00633607804775238;
  t71_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t71_n248;
  t71_n237: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t71_n239;
  t71_n238: return 0.009919838048517704;
  t71_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t71_n245;
  t71_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t71_n242;
  t71_n241: return 0.04844263195991516;
  t71_n242: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t71_n244;
  t71_n243: return 0.01473129354417324;
  t71_n244: return 0.07034698128700256;
  t71_n245: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t71_n247;
  t71_n246: return -0.0012175880838185549;
  t71_n247: return 0.04449552670121193;
  t71_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t71_n252;
  t71_n249: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t71_n251;
  t71_n250: return 0.012419442646205425;
  t71_n251: return -0.02751644141972065;
  t71_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t71_n254;
  t71_n253: return -0.04832860454916954;
  t71_n254: return 0.024103645235300064;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree72(const Example& E) {
  t72_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t72_n190;
  t72_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t72_n145;
  t72_n2: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t72_n120;
  t72_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t72_n5;
  t72_n4: return -0.09145243465900421;
  t72_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t72_n69;
  t72_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t72_n26;
  t72_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t72_n25;
  t72_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t72_n22;
  t72_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t72_n11;
  t72_n10: return 0.008974392898380756;
  t72_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n13;
  t72_n12: return -0.05956672132015228;
  t72_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n17;
  t72_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n16;
  t72_n15: return 0.09748180955648422;
  t72_n16: return 0.05406728386878967;
  t72_n17: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t72_n19;
  t72_n18: return 0.058034222573041916;
  t72_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n21;
  t72_n20: return 0.09540093690156937;
  t72_n21: return 0.08967337757349014;
  t72_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n24;
  t72_n23: return 0.11320774257183075;
  t72_n24: return 0.04846633970737457;
  t72_n25: return -0.018643783405423164;
  t72_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n28;
  t72_n27: return 0.006740173324942589;
  t72_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n34;
  t72_n29: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t72_n33;
  t72_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n32;
  t72_n31: return 0.11389374732971191;
  t72_n32: return 0.0587376169860363;
  t72_n33: return -0.03579071909189224;
  t72_n34: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t72_n56;
  t72_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t72_n39;
  t72_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t72_n38;
  t72_n37: return -0.005326257552951574;
  t72_n38: return 0.010928434319794178;
  t72_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t72_n55;
  t72_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n52;
  t72_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n43;
  t72_n42: return 0.09452398866415024;
  t72_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t72_n51;
  t72_n44: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t72_n46;
  t72_n45: return 0.052776679396629333;
  t72_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t72_n48;
  t72_n47: return -0.3180740177631378;
  t72_n48: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t72_n50;
  t72_n49: return 0.11182691901922226;
  t72_n50: return -0.1659499853849411;
  t72_n51: return 0.09760354459285736;
  t72_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n54;
  t72_n53: return 0.07730898261070251;
  t72_n54: return 0.03350843861699104;
  t72_n55: return 0.026163123548030853;
  t72_n56: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t72_n58;
  t72_n57: return -0.10288795083761215;
  t72_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t72_n60;
  t72_n59: return -0.12407217919826508;
  t72_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t72_n68;
  t72_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n63;
  t72_n62: return -0.044928573071956635;
  t72_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n65;
  t72_n64: return 0.13260389864444733;
  t72_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n67;
  t72_n66: return -0.051145702600479126;
  t72_n67: return 0.03302215039730072;
  t72_n68: return -0.037298403680324554;
  t72_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t72_n73;
  t72_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n72;
  t72_n71: return -0.13034644722938538;
  t72_n72: return 0.005058859474956989;
  t72_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t72_n101;
  t72_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t72_n84;
  t72_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n77;
  t72_n76: return -0.018655981868505478;
  t72_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n83;
  t72_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t72_n80;
  t72_n79: return -0.011648215353488922;
  t72_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t72_n82;
  t72_n81: return 0.05912117287516594;
  t72_n82: return -0.05899897590279579;
  t72_n83: return 0.022947708144783974;
  t72_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n88;
  t72_n85: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t72_n87;
  t72_n86: return 0.027786988765001297;
  t72_n87: return 0.16629987955093384;
  t72_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n100;
  t72_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t72_n91;
  t72_n90: return 0.049610961228609085;
  t72_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t72_n93;
  t72_n92: return 0.0837985947728157;
  t72_n93: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t72_n95;
  t72_n94: return 0.08851328492164612;
  t72_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n97;
  t72_n96: return 0.14277717471122742;
  t72_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n99;
  t72_n98: return 0.11460921168327332;
  t72_n99: return 0.11027269065380096;
  t72_n100: return 0.00778938177973032;
  t72_n101: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n113;
  t72_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n112;
  t72_n103: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t72_n111;
  t72_n104: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n106;
  t72_n105: return 0.14816047251224518;
  t72_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n110;
  t72_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n109;
  t72_n108: return 0.11732891201972961;
  t72_n109: return 0.13654188811779022;
  t72_n110: return 0.12750226259231567;
  t72_n111: return 0.11318790912628174;
  t72_n112: return 0.09435859322547913;
  t72_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n119;
  t72_n114: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t72_n118;
  t72_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n117;
  t72_n116: return 0.08530531823635101;
  t72_n117: return 0.11478248238563538;
  t72_n118: return 0.07781799882650375;
  t72_n119: return 0.08476965874433517;
  t72_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t72_n128;
  t72_n121: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t72_n123;
  t72_n122: return 0.011153722181916237;
  t72_n123: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t72_n125;
  t72_n124: return 0.030557140707969666;
  t72_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n127;
  t72_n126: return 0.1031181663274765;
  t72_n127: return 0.04582836106419563;
  t72_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t72_n140;
  t72_n129: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t72_n137;
  t72_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t72_n132;
  t72_n131: return -0.0008745536906644702;
  t72_n132: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t72_n136;
  t72_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n135;
  t72_n134: return -0.11665480583906174;
  t72_n135: return 0.03801236301660538;
  t72_n136: return -0.025694632902741432;
  t72_n137: if (E.getNumReferences() >= 3308064768 /*2769.0*/) goto t72_n139;
  t72_n138: return 0.28164324164390564;
  t72_n139: return 0.041999075561761856;
  t72_n140: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t72_n142;
  t72_n141: return 0.0346807986497879;
  t72_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t72_n144;
  t72_n143: return 0.03549237549304962;
  t72_n144: return 0.05586666613817215;
  t72_n145: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t72_n189;
  t72_n146: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t72_n148;
  t72_n147: return -0.013309022411704063;
  t72_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n150;
  t72_n149: return -0.037582967430353165;
  t72_n150: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t72_n154;
  t72_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t72_n153;
  t72_n152: return -0.0780198946595192;
  t72_n153: return -0.01575368642807007;
  t72_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n156;
  t72_n155: return 0.008684852160513401;
  t72_n156: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t72_n176;
  t72_n157: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t72_n161;
  t72_n158: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t72_n160;
  t72_n159: return 0.0034120315685868263;
  t72_n160: return -0.06326930224895477;
  t72_n161: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t72_n167;
  t72_n162: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t72_n166;
  t72_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t72_n165;
  t72_n164: return -0.011600787751376629;
  t72_n165: return 0.06358610838651657;
  t72_n166: return 0.013687360100448132;
  t72_n167: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t72_n175;
  t72_n168: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t72_n170;
  t72_n169: return 0.03070611134171486;
  t72_n170: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t72_n172;
  t72_n171: return 0.0800175815820694;
  t72_n172: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n174;
  t72_n173: return 0.12355715036392212;
  t72_n174: return 0.08318299055099487;
  t72_n175: return -0.051322996616363525;
  t72_n176: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t72_n186;
  t72_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n183;
  t72_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t72_n180;
  t72_n179: return -0.29601192474365234;
  t72_n180: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n182;
  t72_n181: return 0.11283493041992188;
  t72_n182: return 0.09719756245613098;
  t72_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t72_n185;
  t72_n184: return 0.11159912496805191;
  t72_n185: return 0.1013784185051918;
  t72_n186: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t72_n188;
  t72_n187: return 0.038963038474321365;
  t72_n188: return -0.011967112310230732;
  t72_n189: return -0.06786329299211502;
  t72_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t72_n248;
  t72_n191: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t72_n203;
  t72_n192: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t72_n196;
  t72_n193: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t72_n195;
  t72_n194: return 0.040552400052547455;
  t72_n195: return 0.02123742736876011;
  t72_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t72_n198;
  t72_n197: return 0.013917717151343822;
  t72_n198: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t72_n202;
  t72_n199: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t72_n201;
  t72_n200: return -0.13424617052078247;
  t72_n201: return 0.08269128203392029;
  t72_n202: return 3.588245090213604e-05;
  t72_n203: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t72_n205;
  t72_n204: return 0.005311501212418079;
  t72_n205: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t72_n213;
  t72_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n210;
  t72_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t72_n209;
  t72_n208: return 0.0708945170044899;
  t72_n209: return 0.10704824328422546;
  t72_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t72_n212;
  t72_n211: return 0.12170860916376114;
  t72_n212: return 0.11348661035299301;
  t72_n213: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t72_n221;
  t72_n214: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t72_n220;
  t72_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t72_n217;
  t72_n216: return 0.04138105735182762;
  t72_n217: if (E.getNumReferences() >= 3328774656 /*14916.5*/) goto t72_n219;
  t72_n218: return 0.11547242850065231;
  t72_n219: return 0.08458447456359863;
  t72_n220: return -0.01776696927845478;
  t72_n221: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t72_n247;
  t72_n222: if (E.getNumReferences() >= 3329614848 /*15737.0*/) goto t72_n244;
  t72_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t72_n225;
  t72_n224: return 0.04295714199542999;
  t72_n225: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t72_n233;
  t72_n226: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t72_n232;
  t72_n227: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t72_n231;
  t72_n228: if (E.getNumReferences() >= 3319294976 /*6925.5*/) goto t72_n230;
  t72_n229: return 0.1124882698059082;
  t72_n230: return 0.11234139651060104;
  t72_n231: return -0.14325794577598572;
  t72_n232: return 0.035000476986169815;
  t72_n233: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t72_n235;
  t72_n234: return 0.04626661539077759;
  t72_n235: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t72_n243;
  t72_n236: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t72_n238;
  t72_n237: return 0.09011195600032806;
  t72_n238: if (E.getNumReferences() >= 3322565632 /*8853.0*/) goto t72_n242;
  t72_n239: if (E.getNumReferences() >= 3322286592 /*8580.5*/) goto t72_n241;
  t72_n240: return 0.12733455002307892;
  t72_n241: return 0.08314336836338043;
  t72_n242: return 0.11338017135858536;
  t72_n243: return 0.07785721868276596;
  t72_n244: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t72_n246;
  t72_n245: return 0.1161368265748024;
  t72_n246: return 0.10774865001440048;
  t72_n247: return 0.04852414131164551;
  t72_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t72_n250;
  t72_n249: return -0.7045518755912781;
  t72_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t72_n252;
  t72_n251: return -0.038162097334861755;
  t72_n252: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t72_n254;
  t72_n253: return 0.01822161115705967;
  t72_n254: return 0.056333646178245544;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree73(const Example& E) {
  t73_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t73_n234;
  t73_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t73_n33;
  t73_n2: if (E.getNumReferences() >= 3324968960 /*11200.0*/) goto t73_n26;
  t73_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t73_n5;
  t73_n4: return 0.0008211841341108084;
  t73_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t73_n7;
  t73_n6: return 0.003174439538270235;
  t73_n7: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t73_n19;
  t73_n8: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t73_n10;
  t73_n9: return 0.009691997431218624;
  t73_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t73_n12;
  t73_n11: return 0.0238500963896513;
  t73_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t73_n18;
  t73_n13: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t73_n15;
  t73_n14: return -0.013926979154348373;
  t73_n15: if (E.getNumReferences() >= 3273555968 /*158.5*/) goto t73_n17;
  t73_n16: return 0.09764174371957779;
  t73_n17: return 0.03844006359577179;
  t73_n18: return 0.046041641384363174;
  t73_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t73_n23;
  t73_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t73_n22;
  t73_n21: return 0.04186335206031799;
  t73_n22: return -0.08391193300485611;
  t73_n23: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t73_n25;
  t73_n24: return 0.05231378600001335;
  t73_n25: return 0.06990315020084381;
  t73_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t73_n32;
  t73_n27: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t73_n29;
  t73_n28: return 0.017125073820352554;
  t73_n29: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t73_n31;
  t73_n30: return 0.022571494802832603;
  t73_n31: return 0.09802475571632385;
  t73_n32: return 0.0437740720808506;
  t73_n33: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t73_n109;
  t73_n34: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t73_n36;
  t73_n35: return -0.006144518498331308;
  t73_n36: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t73_n94;
  t73_n37: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t73_n93;
  t73_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t73_n40;
  t73_n39: return -0.010236942209303379;
  t73_n40: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t73_n74;
  t73_n41: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t73_n73;
  t73_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t73_n66;
  t73_n43: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t73_n45;
  t73_n44: return 0.03182004764676094;
  t73_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t73_n47;
  t73_n46: return 0.08048950880765915;
  t73_n47: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t73_n49;
  t73_n48: return 0.021176116541028023;
  t73_n49: if (E.getNumReferences() >= 3275980800 /*195.5*/) goto t73_n61;
  t73_n50: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t73_n58;
  t73_n51: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t73_n57;
  t73_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n54;
  t73_n53: return 0.12377680838108063;
  t73_n54: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t73_n56;
  t73_n55: return -0.11567174643278122;
  t73_n56: return 0.11979330331087112;
  t73_n57: return 0.13334359228610992;
  t73_n58: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t73_n60;
  t73_n59: return 0.10386400669813156;
  t73_n60: return -0.12275438755750656;
  t73_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n65;
  t73_n62: if (E.getNumReferences() >= 3290087424 /*619.0*/) goto t73_n64;
  t73_n63: return 0.08322305232286453;
  t73_n64: return 0.1320677101612091;
  t73_n65: return 0.12306267023086548;
  t73_n66: if (E.getNumReferences() >= 3280977920 /*287.5*/) goto t73_n68;
  t73_n67: return 0.05800643563270569;
  t73_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t73_n70;
  t73_n69: return 0.09877585619688034;
  t73_n70: if (E.getNumReferences() >= 3293446144 /*824.0*/) goto t73_n72;
  t73_n71: return 0.13195809721946716;
  t73_n72: return 0.09473424404859543;
  t73_n73: return 0.02450399287045002;
  t73_n74: if (E.getNumReferences() >= 3294625792 /*896.0*/) goto t73_n82;
  t73_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t73_n77;
  t73_n76: return -0.02800241857767105;
  t73_n77: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t73_n81;
  t73_n78: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t73_n80;
  t73_n79: return -0.5452554821968079;
  t73_n80: return 0.11183785647153854;
  t73_n81: return 0.02417987771332264;
  t73_n82: if (E.getNumReferences() >= 3294732288 /*902.5*/) goto t73_n86;
  t73_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n85;
  t73_n84: return -0.013579671271145344;
  t73_n85: return 0.10317739844322205;
  t73_n86: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t73_n90;
  t73_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n89;
  t73_n88: return 0.041663188487291336;
  t73_n89: return -0.040039412677288055;
  t73_n90: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t73_n92;
  t73_n91: return 0.10250308364629745;
  t73_n92: return 0.059279367327690125;
  t73_n93: return -0.1793050765991211;
  t73_n94: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t73_n100;
  t73_n95: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t73_n97;
  t73_n96: return 0.05240543559193611;
  t73_n97: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t73_n99;
  t73_n98: return 0.06449808180332184;
  t73_n99: return 0.08775494992733002;
  t73_n100: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t73_n104;
  t73_n101: if (E.getNumReferences() >= 3306219520 /*2318.5*/) goto t73_n103;
  t73_n102: return 0.06275279074907303;
  t73_n103: return 0.05540318414568901;
  t73_n104: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t73_n108;
  t73_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n107;
  t73_n106: return -0.10832421481609344;
  t73_n107: return 0.15652334690093994;
  t73_n108: return 0.048748914152383804;
  t73_n109: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t73_n115;
  t73_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t73_n114;
  t73_n111: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t73_n113;
  t73_n112: return -0.0962938740849495;
  t73_n113: return -0.5757347345352173;
  t73_n114: return -0.037100695073604584;
  t73_n115: if (E.getNumReferences() >= 3288997888 /*552.5*/) goto t73_n145;
  t73_n116: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t73_n144;
  t73_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t73_n119;
  t73_n118: return -0.020698558539152145;
  t73_n119: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t73_n143;
  t73_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t73_n122;
  t73_n121: return -0.008240621536970139;
  t73_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t73_n124;
  t73_n123: return 0.015198169276118279;
  t73_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t73_n126;
  t73_n125: return -0.02821389026939869;
  t73_n126: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n128;
  t73_n127: return 0.05930671840906143;
  t73_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t73_n132;
  t73_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t73_n131;
  t73_n130: return -0.012629859149456024;
  t73_n131: return 0.05939529836177826;
  t73_n132: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n136;
  t73_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t73_n135;
  t73_n134: return 0.0951073169708252;
  t73_n135: return 0.11659520864486694;
  t73_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t73_n142;
  t73_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t73_n139;
  t73_n138: return 0.13254790008068085;
  t73_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t73_n141;
  t73_n140: return -0.05656004324555397;
  t73_n141: return 0.17463083565235138;
  t73_n142: return 0.03182118758559227;
  t73_n143: return -0.13886532187461853;
  t73_n144: return -0.060955073684453964;
  t73_n145: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t73_n147;
  t73_n146: return -0.00032504519913345575;
  t73_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t73_n197;
  t73_n148: if (E.getNumReferences() >= 3313939456 /*4310.5*/) goto t73_n150;
  t73_n149: return 0.0047228457406163216;
  t73_n150: if (E.getNumReferences() >= 3313967104 /*4324.0*/) goto t73_n154;
  t73_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t73_n153;
  t73_n152: return 0.11537405848503113;
  t73_n153: return -0.10170615464448929;
  t73_n154: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t73_n196;
  t73_n155: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t73_n189;
  t73_n156: if (E.getNumReferences() >= 3334608896 /*24844.0*/) goto t73_n184;
  t73_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t73_n173;
  t73_n158: if (E.getNumReferences() >= 3319769088 /*7157.0*/) goto t73_n160;
  t73_n159: return 0.04834446310997009;
  t73_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t73_n162;
  t73_n161: return 0.0496232733130455;
  t73_n162: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n164;
  t73_n163: return 0.07504616677761078;
  t73_n164: if (E.getNumReferences() >= 3325492736 /*11711.5*/) goto t73_n172;
  t73_n165: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t73_n167;
  t73_n166: return 0.0898984968662262;
  t73_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n171;
  t73_n168: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t73_n170;
  t73_n169: return 0.11282537132501602;
  t73_n170: return 0.11807354539632797;
  t73_n171: return -0.12991268932819366;
  t73_n172: return 0.053681761026382446;
  t73_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t73_n183;
  t73_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t73_n182;
  t73_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t73_n177;
  t73_n176: return 0.14996445178985596;
  t73_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n181;
  t73_n178: if (E.getNumReferences() >= 3317499904 /*6049.0*/) goto t73_n180;
  t73_n179: return 0.11532872915267944;
  t73_n180: return 0.09969661384820938;
  t73_n181: return 0.11130837351083755;
  t73_n182: return -0.1635984182357788;
  t73_n183: return 0.11843398213386536;
  t73_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t73_n188;
  t73_n185: if (E.getNumReferences() >= 3335106048 /*25815.0*/) goto t73_n187;
  t73_n186: return -0.8965163230895996;
  t73_n187: return -0.04644164443016052;
  t73_n188: return 0.030947793275117874;
  t73_n189: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t73_n195;
  t73_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t73_n192;
  t73_n191: return 0.014394156634807587;
  t73_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t73_n194;
  t73_n193: return 0.09624797850847244;
  t73_n194: return 0.11269960552453995;
  t73_n195: return 0.048959892243146896;
  t73_n196: return -0.016717178747057915;
  t73_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t73_n221;
  t73_n198: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t73_n200;
  t73_n199: return 0.04176165163516998;
  t73_n200: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t73_n202;
  t73_n201: return 0.1198195293545723;
  t73_n202: if (E.getNumReferences() >= 3334377216 /*24391.5*/) goto t73_n220;
  t73_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t73_n215;
  t73_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t73_n208;
  t73_n205: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t73_n207;
  t73_n206: return -0.009411809034645557;
  t73_n207: return 0.09196814149618149;
  t73_n208: if (E.getNumReferences() >= 3332719104 /*21153.0*/) goto t73_n210;
  t73_n209: return -0.1204800009727478;
  t73_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t73_n214;
  t73_n211: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n213;
  t73_n212: return 0.12123578041791916;
  t73_n213: return 0.103324294090271;
  t73_n214: return 0.11644239723682404;
  t73_n215: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n219;
  t73_n216: if (E.getNumReferences() >= 3332878080 /*21463.5*/) goto t73_n218;
  t73_n217: return 0.07331069558858871;
  t73_n218: return 0.10499155521392822;
  t73_n219: return 0.10958490520715714;
  t73_n220: return 0.031035684049129486;
  t73_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t73_n227;
  t73_n222: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t73_n226;
  t73_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t73_n225;
  t73_n224: return 0.018565984442830086;
  t73_n225: return 0.06920643895864487;
  t73_n226: return 0.05073300749063492;
  t73_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t73_n233;
  t73_n228: if (E.getNumReferences() >= 3325197824 /*11423.5*/) goto t73_n230;
  t73_n229: return 0.12783001363277435;
  t73_n230: if (E.getNumReferences() >= 3333374720 /*22433.5*/) goto t73_n232;
  t73_n231: return 0.10907315462827682;
  t73_n232: return 0.09658346325159073;
  t73_n233: return 0.06496864557266235;
  t73_n234: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t73_n246;
  t73_n235: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t73_n237;
  t73_n236: return 0.008465767838060856;
  t73_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t73_n243;
  t73_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t73_n240;
  t73_n239: return -0.11773887276649475;
  t73_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t73_n242;
  t73_n241: return 0.04938792437314987;
  t73_n242: return 0.02383885160088539;
  t73_n243: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t73_n245;
  t73_n244: return -0.0031014145351946354;
  t73_n245: return 0.045542068779468536;
  t73_n246: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t73_n254;
  t73_n247: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t73_n253;
  t73_n248: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t73_n252;
  t73_n249: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t73_n251;
  t73_n250: return -0.1978420466184616;
  t73_n251: return 0.01674613542854786;
  t73_n252: return 0.020139407366514206;
  t73_n253: return -0.015019124373793602;
  t73_n254: return 0.054418738931417465;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree74(const Example& E) {
  t74_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t74_n230;
  t74_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t74_n181;
  t74_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t74_n32;
  t74_n3: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t74_n5;
  t74_n4: return 0.0006696001510135829;
  t74_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n7;
  t74_n6: return 0.006410025525838137;
  t74_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t74_n11;
  t74_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n10;
  t74_n9: return -0.10695401579141617;
  t74_n10: return 0.05760873481631279;
  t74_n11: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n25;
  t74_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n24;
  t74_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t74_n15;
  t74_n14: return 0.028919130563735962;
  t74_n15: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t74_n17;
  t74_n16: return 0.02903536520898342;
  t74_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t74_n23;
  t74_n18: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t74_n20;
  t74_n19: return 0.04199433699250221;
  t74_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t74_n22;
  t74_n21: return 0.03763628751039505;
  t74_n22: return 0.06198114529252052;
  t74_n23: return 0.03653471916913986;
  t74_n24: return 0.012991616502404213;
  t74_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t74_n29;
  t74_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t74_n28;
  t74_n27: return -0.17730110883712769;
  t74_n28: return -0.018087340518832207;
  t74_n29: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t74_n31;
  t74_n30: return -0.0013212681515142322;
  t74_n31: return 0.04323635995388031;
  t74_n32: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t74_n72;
  t74_n33: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t74_n35;
  t74_n34: return -0.005686386954039335;
  t74_n35: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t74_n37;
  t74_n36: return 0.02216263674199581;
  t74_n37: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t74_n41;
  t74_n38: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t74_n40;
  t74_n39: return 0.06332841515541077;
  t74_n40: return 0.07976129651069641;
  t74_n41: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t74_n43;
  t74_n42: return 0.06747472286224365;
  t74_n43: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t74_n57;
  t74_n44: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t74_n52;
  t74_n45: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t74_n51;
  t74_n46: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t74_n48;
  t74_n47: return -0.01289917528629303;
  t74_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t74_n50;
  t74_n49: return -0.10096262395381927;
  t74_n50: return 0.12590235471725464;
  t74_n51: return 0.15692441165447235;
  t74_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t74_n54;
  t74_n53: return 0.038714636117219925;
  t74_n54: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t74_n56;
  t74_n55: return -0.42555931210517883;
  t74_n56: return 0.11302125453948975;
  t74_n57: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t74_n59;
  t74_n58: return 0.06526617705821991;
  t74_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t74_n61;
  t74_n60: return 0.050306592136621475;
  t74_n61: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t74_n67;
  t74_n62: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t74_n64;
  t74_n63: return 0.09368803352117538;
  t74_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t74_n66;
  t74_n65: return 0.16691552102565765;
  t74_n66: return 0.15957945585250854;
  t74_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t74_n69;
  t74_n68: return 0.1562146544456482;
  t74_n69: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t74_n71;
  t74_n70: return 0.12559424340724945;
  t74_n71: return 0.11416976898908615;
  t74_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t74_n150;
  t74_n73: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t74_n81;
  t74_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t74_n76;
  t74_n75: return -0.04475809633731842;
  t74_n76: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t74_n80;
  t74_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t74_n79;
  t74_n78: return -0.26731985807418823;
  t74_n79: return -0.06397204846143723;
  t74_n80: return 0.052483025938272476;
  t74_n81: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n83;
  t74_n82: return -0.06090843304991722;
  t74_n83: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t74_n149;
  t74_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t74_n126;
  t74_n85: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t74_n117;
  t74_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t74_n88;
  t74_n87: return -0.13053588569164276;
  t74_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n90;
  t74_n89: return -0.0047847554087638855;
  t74_n90: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t74_n114;
  t74_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n95;
  t74_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t74_n94;
  t74_n93: return -0.010925321839749813;
  t74_n94: return 0.06024845689535141;
  t74_n95: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n97;
  t74_n96: return 0.042515333741903305;
  t74_n97: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t74_n107;
  t74_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t74_n100;
  t74_n99: return 0.030341768637299538;
  t74_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t74_n102;
  t74_n101: return 0.06044192612171173;
  t74_n102: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t74_n104;
  t74_n103: return -0.7695448398590088;
  t74_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t74_n106;
  t74_n105: return -0.10762564092874527;
  t74_n106: return 0.11905276775360107;
  t74_n107: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t74_n113;
  t74_n108: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t74_n112;
  t74_n109: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t74_n111;
  t74_n110: return 0.1082824096083641;
  t74_n111: return 0.07735010236501694;
  t74_n112: return 0.048418715596199036;
  t74_n113: return 0.06573942303657532;
  t74_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t74_n116;
  t74_n115: return 0.06807728856801987;
  t74_n116: return 0.10545092821121216;
  t74_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n119;
  t74_n118: return 0.04913511127233505;
  t74_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n125;
  t74_n120: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t74_n124;
  t74_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n123;
  t74_n122: return 0.08614400029182434;
  t74_n123: return 0.15072163939476013;
  t74_n124: return -0.09726296365261078;
  t74_n125: return 0.05654335767030716;
  t74_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n128;
  t74_n127: return 0.1084766685962677;
  t74_n128: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n130;
  t74_n129: return 0.041226983070373535;
  t74_n130: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t74_n140;
  t74_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t74_n133;
  t74_n132: return 0.07294178754091263;
  t74_n133: if (E.getNumReferences() >= 3291119616 /*682.0*/) goto t74_n139;
  t74_n134: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t74_n138;
  t74_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t74_n137;
  t74_n136: return 0.13879667222499847;
  t74_n137: return 0.08501172065734863;
  t74_n138: return -1.5767089128494263;
  t74_n139: return 0.10978098213672638;
  t74_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t74_n146;
  t74_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n143;
  t74_n142: return 0.06383686512708664;
  t74_n143: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t74_n145;
  t74_n144: return -0.28153613209724426;
  t74_n145: return 0.14795951545238495;
  t74_n146: if (E.getNumReferences() >= 3316710400 /*5663.5*/) goto t74_n148;
  t74_n147: return 0.05006154254078865;
  t74_n148: return 0.08966038376092911;
  t74_n149: return 0.003335708985105157;
  t74_n150: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t74_n180;
  t74_n151: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t74_n153;
  t74_n152: return -0.007726233918219805;
  t74_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t74_n157;
  t74_n154: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t74_n156;
  t74_n155: return 0.019109180197119713;
  t74_n156: return -0.1109665036201477;
  t74_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t74_n163;
  t74_n158: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t74_n160;
  t74_n159: return 0.021148880943655968;
  t74_n160: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n162;
  t74_n161: return 0.13034231960773468;
  t74_n162: return 0.08481350541114807;
  t74_n163: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t74_n179;
  t74_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n168;
  t74_n165: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t74_n167;
  t74_n166: return -0.0013734424719586968;
  t74_n167: return 0.10229814797639847;
  t74_n168: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t74_n176;
  t74_n169: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t74_n175;
  t74_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t74_n172;
  t74_n171: return 0.09541306644678116;
  t74_n172: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t74_n174;
  t74_n173: return 0.11198475956916809;
  t74_n174: return 0.0873652920126915;
  t74_n175: return 0.09910009801387787;
  t74_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n178;
  t74_n177: return 0.11495780199766159;
  t74_n178: return -0.10331443697214127;
  t74_n179: return 0.03751181811094284;
  t74_n180: return -0.0640980452299118;
  t74_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t74_n183;
  t74_n182: return -0.00822228193283081;
  t74_n183: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t74_n211;
  t74_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t74_n186;
  t74_n185: return 0.03469590097665787;
  t74_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t74_n188;
  t74_n187: return 0.0027367197908461094;
  t74_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t74_n210;
  t74_n189: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t74_n201;
  t74_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t74_n192;
  t74_n191: return -0.1036909893155098;
  t74_n192: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t74_n200;
  t74_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n199;
  t74_n194: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t74_n196;
  t74_n195: return 0.11961387097835541;
  t74_n196: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t74_n198;
  t74_n197: return 0.1246563121676445;
  t74_n198: return 0.11510356515645981;
  t74_n199: return 0.11569403111934662;
  t74_n200: return -0.4182620048522949;
  t74_n201: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t74_n207;
  t74_n202: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n204;
  t74_n203: return 0.045310404151678085;
  t74_n204: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t74_n206;
  t74_n205: return 0.11771708726882935;
  t74_n206: return 0.07892005890607834;
  t74_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n209;
  t74_n208: return 0.1141238734126091;
  t74_n209: return 0.00949164293706417;
  t74_n210: return 0.08011465519666672;
  t74_n211: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t74_n213;
  t74_n212: return 0.015622173435986042;
  t74_n213: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t74_n229;
  t74_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t74_n228;
  t74_n215: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t74_n221;
  t74_n216: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t74_n220;
  t74_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n219;
  t74_n218: return 0.08048352599143982;
  t74_n219: return 0.11520245671272278;
  t74_n220: return -0.10766060650348663;
  t74_n221: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t74_n227;
  t74_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t74_n226;
  t74_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t74_n225;
  t74_n224: return 0.11547364294528961;
  t74_n225: return 0.1278180181980133;
  t74_n226: return 0.08025994896888733;
  t74_n227: return 0.08944357931613922;
  t74_n228: return 0.012987065128982067;
  t74_n229: return -0.0021319251973181963;
  t74_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t74_n254;
  t74_n231: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t74_n253;
  t74_n232: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t74_n238;
  t74_n233: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t74_n235;
  t74_n234: return -0.2127716839313507;
  t74_n235: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t74_n237;
  t74_n236: return 0.028126386925578117;
  t74_n237: return 0.06867407262325287;
  t74_n238: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t74_n240;
  t74_n239: return 0.015755824744701385;
  t74_n240: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t74_n242;
  t74_n241: return 0.027938485145568848;
  t74_n242: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t74_n252;
  t74_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t74_n251;
  t74_n244: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t74_n246;
  t74_n245: return 0.12208757549524307;
  t74_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t74_n250;
  t74_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t74_n249;
  t74_n248: return 0.10642676055431366;
  t74_n249: return 0.09177760034799576;
  t74_n250: return 0.0304380152374506;
  t74_n251: return 0.03105471283197403;
  t74_n252: return 0.055319253355264664;
  t74_n253: return -0.00011407351848902181;
  t74_n254: return 0.015552625991404057;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree75(const Example& E) {
  t75_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t75_n208;
  t75_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t75_n189;
  t75_n2: if (E.getNumReferences() >= 3324968960 /*11200.0*/) goto t75_n168;
  t75_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t75_n5;
  t75_n4: return -0.0904168039560318;
  t75_n5: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t75_n167;
  t75_n6: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t75_n102;
  t75_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t75_n19;
  t75_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t75_n18;
  t75_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t75_n11;
  t75_n10: return -0.008241844363510609;
  t75_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n15;
  t75_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n14;
  t75_n13: return 0.09463326632976532;
  t75_n14: return 0.02485729567706585;
  t75_n15: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t75_n17;
  t75_n16: return 0.05097726732492447;
  t75_n17: return 0.08411869406700134;
  t75_n18: return -0.09184373915195465;
  t75_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n51;
  t75_n20: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t75_n22;
  t75_n21: return -0.000567403098102659;
  t75_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n24;
  t75_n23: return 0.0008690996328368783;
  t75_n24: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t75_n42;
  t75_n25: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t75_n27;
  t75_n26: return 0.026369882747530937;
  t75_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t75_n31;
  t75_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t75_n30;
  t75_n29: return -0.0005937865353189409;
  t75_n30: return 0.05716024711728096;
  t75_n31: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t75_n41;
  t75_n32: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t75_n34;
  t75_n33: return 0.013069610111415386;
  t75_n34: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t75_n36;
  t75_n35: return 0.06787335127592087;
  t75_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t75_n38;
  t75_n37: return 0.08706019073724747;
  t75_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t75_n40;
  t75_n39: return -0.10381922870874405;
  t75_n40: return 0.11365028470754623;
  t75_n41: return 0.07800186425447464;
  t75_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t75_n48;
  t75_n43: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t75_n45;
  t75_n44: return 0.10784222930669785;
  t75_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t75_n47;
  t75_n46: return -0.1737380474805832;
  t75_n47: return -0.022171664983034134;
  t75_n48: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t75_n50;
  t75_n49: return -0.002333443844690919;
  t75_n50: return 0.041177406907081604;
  t75_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t75_n65;
  t75_n52: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t75_n62;
  t75_n53: if (E.getNumReferences() >= 3316676608 /*5647.0*/) goto t75_n61;
  t75_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t75_n56;
  t75_n55: return 0.04708545655012131;
  t75_n56: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t75_n60;
  t75_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n59;
  t75_n58: return 0.11300810426473618;
  t75_n59: return -0.15542390942573547;
  t75_n60: return 0.04877963662147522;
  t75_n61: return 0.10285380482673645;
  t75_n62: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t75_n64;
  t75_n63: return -0.06423246115446091;
  t75_n64: return -0.01710072159767151;
  t75_n65: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t75_n89;
  t75_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t75_n70;
  t75_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t75_n69;
  t75_n68: return -0.003474958473816514;
  t75_n69: return 0.010449814610183239;
  t75_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t75_n88;
  t75_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n85;
  t75_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n74;
  t75_n73: return 0.14308597147464752;
  t75_n74: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t75_n80;
  t75_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t75_n79;
  t75_n76: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t75_n78;
  t75_n77: return -0.005901901517063379;
  t75_n78: return 0.08669430762529373;
  t75_n79: return 0.09717860072851181;
  t75_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n82;
  t75_n81: return -0.11569187045097351;
  t75_n82: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n84;
  t75_n83: return 0.10867325961589813;
  t75_n84: return -0.16820934414863586;
  t75_n85: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n87;
  t75_n86: return 0.08036213368177414;
  t75_n87: return 0.03233272209763527;
  t75_n88: return 0.02207236737012863;
  t75_n89: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t75_n91;
  t75_n90: return -0.09781377017498016;
  t75_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t75_n93;
  t75_n92: return -0.11868148297071457;
  t75_n93: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t75_n101;
  t75_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n96;
  t75_n95: return -0.04217727109789848;
  t75_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n98;
  t75_n97: return -0.026103336364030838;
  t75_n98: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n100;
  t75_n99: return 0.1372128576040268;
  t75_n100: return 0.029331211000680923;
  t75_n101: return -0.03129812702536583;
  t75_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t75_n126;
  t75_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n105;
  t75_n104: return -0.03806176781654358;
  t75_n105: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n121;
  t75_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n112;
  t75_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n109;
  t75_n108: return 0.02906663715839386;
  t75_n109: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t75_n111;
  t75_n110: return 0.027569977566599846;
  t75_n111: return -0.1762150228023529;
  t75_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t75_n114;
  t75_n113: return -0.005810008849948645;
  t75_n114: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t75_n120;
  t75_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n119;
  t75_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t75_n118;
  t75_n117: return 0.095738984644413;
  t75_n118: return 0.095374695956707;
  t75_n119: return 0.05364629626274109;
  t75_n120: return 0.01009997259825468;
  t75_n121: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n123;
  t75_n122: return -0.022261643782258034;
  t75_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n125;
  t75_n124: return 0.07842114567756653;
  t75_n125: return 0.016845285892486572;
  t75_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t75_n148;
  t75_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t75_n131;
  t75_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n130;
  t75_n129: return -0.019480399787425995;
  t75_n130: return 0.02602410688996315;
  t75_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n133;
  t75_n132: return 0.024207694455981255;
  t75_n133: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n147;
  t75_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t75_n136;
  t75_n135: return 0.04599772021174431;
  t75_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t75_n138;
  t75_n137: return 0.07901700586080551;
  t75_n138: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n140;
  t75_n139: return 0.08518686145544052;
  t75_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n142;
  t75_n141: return 0.13856889307498932;
  t75_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n144;
  t75_n143: return 0.11222730576992035;
  t75_n144: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t75_n146;
  t75_n145: return -0.10706224292516708;
  t75_n146: return 0.1202009841799736;
  t75_n147: return 0.0061248852871358395;
  t75_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n160;
  t75_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n159;
  t75_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t75_n158;
  t75_n151: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n153;
  t75_n152: return 0.13111086189746857;
  t75_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n157;
  t75_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t75_n156;
  t75_n155: return 0.11409441381692886;
  t75_n156: return 0.13106076419353485;
  t75_n157: return 0.1275779902935028;
  t75_n158: return 0.11062607169151306;
  t75_n159: return 0.08939637243747711;
  t75_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n166;
  t75_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t75_n165;
  t75_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n164;
  t75_n163: return 0.08152207732200623;
  t75_n164: return 0.11376751959323883;
  t75_n165: return 0.07686042040586472;
  t75_n166: return 0.08305396139621735;
  t75_n167: return -0.08605776727199554;
  t75_n168: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t75_n182;
  t75_n169: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t75_n175;
  t75_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n172;
  t75_n171: return 0.3320293426513672;
  t75_n172: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t75_n174;
  t75_n173: return 0.007333116605877876;
  t75_n174: return 0.17811445891857147;
  t75_n175: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t75_n177;
  t75_n176: return 0.025862064212560654;
  t75_n177: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t75_n181;
  t75_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n180;
  t75_n179: return 0.14313814043998718;
  t75_n180: return 0.07834864407777786;
  t75_n181: return -0.025416487827897072;
  t75_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n188;
  t75_n183: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t75_n185;
  t75_n184: return 0.017386402934789658;
  t75_n185: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t75_n187;
  t75_n186: return 0.021359283477067947;
  t75_n187: return 0.0961955264210701;
  t75_n188: return 0.04206709936261177;
  t75_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t75_n207;
  t75_n190: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t75_n192;
  t75_n191: return -0.057283490896224976;
  t75_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t75_n204;
  t75_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n197;
  t75_n194: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t75_n196;
  t75_n195: return -0.007521668449044228;
  t75_n196: return -0.1148671880364418;
  t75_n197: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t75_n199;
  t75_n198: return 0.017947833985090256;
  t75_n199: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t75_n203;
  t75_n200: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t75_n202;
  t75_n201: return -0.11005115509033203;
  t75_n202: return 0.09606858342885971;
  t75_n203: return -0.058628056198358536;
  t75_n204: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t75_n206;
  t75_n205: return 0.027053629979491234;
  t75_n206: return 0.13659057021141052;
  t75_n207: return -0.0038868889678269625;
  t75_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t75_n252;
  t75_n209: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t75_n213;
  t75_n210: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t75_n212;
  t75_n211: return 0.02525823749601841;
  t75_n212: return 0.041260696947574615;
  t75_n213: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t75_n231;
  t75_n214: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t75_n226;
  t75_n215: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t75_n217;
  t75_n216: return 0.0027727577835321426;
  t75_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t75_n221;
  t75_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n220;
  t75_n219: return 0.02124938741326332;
  t75_n220: return -0.0004779496230185032;
  t75_n221: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t75_n223;
  t75_n222: return 0.04227396100759506;
  t75_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t75_n225;
  t75_n224: return 0.038583628833293915;
  t75_n225: return 0.07122763246297836;
  t75_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t75_n228;
  t75_n227: return -0.059455111622810364;
  t75_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t75_n230;
  t75_n229: return -0.01669161207973957;
  t75_n230: return 0.04630691930651665;
  t75_n231: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t75_n239;
  t75_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n236;
  t75_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t75_n235;
  t75_n234: return 0.06534349918365479;
  t75_n235: return 0.10557905584573746;
  t75_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t75_n238;
  t75_n237: return 0.12125342339277267;
  t75_n238: return 0.11220629513263702;
  t75_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t75_n247;
  t75_n240: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t75_n246;
  t75_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t75_n243;
  t75_n242: return 0.041039399802684784;
  t75_n243: if (E.getNumReferences() >= 3328774656 /*14916.5*/) goto t75_n245;
  t75_n244: return 0.11428388953208923;
  t75_n245: return 0.08217563480138779;
  t75_n246: return -0.018885938450694084;
  t75_n247: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t75_n251;
  t75_n248: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t75_n250;
  t75_n249: return 0.0672244057059288;
  t75_n250: return 0.112042136490345;
  t75_n251: return 0.04681795835494995;
  t75_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t75_n254;
  t75_n253: return -0.03795398399233818;
  t75_n254: return 0.0163880567997694;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree76(const Example& E) {
  t76_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t76_n230;
  t76_n1: if (E.getNumReferences() >= 3304779776 /*2007.5*/) goto t76_n133;
  t76_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t76_n82;
  t76_n3: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t76_n49;
  t76_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t76_n44;
  t76_n5: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t76_n7;
  t76_n6: return 0.0005468350718729198;
  t76_n7: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t76_n15;
  t76_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n10;
  t76_n9: return 0.008156634867191315;
  t76_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t76_n14;
  t76_n11: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t76_n13;
  t76_n12: return 0.023986244574189186;
  t76_n13: return 0.055791549384593964;
  t76_n14: return 0.03874659910798073;
  t76_n15: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t76_n21;
  t76_n16: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t76_n18;
  t76_n17: return 0.06513924896717072;
  t76_n18: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t76_n20;
  t76_n19: return 0.07777409255504608;
  t76_n20: return 0.08924373239278793;
  t76_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t76_n23;
  t76_n22: return 0.04000730812549591;
  t76_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t76_n25;
  t76_n24: return 0.06563470512628555;
  t76_n25: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t76_n35;
  t76_n26: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t76_n28;
  t76_n27: return 0.09320685267448425;
  t76_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n30;
  t76_n29: return 0.05607953667640686;
  t76_n30: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t76_n34;
  t76_n31: if (E.getFilterLength() >= 3242196992 /*12.0*/) goto t76_n33;
  t76_n32: return 0.11426982283592224;
  t76_n33: return 0.1661926507949829;
  t76_n34: return 0.10719461739063263;
  t76_n35: if (E.getFilterLength() >= 3245867008 /*15.5*/) goto t76_n37;
  t76_n36: return 0.10584205389022827;
  t76_n37: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t76_n41;
  t76_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t76_n40;
  t76_n39: return 0.059271037578582764;
  t76_n40: return 0.11059929430484772;
  t76_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t76_n43;
  t76_n42: return 0.12595206499099731;
  t76_n43: return 0.15139897167682648;
  t76_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t76_n46;
  t76_n45: return 0.034818727523088455;
  t76_n46: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t76_n48;
  t76_n47: return 0.0344441793859005;
  t76_n48: return 0.06550610065460205;
  t76_n49: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t76_n69;
  t76_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t76_n52;
  t76_n51: return -0.049524303525686264;
  t76_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t76_n54;
  t76_n53: return -0.007647773716598749;
  t76_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n56;
  t76_n55: return -0.0023124851286411285;
  t76_n56: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t76_n58;
  t76_n57: return 0.008214760571718216;
  t76_n58: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t76_n68;
  t76_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t76_n61;
  t76_n60: return 0.047842223197221756;
  t76_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t76_n63;
  t76_n62: return -1.745175541145727e-05;
  t76_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t76_n67;
  t76_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t76_n66;
  t76_n65: return -0.11949720233678818;
  t76_n66: return 0.11334889382123947;
  t76_n67: return 0.10318152606487274;
  t76_n68: return -0.11774799227714539;
  t76_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t76_n71;
  t76_n70: return -0.05266650393605232;
  t76_n71: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t76_n73;
  t76_n72: return -0.07096695154905319;
  t76_n73: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t76_n75;
  t76_n74: return -0.016733642667531967;
  t76_n75: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t76_n77;
  t76_n76: return 0.04817560315132141;
  t76_n77: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t76_n79;
  t76_n78: return 0.06850282847881317;
  t76_n79: if (E.getNumReferences() >= 3286564864 /*458.0*/) goto t76_n81;
  t76_n80: return 0.13051718473434448;
  t76_n81: return 0.07547803968191147;
  t76_n82: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t76_n96;
  t76_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t76_n87;
  t76_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t76_n86;
  t76_n85: return -0.04712958633899689;
  t76_n86: return -0.02028624527156353;
  t76_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n95;
  t76_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n92;
  t76_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n91;
  t76_n90: return 0.09227734804153442;
  t76_n91: return 0.01670435443520546;
  t76_n92: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t76_n94;
  t76_n93: return 0.041397031396627426;
  t76_n94: return 0.07887017726898193;
  t76_n95: return -0.06624539196491241;
  t76_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t76_n98;
  t76_n97: return 0.0001914749591378495;
  t76_n98: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t76_n102;
  t76_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t76_n101;
  t76_n100: return -0.0173349529504776;
  t76_n101: return 0.01196307223290205;
  t76_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t76_n120;
  t76_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t76_n105;
  t76_n104: return 0.0035209027118980885;
  t76_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n107;
  t76_n106: return 0.02448834665119648;
  t76_n107: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n119;
  t76_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t76_n110;
  t76_n109: return 0.04353887960314751;
  t76_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t76_n112;
  t76_n111: return 0.07347958534955978;
  t76_n112: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t76_n114;
  t76_n113: return 0.08201462030410767;
  t76_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n118;
  t76_n115: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t76_n117;
  t76_n116: return 0.12249799072742462;
  t76_n117: return 0.11830440163612366;
  t76_n118: return 0.09563586860895157;
  t76_n119: return 0.006577915512025356;
  t76_n120: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t76_n132;
  t76_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n131;
  t76_n122: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n130;
  t76_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n127;
  t76_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t76_n126;
  t76_n125: return 0.12409568578004837;
  t76_n126: return 0.1284111589193344;
  t76_n127: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t76_n129;
  t76_n128: return 0.12791672348976135;
  t76_n129: return 0.10949837416410446;
  t76_n130: return 0.09228067100048065;
  t76_n131: return 0.09290014207363129;
  t76_n132: return -0.061394624412059784;
  t76_n133: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n139;
  t76_n134: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t76_n138;
  t76_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t76_n137;
  t76_n136: return 0.014106810092926025;
  t76_n137: return 0.04287667199969292;
  t76_n138: return -0.0062354435212910175;
  t76_n139: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t76_n229;
  t76_n140: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t76_n218;
  t76_n141: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t76_n145;
  t76_n142: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t76_n144;
  t76_n143: return 0.028523892164230347;
  t76_n144: return -0.3700868785381317;
  t76_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t76_n159;
  t76_n146: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t76_n148;
  t76_n147: return 0.039904747158288956;
  t76_n148: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t76_n154;
  t76_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t76_n151;
  t76_n150: return 0.05078556761145592;
  t76_n151: if (E.getNumReferences() >= 3334260992 /*24164.5*/) goto t76_n153;
  t76_n152: return 0.11504463851451874;
  t76_n153: return -0.10250594466924667;
  t76_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t76_n156;
  t76_n155: return -0.08146880567073822;
  t76_n156: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t76_n158;
  t76_n157: return 0.10701030492782593;
  t76_n158: return 0.08765628188848495;
  t76_n159: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t76_n197;
  t76_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t76_n162;
  t76_n161: return 0.04619299992918968;
  t76_n162: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t76_n164;
  t76_n163: return 0.06540583819150925;
  t76_n164: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t76_n176;
  t76_n165: if (E.getNumReferences() >= 3328404480 /*14555.0*/) goto t76_n167;
  t76_n166: return 0.08137495070695877;
  t76_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t76_n169;
  t76_n168: return 0.10808650404214859;
  t76_n169: if (E.getNumReferences() >= 3331176192 /*18139.5*/) goto t76_n175;
  t76_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t76_n172;
  t76_n171: return -0.11415302008390427;
  t76_n172: if (E.getNumReferences() >= 3330760192 /*17327.0*/) goto t76_n174;
  t76_n173: return 0.11429555714130402;
  t76_n174: return 0.12086668610572815;
  t76_n175: return -0.10728286951780319;
  t76_n176: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t76_n180;
  t76_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n179;
  t76_n178: return 0.0745239183306694;
  t76_n179: return 0.12240078300237656;
  t76_n180: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t76_n196;
  t76_n181: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t76_n195;
  t76_n182: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t76_n188;
  t76_n183: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t76_n185;
  t76_n184: return 0.11119896918535233;
  t76_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t76_n187;
  t76_n186: return 0.08336123824119568;
  t76_n187: return 0.10835311561822891;
  t76_n188: if (E.getNumReferences() >= 3321878528 /*8187.0*/) goto t76_n190;
  t76_n189: return -0.002903086831793189;
  t76_n190: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t76_n192;
  t76_n191: return 0.11369460821151733;
  t76_n192: if (E.getNumReferences() >= 3322210304 /*8506.0*/) goto t76_n194;
  t76_n193: return -0.15736214816570282;
  t76_n194: return 0.11055117100477219;
  t76_n195: return 0.11044168472290039;
  t76_n196: return 0.033564455807209015;
  t76_n197: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t76_n213;
  t76_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t76_n210;
  t76_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t76_n209;
  t76_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t76_n202;
  t76_n201: return 0.11588437855243683;
  t76_n202: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t76_n206;
  t76_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t76_n205;
  t76_n204: return 0.13231933116912842;
  t76_n205: return 0.14669111371040344;
  t76_n206: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t76_n208;
  t76_n207: return 0.11785533279180527;
  t76_n208: return 0.10628580302000046;
  t76_n209: return -0.13264977931976318;
  t76_n210: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t76_n212;
  t76_n211: return 0.0974397137761116;
  t76_n212: return 0.10611044615507126;
  t76_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t76_n215;
  t76_n214: return 0.05326658859848976;
  t76_n215: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t76_n217;
  t76_n216: return 0.11808077245950699;
  t76_n217: return 0.059845615178346634;
  t76_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t76_n228;
  t76_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t76_n227;
  t76_n220: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t76_n224;
  t76_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t76_n223;
  t76_n222: return -0.03851113095879555;
  t76_n223: return -0.1399393081665039;
  t76_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t76_n226;
  t76_n225: return 0.039518777281045914;
  t76_n226: return -0.33262401819229126;
  t76_n227: return 0.014135392382740974;
  t76_n228: return 0.011370310559868813;
  t76_n229: return 0.0895376205444336;
  t76_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t76_n236;
  t76_n231: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t76_n233;
  t76_n232: return 0.00724938465282321;
  t76_n233: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t76_n235;
  t76_n234: return 0.06697653979063034;
  t76_n235: return 0.012712503783404827;
  t76_n236: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t76_n240;
  t76_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t76_n239;
  t76_n238: return -0.011384723708033562;
  t76_n239: return 0.014218645170331001;
  t76_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t76_n252;
  t76_n241: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t76_n243;
  t76_n242: return -0.02376498281955719;
  t76_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t76_n245;
  t76_n244: return -0.013304667547345161;
  t76_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t76_n249;
  t76_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t76_n248;
  t76_n247: return -0.2673211693763733;
  t76_n248: return 0.12102676182985306;
  t76_n249: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t76_n251;
  t76_n250: return -0.1068832278251648;
  t76_n251: return 0.16028663516044617;
  t76_n252: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t76_n254;
  t76_n253: return 0.02255217730998993;
  t76_n254: return 0.08638183027505875;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree77(const Example& E) {
  t77_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t77_n200;
  t77_n1: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t77_n121;
  t77_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t77_n60;
  t77_n3: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t77_n5;
  t77_n4: return 0.0002227326767751947;
  t77_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n13;
  t77_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t77_n8;
  t77_n7: return -0.002932087518274784;
  t77_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n10;
  t77_n9: return 0.1653481423854828;
  t77_n10: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t77_n12;
  t77_n11: return 0.10770446062088013;
  t77_n12: return -0.17813318967819214;
  t77_n13: if (E.getNumReferences() >= 3354076032 /*120391.0*/) goto t77_n45;
  t77_n14: if (E.getNumReferences() >= 3308374016 /*2844.5*/) goto t77_n20;
  t77_n15: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t77_n19;
  t77_n16: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t77_n18;
  t77_n17: return 0.02501790225505829;
  t77_n18: return 0.04458343982696533;
  t77_n19: return 0.00771256722509861;
  t77_n20: if (E.getNumReferences() >= 3308460032 /*2865.5*/) goto t77_n24;
  t77_n21: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t77_n23;
  t77_n22: return 0.12180040031671524;
  t77_n23: return -0.006039645057171583;
  t77_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t77_n26;
  t77_n25: return 0.010592574253678322;
  t77_n26: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t77_n28;
  t77_n27: return 0.04352768510580063;
  t77_n28: if (E.getNumReferences() >= 3309135872 /*3030.5*/) goto t77_n32;
  t77_n29: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t77_n31;
  t77_n30: return 0.1007986068725586;
  t77_n31: return 0.12183598428964615;
  t77_n32: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t77_n34;
  t77_n33: return 0.03603222966194153;
  t77_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t77_n36;
  t77_n35: return 0.060881588608026505;
  t77_n36: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n40;
  t77_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t77_n39;
  t77_n38: return 0.0946098268032074;
  t77_n39: return 0.1363314539194107;
  t77_n40: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t77_n42;
  t77_n41: return -0.04612359404563904;
  t77_n42: if (E.getNumReferences() >= 3333697280 /*23063.5*/) goto t77_n44;
  t77_n43: return -0.05037100985646248;
  t77_n44: return 0.11862793564796448;
  t77_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t77_n47;
  t77_n46: return -0.03776627033948898;
  t77_n47: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n59;
  t77_n48: if (E.getNumReferences() >= 3355447552 /*131140.0*/) goto t77_n56;
  t77_n49: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t77_n51;
  t77_n50: return 0.11325450241565704;
  t77_n51: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t77_n53;
  t77_n52: return 0.1221337541937828;
  t77_n53: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t77_n55;
  t77_n54: return 0.11825942993164062;
  t77_n55: return 0.10818924754858017;
  t77_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n58;
  t77_n57: return 0.08203589171171188;
  t77_n58: return 0.10320436954498291;
  t77_n59: return 0.07125776261091232;
  t77_n60: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t77_n64;
  t77_n61: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t77_n63;
  t77_n62: return 0.005505015607923269;
  t77_n63: return -0.06371573358774185;
  t77_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t77_n66;
  t77_n65: return -0.006132381036877632;
  t77_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t77_n96;
  t77_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t77_n95;
  t77_n68: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t77_n76;
  t77_n69: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t77_n75;
  t77_n70: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t77_n72;
  t77_n71: return 0.0528707318007946;
  t77_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n74;
  t77_n73: return -0.10251528024673462;
  t77_n74: return 0.11728756129741669;
  t77_n75: return 0.008440650068223476;
  t77_n76: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t77_n94;
  t77_n77: if (E.getNumReferences() >= 3348327104 /*75477.5*/) goto t77_n79;
  t77_n78: return 0.05645914748311043;
  t77_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n93;
  t77_n80: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t77_n92;
  t77_n81: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t77_n87;
  t77_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t77_n86;
  t77_n83: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t77_n85;
  t77_n84: return 0.1789778172969818;
  t77_n85: return 0.017442164942622185;
  t77_n86: return 0.11542760580778122;
  t77_n87: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t77_n91;
  t77_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n90;
  t77_n89: return -0.10612571984529495;
  t77_n90: return 0.12468650937080383;
  t77_n91: return 0.11610791087150574;
  t77_n92: return 0.04038776457309723;
  t77_n93: return 0.153207927942276;
  t77_n94: return -0.08317742496728897;
  t77_n95: return -0.3591793179512024;
  t77_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t77_n110;
  t77_n97: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t77_n109;
  t77_n98: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t77_n100;
  t77_n99: return 0.05330626294016838;
  t77_n100: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t77_n102;
  t77_n101: return 0.016417235136032104;
  t77_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n104;
  t77_n103: return -0.019600864499807358;
  t77_n104: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t77_n108;
  t77_n105: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t77_n107;
  t77_n106: return 0.08395574241876602;
  t77_n107: return 0.12297366559505463;
  t77_n108: return 0.04332993924617767;
  t77_n109: return 0.08033515512943268;
  t77_n110: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t77_n114;
  t77_n111: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t77_n113;
  t77_n112: return 0.061129167675971985;
  t77_n113: return 0.0993603989481926;
  t77_n114: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t77_n120;
  t77_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n117;
  t77_n116: return 0.13015080988407135;
  t77_n117: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t77_n119;
  t77_n118: return 0.07647211104631424;
  t77_n119: return 0.13591215014457703;
  t77_n120: return 0.0947161540389061;
  t77_n121: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t77_n159;
  t77_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t77_n132;
  t77_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n125;
  t77_n124: return 0.12412501871585846;
  t77_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t77_n127;
  t77_n126: return -0.17893339693546295;
  t77_n127: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t77_n129;
  t77_n128: return 0.08231890201568604;
  t77_n129: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t77_n131;
  t77_n130: return 0.1273864209651947;
  t77_n131: return 0.11954725533723831;
  t77_n132: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t77_n144;
  t77_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t77_n139;
  t77_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t77_n138;
  t77_n135: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t77_n137;
  t77_n136: return 0.08160386979579926;
  t77_n137: return 0.09538482129573822;
  t77_n138: return -0.011293618008494377;
  t77_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n141;
  t77_n140: return 0.1248968094587326;
  t77_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t77_n143;
  t77_n142: return 0.10518518090248108;
  t77_n143: return 0.09965753555297852;
  t77_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t77_n150;
  t77_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t77_n147;
  t77_n146: return 0.04512179642915726;
  t77_n147: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t77_n149;
  t77_n148: return 0.1229669526219368;
  t77_n149: return 0.09272880852222443;
  t77_n150: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t77_n152;
  t77_n151: return -0.2761431932449341;
  t77_n152: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t77_n156;
  t77_n153: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t77_n155;
  t77_n154: return 0.08654813468456268;
  t77_n155: return 0.04840891808271408;
  t77_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n158;
  t77_n157: return 0.10971719771623611;
  t77_n158: return 0.057571012526750565;
  t77_n159: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t77_n173;
  t77_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t77_n162;
  t77_n161: return 0.03365654870867729;
  t77_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t77_n170;
  t77_n163: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t77_n165;
  t77_n164: return 0.010189978405833244;
  t77_n165: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t77_n169;
  t77_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t77_n168;
  t77_n167: return -0.11514341086149216;
  t77_n168: return 0.11851023882627487;
  t77_n169: return 0.30719491839408875;
  t77_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t77_n172;
  t77_n171: return -0.11061277240514755;
  t77_n172: return 0.08744392544031143;
  t77_n173: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t77_n177;
  t77_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t77_n176;
  t77_n175: return -0.43231233954429626;
  t77_n176: return -0.047518130391836166;
  t77_n177: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t77_n183;
  t77_n178: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t77_n180;
  t77_n179: return 0.024593517184257507;
  t77_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t77_n182;
  t77_n181: return 0.03696778044104576;
  t77_n182: return 0.1269340068101883;
  t77_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t77_n185;
  t77_n184: return -0.0013560170773416758;
  t77_n185: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t77_n199;
  t77_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t77_n188;
  t77_n187: return 0.022188421338796616;
  t77_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t77_n194;
  t77_n189: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t77_n191;
  t77_n190: return 0.01993466354906559;
  t77_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t77_n193;
  t77_n192: return 0.10006901621818542;
  t77_n193: return 0.12283138930797577;
  t77_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t77_n198;
  t77_n195: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t77_n197;
  t77_n196: return 0.03467216342687607;
  t77_n197: return 0.10226493328809738;
  t77_n198: return 0.0034738928079605103;
  t77_n199: return 0.10356961935758591;
  t77_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t77_n252;
  t77_n201: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t77_n245;
  t77_n202: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t77_n244;
  t77_n203: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t77_n237;
  t77_n204: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t77_n232;
  t77_n205: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t77_n211;
  t77_n206: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t77_n210;
  t77_n207: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t77_n209;
  t77_n208: return 0.027055658400058746;
  t77_n209: return 0.0547906830906868;
  t77_n210: return 0.008605257607996464;
  t77_n211: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t77_n219;
  t77_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t77_n214;
  t77_n213: return -0.09721001982688904;
  t77_n214: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t77_n216;
  t77_n215: return -0.04578853398561478;
  t77_n216: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t77_n218;
  t77_n217: return 0.027807150036096573;
  t77_n218: return 0.05125279352068901;
  t77_n219: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t77_n231;
  t77_n220: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t77_n224;
  t77_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t77_n223;
  t77_n222: return -0.0417315810918808;
  t77_n223: return 0.0513664074242115;
  t77_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n226;
  t77_n225: return 0.10115622729063034;
  t77_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t77_n230;
  t77_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t77_n229;
  t77_n228: return 0.10325681418180466;
  t77_n229: return 0.08065369725227356;
  t77_n230: return -0.025118399411439896;
  t77_n231: return 0.06033611670136452;
  t77_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t77_n234;
  t77_n233: return -0.006880889646708965;
  t77_n234: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t77_n236;
  t77_n235: return 0.0056487214751541615;
  t77_n236: return -0.10072097927331924;
  t77_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t77_n239;
  t77_n238: return 0.007536064833402634;
  t77_n239: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t77_n241;
  t77_n240: return 0.02795519307255745;
  t77_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t77_n243;
  t77_n242: return 0.038604360073804855;
  t77_n243: return 0.06774892657995224;
  t77_n244: return -0.0278407521545887;
  t77_n245: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t77_n251;
  t77_n246: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t77_n250;
  t77_n247: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t77_n249;
  t77_n248: return 0.12966704368591309;
  t77_n249: return 0.07028959691524506;
  t77_n250: return 0.06156446039676666;
  t77_n251: return 0.016222042962908745;
  t77_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t77_n254;
  t77_n253: return -0.0377466194331646;
  t77_n254: return 0.015222183428704739;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree78(const Example& E) {
  t78_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t78_n220;
  t78_n1: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t78_n97;
  t78_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t78_n12;
  t78_n3: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t78_n11;
  t78_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t78_n6;
  t78_n5: return 0.012124607339501381;
  t78_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t78_n8;
  t78_n7: return 0.03886092081665993;
  t78_n8: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t78_n10;
  t78_n9: return 0.0846586525440216;
  t78_n10: return 0.05885821953415871;
  t78_n11: return -0.01681201532483101;
  t78_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t78_n32;
  t78_n13: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t78_n31;
  t78_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t78_n16;
  t78_n15: return 0.013967829756438732;
  t78_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n26;
  t78_n17: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t78_n25;
  t78_n18: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t78_n20;
  t78_n19: return 0.05879083648324013;
  t78_n20: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t78_n24;
  t78_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n23;
  t78_n22: return 0.0986100286245346;
  t78_n23: return 0.08323410153388977;
  t78_n24: return 0.08226409554481506;
  t78_n25: return 0.009345168247818947;
  t78_n26: if (E.getNumReferences() >= 3322196992 /*8493.0*/) goto t78_n28;
  t78_n27: return 0.019718071445822716;
  t78_n28: if (E.getNumReferences() >= 3322410496 /*8701.5*/) goto t78_n30;
  t78_n29: return 0.12600693106651306;
  t78_n30: return 0.07238571345806122;
  t78_n31: return -0.02551882527768612;
  t78_n32: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t78_n84;
  t78_n33: if (E.getNumReferences() >= 3305154560 /*2058.5*/) goto t78_n41;
  t78_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n38;
  t78_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t78_n37;
  t78_n36: return 0.013387041166424751;
  t78_n37: return 0.10083679109811783;
  t78_n38: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t78_n40;
  t78_n39: return 0.01450202614068985;
  t78_n40: return -0.03487382084131241;
  t78_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n47;
  t78_n42: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t78_n44;
  t78_n43: return 0.025837615132331848;
  t78_n44: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t78_n46;
  t78_n45: return -0.4604669511318207;
  t78_n46: return -0.1104644387960434;
  t78_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t78_n81;
  t78_n48: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t78_n70;
  t78_n49: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t78_n69;
  t78_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n52;
  t78_n51: return 0.07595030963420868;
  t78_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t78_n58;
  t78_n53: if (E.getNumReferences() >= 3345992448 /*61387.0*/) goto t78_n55;
  t78_n54: return 0.04710274934768677;
  t78_n55: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t78_n57;
  t78_n56: return -0.40766119956970215;
  t78_n57: return 0.11491192132234573;
  t78_n58: if (E.getNumReferences() >= 3317255168 /*5929.5*/) goto t78_n60;
  t78_n59: return -0.17713280022144318;
  t78_n60: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t78_n64;
  t78_n61: if (E.getNumReferences() >= 3320085504 /*7311.5*/) goto t78_n63;
  t78_n62: return 0.11686693876981735;
  t78_n63: return 0.10276421904563904;
  t78_n64: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t78_n68;
  t78_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t78_n67;
  t78_n66: return 0.1271827518939972;
  t78_n67: return 0.11510835587978363;
  t78_n68: return 0.042568791657686234;
  t78_n69: return -0.004879108630120754;
  t78_n70: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t78_n80;
  t78_n71: if (E.getNumReferences() >= 3333558528 /*22792.5*/) goto t78_n75;
  t78_n72: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t78_n74;
  t78_n73: return 0.11546960473060608;
  t78_n74: return 0.07441685348749161;
  t78_n75: if (E.getNumReferences() >= 3334368512 /*24374.5*/) goto t78_n77;
  t78_n76: return 0.12723033130168915;
  t78_n77: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t78_n79;
  t78_n78: return -0.2746266722679138;
  t78_n79: return 0.1828867793083191;
  t78_n80: return 0.04824136570096016;
  t78_n81: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t78_n83;
  t78_n82: return 0.03334589675068855;
  t78_n83: return 0.1438121646642685;
  t78_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t78_n86;
  t78_n85: return -0.06396342813968658;
  t78_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n88;
  t78_n87: return 0.010714899748563766;
  t78_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t78_n90;
  t78_n89: return 0.02989281341433525;
  t78_n90: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t78_n96;
  t78_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t78_n93;
  t78_n92: return 0.08426232635974884;
  t78_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n95;
  t78_n94: return 0.1158699169754982;
  t78_n95: return 0.06609336286783218;
  t78_n96: return 0.015894591808319092;
  t78_n97: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t78_n99;
  t78_n98: return -0.0064721787348389626;
  t78_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t78_n133;
  t78_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t78_n102;
  t78_n101: return 0.030760420486330986;
  t78_n102: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t78_n110;
  t78_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n105;
  t78_n104: return -0.030436193570494652;
  t78_n105: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t78_n109;
  t78_n106: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t78_n108;
  t78_n107: return -0.1482658088207245;
  t78_n108: return 0.10775597393512726;
  t78_n109: return 0.055174145847558975;
  t78_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n132;
  t78_n111: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t78_n121;
  t78_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n114;
  t78_n113: return -0.10334983468055725;
  t78_n114: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t78_n116;
  t78_n115: return 0.11224214732646942;
  t78_n116: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t78_n120;
  t78_n117: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n119;
  t78_n118: return 0.11921567469835281;
  t78_n119: return 0.11621260643005371;
  t78_n120: return 0.10606135427951813;
  t78_n121: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t78_n129;
  t78_n122: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t78_n124;
  t78_n123: return 0.11584791541099548;
  t78_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n126;
  t78_n125: return -0.03521697595715523;
  t78_n126: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t78_n128;
  t78_n127: return 0.11524003744125366;
  t78_n128: return 0.07562145590782166;
  t78_n129: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n131;
  t78_n130: return 0.11042357236146927;
  t78_n131: return 0.00036272304714657366;
  t78_n132: return 0.07739751785993576;
  t78_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t78_n219;
  t78_n134: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t78_n200;
  t78_n135: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t78_n171;
  t78_n136: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t78_n168;
  t78_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n139;
  t78_n138: return 0.013728059828281403;
  t78_n139: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t78_n165;
  t78_n140: if (E.getNumReferences() >= 3353767936 /*117984.0*/) goto t78_n164;
  t78_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n163;
  t78_n142: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t78_n160;
  t78_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t78_n145;
  t78_n144: return 0.04885426536202431;
  t78_n145: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t78_n147;
  t78_n146: return 0.0532398521900177;
  t78_n147: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t78_n149;
  t78_n148: return 0.0410345084965229;
  t78_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n151;
  t78_n150: return -0.10716181248426437;
  t78_n151: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t78_n159;
  t78_n152: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t78_n158;
  t78_n153: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t78_n155;
  t78_n154: return 0.07885532081127167;
  t78_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n157;
  t78_n156: return 0.11988192051649094;
  t78_n157: return 0.09200350940227509;
  t78_n158: return -0.07779654860496521;
  t78_n159: return 0.10819052904844284;
  t78_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t78_n162;
  t78_n161: return 0.02147352695465088;
  t78_n162: return 0.11747898906469345;
  t78_n163: return 0.01827598176896572;
  t78_n164: return -0.04510018229484558;
  t78_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t78_n167;
  t78_n166: return -0.2130347490310669;
  t78_n167: return 0.10661912709474564;
  t78_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t78_n170;
  t78_n169: return -0.054119233042001724;
  t78_n170: return 0.18074509501457214;
  t78_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t78_n185;
  t78_n172: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t78_n174;
  t78_n173: return 0.08267640322446823;
  t78_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n184;
  t78_n175: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t78_n183;
  t78_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n182;
  t78_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t78_n181;
  t78_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t78_n180;
  t78_n179: return 0.11987292766571045;
  t78_n180: return 0.12072662264108658;
  t78_n181: return 0.12095407396554947;
  t78_n182: return 0.06725556403398514;
  t78_n183: return 0.04104802384972572;
  t78_n184: return -0.017223643139004707;
  t78_n185: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t78_n191;
  t78_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t78_n188;
  t78_n187: return 0.0032719627488404512;
  t78_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n190;
  t78_n189: return 0.11958421766757965;
  t78_n190: return 0.10148710012435913;
  t78_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t78_n193;
  t78_n192: return -0.12070313096046448;
  t78_n193: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t78_n199;
  t78_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t78_n198;
  t78_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t78_n197;
  t78_n196: return 0.08773238211870193;
  t78_n197: return 0.1119827926158905;
  t78_n198: return 0.1061350628733635;
  t78_n199: return 0.019974706694483757;
  t78_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n204;
  t78_n201: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t78_n203;
  t78_n202: return -0.16796249151229858;
  t78_n203: return -0.32428252696990967;
  t78_n204: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t78_n206;
  t78_n205: return -0.06190063804388046;
  t78_n206: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t78_n216;
  t78_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t78_n211;
  t78_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t78_n210;
  t78_n209: return -0.14019200205802917;
  t78_n210: return -1.0884262323379517;
  t78_n211: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t78_n213;
  t78_n212: return 0.12444748729467392;
  t78_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n215;
  t78_n214: return -0.13667242228984833;
  t78_n215: return 0.08178090304136276;
  t78_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t78_n218;
  t78_n217: return 0.014580471441149712;
  t78_n218: return -0.05097613483667374;
  t78_n219: return 0.05997221916913986;
  t78_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t78_n228;
  t78_n221: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t78_n225;
  t78_n222: if (E.getNumReferences() >= 3306149888 /*2301.5*/) goto t78_n224;
  t78_n223: return 0.004419982898980379;
  t78_n224: return 0.014720641076564789;
  t78_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t78_n227;
  t78_n226: return -0.021000143140554428;
  t78_n227: return 0.1067826896905899;
  t78_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t78_n230;
  t78_n229: return -0.012265131808817387;
  t78_n230: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t78_n254;
  t78_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t78_n233;
  t78_n232: return 0.0229963269084692;
  t78_n233: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t78_n247;
  t78_n234: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t78_n246;
  t78_n235: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t78_n241;
  t78_n236: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t78_n238;
  t78_n237: return -0.01723775453865528;
  t78_n238: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t78_n240;
  t78_n239: return 0.03088224120438099;
  t78_n240: return 0.007305405102670193;
  t78_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t78_n243;
  t78_n242: return -0.10071002691984177;
  t78_n243: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t78_n245;
  t78_n244: return 0.01871163584291935;
  t78_n245: return 0.09378086775541306;
  t78_n246: return 0.01858401671051979;
  t78_n247: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t78_n251;
  t78_n248: if (E.getNumReferences() >= 3270836224 /*122.5*/) goto t78_n250;
  t78_n249: return 0.13287925720214844;
  t78_n250: return 0.06485482305288315;
  t78_n251: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t78_n253;
  t78_n252: return 0.012407969683408737;
  t78_n253: return 0.07150706648826599;
  t78_n254: return 0.02605646476149559;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree79(const Example& E) {
  t79_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t79_n220;
  t79_n1: if (E.getNumReferences() >= 3304824832 /*2013.0*/) goto t79_n93;
  t79_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t79_n22;
  t79_n3: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t79_n21;
  t79_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t79_n16;
  t79_n5: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t79_n7;
  t79_n6: return -0.002789352321997285;
  t79_n7: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t79_n9;
  t79_n8: return 0.020721709355711937;
  t79_n9: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t79_n13;
  t79_n10: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t79_n12;
  t79_n11: return 0.04231167212128639;
  t79_n12: return 0.07773824781179428;
  t79_n13: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t79_n15;
  t79_n14: return 0.0641339048743248;
  t79_n15: return 0.07891016453504562;
  t79_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t79_n18;
  t79_n17: return 0.025531373918056488;
  t79_n18: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t79_n20;
  t79_n19: return 0.07012762874364853;
  t79_n20: return 0.01668235845863819;
  t79_n21: return -0.020884381607174873;
  t79_n22: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t79_n38;
  t79_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t79_n27;
  t79_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t79_n26;
  t79_n25: return -0.04421335831284523;
  t79_n26: return -0.01858322136104107;
  t79_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t79_n37;
  t79_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n32;
  t79_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n31;
  t79_n30: return 0.08948705345392227;
  t79_n31: return 0.015359980054199696;
  t79_n32: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t79_n34;
  t79_n33: return 0.040612783282995224;
  t79_n34: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t79_n36;
  t79_n35: return 0.0843447595834732;
  t79_n36: return -0.3640061318874359;
  t79_n37: return -0.057473812252283096;
  t79_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t79_n40;
  t79_n39: return 0.0001373049453832209;
  t79_n40: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t79_n62;
  t79_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t79_n43;
  t79_n42: return -0.016626683995127678;
  t79_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n45;
  t79_n44: return 0.011555218137800694;
  t79_n45: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t79_n49;
  t79_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n48;
  t79_n47: return 0.04512559995055199;
  t79_n48: return -0.02048751711845398;
  t79_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n51;
  t79_n50: return -0.04695618897676468;
  t79_n51: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t79_n53;
  t79_n52: return 0.020107341930270195;
  t79_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n61;
  t79_n54: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t79_n56;
  t79_n55: return -0.34607475996017456;
  t79_n56: if (E.getNumReferences() >= 3260547072 /*54.0*/) goto t79_n58;
  t79_n57: return -0.026681138202548027;
  t79_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n60;
  t79_n59: return 0.0657273381948471;
  t79_n60: return 0.104324571788311;
  t79_n61: return 0.0052857547998428345;
  t79_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t79_n80;
  t79_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t79_n65;
  t79_n64: return 0.004450944717973471;
  t79_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n67;
  t79_n66: return 0.021564926952123642;
  t79_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t79_n79;
  t79_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n70;
  t79_n69: return 0.03830990940332413;
  t79_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t79_n72;
  t79_n71: return 0.07131318002939224;
  t79_n72: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t79_n74;
  t79_n73: return 0.07922372967004776;
  t79_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n78;
  t79_n75: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t79_n77;
  t79_n76: return 0.11807162314653397;
  t79_n77: return 0.11578259617090225;
  t79_n78: return 0.09607616066932678;
  t79_n79: return 0.004684169311076403;
  t79_n80: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t79_n92;
  t79_n81: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n91;
  t79_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t79_n90;
  t79_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n87;
  t79_n84: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t79_n86;
  t79_n85: return 0.1225782185792923;
  t79_n86: return 0.12581218779087067;
  t79_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t79_n89;
  t79_n88: return 0.12780897319316864;
  t79_n89: return 0.1095169186592102;
  t79_n90: return 0.0806216225028038;
  t79_n91: return 0.0907345712184906;
  t79_n92: return -0.048389632254838943;
  t79_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n99;
  t79_n94: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t79_n98;
  t79_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n97;
  t79_n96: return 0.01353180781006813;
  t79_n97: return 0.039960604161024094;
  t79_n98: return -0.004733403213322163;
  t79_n99: if (E.getNumReferences() >= 3304845312 /*2015.5*/) goto t79_n101;
  t79_n100: return 0.12933818995952606;
  t79_n101: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t79_n219;
  t79_n102: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t79_n200;
  t79_n103: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t79_n107;
  t79_n104: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t79_n106;
  t79_n105: return 0.025745665654540062;
  t79_n106: return -0.273457795381546;
  t79_n107: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t79_n119;
  t79_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t79_n118;
  t79_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t79_n111;
  t79_n110: return -0.04512675106525421;
  t79_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t79_n113;
  t79_n112: return 0.035124797374010086;
  t79_n113: if (E.getNumReferences() >= 3337313280 /*30126.0*/) goto t79_n115;
  t79_n114: return 0.11146797984838486;
  t79_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n117;
  t79_n116: return 0.09128059446811676;
  t79_n117: return 0.10617195814847946;
  t79_n118: return 0.03932145982980728;
  t79_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t79_n169;
  t79_n120: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t79_n156;
  t79_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t79_n125;
  t79_n122: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t79_n124;
  t79_n123: return -0.04911450669169426;
  t79_n124: return 0.09380879253149033;
  t79_n125: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t79_n149;
  t79_n126: if (E.getNumReferences() >= 3333934848 /*23527.5*/) goto t79_n148;
  t79_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t79_n141;
  t79_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t79_n132;
  t79_n129: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t79_n131;
  t79_n130: return 0.05140407010912895;
  t79_n131: return 0.07490140199661255;
  t79_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n140;
  t79_n133: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t79_n139;
  t79_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t79_n136;
  t79_n135: return 0.21850866079330444;
  t79_n136: if (E.getNumReferences() >= 3325483008 /*11702.0*/) goto t79_n138;
  t79_n137: return 0.12848113477230072;
  t79_n138: return -0.1046375259757042;
  t79_n139: return 0.10410760343074799;
  t79_n140: return 0.05357908084988594;
  t79_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n147;
  t79_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n146;
  t79_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t79_n145;
  t79_n144: return 0.14129230380058289;
  t79_n145: return 0.11222623288631439;
  t79_n146: return 0.1135098785161972;
  t79_n147: return -0.19664224982261658;
  t79_n148: return -0.03479449823498726;
  t79_n149: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t79_n155;
  t79_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t79_n154;
  t79_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n153;
  t79_n152: return 0.06705186516046524;
  t79_n153: return 0.12250497937202454;
  t79_n154: return 0.12022699415683746;
  t79_n155: return 0.054379794746637344;
  t79_n156: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t79_n166;
  t79_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t79_n159;
  t79_n158: return 0.04636991024017334;
  t79_n159: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t79_n163;
  t79_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t79_n162;
  t79_n161: return -0.1497158706188202;
  t79_n162: return 0.0972176119685173;
  t79_n163: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t79_n165;
  t79_n164: return 0.11561378091573715;
  t79_n165: return -0.21993780136108398;
  t79_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n168;
  t79_n167: return 0.07061014324426651;
  t79_n168: return 0.12453475594520569;
  t79_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t79_n173;
  t79_n170: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t79_n172;
  t79_n171: return 0.1221412792801857;
  t79_n172: return 0.06176665797829628;
  t79_n173: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t79_n189;
  t79_n174: if (E.getNumReferences() >= 3332440064 /*20608.0*/) goto t79_n184;
  t79_n175: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t79_n181;
  t79_n176: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t79_n180;
  t79_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t79_n179;
  t79_n178: return -0.10434170067310333;
  t79_n179: return 0.12069585919380188;
  t79_n180: return 0.06893905997276306;
  t79_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t79_n183;
  t79_n182: return 0.10027848929166794;
  t79_n183: return 0.11053047329187393;
  t79_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n186;
  t79_n185: return -0.06636503338813782;
  t79_n186: if (E.getNumReferences() >= 3342897920 /*49299.0*/) goto t79_n188;
  t79_n187: return -0.1319546401500702;
  t79_n188: return 0.11022043973207474;
  t79_n189: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t79_n193;
  t79_n190: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t79_n192;
  t79_n191: return 0.20014412701129913;
  t79_n192: return 0.11289793998003006;
  t79_n193: if (E.getNumReferences() >= 3322110464 /*8408.5*/) goto t79_n195;
  t79_n194: return 0.019152894616127014;
  t79_n195: if (E.getNumReferences() >= 3322180096 /*8476.5*/) goto t79_n199;
  t79_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n198;
  t79_n197: return -0.1595335602760315;
  t79_n198: return 0.11628075689077377;
  t79_n199: return 0.07592881470918655;
  t79_n200: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t79_n212;
  t79_n201: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t79_n203;
  t79_n202: return -0.027667861431837082;
  t79_n203: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t79_n207;
  t79_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n206;
  t79_n205: return -0.009118026122450829;
  t79_n206: return 0.12332145124673843;
  t79_n207: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t79_n209;
  t79_n208: return -0.4166484773159027;
  t79_n209: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t79_n211;
  t79_n210: return -0.346941739320755;
  t79_n211: return 0.06394219398498535;
  t79_n212: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t79_n214;
  t79_n213: return 0.10863428562879562;
  t79_n214: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t79_n216;
  t79_n215: return -0.006593164522200823;
  t79_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t79_n218;
  t79_n217: return -0.11647643893957138;
  t79_n218: return 0.033034548163414;
  t79_n219: return 0.08531233668327332;
  t79_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t79_n222;
  t79_n221: return -0.010983777232468128;
  t79_n222: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t79_n234;
  t79_n223: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t79_n233;
  t79_n224: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t79_n232;
  t79_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t79_n231;
  t79_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t79_n228;
  t79_n227: return 0.08274255692958832;
  t79_n228: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t79_n230;
  t79_n229: return 0.01574854366481304;
  t79_n230: return -0.07371587306261063;
  t79_n231: return 0.028692355379462242;
  t79_n232: return 0.017206978052854538;
  t79_n233: return 0.0319412536919117;
  t79_n234: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t79_n254;
  t79_n235: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t79_n237;
  t79_n236: return 0.005348753184080124;
  t79_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t79_n253;
  t79_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t79_n240;
  t79_n239: return 0.02018781192600727;
  t79_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t79_n252;
  t79_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t79_n243;
  t79_n242: return 0.046314626932144165;
  t79_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t79_n251;
  t79_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t79_n250;
  t79_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t79_n247;
  t79_n246: return 0.079247385263443;
  t79_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t79_n249;
  t79_n248: return 0.10471045970916748;
  t79_n249: return 0.0905570536851883;
  t79_n250: return 0.1127360463142395;
  t79_n251: return -0.017158769071102142;
  t79_n252: return 0.05817131698131561;
  t79_n253: return 0.014192401431500912;
  t79_n254: return -0.1996075063943863;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree80(const Example& E) {
  t80_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t80_n174;
  t80_n1: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t80_n87;
  t80_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n26;
  t80_n3: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t80_n5;
  t80_n4: return 0.10804293304681778;
  t80_n5: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t80_n7;
  t80_n6: return -0.009724891744554043;
  t80_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t80_n25;
  t80_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t80_n20;
  t80_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t80_n11;
  t80_n10: return 0.012032714672386646;
  t80_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t80_n13;
  t80_n12: return 0.02128901518881321;
  t80_n13: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t80_n15;
  t80_n14: return -0.04718570038676262;
  t80_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t80_n17;
  t80_n16: return 0.0752057135105133;
  t80_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n19;
  t80_n18: return 0.08269169181585312;
  t80_n19: return 0.010968293063342571;
  t80_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n24;
  t80_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t80_n23;
  t80_n22: return 0.05455932393670082;
  t80_n23: return 0.12384967505931854;
  t80_n24: return 0.01238090917468071;
  t80_n25: return -0.02093484252691269;
  t80_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t80_n86;
  t80_n27: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t80_n73;
  t80_n28: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t80_n42;
  t80_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t80_n33;
  t80_n30: if (E.getNumReferences() >= 3290472448 /*642.5*/) goto t80_n32;
  t80_n31: return -0.02861838974058628;
  t80_n32: return 0.1118425652384758;
  t80_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n35;
  t80_n34: return -0.18952351808547974;
  t80_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t80_n41;
  t80_n36: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t80_n38;
  t80_n37: return -0.11049740016460419;
  t80_n38: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t80_n40;
  t80_n39: return 0.12378106266260147;
  t80_n40: return 0.027988947927951813;
  t80_n41: return 0.02779395319521427;
  t80_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t80_n58;
  t80_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n45;
  t80_n44: return -0.009397591464221478;
  t80_n45: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t80_n57;
  t80_n46: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t80_n52;
  t80_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n51;
  t80_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t80_n50;
  t80_n49: return 0.04574039578437805;
  t80_n50: return 0.09228396415710449;
  t80_n51: return 0.023183384910225868;
  t80_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t80_n56;
  t80_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t80_n55;
  t80_n54: return -0.07267352938652039;
  t80_n55: return 0.14352332055568695;
  t80_n56: return 0.02379699796438217;
  t80_n57: return 0.006918361876159906;
  t80_n58: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t80_n64;
  t80_n59: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t80_n61;
  t80_n60: return 0.03939148783683777;
  t80_n61: if (E.getNumReferences() >= 3292602368 /*772.5*/) goto t80_n63;
  t80_n62: return 0.12576648592948914;
  t80_n63: return 0.05271639674901962;
  t80_n64: if (E.getNumReferences() >= 3324791296 /*11026.5*/) goto t80_n66;
  t80_n65: return 0.01208366546779871;
  t80_n66: if (E.getNumReferences() >= 3326378496 /*12576.5*/) goto t80_n68;
  t80_n67: return 0.12794028222560883;
  t80_n68: if (E.getNumReferences() >= 3329918464 /*16033.5*/) goto t80_n72;
  t80_n69: if (E.getNumReferences() >= 3329426944 /*15553.5*/) goto t80_n71;
  t80_n70: return 0.049553919583559036;
  t80_n71: return 0.11202451586723328;
  t80_n72: return -0.023699894547462463;
  t80_n73: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t80_n79;
  t80_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n78;
  t80_n75: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t80_n77;
  t80_n76: return -0.2522695064544678;
  t80_n77: return -0.11833084374666214;
  t80_n78: return -0.01764434576034546;
  t80_n79: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t80_n81;
  t80_n80: return -0.1840236932039261;
  t80_n81: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t80_n85;
  t80_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n84;
  t80_n83: return 0.1313660889863968;
  t80_n84: return 0.06182263791561127;
  t80_n85: return -0.023582441732287407;
  t80_n86: return 0.00610074307769537;
  t80_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n89;
  t80_n88: return -0.00872153788805008;
  t80_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t80_n153;
  t80_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t80_n128;
  t80_n91: if (E.getNumReferences() >= 3338616320 /*32671.0*/) goto t80_n95;
  t80_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n94;
  t80_n93: return 0.14319466054439545;
  t80_n94: return 0.10099197924137115;
  t80_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t80_n99;
  t80_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n98;
  t80_n97: return 0.024190492928028107;
  t80_n98: return -0.10278269648551941;
  t80_n99: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t80_n111;
  t80_n100: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t80_n110;
  t80_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t80_n103;
  t80_n102: return -0.3840232491493225;
  t80_n103: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t80_n105;
  t80_n104: return 0.05782601609826088;
  t80_n105: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t80_n107;
  t80_n106: return 0.0885034054517746;
  t80_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t80_n109;
  t80_n108: return 0.1426907181739807;
  t80_n109: return 0.021658822894096375;
  t80_n110: return -0.05766738951206207;
  t80_n111: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t80_n119;
  t80_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n114;
  t80_n113: return 0.09260090440511703;
  t80_n114: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t80_n118;
  t80_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n117;
  t80_n116: return 0.09781865775585175;
  t80_n117: return 0.09149586409330368;
  t80_n118: return 0.05324823781847954;
  t80_n119: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t80_n121;
  t80_n120: return -0.08669420331716537;
  t80_n121: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t80_n123;
  t80_n122: return 0.08360887318849564;
  t80_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t80_n125;
  t80_n124: return -0.2875328063964844;
  t80_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t80_n127;
  t80_n126: return -0.4047398865222931;
  t80_n127: return 0.048165977001190186;
  t80_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t80_n130;
  t80_n129: return 0.006486658006906509;
  t80_n130: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n144;
  t80_n131: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t80_n143;
  t80_n132: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t80_n138;
  t80_n133: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t80_n135;
  t80_n134: return 0.10914255678653717;
  t80_n135: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t80_n137;
  t80_n136: return 0.11962917447090149;
  t80_n137: return 0.11391232907772064;
  t80_n138: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t80_n140;
  t80_n139: return 0.11725358664989471;
  t80_n140: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t80_n142;
  t80_n141: return -0.1588388979434967;
  t80_n142: return 0.12389513850212097;
  t80_n143: return 0.09240482747554779;
  t80_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n152;
  t80_n145: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t80_n151;
  t80_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t80_n148;
  t80_n147: return -0.10209174454212189;
  t80_n148: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t80_n150;
  t80_n149: return 0.11123050004243851;
  t80_n150: return 0.04829201474785805;
  t80_n151: return -0.004018864594399929;
  t80_n152: return 0.07443921267986298;
  t80_n153: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t80_n155;
  t80_n154: return 0.015606660395860672;
  t80_n155: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t80_n167;
  t80_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t80_n166;
  t80_n157: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t80_n159;
  t80_n158: return 0.0713287889957428;
  t80_n159: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t80_n165;
  t80_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t80_n162;
  t80_n161: return 0.09646614640951157;
  t80_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n164;
  t80_n163: return 0.11880388110876083;
  t80_n164: return 0.07808496057987213;
  t80_n165: return 0.08300144970417023;
  t80_n166: return -0.006212947890162468;
  t80_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t80_n169;
  t80_n168: return -0.02508707530796528;
  t80_n169: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t80_n171;
  t80_n170: return -0.1240813285112381;
  t80_n171: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t80_n173;
  t80_n172: return 0.13038551807403564;
  t80_n173: return 0.18201309442520142;
  t80_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t80_n176;
  t80_n175: return -0.010363410227000713;
  t80_n176: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t80_n234;
  t80_n177: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t80_n191;
  t80_n178: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t80_n186;
  t80_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t80_n185;
  t80_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t80_n182;
  t80_n181: return 0.08347325026988983;
  t80_n182: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t80_n184;
  t80_n183: return 0.014627008698880672;
  t80_n184: return -0.07454022020101547;
  t80_n185: return 0.02779490500688553;
  t80_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t80_n190;
  t80_n187: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t80_n189;
  t80_n188: return -0.15154536068439484;
  t80_n189: return 0.01066802442073822;
  t80_n190: return 0.020192885771393776;
  t80_n191: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t80_n233;
  t80_n192: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t80_n194;
  t80_n193: return -0.3578667640686035;
  t80_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t80_n196;
  t80_n195: return 0.022568078711628914;
  t80_n196: if (E.getNumReferences() >= 3324623872 /*10863.0*/) goto t80_n230;
  t80_n197: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t80_n199;
  t80_n198: return 0.030223509296774864;
  t80_n199: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t80_n229;
  t80_n200: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t80_n214;
  t80_n201: if (E.getNumReferences() >= 3282272256 /*327.0*/) goto t80_n211;
  t80_n202: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t80_n204;
  t80_n203: return 0.03621279448270798;
  t80_n204: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t80_n210;
  t80_n205: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t80_n207;
  t80_n206: return 0.18350866436958313;
  t80_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n209;
  t80_n208: return 0.11368590593338013;
  t80_n209: return -0.08548647910356522;
  t80_n210: return 0.04957890510559082;
  t80_n211: if (E.getNumReferences() >= 3285565440 /*427.5*/) goto t80_n213;
  t80_n212: return 0.11220376938581467;
  t80_n213: return 0.08536221086978912;
  t80_n214: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t80_n228;
  t80_n215: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t80_n227;
  t80_n216: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t80_n224;
  t80_n217: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t80_n223;
  t80_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n220;
  t80_n219: return -0.10415113717317581;
  t80_n220: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t80_n222;
  t80_n221: return 0.14708401262760162;
  t80_n222: return -0.4223143756389618;
  t80_n223: return -0.10295672714710236;
  t80_n224: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t80_n226;
  t80_n225: return 0.11435553431510925;
  t80_n226: return 0.007711535785347223;
  t80_n227: return 0.13899430632591248;
  t80_n228: return 0.024445977061986923;
  t80_n229: return 0.03871970996260643;
  t80_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t80_n232;
  t80_n231: return 0.11151157319545746;
  t80_n232: return 0.004408429376780987;
  t80_n233: return 0.06808024644851685;
  t80_n234: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t80_n254;
  t80_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t80_n237;
  t80_n236: return 0.004922512453049421;
  t80_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t80_n253;
  t80_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t80_n240;
  t80_n239: return 0.01806282438337803;
  t80_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t80_n252;
  t80_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t80_n243;
  t80_n242: return 0.04848923161625862;
  t80_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t80_n251;
  t80_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t80_n250;
  t80_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t80_n247;
  t80_n246: return 0.09717953205108643;
  t80_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t80_n249;
  t80_n248: return 0.1038350984454155;
  t80_n249: return 0.09595806896686554;
  t80_n250: return 0.1172543466091156;
  t80_n251: return -0.05095802992582321;
  t80_n252: return 0.05164337158203125;
  t80_n253: return 0.014055776409804821;
  t80_n254: return -0.1332462579011917;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree81(const Example& E) {
  t81_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t81_n200;
  t81_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t81_n33;
  t81_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t81_n6;
  t81_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n5;
  t81_n4: return -0.014507715590298176;
  t81_n5: return -0.03606438636779785;
  t81_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t81_n8;
  t81_n7: return -0.013494818471372128;
  t81_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n10;
  t81_n9: return 0.0008899254025891423;
  t81_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t81_n12;
  t81_n11: return -0.1322566419839859;
  t81_n12: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t81_n16;
  t81_n13: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t81_n15;
  t81_n14: return -0.03214407339692116;
  t81_n15: return 0.012208306230604649;
  t81_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t81_n32;
  t81_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n19;
  t81_n18: return 0.03301555663347244;
  t81_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t81_n21;
  t81_n20: return 0.06701027601957321;
  t81_n21: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t81_n23;
  t81_n22: return 0.0716828927397728;
  t81_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t81_n25;
  t81_n24: return 0.12637177109718323;
  t81_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n29;
  t81_n26: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t81_n28;
  t81_n27: return 0.10282764583826065;
  t81_n28: return 0.11595622450113297;
  t81_n29: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t81_n31;
  t81_n30: return -0.11272714287042618;
  t81_n31: return 0.11447829753160477;
  t81_n32: return 0.012724822387099266;
  t81_n33: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t81_n199;
  t81_n34: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t81_n150;
  t81_n35: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t81_n37;
  t81_n36: return 0.10691174119710922;
  t81_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n97;
  t81_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t81_n72;
  t81_n39: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t81_n41;
  t81_n40: return -0.017166145145893097;
  t81_n41: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t81_n71;
  t81_n42: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n64;
  t81_n43: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t81_n55;
  t81_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n46;
  t81_n45: return 0.053303658962249756;
  t81_n46: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t81_n52;
  t81_n47: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t81_n49;
  t81_n48: return 0.10659977793693542;
  t81_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n51;
  t81_n50: return 0.07618407905101776;
  t81_n51: return 0.03261910378932953;
  t81_n52: if (E.getNumReferences() >= 3347570176 /*69564.0*/) goto t81_n54;
  t81_n53: return -0.0015654595335945487;
  t81_n54: return -0.4305429458618164;
  t81_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n57;
  t81_n56: return 0.10009314119815826;
  t81_n57: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t81_n63;
  t81_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n62;
  t81_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n61;
  t81_n60: return -0.10612674057483673;
  t81_n61: return 0.10750653594732285;
  t81_n62: return 0.1539601981639862;
  t81_n63: return -0.057793643325567245;
  t81_n64: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t81_n66;
  t81_n65: return 0.013890981674194336;
  t81_n66: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t81_n70;
  t81_n67: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t81_n69;
  t81_n68: return -0.003961089998483658;
  t81_n69: return 0.10965045541524887;
  t81_n70: return -0.05553411319851875;
  t81_n71: return -0.11752330511808395;
  t81_n72: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t81_n88;
  t81_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n75;
  t81_n74: return 0.0037271936889737844;
  t81_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n77;
  t81_n76: return 0.04468134418129921;
  t81_n77: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t81_n83;
  t81_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t81_n80;
  t81_n79: return 0.051201362162828445;
  t81_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n82;
  t81_n81: return 0.07965259253978729;
  t81_n82: return 0.029125092551112175;
  t81_n83: if (E.getNumReferences() >= 3318872064 /*6719.0*/) goto t81_n87;
  t81_n84: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t81_n86;
  t81_n85: return 0.10687073320150375;
  t81_n86: return 0.14223125576972961;
  t81_n87: return 0.059216514229774475;
  t81_n88: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t81_n96;
  t81_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n91;
  t81_n90: return 0.060733988881111145;
  t81_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n93;
  t81_n92: return 0.036832358688116074;
  t81_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n95;
  t81_n94: return 0.08945021033287048;
  t81_n95: return 0.04933464527130127;
  t81_n96: return -0.011062785051763058;
  t81_n97: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t81_n99;
  t81_n98: return 0.008107968606054783;
  t81_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t81_n101;
  t81_n100: return -0.006712046917527914;
  t81_n101: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t81_n133;
  t81_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t81_n104;
  t81_n103: return 0.0354640893638134;
  t81_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t81_n116;
  t81_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t81_n107;
  t81_n106: return -0.15891118347644806;
  t81_n107: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t81_n109;
  t81_n108: return 0.060997530817985535;
  t81_n109: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t81_n115;
  t81_n110: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n112;
  t81_n111: return 0.12430063635110855;
  t81_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n114;
  t81_n113: return 0.07110124826431274;
  t81_n114: return 0.10925406217575073;
  t81_n115: return -0.01046582031995058;
  t81_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t81_n118;
  t81_n117: return 0.02011762745678425;
  t81_n118: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t81_n130;
  t81_n119: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t81_n123;
  t81_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t81_n122;
  t81_n121: return 0.07632116973400116;
  t81_n122: return 0.03673330321907997;
  t81_n123: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t81_n125;
  t81_n124: return 0.021261192858219147;
  t81_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t81_n127;
  t81_n126: return 0.09120655804872513;
  t81_n127: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t81_n129;
  t81_n128: return 0.11755393445491791;
  t81_n129: return 0.11072497814893723;
  t81_n130: if (E.getNumReferences() >= 3359032704 /*187158.0*/) goto t81_n132;
  t81_n131: return 0.01687467284500599;
  t81_n132: return 0.07880914211273193;
  t81_n133: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t81_n135;
  t81_n134: return -0.1289965808391571;
  t81_n135: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t81_n147;
  t81_n136: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t81_n142;
  t81_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t81_n141;
  t81_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n140;
  t81_n139: return 0.022876271978020668;
  t81_n140: return -0.2578778862953186;
  t81_n141: return 0.06598395109176636;
  t81_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t81_n144;
  t81_n143: return 0.04936535283923149;
  t81_n144: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t81_n146;
  t81_n145: return 0.11701102554798126;
  t81_n146: return 0.030393358319997787;
  t81_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n149;
  t81_n148: return -0.16632439196109772;
  t81_n149: return 0.00725763663649559;
  t81_n150: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t81_n164;
  t81_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t81_n157;
  t81_n152: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t81_n154;
  t81_n153: return -0.020351102575659752;
  t81_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t81_n156;
  t81_n155: return -0.16240444779396057;
  t81_n156: return -0.12530675530433655;
  t81_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n159;
  t81_n158: return 0.005556175950914621;
  t81_n159: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t81_n161;
  t81_n160: return 0.05111529678106308;
  t81_n161: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t81_n163;
  t81_n162: return 0.013476116582751274;
  t81_n163: return 0.07646924257278442;
  t81_n164: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t81_n198;
  t81_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t81_n171;
  t81_n166: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n168;
  t81_n167: return 0.13654464483261108;
  t81_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t81_n170;
  t81_n169: return -0.07791402190923691;
  t81_n170: return 0.10330379009246826;
  t81_n171: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t81_n187;
  t81_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n184;
  t81_n173: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t81_n179;
  t81_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t81_n176;
  t81_n175: return 0.061248764395713806;
  t81_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n178;
  t81_n177: return 0.11762837320566177;
  t81_n178: return 0.08512867987155914;
  t81_n179: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t81_n181;
  t81_n180: return 0.054514698684215546;
  t81_n181: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t81_n183;
  t81_n182: return 0.12089163064956665;
  t81_n183: return 0.030597034841775894;
  t81_n184: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n186;
  t81_n185: return 0.07961930334568024;
  t81_n186: return 0.03936902806162834;
  t81_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t81_n193;
  t81_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t81_n190;
  t81_n189: return 0.08788397908210754;
  t81_n190: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n192;
  t81_n191: return 0.10548625141382217;
  t81_n192: return 0.05411136522889137;
  t81_n193: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t81_n197;
  t81_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t81_n196;
  t81_n195: return 0.11726599931716919;
  t81_n196: return 0.10746300220489502;
  t81_n197: return -0.10103780776262283;
  t81_n198: return -0.07901834696531296;
  t81_n199: return -0.11495991796255112;
  t81_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t81_n252;
  t81_n201: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t81_n251;
  t81_n202: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t81_n238;
  t81_n203: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t81_n233;
  t81_n204: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t81_n226;
  t81_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t81_n225;
  t81_n206: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t81_n212;
  t81_n207: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t81_n209;
  t81_n208: return -0.15626581013202667;
  t81_n209: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t81_n211;
  t81_n210: return 0.01924777589738369;
  t81_n211: return 0.03734108805656433;
  t81_n212: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t81_n214;
  t81_n213: return 0.010595511645078659;
  t81_n214: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n216;
  t81_n215: return 0.02208452671766281;
  t81_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t81_n224;
  t81_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t81_n223;
  t81_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t81_n220;
  t81_n219: return 0.0961068719625473;
  t81_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t81_n222;
  t81_n221: return 0.10290994495153427;
  t81_n222: return 0.08371914178133011;
  t81_n223: return 0.016124555841088295;
  t81_n224: return 0.05426621809601784;
  t81_n225: return -0.014947880990803242;
  t81_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t81_n228;
  t81_n227: return 0.008944462053477764;
  t81_n228: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t81_n230;
  t81_n229: return 0.022722214460372925;
  t81_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t81_n232;
  t81_n231: return 0.03216971084475517;
  t81_n232: return 0.06426052004098892;
  t81_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t81_n235;
  t81_n234: return -0.05558621510863304;
  t81_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t81_n237;
  t81_n236: return -0.013693063519895077;
  t81_n237: return 0.044690247625112534;
  t81_n238: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t81_n244;
  t81_n239: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t81_n243;
  t81_n240: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t81_n242;
  t81_n241: return 0.10489927977323532;
  t81_n242: return 0.12427271902561188;
  t81_n243: return 0.06150725483894348;
  t81_n244: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t81_n246;
  t81_n245: return 0.01005419623106718;
  t81_n246: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t81_n248;
  t81_n247: return 0.045386798679828644;
  t81_n248: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t81_n250;
  t81_n249: return 0.0801817923784256;
  t81_n250: return 0.11682413518428802;
  t81_n251: return -0.08937713503837585;
  t81_n252: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t81_n254;
  t81_n253: return 0.0001837198797147721;
  t81_n254: return 0.016702953726053238;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree82(const Example& E) {
  t82_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t82_n210;
  t82_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n49;
  t82_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t82_n26;
  t82_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n5;
  t82_n4: return -0.01548166386783123;
  t82_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t82_n7;
  t82_n6: return -0.04332064837217331;
  t82_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n9;
  t82_n8: return -0.10716072469949722;
  t82_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t82_n15;
  t82_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t82_n12;
  t82_n11: return 0.007705328520387411;
  t82_n12: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n14;
  t82_n13: return 0.03594211861491203;
  t82_n14: return -0.012259744107723236;
  t82_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t82_n25;
  t82_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n24;
  t82_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n21;
  t82_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n20;
  t82_n19: return 0.11450190842151642;
  t82_n20: return 0.10680568963289261;
  t82_n21: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t82_n23;
  t82_n22: return 0.12118831276893616;
  t82_n23: return 0.09538585692644119;
  t82_n24: return 0.08017583936452866;
  t82_n25: return -0.06519264727830887;
  t82_n26: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t82_n28;
  t82_n27: return -0.013377374969422817;
  t82_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n30;
  t82_n29: return 0.0009384581935591996;
  t82_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n32;
  t82_n31: return -0.13102269172668457;
  t82_n32: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t82_n36;
  t82_n33: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t82_n35;
  t82_n34: return -0.02795409969985485;
  t82_n35: return 0.010966116562485695;
  t82_n36: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n48;
  t82_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n39;
  t82_n38: return 0.02998708002269268;
  t82_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t82_n41;
  t82_n40: return 0.06353985518217087;
  t82_n41: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t82_n43;
  t82_n42: return 0.06566102802753448;
  t82_n43: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n45;
  t82_n44: return 0.1214480772614479;
  t82_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n47;
  t82_n46: return 0.10414449870586395;
  t82_n47: return 0.09244261682033539;
  t82_n48: return 0.011982697993516922;
  t82_n49: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t82_n209;
  t82_n50: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t82_n122;
  t82_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t82_n109;
  t82_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t82_n96;
  t82_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t82_n55;
  t82_n54: return -0.015826666727662086;
  t82_n55: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t82_n95;
  t82_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n88;
  t82_n57: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t82_n79;
  t82_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n60;
  t82_n59: return 0.04853120446205139;
  t82_n60: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t82_n76;
  t82_n61: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t82_n65;
  t82_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n64;
  t82_n63: return 0.0716937705874443;
  t82_n64: return 0.029415879398584366;
  t82_n65: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n75;
  t82_n66: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t82_n74;
  t82_n67: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t82_n69;
  t82_n68: return 0.14385080337524414;
  t82_n69: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n71;
  t82_n70: return 0.08985763043165207;
  t82_n71: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t82_n73;
  t82_n72: return 0.1404128223657608;
  t82_n73: return 0.09375040978193283;
  t82_n74: return -0.20269225537776947;
  t82_n75: return 0.11361376941204071;
  t82_n76: if (E.getNumReferences() >= 3347570176 /*69564.0*/) goto t82_n78;
  t82_n77: return 0.0005488388705998659;
  t82_n78: return -0.34375324845314026;
  t82_n79: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n81;
  t82_n80: return 0.09585534781217575;
  t82_n81: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t82_n87;
  t82_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n86;
  t82_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t82_n85;
  t82_n84: return -0.10550494492053986;
  t82_n85: return 0.10423329472541809;
  t82_n86: return 0.14521050453186035;
  t82_n87: return -0.057488758116960526;
  t82_n88: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t82_n90;
  t82_n89: return 0.011724439449608326;
  t82_n90: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n94;
  t82_n91: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t82_n93;
  t82_n92: return -0.024949977174401283;
  t82_n93: return 0.10834012180566788;
  t82_n94: return -0.04885396733880043;
  t82_n95: return -0.11656895279884338;
  t82_n96: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t82_n100;
  t82_n97: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t82_n99;
  t82_n98: return 0.01683053933084011;
  t82_n99: return -0.035294245928525925;
  t82_n100: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t82_n108;
  t82_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n103;
  t82_n102: return 0.03924889490008354;
  t82_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n105;
  t82_n104: return 0.03326618671417236;
  t82_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n107;
  t82_n106: return 0.08594009280204773;
  t82_n107: return 0.0467476025223732;
  t82_n108: return -0.010314283892512321;
  t82_n109: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t82_n111;
  t82_n110: return 0.007605336140841246;
  t82_n111: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t82_n113;
  t82_n112: return -0.007912864908576012;
  t82_n113: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t82_n117;
  t82_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n116;
  t82_n115: return 0.0328800231218338;
  t82_n116: return 0.048753056675195694;
  t82_n117: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t82_n119;
  t82_n118: return -0.11767002940177917;
  t82_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t82_n121;
  t82_n120: return 0.0010233648354187608;
  t82_n121: return 0.032615721225738525;
  t82_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t82_n154;
  t82_n123: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t82_n125;
  t82_n124: return -0.020620618015527725;
  t82_n125: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t82_n153;
  t82_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t82_n130;
  t82_n127: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n129;
  t82_n128: return 0.1466289460659027;
  t82_n129: return 0.09506255388259888;
  t82_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t82_n144;
  t82_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t82_n133;
  t82_n132: return 0.06923183053731918;
  t82_n133: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t82_n141;
  t82_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t82_n140;
  t82_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n137;
  t82_n136: return 0.06432972103357315;
  t82_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n139;
  t82_n138: return 0.09460094571113586;
  t82_n139: return 0.08159423619508743;
  t82_n140: return 0.021624360233545303;
  t82_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n143;
  t82_n142: return 0.10494249314069748;
  t82_n143: return 0.0488741435110569;
  t82_n144: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t82_n152;
  t82_n145: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n149;
  t82_n146: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t82_n148;
  t82_n147: return 0.11116784811019897;
  t82_n148: return 0.11553255468606949;
  t82_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t82_n151;
  t82_n150: return 0.10384050011634827;
  t82_n151: return 0.07769101113080978;
  t82_n152: return -0.13762132823467255;
  t82_n153: return -0.10557188093662262;
  t82_n154: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n208;
  t82_n155: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t82_n187;
  t82_n156: if (E.getNumReferences() >= 3282223104 /*325.5*/) goto t82_n160;
  t82_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n159;
  t82_n158: return 0.018434183672070503;
  t82_n159: return 0.02283564582467079;
  t82_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n162;
  t82_n161: return 0.053169041872024536;
  t82_n162: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t82_n182;
  t82_n163: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t82_n165;
  t82_n164: return 0.1357036530971527;
  t82_n165: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t82_n177;
  t82_n166: if (E.getNumReferences() >= 3310379008 /*3334.0*/) goto t82_n168;
  t82_n167: return 0.09511519223451614;
  t82_n168: if (E.getNumReferences() >= 3313898496 /*4290.5*/) goto t82_n176;
  t82_n169: if (E.getNumReferences() >= 3313839104 /*4261.5*/) goto t82_n175;
  t82_n170: if (E.getNumReferences() >= 3313203200 /*4023.5*/) goto t82_n174;
  t82_n171: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t82_n173;
  t82_n172: return -0.10851377248764038;
  t82_n173: return 0.11336667090654373;
  t82_n174: return -0.14925332367420197;
  t82_n175: return 0.15969248116016388;
  t82_n176: return 0.0943632647395134;
  t82_n177: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t82_n179;
  t82_n178: return 0.11336550861597061;
  t82_n179: if (E.getNumReferences() >= 3289817088 /*602.5*/) goto t82_n181;
  t82_n180: return 0.12456053495407104;
  t82_n181: return 0.10664474964141846;
  t82_n182: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t82_n186;
  t82_n183: if (E.getNumReferences() >= 3290030080 /*615.5*/) goto t82_n185;
  t82_n184: return 0.03743361681699753;
  t82_n185: return 0.10947438329458237;
  t82_n186: return 0.06522759795188904;
  t82_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t82_n189;
  t82_n188: return 0.5832801461219788;
  t82_n189: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n207;
  t82_n190: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t82_n198;
  t82_n191: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t82_n193;
  t82_n192: return 0.10781931132078171;
  t82_n193: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t82_n195;
  t82_n194: return 0.11702177673578262;
  t82_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n197;
  t82_n196: return 0.11223107576370239;
  t82_n197: return 0.10086531937122345;
  t82_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t82_n204;
  t82_n199: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t82_n201;
  t82_n200: return 0.11302413046360016;
  t82_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n203;
  t82_n202: return -0.006916820537298918;
  t82_n203: return 0.10650277137756348;
  t82_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n206;
  t82_n205: return 0.10965774953365326;
  t82_n206: return 0.012773687951266766;
  t82_n207: return 0.07222352921962738;
  t82_n208: return -0.015856510028243065;
  t82_n209: return -0.11399387568235397;
  t82_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t82_n212;
  t82_n211: return -0.010329888202250004;
  t82_n212: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t82_n230;
  t82_n213: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t82_n227;
  t82_n214: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t82_n222;
  t82_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n217;
  t82_n216: return 0.03461311757564545;
  t82_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t82_n221;
  t82_n218: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t82_n220;
  t82_n219: return -0.07553571462631226;
  t82_n220: return 0.032699476927518845;
  t82_n221: return 0.016848981380462646;
  t82_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n224;
  t82_n223: return 0.008776834234595299;
  t82_n224: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t82_n226;
  t82_n225: return -0.12636466324329376;
  t82_n226: return 0.0208554919809103;
  t82_n227: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t82_n229;
  t82_n228: return 0.027581846341490746;
  t82_n229: return 0.06857681274414062;
  t82_n230: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t82_n254;
  t82_n231: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t82_n233;
  t82_n232: return 0.00550473527982831;
  t82_n233: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t82_n253;
  t82_n234: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t82_n238;
  t82_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t82_n237;
  t82_n236: return 0.054479245096445084;
  t82_n237: return -0.08088043332099915;
  t82_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t82_n240;
  t82_n239: return 0.024388333782553673;
  t82_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t82_n252;
  t82_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t82_n243;
  t82_n242: return 0.05173017084598541;
  t82_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t82_n251;
  t82_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t82_n250;
  t82_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t82_n247;
  t82_n246: return 0.147722989320755;
  t82_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t82_n249;
  t82_n248: return 0.10236550867557526;
  t82_n249: return 0.08806188404560089;
  t82_n250: return 0.12738679349422455;
  t82_n251: return 0.025183066725730896;
  t82_n252: return 0.048918597400188446;
  t82_n253: return 0.011226381175220013;
  t82_n254: return -0.16856133937835693;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree83(const Example& E) {
  t83_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t83_n196;
  t83_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n11;
  t83_n2: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n4;
  t83_n3: return -0.014602585695683956;
  t83_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n6;
  t83_n5: return -0.033047690987586975;
  t83_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t83_n8;
  t83_n7: return -0.08326694369316101;
  t83_n8: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t83_n10;
  t83_n9: return -0.02605581097304821;
  t83_n10: return 0.10069455951452255;
  t83_n11: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t83_n59;
  t83_n12: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t83_n14;
  t83_n13: return 0.0067834872752428055;
  t83_n14: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t83_n18;
  t83_n15: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t83_n17;
  t83_n16: return 0.11832141876220703;
  t83_n17: return 0.009153135120868683;
  t83_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t83_n38;
  t83_n19: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t83_n21;
  t83_n20: return 0.005359038710594177;
  t83_n21: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t83_n37;
  t83_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t83_n24;
  t83_n23: return 0.0689048022031784;
  t83_n24: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t83_n34;
  t83_n25: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t83_n33;
  t83_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n32;
  t83_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t83_n29;
  t83_n28: return 0.06651009619235992;
  t83_n29: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n31;
  t83_n30: return 0.09025805443525314;
  t83_n31: return 0.07548262178897858;
  t83_n32: return 0.045940954238176346;
  t83_n33: return 0.04294333606958389;
  t83_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t83_n36;
  t83_n35: return 0.10133904218673706;
  t83_n36: return 0.05208778381347656;
  t83_n37: return -0.04955887049436569;
  t83_n38: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t83_n40;
  t83_n39: return 0.4045504927635193;
  t83_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n58;
  t83_n41: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t83_n49;
  t83_n42: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t83_n44;
  t83_n43: return 0.10706435889005661;
  t83_n44: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t83_n48;
  t83_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n47;
  t83_n46: return 0.11503367871046066;
  t83_n47: return 0.1130182221531868;
  t83_n48: return 0.09775012731552124;
  t83_n49: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t83_n51;
  t83_n50: return 0.1029408723115921;
  t83_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t83_n55;
  t83_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n54;
  t83_n53: return 0.017561836168169975;
  t83_n54: return 0.10333742946386337;
  t83_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t83_n57;
  t83_n56: return 0.10551965236663818;
  t83_n57: return 0.05784045532345772;
  t83_n58: return 0.06816952675580978;
  t83_n59: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t83_n61;
  t83_n60: return -0.03316879644989967;
  t83_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t83_n63;
  t83_n62: return -0.006083586718887091;
  t83_n63: if (E.getNumReferences() >= 3299295232 /*1338.0*/) goto t83_n151;
  t83_n64: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t83_n100;
  t83_n65: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n91;
  t83_n66: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t83_n68;
  t83_n67: return 0.001484749955125153;
  t83_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t83_n72;
  t83_n69: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t83_n71;
  t83_n70: return 0.027355976402759552;
  t83_n71: return 0.13347220420837402;
  t83_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n76;
  t83_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t83_n75;
  t83_n74: return -0.08022787421941757;
  t83_n75: return 0.14234286546707153;
  t83_n76: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t83_n90;
  t83_n77: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t83_n79;
  t83_n78: return 0.06132744997739792;
  t83_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t83_n81;
  t83_n80: return 0.028782865032553673;
  t83_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t83_n87;
  t83_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t83_n84;
  t83_n83: return -0.10004149377346039;
  t83_n84: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t83_n86;
  t83_n85: return 0.1365996152162552;
  t83_n86: return 0.14797350764274597;
  t83_n87: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t83_n89;
  t83_n88: return 0.04807942360639572;
  t83_n89: return 0.12224933505058289;
  t83_n90: return -0.11934079229831696;
  t83_n91: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t83_n99;
  t83_n92: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t83_n98;
  t83_n93: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t83_n95;
  t83_n94: return 0.05232779681682587;
  t83_n95: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t83_n97;
  t83_n96: return 0.10125166177749634;
  t83_n97: return 0.07975462824106216;
  t83_n98: return -0.0029069846495985985;
  t83_n99: return -0.012662793509662151;
  t83_n100: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t83_n118;
  t83_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t83_n103;
  t83_n102: return 0.05221688002347946;
  t83_n103: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t83_n115;
  t83_n104: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t83_n106;
  t83_n105: return 0.07716834545135498;
  t83_n106: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t83_n114;
  t83_n107: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t83_n113;
  t83_n108: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t83_n110;
  t83_n109: return 0.10285953432321548;
  t83_n110: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t83_n112;
  t83_n111: return 0.12145843356847763;
  t83_n112: return 0.09967140853404999;
  t83_n113: return 0.0311103668063879;
  t83_n114: return 0.06928569823503494;
  t83_n115: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t83_n117;
  t83_n116: return 0.1007390022277832;
  t83_n117: return 0.10795661807060242;
  t83_n118: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t83_n120;
  t83_n119: return -0.0664248913526535;
  t83_n120: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t83_n130;
  t83_n121: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t83_n123;
  t83_n122: return 0.11828433722257614;
  t83_n123: if (E.getNumReferences() >= 3287203840 /*477.5*/) goto t83_n125;
  t83_n124: return 0.08903247117996216;
  t83_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t83_n129;
  t83_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t83_n128;
  t83_n127: return 0.0721789300441742;
  t83_n128: return 0.12546072900295258;
  t83_n129: return 0.13028088212013245;
  t83_n130: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t83_n138;
  t83_n131: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t83_n133;
  t83_n132: return 0.025409357622265816;
  t83_n133: if (E.getNumReferences() >= 3297042432 /*1063.0*/) goto t83_n135;
  t83_n134: return 0.04461882263422012;
  t83_n135: if (E.getNumReferences() >= 3297943552 /*1173.0*/) goto t83_n137;
  t83_n136: return 0.10247526317834854;
  t83_n137: return 0.11451691389083862;
  t83_n138: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t83_n146;
  t83_n139: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t83_n145;
  t83_n140: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t83_n144;
  t83_n141: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t83_n143;
  t83_n142: return -0.10033196955919266;
  t83_n143: return 0.14036323130130768;
  t83_n144: return 0.14327941834926605;
  t83_n145: return 0.0893532782793045;
  t83_n146: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t83_n150;
  t83_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t83_n149;
  t83_n148: return -0.08475448936223984;
  t83_n149: return 0.11880559474229813;
  t83_n150: return 0.07555035501718521;
  t83_n151: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t83_n193;
  t83_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t83_n154;
  t83_n153: return -0.012040579691529274;
  t83_n154: if (E.getNumReferences() >= 3299307520 /*1339.5*/) goto t83_n156;
  t83_n155: return 0.11503124982118607;
  t83_n156: if (E.getNumReferences() >= 3316608000 /*5613.5*/) goto t83_n158;
  t83_n157: return 0.042888931930065155;
  t83_n158: if (E.getNumReferences() >= 3327202816 /*13381.5*/) goto t83_n192;
  t83_n159: if (E.getNumReferences() >= 3320417280 /*7473.5*/) goto t83_n165;
  t83_n160: if (E.getNumReferences() >= 3316660224 /*5639.0*/) goto t83_n164;
  t83_n161: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t83_n163;
  t83_n162: return 0.10875387489795685;
  t83_n163: return 0.1982704997062683;
  t83_n164: return 0.05240587517619133;
  t83_n165: if (E.getNumReferences() >= 3322356224 /*8648.5*/) goto t83_n177;
  t83_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t83_n176;
  t83_n167: if (E.getNumReferences() >= 3321306112 /*7907.5*/) goto t83_n169;
  t83_n168: return 0.08589472621679306;
  t83_n169: if (E.getNumReferences() >= 3321602048 /*8052.0*/) goto t83_n171;
  t83_n170: return 0.12749911844730377;
  t83_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t83_n173;
  t83_n172: return 0.0954146608710289;
  t83_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t83_n175;
  t83_n174: return 0.09295118600130081;
  t83_n175: return 0.1161971315741539;
  t83_n176: return 0.11862608045339584;
  t83_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t83_n183;
  t83_n178: if (E.getNumReferences() >= 3326796288 /*12984.5*/) goto t83_n180;
  t83_n179: return 0.04924769699573517;
  t83_n180: if (E.getNumReferences() >= 3326878720 /*13065.0*/) goto t83_n182;
  t83_n181: return 0.11431295424699783;
  t83_n182: return 0.07848555594682693;
  t83_n183: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t83_n185;
  t83_n184: return 0.0758550688624382;
  t83_n185: if (E.getNumReferences() >= 3324699136 /*10936.5*/) goto t83_n187;
  t83_n186: return 0.09861699491739273;
  t83_n187: if (E.getNumReferences() >= 3325492736 /*11711.5*/) goto t83_n191;
  t83_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t83_n190;
  t83_n189: return 0.11090420186519623;
  t83_n190: return 0.09686630219221115;
  t83_n191: return 0.07055792957544327;
  t83_n192: return 0.03483198210597038;
  t83_n193: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t83_n195;
  t83_n194: return -1.0459266901016235;
  t83_n195: return -0.03309917077422142;
  t83_n196: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t83_n236;
  t83_n197: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t83_n233;
  t83_n198: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t83_n232;
  t83_n199: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t83_n229;
  t83_n200: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t83_n220;
  t83_n201: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t83_n213;
  t83_n202: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t83_n210;
  t83_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t83_n205;
  t83_n204: return -0.03738189861178398;
  t83_n205: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t83_n207;
  t83_n206: return 0.053538139909505844;
  t83_n207: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t83_n209;
  t83_n208: return 0.08568163216114044;
  t83_n209: return 0.11837257444858551;
  t83_n210: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t83_n212;
  t83_n211: return 0.10287932306528091;
  t83_n212: return -0.08127401769161224;
  t83_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t83_n219;
  t83_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t83_n216;
  t83_n215: return -0.21586070954799652;
  t83_n216: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n218;
  t83_n217: return 0.12401336431503296;
  t83_n218: return 0.02951006591320038;
  t83_n219: return -0.08082114160060883;
  t83_n220: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t83_n226;
  t83_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t83_n223;
  t83_n222: return 0.07701389491558075;
  t83_n223: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t83_n225;
  t83_n224: return 0.017160529270768166;
  t83_n225: return 0.11642176657915115;
  t83_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t83_n228;
  t83_n227: return -0.004902319051325321;
  t83_n228: return 0.10159864276647568;
  t83_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t83_n231;
  t83_n230: return -0.08448465913534164;
  t83_n231: return -0.004745012149214745;
  t83_n232: return 0.0052828602492809296;
  t83_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t83_n235;
  t83_n234: return -0.021253082901239395;
  t83_n235: return 0.10316027700901031;
  t83_n236: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t83_n242;
  t83_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol))) goto t83_n241;
  t83_n238: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t83_n240;
  t83_n239: return 0.01767251268029213;
  t83_n240: return -0.007127881515771151;
  t83_n241: return 0.017696114256978035;
  t83_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t83_n254;
  t83_n243: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t83_n245;
  t83_n244: return -0.02462395653128624;
  t83_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t83_n247;
  t83_n246: return 0.0014464674750342965;
  t83_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t83_n251;
  t83_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n250;
  t83_n249: return -0.12482620775699615;
  t83_n250: return 0.12040341645479202;
  t83_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t83_n253;
  t83_n252: return -0.0918249785900116;
  t83_n253: return 0.23776139318943024;
  t83_n254: return 0.017733745276927948;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree84(const Example& E) {
  t84_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t84_n98;
  t84_n1: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t84_n9;
  t84_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t84_n4;
  t84_n3: return -0.009383740834891796;
  t84_n4: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t84_n6;
  t84_n5: return 0.008689966052770615;
  t84_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t84_n8;
  t84_n7: return -0.030240662395954132;
  t84_n8: return 0.02819407917559147;
  t84_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t84_n15;
  t84_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t84_n14;
  t84_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t84_n13;
  t84_n12: return 0.018327239900827408;
  t84_n13: return 0.04681963101029396;
  t84_n14: return -0.006251648999750614;
  t84_n15: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t84_n91;
  t84_n16: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t84_n80;
  t84_n17: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t84_n79;
  t84_n18: if (E.getNumReferences() >= 3358250528 /*174936.5*/) goto t84_n74;
  t84_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t84_n35;
  t84_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t84_n24;
  t84_n21: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t84_n23;
  t84_n22: return -0.006807259749621153;
  t84_n23: return -0.09474243968725204;
  t84_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t84_n26;
  t84_n25: return 0.024136044085025787;
  t84_n26: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t84_n28;
  t84_n27: return 0.0030552095267921686;
  t84_n28: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t84_n30;
  t84_n29: return 0.09613671153783798;
  t84_n30: if (E.getNumReferences() >= 3341641728 /*44392.0*/) goto t84_n34;
  t84_n31: if (E.getNumReferences() >= 3338617856 /*32674.0*/) goto t84_n33;
  t84_n32: return -0.16813907027244568;
  t84_n33: return 0.09304960072040558;
  t84_n34: return 0.027543196454644203;
  t84_n35: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t84_n51;
  t84_n36: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t84_n48;
  t84_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t84_n47;
  t84_n38: if (E.getNumReferences() >= 3326734336 /*12924.0*/) goto t84_n40;
  t84_n39: return 0.10856101661920547;
  t84_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t84_n42;
  t84_n41: return 0.08216260373592377;
  t84_n42: if (E.getNumReferences() >= 3327008768 /*13192.0*/) goto t84_n46;
  t84_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t84_n45;
  t84_n44: return 0.10485021024942398;
  t84_n45: return 0.11518270522356033;
  t84_n46: return -0.28609707951545715;
  t84_n47: return 0.051534153521060944;
  t84_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n50;
  t84_n49: return 0.12363641709089279;
  t84_n50: return 0.07794139534235;
  t84_n51: if (E.getNumReferences() >= 3334350336 /*24339.0*/) goto t84_n73;
  t84_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t84_n54;
  t84_n53: return 0.04212542623281479;
  t84_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion))) goto t84_n56;
  t84_n55: return 0.06196891888976097;
  t84_n56: if (E.getNumReferences() >= 3331378176 /*18534.0*/) goto t84_n66;
  t84_n57: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t84_n63;
  t84_n58: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t84_n60;
  t84_n59: return 0.007343273144215345;
  t84_n60: if (E.getNumReferences() >= 3330116608 /*16227.0*/) goto t84_n62;
  t84_n61: return 0.11493513733148575;
  t84_n62: return -0.13028055429458618;
  t84_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t84_n65;
  t84_n64: return 0.04679002985358238;
  t84_n65: return 0.11379911005496979;
  t84_n66: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t84_n70;
  t84_n67: if (E.getNumReferences() >= 3331808000 /*19373.5*/) goto t84_n69;
  t84_n68: return 0.28200554847717285;
  t84_n69: return 0.11039309948682785;
  t84_n70: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t84_n72;
  t84_n71: return 0.10866213589906693;
  t84_n72: return 0.023726141080260277;
  t84_n73: return 0.015632594004273415;
  t84_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t84_n76;
  t84_n75: return -0.201684832572937;
  t84_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t84_n78;
  t84_n77: return 0.1230851262807846;
  t84_n78: return 0.04872918501496315;
  t84_n79: return -0.10569055378437042;
  t84_n80: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t84_n86;
  t84_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t84_n83;
  t84_n82: return 0.07845914363861084;
  t84_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t84_n85;
  t84_n84: return 0.10145487636327744;
  t84_n85: return 0.08450423181056976;
  t84_n86: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t84_n88;
  t84_n87: return -0.3567558825016022;
  t84_n88: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t84_n90;
  t84_n89: return 0.06937139481306076;
  t84_n90: return 0.07335144281387329;
  t84_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n95;
  t84_n92: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t84_n94;
  t84_n93: return -0.08655750006437302;
  t84_n94: return -0.46008795499801636;
  t84_n95: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t84_n97;
  t84_n96: return -0.044042449444532394;
  t84_n97: return 0.015986865386366844;
  t84_n98: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t84_n250;
  t84_n99: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t84_n227;
  t84_n100: if (E.getNumReferences() >= 3309033472 /*3005.5*/) goto t84_n224;
  t84_n101: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t84_n157;
  t84_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n128;
  t84_n103: if (E.getNumReferences() >= 3298205696 /*1205.0*/) goto t84_n127;
  t84_n104: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t84_n120;
  t84_n105: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t84_n119;
  t84_n106: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n116;
  t84_n107: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t84_n115;
  t84_n108: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t84_n110;
  t84_n109: return -0.11069086939096451;
  t84_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t84_n112;
  t84_n111: return -0.11851025372743607;
  t84_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n114;
  t84_n113: return -0.06212635710835457;
  t84_n114: return 0.05814635753631592;
  t84_n115: return -0.1942962408065796;
  t84_n116: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t84_n118;
  t84_n117: return 0.11501388996839523;
  t84_n118: return 0.057540904730558395;
  t84_n119: return 0.08777084201574326;
  t84_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t84_n122;
  t84_n121: return 0.0057294913567602634;
  t84_n122: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n126;
  t84_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t84_n125;
  t84_n124: return -0.1584426611661911;
  t84_n125: return -0.05909976735711098;
  t84_n126: return -0.11157297343015671;
  t84_n127: return 0.10407000035047531;
  t84_n128: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t84_n152;
  t84_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t84_n135;
  t84_n130: if (E.getNumReferences() >= 3296526336 /*1012.0*/) goto t84_n132;
  t84_n131: return -0.05854639410972595;
  t84_n132: if (E.getNumReferences() >= 3298254848 /*1211.0*/) goto t84_n134;
  t84_n133: return 0.09093716740608215;
  t84_n134: return -0.015593823045492172;
  t84_n135: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t84_n137;
  t84_n136: return -0.010137274861335754;
  t84_n137: if (E.getNumReferences() >= 3264086016 /*71.0*/) goto t84_n151;
  t84_n138: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t84_n150;
  t84_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t84_n141;
  t84_n140: return 0.026409391313791275;
  t84_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t84_n143;
  t84_n142: return -0.025919266045093536;
  t84_n143: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t84_n149;
  t84_n144: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t84_n146;
  t84_n145: return 0.13025374710559845;
  t84_n146: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t84_n148;
  t84_n147: return -0.060143545269966125;
  t84_n148: return 0.10721609741449356;
  t84_n149: return 0.13769814372062683;
  t84_n150: return 0.12292664498090744;
  t84_n151: return -0.06571249663829803;
  t84_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t84_n156;
  t84_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t84_n155;
  t84_n154: return -0.020671159029006958;
  t84_n155: return 0.036052439361810684;
  t84_n156: return -0.015702322125434875;
  t84_n157: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n159;
  t84_n158: return 0.007516422308981419;
  t84_n159: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t84_n217;
  t84_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t84_n166;
  t84_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t84_n165;
  t84_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t84_n164;
  t84_n163: return -0.09655643999576569;
  t84_n164: return -0.11684924364089966;
  t84_n165: return -0.022714626044034958;
  t84_n166: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t84_n190;
  t84_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t84_n173;
  t84_n168: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t84_n172;
  t84_n169: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t84_n171;
  t84_n170: return -0.03374127298593521;
  t84_n171: return -0.01356183085590601;
  t84_n172: return 0.009083997458219528;
  t84_n173: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t84_n181;
  t84_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t84_n176;
  t84_n175: return -0.006602647714316845;
  t84_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t84_n178;
  t84_n177: return -0.11662982404232025;
  t84_n178: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t84_n180;
  t84_n179: return 0.09708821773529053;
  t84_n180: return -0.027854278683662415;
  t84_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t84_n185;
  t84_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n184;
  t84_n183: return -0.09550648927688599;
  t84_n184: return 0.004520157352089882;
  t84_n185: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t84_n189;
  t84_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t84_n188;
  t84_n187: return 0.030500654131174088;
  t84_n188: return 0.027494490146636963;
  t84_n189: return -0.11158162355422974;
  t84_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t84_n192;
  t84_n191: return 0.02695772796869278;
  t84_n192: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t84_n216;
  t84_n193: if (E.getNumReferences() >= 3307921408 /*2734.0*/) goto t84_n213;
  t84_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t84_n196;
  t84_n195: return 0.032116666436195374;
  t84_n196: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t84_n198;
  t84_n197: return 0.06865250319242477;
  t84_n198: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t84_n212;
  t84_n199: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t84_n211;
  t84_n200: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n208;
  t84_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t84_n207;
  t84_n202: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t84_n204;
  t84_n203: return 0.10786628723144531;
  t84_n204: if (E.getNumReferences() >= 3258974208 /*48.0*/) goto t84_n206;
  t84_n205: return 0.02510826289653778;
  t84_n206: return 0.12145481258630753;
  t84_n207: return 0.060176920145750046;
  t84_n208: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t84_n210;
  t84_n209: return -0.17328450083732605;
  t84_n210: return 0.12136198580265045;
  t84_n211: return 0.14608028531074524;
  t84_n212: return 0.0675099790096283;
  t84_n213: if (E.getNumReferences() >= 3308165120 /*2793.5*/) goto t84_n215;
  t84_n214: return 0.11173368245363235;
  t84_n215: return -0.030927347019314766;
  t84_n216: return 0.006117547396570444;
  t84_n217: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t84_n223;
  t84_n218: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t84_n220;
  t84_n219: return 0.019355997443199158;
  t84_n220: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t84_n222;
  t84_n221: return 0.07845385372638702;
  t84_n222: return 0.016595080494880676;
  t84_n223: return -0.5566332340240479;
  t84_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t84_n226;
  t84_n225: return 0.008615506812930107;
  t84_n226: return 0.0234302319586277;
  t84_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t84_n229;
  t84_n228: return -0.005631088744848967;
  t84_n229: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t84_n249;
  t84_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t84_n232;
  t84_n231: return 0.027154888957738876;
  t84_n232: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t84_n244;
  t84_n233: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t84_n235;
  t84_n234: return -0.015141594223678112;
  t84_n235: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t84_n243;
  t84_n236: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t84_n242;
  t84_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t84_n239;
  t84_n238: return -0.021443016827106476;
  t84_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t84_n241;
  t84_n240: return 0.06603620201349258;
  t84_n241: return 0.025172824040055275;
  t84_n242: return 0.03792133182287216;
  t84_n243: return 0.008086701855063438;
  t84_n244: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t84_n246;
  t84_n245: return -0.10062400251626968;
  t84_n246: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t84_n248;
  t84_n247: return 0.02066684141755104;
  t84_n248: return 0.0896696075797081;
  t84_n249: return 0.015345647931098938;
  t84_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t84_n254;
  t84_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t84_n253;
  t84_n252: return -0.05204370617866516;
  t84_n253: return -0.0004056215693708509;
  t84_n254: return 0.09905215352773666;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree85(const Example& E) {
  t85_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t85_n180;
  t85_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t85_n103;
  t85_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t85_n66;
  t85_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t85_n9;
  t85_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n6;
  t85_n5: return -0.015542824752628803;
  t85_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t85_n8;
  t85_n7: return -0.07604283839464188;
  t85_n8: return -0.021360863000154495;
  t85_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t85_n17;
  t85_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t85_n12;
  t85_n11: return -0.017611874267458916;
  t85_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n14;
  t85_n13: return 0.00018556686700321734;
  t85_n14: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t85_n16;
  t85_n15: return 0.006269518285989761;
  t85_n16: return 0.014626646414399147;
  t85_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t85_n19;
  t85_n18: return -0.09656775742769241;
  t85_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t85_n55;
  t85_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t85_n34;
  t85_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n25;
  t85_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t85_n24;
  t85_n23: return -0.03614649921655655;
  t85_n24: return 0.037311144173145294;
  t85_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t85_n27;
  t85_n26: return -0.019942631945014;
  t85_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n31;
  t85_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t85_n30;
  t85_n29: return 0.05281674489378929;
  t85_n30: return 0.003408469259738922;
  t85_n31: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t85_n33;
  t85_n32: return 0.054175324738025665;
  t85_n33: return -0.1320701688528061;
  t85_n34: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t85_n52;
  t85_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n37;
  t85_n36: return 0.02310745231807232;
  t85_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n51;
  t85_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t85_n42;
  t85_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n41;
  t85_n40: return 0.04897391051054001;
  t85_n41: return 0.010466992855072021;
  t85_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t85_n44;
  t85_n43: return 0.060808759182691574;
  t85_n44: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t85_n46;
  t85_n45: return 0.06817863136529922;
  t85_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n48;
  t85_n47: return 0.11968647688627243;
  t85_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n50;
  t85_n49: return 0.10182957351207733;
  t85_n50: return 0.08944956213235855;
  t85_n51: return 0.0032805593218654394;
  t85_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n54;
  t85_n53: return 0.07440938800573349;
  t85_n54: return 0.027999527752399445;
  t85_n55: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t85_n65;
  t85_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n64;
  t85_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n63;
  t85_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t85_n60;
  t85_n59: return 0.11848317086696625;
  t85_n60: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t85_n62;
  t85_n61: return 0.12606890499591827;
  t85_n62: return 0.10898932069540024;
  t85_n63: return 0.08283797651529312;
  t85_n64: return 0.08835535496473312;
  t85_n65: return -0.05761202052235603;
  t85_n66: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t85_n102;
  t85_n67: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t85_n101;
  t85_n68: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t85_n100;
  t85_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t85_n99;
  t85_n70: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t85_n98;
  t85_n71: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t85_n97;
  t85_n72: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n92;
  t85_n73: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t85_n75;
  t85_n74: return -5.609936488326639e-05;
  t85_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n77;
  t85_n76: return 0.019254712387919426;
  t85_n77: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t85_n81;
  t85_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t85_n80;
  t85_n79: return 0.024164322763681412;
  t85_n80: return -0.034485019743442535;
  t85_n81: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t85_n83;
  t85_n82: return 0.038324348628520966;
  t85_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n91;
  t85_n84: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t85_n86;
  t85_n85: return 0.05150885134935379;
  t85_n86: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t85_n90;
  t85_n87: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t85_n89;
  t85_n88: return 0.0875178873538971;
  t85_n89: return -0.0593934990465641;
  t85_n90: return 0.013491070829331875;
  t85_n91: return 0.03078744374215603;
  t85_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t85_n94;
  t85_n93: return -0.024977784603834152;
  t85_n94: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t85_n96;
  t85_n95: return 0.0021273980382829905;
  t85_n96: return 0.04817595332860947;
  t85_n97: return 0.03112807869911194;
  t85_n98: return -0.041530925780534744;
  t85_n99: return 0.011040485464036465;
  t85_n100: return -0.08357851952314377;
  t85_n101: return -0.11404133588075638;
  t85_n102: return -0.024975204840302467;
  t85_n103: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t85_n111;
  t85_n104: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n106;
  t85_n105: return -0.07177554816007614;
  t85_n106: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n108;
  t85_n107: return -0.13698218762874603;
  t85_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t85_n110;
  t85_n109: return -0.21385513246059418;
  t85_n110: return 0.11469583213329315;
  t85_n111: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t85_n179;
  t85_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t85_n178;
  t85_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t85_n127;
  t85_n114: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t85_n116;
  t85_n115: return 0.00651297764852643;
  t85_n116: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t85_n118;
  t85_n117: return 0.03376302495598793;
  t85_n118: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t85_n120;
  t85_n119: return 0.11050157248973846;
  t85_n120: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t85_n122;
  t85_n121: return -0.14729788899421692;
  t85_n122: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t85_n124;
  t85_n123: return 0.0649547204375267;
  t85_n124: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t85_n126;
  t85_n125: return 0.1279321312904358;
  t85_n126: return -0.148782879114151;
  t85_n127: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t85_n131;
  t85_n128: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t85_n130;
  t85_n129: return 0.04061449319124222;
  t85_n130: return -0.002144545316696167;
  t85_n131: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t85_n157;
  t85_n132: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t85_n134;
  t85_n133: return 0.004929039627313614;
  t85_n134: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t85_n136;
  t85_n135: return 0.0645354688167572;
  t85_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t85_n138;
  t85_n137: return -0.0791751891374588;
  t85_n138: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t85_n140;
  t85_n139: return 0.08006951212882996;
  t85_n140: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t85_n148;
  t85_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n143;
  t85_n142: return -0.06731564551591873;
  t85_n143: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t85_n147;
  t85_n144: if (E.getFilterLength() >= 3242196992 /*12.0*/) goto t85_n146;
  t85_n145: return 0.11082581430673599;
  t85_n146: return 0.15652871131896973;
  t85_n147: return 0.09919018298387527;
  t85_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t85_n150;
  t85_n149: return -0.12512187659740448;
  t85_n150: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t85_n154;
  t85_n151: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t85_n153;
  t85_n152: return 0.10832832008600235;
  t85_n153: return -0.11848624050617218;
  t85_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n156;
  t85_n155: return 0.1630907505750656;
  t85_n156: return 0.1113179475069046;
  t85_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t85_n175;
  t85_n158: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t85_n160;
  t85_n159: return 0.06304684281349182;
  t85_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t85_n162;
  t85_n161: return -0.0051230210810899734;
  t85_n162: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t85_n168;
  t85_n163: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t85_n165;
  t85_n164: return -0.10022890567779541;
  t85_n165: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t85_n167;
  t85_n166: return 0.1591312140226364;
  t85_n167: return 0.12354361265897751;
  t85_n168: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t85_n174;
  t85_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n171;
  t85_n170: return 0.11606702953577042;
  t85_n171: if (E.getSymbolScopeDistance() >= 3229614080 /*4.0*/) goto t85_n173;
  t85_n172: return 0.16553561389446259;
  t85_n173: return 0.11816012114286423;
  t85_n174: return 0.07860857993364334;
  t85_n175: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t85_n177;
  t85_n176: return 0.1464824676513672;
  t85_n177: return -0.009175068698823452;
  t85_n178: return 0.02731511741876602;
  t85_n179: return -0.04696986451745033;
  t85_n180: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t85_n232;
  t85_n181: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t85_n231;
  t85_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t85_n184;
  t85_n183: return 0.005967679433524609;
  t85_n184: if (E.getNumReferences() >= 3317228544 /*5916.5*/) goto t85_n226;
  t85_n185: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t85_n223;
  t85_n186: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t85_n196;
  t85_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t85_n189;
  t85_n188: return 0.019475573673844337;
  t85_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t85_n191;
  t85_n190: return 0.06506606936454773;
  t85_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n195;
  t85_n192: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t85_n194;
  t85_n193: return 0.13125775754451752;
  t85_n194: return 0.3566650152206421;
  t85_n195: return 0.054847683757543564;
  t85_n196: if (E.getNumReferences() >= 3288604672 /*528.5*/) goto t85_n216;
  t85_n197: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t85_n211;
  t85_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t85_n210;
  t85_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t85_n207;
  t85_n200: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t85_n206;
  t85_n201: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t85_n205;
  t85_n202: if (E.getNumReferences() >= 3287220224 /*478.0*/) goto t85_n204;
  t85_n203: return 0.09429962933063507;
  t85_n204: return 0.12187453359365463;
  t85_n205: return -0.30139365792274475;
  t85_n206: return 0.06909742951393127;
  t85_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t85_n209;
  t85_n208: return 0.13080105185508728;
  t85_n209: return -0.2311224341392517;
  t85_n210: return 0.10969620943069458;
  t85_n211: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t85_n213;
  t85_n212: return -0.11810654401779175;
  t85_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t85_n215;
  t85_n214: return -0.1379636824131012;
  t85_n215: return 0.17864273488521576;
  t85_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t85_n218;
  t85_n217: return 0.03309042006731033;
  t85_n218: if (E.getNumReferences() >= 3292446720 /*763.0*/) goto t85_n222;
  t85_n219: if (E.getNumReferences() >= 3291512832 /*706.0*/) goto t85_n221;
  t85_n220: return 0.059592969715595245;
  t85_n221: return 0.1210116297006607;
  t85_n222: return 0.07565879821777344;
  t85_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t85_n225;
  t85_n224: return -0.0008300002082251012;
  t85_n225: return 0.024334469810128212;
  t85_n226: if (E.getNumReferences() >= 3317296128 /*5949.5*/) goto t85_n230;
  t85_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t85_n229;
  t85_n228: return 0.062056198716163635;
  t85_n229: return 0.1106129139661789;
  t85_n230: return 0.04088205099105835;
  t85_n231: return 0.0007354388944804668;
  t85_n232: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t85_n246;
  t85_n233: if (E.getNumReferences() >= 3313614848 /*4152.0*/) goto t85_n243;
  t85_n234: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t85_n236;
  t85_n235: return -0.03341435641050339;
  t85_n236: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t85_n238;
  t85_n237: return 0.04875978082418442;
  t85_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t85_n240;
  t85_n239: return 0.04381747171282768;
  t85_n240: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t85_n242;
  t85_n241: return 0.04694843664765358;
  t85_n242: return 0.09913903474807739;
  t85_n243: if (E.getNumReferences() >= 3313630208 /*4159.5*/) goto t85_n245;
  t85_n244: return 0.11507496237754822;
  t85_n245: return 0.03592969849705696;
  t85_n246: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t85_n252;
  t85_n247: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t85_n249;
  t85_n248: return 0.03979099541902542;
  t85_n249: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t85_n251;
  t85_n250: return 0.0696120336651802;
  t85_n251: return 0.03876448795199394;
  t85_n252: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t85_n254;
  t85_n253: return 0.12205598503351212;
  t85_n254: return -0.16799412667751312;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree86(const Example& E) {
  t86_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t86_n222;
  t86_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t86_n33;
  t86_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t86_n32;
  t86_n3: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t86_n25;
  t86_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n24;
  t86_n5: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t86_n11;
  t86_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t86_n8;
  t86_n7: return -0.014901822432875633;
  t86_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n10;
  t86_n9: return -0.03921071067452431;
  t86_n10: return 0.06309624016284943;
  t86_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t86_n13;
  t86_n12: return -0.004372728522866964;
  t86_n13: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t86_n17;
  t86_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t86_n16;
  t86_n15: return 0.05612543225288391;
  t86_n16: return -0.04221540316939354;
  t86_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n23;
  t86_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t86_n22;
  t86_n19: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t86_n21;
  t86_n20: return 0.11984872817993164;
  t86_n21: return 0.10750753432512283;
  t86_n22: return 0.08492794632911682;
  t86_n23: return 0.08461099863052368;
  t86_n24: return 0.0026814586017280817;
  t86_n25: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n27;
  t86_n26: return 0.009963863529264927;
  t86_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n29;
  t86_n28: return 0.0257763359695673;
  t86_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n31;
  t86_n30: return -0.08343840390443802;
  t86_n31: return 0.029688145965337753;
  t86_n32: return -0.008136586286127567;
  t86_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t86_n35;
  t86_n34: return -0.005581398960202932;
  t86_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t86_n81;
  t86_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t86_n56;
  t86_n37: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t86_n45;
  t86_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n40;
  t86_n39: return 0.12495332956314087;
  t86_n40: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t86_n42;
  t86_n41: return -0.07598315924406052;
  t86_n42: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n44;
  t86_n43: return 0.11774074286222458;
  t86_n44: return 0.11347357928752899;
  t86_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n49;
  t86_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t86_n48;
  t86_n47: return -0.0026366624515503645;
  t86_n48: return 0.046492259949445724;
  t86_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t86_n51;
  t86_n50: return 0.041892506182193756;
  t86_n51: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t86_n53;
  t86_n52: return 0.03621353581547737;
  t86_n53: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t86_n55;
  t86_n54: return 0.14077933132648468;
  t86_n55: return 0.005459258332848549;
  t86_n56: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t86_n60;
  t86_n57: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t86_n59;
  t86_n58: return -0.0655016154050827;
  t86_n59: return 0.046225108206272125;
  t86_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n72;
  t86_n61: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t86_n71;
  t86_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t86_n68;
  t86_n63: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t86_n67;
  t86_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t86_n66;
  t86_n65: return 0.10998072475194931;
  t86_n66: return 0.07007722556591034;
  t86_n67: return -0.1334874927997589;
  t86_n68: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t86_n70;
  t86_n69: return 0.11380952596664429;
  t86_n70: return 0.11952745914459229;
  t86_n71: return 0.08088698238134384;
  t86_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n80;
  t86_n73: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t86_n79;
  t86_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n76;
  t86_n75: return -0.10156150907278061;
  t86_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t86_n78;
  t86_n77: return 0.1060749739408493;
  t86_n78: return 0.03898996114730835;
  t86_n79: return 0.0032315836288034916;
  t86_n80: return 0.06463178992271423;
  t86_n81: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t86_n199;
  t86_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t86_n136;
  t86_n83: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t86_n131;
  t86_n84: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t86_n112;
  t86_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t86_n99;
  t86_n86: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t86_n88;
  t86_n87: return 0.016658395528793335;
  t86_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n94;
  t86_n89: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t86_n93;
  t86_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n92;
  t86_n91: return -0.13075308501720428;
  t86_n92: return 0.11736086010932922;
  t86_n93: return -0.04811609536409378;
  t86_n94: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n96;
  t86_n95: return 0.7134833931922913;
  t86_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n98;
  t86_n97: return 0.13981030881404877;
  t86_n98: return 0.18995285034179688;
  t86_n99: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t86_n111;
  t86_n100: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t86_n108;
  t86_n101: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t86_n103;
  t86_n102: return 0.046591538935899734;
  t86_n103: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t86_n107;
  t86_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t86_n106;
  t86_n105: return -0.22179043292999268;
  t86_n106: return 0.13202279806137085;
  t86_n107: return -0.05155754089355469;
  t86_n108: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t86_n110;
  t86_n109: return 0.1233953982591629;
  t86_n110: return 0.10910964012145996;
  t86_n111: return 0.008303452283143997;
  t86_n112: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t86_n116;
  t86_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t86_n115;
  t86_n114: return -0.06151549518108368;
  t86_n115: return 0.1118842288851738;
  t86_n116: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t86_n118;
  t86_n117: return -0.00945724081248045;
  t86_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t86_n124;
  t86_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n121;
  t86_n120: return -0.028524456545710564;
  t86_n121: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t86_n123;
  t86_n122: return -0.2677353620529175;
  t86_n123: return 0.07398351281881332;
  t86_n124: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t86_n130;
  t86_n125: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t86_n129;
  t86_n126: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t86_n128;
  t86_n127: return -0.07490992546081543;
  t86_n128: return 0.09776517003774643;
  t86_n129: return 0.07099756598472595;
  t86_n130: return 0.015354830771684647;
  t86_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n135;
  t86_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t86_n134;
  t86_n133: return -0.022295678034424782;
  t86_n134: return 0.03345656767487526;
  t86_n135: return -0.18300673365592957;
  t86_n136: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t86_n144;
  t86_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t86_n139;
  t86_n138: return -0.348863810300827;
  t86_n139: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t86_n141;
  t86_n140: return 0.11525668948888779;
  t86_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n143;
  t86_n142: return 0.10738355666399002;
  t86_n143: return -0.16689898073673248;
  t86_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n196;
  t86_n145: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t86_n151;
  t86_n146: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t86_n148;
  t86_n147: return 0.003938344307243824;
  t86_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t86_n150;
  t86_n149: return -0.03133254498243332;
  t86_n150: return 0.10747141391038895;
  t86_n151: if (E.getNumReferences() >= 3346880384 /*64855.5*/) goto t86_n155;
  t86_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t86_n154;
  t86_n153: return -0.21179643273353577;
  t86_n154: return -0.033725619316101074;
  t86_n155: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t86_n171;
  t86_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t86_n158;
  t86_n157: return -0.02715246193110943;
  t86_n158: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t86_n168;
  t86_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t86_n161;
  t86_n160: return -0.062438081949949265;
  t86_n161: if (E.getNumReferences() >= 3349697792 /*86186.0*/) goto t86_n167;
  t86_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n164;
  t86_n163: return 0.008589815348386765;
  t86_n164: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t86_n166;
  t86_n165: return 0.1095663458108902;
  t86_n166: return 0.07346916198730469;
  t86_n167: return 0.10189205408096313;
  t86_n168: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t86_n170;
  t86_n169: return 0.05346772074699402;
  t86_n170: return 0.11650291830301285;
  t86_n171: if (E.getNumReferences() >= 3358250528 /*174936.5*/) goto t86_n177;
  t86_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n174;
  t86_n173: return -2.070903778076172;
  t86_n174: if (E.getNumReferences() >= 3357701696 /*166361.0*/) goto t86_n176;
  t86_n175: return -0.08307034522294998;
  t86_n176: return -0.5219283103942871;
  t86_n177: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t86_n189;
  t86_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t86_n180;
  t86_n179: return -0.03606041893362999;
  t86_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n182;
  t86_n181: return -0.06333442777395248;
  t86_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t86_n184;
  t86_n183: return 0.04635797068476677;
  t86_n184: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t86_n188;
  t86_n185: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t86_n187;
  t86_n186: return 0.11455372720956802;
  t86_n187: return 0.06255797296762466;
  t86_n188: return 0.07654829323291779;
  t86_n189: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t86_n195;
  t86_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t86_n194;
  t86_n191: if (E.getNumReferences() >= 3364686096 /*288840.5*/) goto t86_n193;
  t86_n192: return -0.46236273646354675;
  t86_n193: return -0.6314000487327576;
  t86_n194: return -0.10784579813480377;
  t86_n195: return 0.012188334949314594;
  t86_n196: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t86_n198;
  t86_n197: return 0.005771809257566929;
  t86_n198: return 0.06031012535095215;
  t86_n199: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t86_n215;
  t86_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t86_n214;
  t86_n201: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t86_n207;
  t86_n202: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t86_n206;
  t86_n203: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n205;
  t86_n204: return 0.07712389528751373;
  t86_n205: return 0.11336848139762878;
  t86_n206: return -0.07334688305854797;
  t86_n207: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t86_n213;
  t86_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t86_n212;
  t86_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t86_n211;
  t86_n210: return 0.09264495968818665;
  t86_n211: return 0.11788507550954819;
  t86_n212: return 0.060460858047008514;
  t86_n213: return 0.07946082949638367;
  t86_n214: return -0.004051030147820711;
  t86_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t86_n217;
  t86_n216: return -0.016884129494428635;
  t86_n217: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t86_n219;
  t86_n218: return -0.12051382660865784;
  t86_n219: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t86_n221;
  t86_n220: return 0.12943081557750702;
  t86_n221: return 0.15910527110099792;
  t86_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t86_n238;
  t86_n223: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t86_n233;
  t86_n224: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t86_n228;
  t86_n225: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t86_n227;
  t86_n226: return -0.14771823585033417;
  t86_n227: return -0.09828212112188339;
  t86_n228: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t86_n230;
  t86_n229: return 0.05361367389559746;
  t86_n230: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t86_n232;
  t86_n231: return 0.12988892197608948;
  t86_n232: return 0.08947324007749557;
  t86_n233: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t86_n235;
  t86_n234: return 0.002482177224010229;
  t86_n235: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t86_n237;
  t86_n236: return 0.05718285217881203;
  t86_n237: return 0.009992234408855438;
  t86_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t86_n240;
  t86_n239: return 0.007579066790640354;
  t86_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t86_n252;
  t86_n241: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t86_n243;
  t86_n242: return -0.01450575701892376;
  t86_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t86_n245;
  t86_n244: return 0.005504683591425419;
  t86_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t86_n249;
  t86_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n248;
  t86_n247: return -0.1195109561085701;
  t86_n248: return 0.11849839985370636;
  t86_n249: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t86_n251;
  t86_n250: return -0.09384829550981522;
  t86_n251: return 0.15181852877140045;
  t86_n252: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t86_n254;
  t86_n253: return 0.013866784051060677;
  t86_n254: return 0.07809092104434967;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree87(const Example& E) {
  t87_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t87_n196;
  t87_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t87_n125;
  t87_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t87_n4;
  t87_n3: return -0.11628775298595428;
  t87_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t87_n14;
  t87_n5: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t87_n7;
  t87_n6: return 0.1057330071926117;
  t87_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t87_n9;
  t87_n8: return -0.008813121356070042;
  t87_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other))) goto t87_n13;
  t87_n10: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t87_n12;
  t87_n11: return 0.0076848724856972694;
  t87_n12: return -0.019063960760831833;
  t87_n13: return 0.03308931365609169;
  t87_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t87_n70;
  t87_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t87_n65;
  t87_n16: if (E.getNumReferences() >= 3341062528 /*42129.5*/) goto t87_n64;
  t87_n17: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t87_n35;
  t87_n18: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t87_n22;
  t87_n19: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t87_n21;
  t87_n20: return -0.030490517616271973;
  t87_n21: return 0.07135670632123947;
  t87_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n28;
  t87_n23: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t87_n25;
  t87_n24: return -0.22776134312152863;
  t87_n25: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t87_n27;
  t87_n26: return 0.08167427778244019;
  t87_n27: return -0.08915475755929947;
  t87_n28: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t87_n34;
  t87_n29: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t87_n31;
  t87_n30: return -0.09956569969654083;
  t87_n31: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t87_n33;
  t87_n32: return 0.11937577277421951;
  t87_n33: return 0.019082440063357353;
  t87_n34: return 0.028979215770959854;
  t87_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t87_n47;
  t87_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t87_n38;
  t87_n37: return -0.01118216197937727;
  t87_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t87_n46;
  t87_n39: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t87_n43;
  t87_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n42;
  t87_n41: return 0.09292887896299362;
  t87_n42: return 0.019500430673360825;
  t87_n43: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t87_n45;
  t87_n44: return 0.13720329105854034;
  t87_n45: return 0.05126666650176048;
  t87_n46: return 0.003968892153352499;
  t87_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t87_n53;
  t87_n48: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t87_n50;
  t87_n49: return 0.03480007126927376;
  t87_n50: if (E.getNumReferences() >= 3292602368 /*772.5*/) goto t87_n52;
  t87_n51: return 0.11955268681049347;
  t87_n52: return 0.044035524129867554;
  t87_n53: if (E.getNumReferences() >= 3324791296 /*11026.5*/) goto t87_n55;
  t87_n54: return 0.007562835235148668;
  t87_n55: if (E.getNumReferences() >= 3326378496 /*12576.5*/) goto t87_n57;
  t87_n56: return 0.12028569728136063;
  t87_n57: if (E.getNumReferences() >= 3329918464 /*16033.5*/) goto t87_n63;
  t87_n58: if (E.getNumReferences() >= 3329426944 /*15553.5*/) goto t87_n62;
  t87_n59: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t87_n61;
  t87_n60: return -0.0315476730465889;
  t87_n61: return 0.10553552955389023;
  t87_n62: return 0.10914351046085358;
  t87_n63: return -0.051981035619974136;
  t87_n64: return 0.09598565101623535;
  t87_n65: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t87_n69;
  t87_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n68;
  t87_n67: return -0.08942768722772598;
  t87_n68: return -0.03278869763016701;
  t87_n69: return 0.03731226921081543;
  t87_n70: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t87_n124;
  t87_n71: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n99;
  t87_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n76;
  t87_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n75;
  t87_n74: return 0.010031315498054028;
  t87_n75: return 0.043676409870386124;
  t87_n76: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t87_n78;
  t87_n77: return -0.0016155883204191923;
  t87_n78: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t87_n80;
  t87_n79: return 0.03199528157711029;
  t87_n80: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t87_n92;
  t87_n81: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t87_n91;
  t87_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t87_n86;
  t87_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t87_n85;
  t87_n84: return 0.6076871752738953;
  t87_n85: return 0.15731285512447357;
  t87_n86: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t87_n88;
  t87_n87: return -0.17192815244197845;
  t87_n88: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t87_n90;
  t87_n89: return 0.1389112025499344;
  t87_n90: return -0.1223527044057846;
  t87_n91: return 0.13791482150554657;
  t87_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t87_n98;
  t87_n93: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t87_n95;
  t87_n94: return 0.07837001234292984;
  t87_n95: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t87_n97;
  t87_n96: return 0.12223285436630249;
  t87_n97: return 0.2066696286201477;
  t87_n98: return 0.09307120740413666;
  t87_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t87_n111;
  t87_n100: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t87_n106;
  t87_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t87_n105;
  t87_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n104;
  t87_n103: return -0.042409759014844894;
  t87_n104: return -0.0023053751792758703;
  t87_n105: return 0.0372106172144413;
  t87_n106: if (E.getNumReferences() >= 3310428160 /*3346.0*/) goto t87_n108;
  t87_n107: return -0.19197282195091248;
  t87_n108: if (E.getNumReferences() >= 3320318976 /*7425.5*/) goto t87_n110;
  t87_n109: return 0.11022191494703293;
  t87_n110: return -0.4107034206390381;
  t87_n111: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t87_n113;
  t87_n112: return -0.015368728898465633;
  t87_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t87_n115;
  t87_n114: return -0.011141096241772175;
  t87_n115: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t87_n123;
  t87_n116: if (E.getNumReferences() >= 3294732288 /*902.5*/) goto t87_n122;
  t87_n117: if (E.getNumReferences() >= 3294625792 /*896.0*/) goto t87_n121;
  t87_n118: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t87_n120;
  t87_n119: return 0.06533105671405792;
  t87_n120: return -0.03829217329621315;
  t87_n121: return 0.10123725235462189;
  t87_n122: return -0.0644921138882637;
  t87_n123: return -0.028211770579218864;
  t87_n124: return 0.002810490084812045;
  t87_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n129;
  t87_n126: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t87_n128;
  t87_n127: return 0.01770184375345707;
  t87_n128: return -0.046288687735795975;
  t87_n129: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t87_n175;
  t87_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t87_n140;
  t87_n131: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t87_n139;
  t87_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n134;
  t87_n133: return 0.11155658960342407;
  t87_n134: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t87_n136;
  t87_n135: return -0.06173698604106903;
  t87_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n138;
  t87_n137: return 0.11639665812253952;
  t87_n138: return 0.11226838827133179;
  t87_n139: return 0.02394901029765606;
  t87_n140: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t87_n152;
  t87_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t87_n143;
  t87_n142: return -0.034080829471349716;
  t87_n143: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t87_n145;
  t87_n144: return -0.2733260691165924;
  t87_n145: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t87_n147;
  t87_n146: return 0.10914500802755356;
  t87_n147: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t87_n149;
  t87_n148: return -0.018672971054911613;
  t87_n149: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t87_n151;
  t87_n150: return 0.11269985884428024;
  t87_n151: return 0.08672671020030975;
  t87_n152: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n166;
  t87_n153: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t87_n165;
  t87_n154: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t87_n160;
  t87_n155: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t87_n159;
  t87_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n158;
  t87_n157: return 0.10816220939159393;
  t87_n158: return 0.0665724128484726;
  t87_n159: return -0.1278628259897232;
  t87_n160: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t87_n162;
  t87_n161: return 0.11802761256694794;
  t87_n162: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t87_n164;
  t87_n163: return 0.11014766246080399;
  t87_n164: return 0.09785891324281693;
  t87_n165: return 0.08020705729722977;
  t87_n166: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n174;
  t87_n167: if (E.getNumReferences() >= 3359238848 /*190379.0*/) goto t87_n173;
  t87_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t87_n170;
  t87_n169: return -0.10151039063930511;
  t87_n170: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n172;
  t87_n171: return 0.10457836836576462;
  t87_n172: return 0.03513401746749878;
  t87_n173: return 0.0029950204771012068;
  t87_n174: return 0.06180323660373688;
  t87_n175: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t87_n177;
  t87_n176: return 0.013550016097724438;
  t87_n177: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t87_n189;
  t87_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t87_n188;
  t87_n179: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t87_n181;
  t87_n180: return 0.06772007793188095;
  t87_n181: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t87_n187;
  t87_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t87_n184;
  t87_n183: return 0.08255258202552795;
  t87_n184: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t87_n186;
  t87_n185: return 0.11635338515043259;
  t87_n186: return 0.07400606572628021;
  t87_n187: return 0.07563205808401108;
  t87_n188: return -0.00704483687877655;
  t87_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t87_n191;
  t87_n190: return -0.01489521935582161;
  t87_n191: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t87_n193;
  t87_n192: return -0.11848245561122894;
  t87_n193: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t87_n195;
  t87_n194: return 0.1270388960838318;
  t87_n195: return 0.17390106618404388;
  t87_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t87_n198;
  t87_n197: return -0.009208745323121548;
  t87_n198: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t87_n248;
  t87_n199: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t87_n237;
  t87_n200: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t87_n228;
  t87_n201: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t87_n225;
  t87_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t87_n222;
  t87_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n205;
  t87_n204: return 0.05467723309993744;
  t87_n205: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t87_n209;
  t87_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t87_n208;
  t87_n207: return -0.05254213511943817;
  t87_n208: return 0.018022621050477028;
  t87_n209: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t87_n221;
  t87_n210: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t87_n212;
  t87_n211: return -0.1325269341468811;
  t87_n212: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t87_n214;
  t87_n213: return -0.03378302603960037;
  t87_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t87_n220;
  t87_n215: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t87_n217;
  t87_n216: return -0.09474018216133118;
  t87_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t87_n219;
  t87_n218: return 0.11489252001047134;
  t87_n219: return -0.09392505139112473;
  t87_n220: return 0.0020563064608722925;
  t87_n221: return 0.01829403266310692;
  t87_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t87_n224;
  t87_n223: return 0.024965614080429077;
  t87_n224: return 0.026654548943042755;
  t87_n225: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n227;
  t87_n226: return -0.017781270667910576;
  t87_n227: return -0.20119620859622955;
  t87_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t87_n232;
  t87_n229: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t87_n231;
  t87_n230: return -0.14481323957443237;
  t87_n231: return 0.009740496054291725;
  t87_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n236;
  t87_n233: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t87_n235;
  t87_n234: return 0.0016646413132548332;
  t87_n235: return 0.08628743141889572;
  t87_n236: return 0.03244130685925484;
  t87_n237: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t87_n241;
  t87_n238: if (E.getNumReferences() >= 3290382336 /*637.0*/) goto t87_n240;
  t87_n239: return 0.030123943462967873;
  t87_n240: return -0.022763114422559738;
  t87_n241: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t87_n243;
  t87_n242: return 0.11538082361221313;
  t87_n243: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t87_n245;
  t87_n244: return 0.035427525639534;
  t87_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t87_n247;
  t87_n246: return 0.10907746106386185;
  t87_n247: return 0.010225612670183182;
  t87_n248: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t87_n254;
  t87_n249: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t87_n251;
  t87_n250: return -0.0002573787060100585;
  t87_n251: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t87_n253;
  t87_n252: return 0.04091113060712814;
  t87_n253: return 0.011085816659033298;
  t87_n254: return -0.1339544802904129;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree88(const Example& E) {
  t88_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t88_n222;
  t88_n1: if (E.getNumReferences() >= 3305279488 /*2089.0*/) goto t88_n3;
  t88_n2: return -0.0019331062212586403;
  t88_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t88_n9;
  t88_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t88_n8;
  t88_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t88_n7;
  t88_n6: return 0.013066159561276436;
  t88_n7: return 0.036648016422986984;
  t88_n8: return -0.004229486919939518;
  t88_n9: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t88_n91;
  t88_n10: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t88_n20;
  t88_n11: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t88_n19;
  t88_n12: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t88_n16;
  t88_n13: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n15;
  t88_n14: return 0.016373395919799805;
  t88_n15: return 0.03305162861943245;
  t88_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t88_n18;
  t88_n17: return 0.11941665410995483;
  t88_n18: return 0.10877404361963272;
  t88_n19: return -0.23268960416316986;
  t88_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t88_n44;
  t88_n21: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t88_n35;
  t88_n22: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t88_n30;
  t88_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t88_n25;
  t88_n24: return 0.02682199329137802;
  t88_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n27;
  t88_n26: return 0.0781576856970787;
  t88_n27: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t88_n29;
  t88_n28: return 0.12235121428966522;
  t88_n29: return 0.09662851691246033;
  t88_n30: if (E.getNumReferences() >= 3331599872 /*18967.0*/) goto t88_n32;
  t88_n31: return 0.02399316057562828;
  t88_n32: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t88_n34;
  t88_n33: return 0.1149120032787323;
  t88_n34: return 0.07038096338510513;
  t88_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t88_n37;
  t88_n36: return 0.05915047600865364;
  t88_n37: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n41;
  t88_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t88_n40;
  t88_n39: return 0.07722964882850647;
  t88_n40: return 0.10718347132205963;
  t88_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t88_n43;
  t88_n42: return -0.0241363737732172;
  t88_n43: return 0.11518587917089462;
  t88_n44: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t88_n68;
  t88_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t88_n53;
  t88_n46: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t88_n52;
  t88_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n51;
  t88_n48: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t88_n50;
  t88_n49: return 0.11610724031925201;
  t88_n50: return 0.11346647888422012;
  t88_n51: return 0.09196876734495163;
  t88_n52: return 0.037682611495256424;
  t88_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t88_n55;
  t88_n54: return 0.059955623000860214;
  t88_n55: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t88_n61;
  t88_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t88_n60;
  t88_n57: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n59;
  t88_n58: return -0.10862762480974197;
  t88_n59: return 0.11845000088214874;
  t88_n60: return 0.06913544237613678;
  t88_n61: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t88_n63;
  t88_n62: return 0.10987668484449387;
  t88_n63: if (E.getNumReferences() >= 3322584576 /*8871.5*/) goto t88_n65;
  t88_n64: return -0.0625702366232872;
  t88_n65: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t88_n67;
  t88_n66: return 0.13229703903198242;
  t88_n67: return 0.10043883323669434;
  t88_n68: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t88_n86;
  t88_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t88_n83;
  t88_n70: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t88_n76;
  t88_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t88_n73;
  t88_n72: return 0.056730277836322784;
  t88_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n75;
  t88_n74: return 0.13039585947990417;
  t88_n75: return 0.12754791975021362;
  t88_n76: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t88_n78;
  t88_n77: return 0.05046508088707924;
  t88_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t88_n80;
  t88_n79: return 0.11771417409181595;
  t88_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n82;
  t88_n81: return 0.1108623668551445;
  t88_n82: return -0.10089197009801865;
  t88_n83: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t88_n85;
  t88_n84: return 0.09522618353366852;
  t88_n85: return 0.10524334758520126;
  t88_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t88_n88;
  t88_n87: return 0.045019928365945816;
  t88_n88: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t88_n90;
  t88_n89: return 0.11753499507904053;
  t88_n90: return 0.05308033525943756;
  t88_n91: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t88_n221;
  t88_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t88_n128;
  t88_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t88_n113;
  t88_n94: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t88_n104;
  t88_n95: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t88_n101;
  t88_n96: if (E.getNumReferences() >= 3335106048 /*25815.0*/) goto t88_n100;
  t88_n97: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t88_n99;
  t88_n98: return -0.2342379093170166;
  t88_n99: return -0.5293570160865784;
  t88_n100: return -0.06391661614179611;
  t88_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t88_n103;
  t88_n102: return 0.04596942290663719;
  t88_n103: return 0.1093929186463356;
  t88_n104: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n110;
  t88_n105: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n109;
  t88_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t88_n108;
  t88_n107: return -0.23768188059329987;
  t88_n108: return 0.07575423270463943;
  t88_n109: return -0.3871825337409973;
  t88_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t88_n112;
  t88_n111: return 0.021476713940501213;
  t88_n112: return 0.10897155851125717;
  t88_n113: if (E.getNumReferences() >= 3336214528 /*27980.0*/) goto t88_n115;
  t88_n114: return -0.13653625547885895;
  t88_n115: if (E.getNumReferences() >= 3339846528 /*37379.5*/) goto t88_n127;
  t88_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t88_n122;
  t88_n117: if (E.getNumReferences() >= 3339141760 /*34626.5*/) goto t88_n119;
  t88_n118: return 0.032722488045692444;
  t88_n119: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n121;
  t88_n120: return 0.11435133963823318;
  t88_n121: return 0.027848633006215096;
  t88_n122: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t88_n124;
  t88_n123: return -0.13918714225292206;
  t88_n124: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n126;
  t88_n125: return 0.10476019978523254;
  t88_n126: return 0.10773727297782898;
  t88_n127: return 0.007035726681351662;
  t88_n128: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t88_n130;
  t88_n129: return -0.02428918145596981;
  t88_n130: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t88_n142;
  t88_n131: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t88_n135;
  t88_n132: if (E.getNumReferences() >= 3338727808 /*33009.5*/) goto t88_n134;
  t88_n133: return 0.10497194528579712;
  t88_n134: return -0.1241740956902504;
  t88_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t88_n139;
  t88_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n138;
  t88_n137: return 0.1099093034863472;
  t88_n138: return 0.12273116409778595;
  t88_n139: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t88_n141;
  t88_n140: return 0.11190260946750641;
  t88_n141: return 0.1273903250694275;
  t88_n142: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t88_n178;
  t88_n143: if (E.getNumReferences() >= 3341381632 /*43376.0*/) goto t88_n145;
  t88_n144: return -0.016191232949495316;
  t88_n145: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t88_n159;
  t88_n146: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t88_n148;
  t88_n147: return 0.11207404732704163;
  t88_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t88_n152;
  t88_n149: if (E.getNumReferences() >= 3341684224 /*44558.0*/) goto t88_n151;
  t88_n150: return 0.069486603140831;
  t88_n151: return 0.11058168113231659;
  t88_n152: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t88_n154;
  t88_n153: return 0.09273581206798553;
  t88_n154: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n158;
  t88_n155: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t88_n157;
  t88_n156: return 0.11125440150499344;
  t88_n157: return 0.10440949350595474;
  t88_n158: return 0.09163620322942734;
  t88_n159: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t88_n173;
  t88_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t88_n166;
  t88_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t88_n163;
  t88_n162: return -0.053489070385694504;
  t88_n163: if (E.getNumReferences() >= 3342583296 /*48070.0*/) goto t88_n165;
  t88_n164: return 0.09598264843225479;
  t88_n165: return -0.0037742946296930313;
  t88_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t88_n168;
  t88_n167: return -0.28468555212020874;
  t88_n168: if (E.getNumReferences() >= 3343171712 /*50368.5*/) goto t88_n170;
  t88_n169: return -0.11519620567560196;
  t88_n170: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n172;
  t88_n171: return 0.10907400399446487;
  t88_n172: return 0.10131342709064484;
  t88_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n175;
  t88_n174: return -0.10549720376729965;
  t88_n175: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t88_n177;
  t88_n176: return -0.12050549685955048;
  t88_n177: return 0.12100321054458618;
  t88_n178: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t88_n188;
  t88_n179: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t88_n181;
  t88_n180: return -0.010635670274496078;
  t88_n181: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t88_n183;
  t88_n182: return 0.09564999490976334;
  t88_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n185;
  t88_n184: return -0.3434999883174896;
  t88_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n187;
  t88_n186: return -0.2591334879398346;
  t88_n187: return 0.05697208270430565;
  t88_n188: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t88_n190;
  t88_n189: return 0.10973823815584183;
  t88_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t88_n216;
  t88_n191: if (E.getNumReferences() >= 3362054368 /*234371.5*/) goto t88_n213;
  t88_n192: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t88_n204;
  t88_n193: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t88_n203;
  t88_n194: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t88_n196;
  t88_n195: return -0.019143179059028625;
  t88_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t88_n200;
  t88_n197: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t88_n199;
  t88_n198: return 0.10705012828111649;
  t88_n199: return 0.0575571171939373;
  t88_n200: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t88_n202;
  t88_n201: return 0.11975093930959702;
  t88_n202: return 0.10168440639972687;
  t88_n203: return -0.07567106932401657;
  t88_n204: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t88_n206;
  t88_n205: return 0.012577020563185215;
  t88_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t88_n208;
  t88_n207: return 0.07843604683876038;
  t88_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t88_n210;
  t88_n209: return 0.03099081665277481;
  t88_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t88_n212;
  t88_n211: return 0.11205422133207321;
  t88_n212: return 0.1086130142211914;
  t88_n213: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t88_n215;
  t88_n214: return -0.1367592066526413;
  t88_n215: return 0.01713823899626732;
  t88_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t88_n220;
  t88_n217: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t88_n219;
  t88_n218: return 0.11292009800672531;
  t88_n219: return 0.011175904422998428;
  t88_n220: return 0.06272812932729721;
  t88_n221: return 0.08221212774515152;
  t88_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t88_n224;
  t88_n223: return -0.008496902883052826;
  t88_n224: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t88_n234;
  t88_n225: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t88_n227;
  t88_n226: return 0.012493439950048923;
  t88_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t88_n231;
  t88_n228: if (E.getNumReferences() >= 3319676928 /*7112.0*/) goto t88_n230;
  t88_n229: return 0.07888499647378922;
  t88_n230: return 0.033925026655197144;
  t88_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t88_n233;
  t88_n232: return 0.10946422070264816;
  t88_n233: return -0.03800981491804123;
  t88_n234: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t88_n254;
  t88_n235: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t88_n237;
  t88_n236: return 0.003587705083191395;
  t88_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t88_n253;
  t88_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t88_n240;
  t88_n239: return 0.013412882573902607;
  t88_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t88_n252;
  t88_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t88_n243;
  t88_n242: return 0.02536408230662346;
  t88_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t88_n251;
  t88_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t88_n250;
  t88_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t88_n247;
  t88_n246: return 0.14960120618343353;
  t88_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t88_n249;
  t88_n248: return 0.10195866972208023;
  t88_n249: return 0.10008913278579712;
  t88_n250: return 0.10985641181468964;
  t88_n251: return -0.014676832593977451;
  t88_n252: return 0.04904639720916748;
  t88_n253: return 0.012395542114973068;
  t88_n254: return -0.1517466902732849;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree89(const Example& E) {
  t89_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t89_n234;
  t89_n1: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t89_n47;
  t89_n2: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t89_n12;
  t89_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t89_n5;
  t89_n4: return -0.0013932842994108796;
  t89_n5: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t89_n7;
  t89_n6: return 0.013302811421453953;
  t89_n7: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t89_n9;
  t89_n8: return 0.032376479357481;
  t89_n9: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t89_n11;
  t89_n10: return 0.04370465129613876;
  t89_n11: return 0.0591544583439827;
  t89_n12: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t89_n14;
  t89_n13: return -0.014443906955420971;
  t89_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t89_n24;
  t89_n15: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t89_n17;
  t89_n16: return -0.0012911359081044793;
  t89_n17: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t89_n23;
  t89_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t89_n20;
  t89_n19: return -0.10082975029945374;
  t89_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n22;
  t89_n21: return 0.11656443774700165;
  t89_n22: return 0.10888804495334625;
  t89_n23: return -0.21046681702136993;
  t89_n24: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t89_n32;
  t89_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t89_n27;
  t89_n26: return -0.014010416343808174;
  t89_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n29;
  t89_n28: return 0.00863976962864399;
  t89_n29: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t89_n31;
  t89_n30: return 0.0021820913534611464;
  t89_n31: return 0.03534537926316261;
  t89_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t89_n36;
  t89_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t89_n35;
  t89_n34: return 0.004169144667685032;
  t89_n35: return 0.024154052138328552;
  t89_n36: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t89_n46;
  t89_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n45;
  t89_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t89_n44;
  t89_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n41;
  t89_n40: return 0.11448563635349274;
  t89_n41: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t89_n43;
  t89_n42: return 0.12266288697719574;
  t89_n43: return 0.10746205598115921;
  t89_n44: return 0.08609066158533096;
  t89_n45: return 0.0832735076546669;
  t89_n46: return -0.05329224839806557;
  t89_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t89_n63;
  t89_n48: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t89_n50;
  t89_n49: return -0.0103424321860075;
  t89_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t89_n58;
  t89_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t89_n53;
  t89_n52: return 0.11376003175973892;
  t89_n53: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t89_n57;
  t89_n54: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t89_n56;
  t89_n55: return 0.07986650615930557;
  t89_n56: return -0.0852760449051857;
  t89_n57: return 0.053016677498817444;
  t89_n58: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t89_n60;
  t89_n59: return 0.10637388378381729;
  t89_n60: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t89_n62;
  t89_n61: return 0.07459811121225357;
  t89_n62: return -0.43355345726013184;
  t89_n63: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t89_n195;
  t89_n64: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t89_n186;
  t89_n65: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t89_n173;
  t89_n66: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t89_n170;
  t89_n67: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t89_n141;
  t89_n68: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t89_n136;
  t89_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t89_n105;
  t89_n70: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t89_n72;
  t89_n71: return 0.008188581094145775;
  t89_n72: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t89_n80;
  t89_n73: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t89_n75;
  t89_n74: return -0.04972122237086296;
  t89_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t89_n77;
  t89_n76: return 0.07616344094276428;
  t89_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n79;
  t89_n78: return 0.13423706591129303;
  t89_n79: return 0.09807059168815613;
  t89_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t89_n82;
  t89_n81: return 0.020908555015921593;
  t89_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n94;
  t89_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t89_n85;
  t89_n84: return -0.14218737185001373;
  t89_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n91;
  t89_n86: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t89_n90;
  t89_n87: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t89_n89;
  t89_n88: return 0.10389479994773865;
  t89_n89: return 0.11176566034555435;
  t89_n90: return 0.08990396559238434;
  t89_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n93;
  t89_n92: return 0.1028042733669281;
  t89_n93: return 0.07266785204410553;
  t89_n94: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t89_n96;
  t89_n95: return 0.01721895858645439;
  t89_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t89_n98;
  t89_n97: return -0.15233644843101501;
  t89_n98: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t89_n104;
  t89_n99: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t89_n103;
  t89_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n102;
  t89_n101: return 0.15126611292362213;
  t89_n102: return 0.11078572273254395;
  t89_n103: return 0.1379106342792511;
  t89_n104: return 0.09415178000926971;
  t89_n105: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t89_n107;
  t89_n106: return 0.11246531456708908;
  t89_n107: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t89_n109;
  t89_n108: return 0.011042041704058647;
  t89_n109: if (E.getNumReferences() >= 3350198272 /*90096.0*/) goto t89_n131;
  t89_n110: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t89_n128;
  t89_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t89_n113;
  t89_n112: return -0.041147999465465546;
  t89_n113: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t89_n115;
  t89_n114: return 0.07656379789113998;
  t89_n115: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t89_n127;
  t89_n116: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t89_n126;
  t89_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t89_n121;
  t89_n118: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t89_n120;
  t89_n119: return 0.11539280414581299;
  t89_n120: return 0.12057202309370041;
  t89_n121: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t89_n125;
  t89_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n124;
  t89_n123: return 0.07725638896226883;
  t89_n124: return 0.10585633665323257;
  t89_n125: return 0.14829492568969727;
  t89_n126: return -0.4393380284309387;
  t89_n127: return -0.02223432995378971;
  t89_n128: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t89_n130;
  t89_n129: return 0.11816740036010742;
  t89_n130: return 0.10554343461990356;
  t89_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n133;
  t89_n132: return -0.025664135813713074;
  t89_n133: if (E.getNumReferences() >= 3350665472 /*93746.0*/) goto t89_n135;
  t89_n134: return -0.3605574667453766;
  t89_n135: return 0.09625992923974991;
  t89_n136: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t89_n138;
  t89_n137: return -0.032794274389743805;
  t89_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t89_n140;
  t89_n139: return -0.4087933599948883;
  t89_n140: return -0.11341601610183716;
  t89_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t89_n157;
  t89_n142: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t89_n144;
  t89_n143: return 0.011381156742572784;
  t89_n144: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t89_n156;
  t89_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t89_n147;
  t89_n146: return -0.12228679656982422;
  t89_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n149;
  t89_n148: return 0.12217558175325394;
  t89_n149: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t89_n151;
  t89_n150: return 0.07143720984458923;
  t89_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t89_n153;
  t89_n152: return 0.05527637526392937;
  t89_n153: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t89_n155;
  t89_n154: return 0.1143098920583725;
  t89_n155: return 0.10860484838485718;
  t89_n156: return 0.02283373475074768;
  t89_n157: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t89_n163;
  t89_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t89_n160;
  t89_n159: return 0.016740091145038605;
  t89_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n162;
  t89_n161: return 0.10408038645982742;
  t89_n162: return 0.07885202765464783;
  t89_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t89_n165;
  t89_n164: return -0.12119932472705841;
  t89_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n167;
  t89_n166: return 0.08818630129098892;
  t89_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t89_n169;
  t89_n168: return -0.09497532993555069;
  t89_n169: return 0.06353402137756348;
  t89_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n172;
  t89_n171: return -0.04333725944161415;
  t89_n172: return -0.18325291574001312;
  t89_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t89_n175;
  t89_n174: return 0.031017020344734192;
  t89_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n177;
  t89_n176: return 0.05815437063574791;
  t89_n177: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t89_n185;
  t89_n178: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t89_n184;
  t89_n179: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t89_n181;
  t89_n180: return 0.16016143560409546;
  t89_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n183;
  t89_n182: return 0.14304210245609283;
  t89_n183: return 0.17072182893753052;
  t89_n184: return -0.07953408360481262;
  t89_n185: return -0.023030830547213554;
  t89_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t89_n194;
  t89_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t89_n191;
  t89_n188: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t89_n190;
  t89_n189: return 0.04135977849364281;
  t89_n190: return -0.06907347589731216;
  t89_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t89_n193;
  t89_n192: return -0.17768962681293488;
  t89_n193: return 0.034727275371551514;
  t89_n194: return -0.24480852484703064;
  t89_n195: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t89_n221;
  t89_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t89_n214;
  t89_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t89_n203;
  t89_n198: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t89_n202;
  t89_n199: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t89_n201;
  t89_n200: return 0.09666161984205246;
  t89_n201: return 0.021892733871936798;
  t89_n202: return 0.07517735660076141;
  t89_n203: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t89_n213;
  t89_n204: if (E.getNumReferences() >= 3338840960 /*33451.5*/) goto t89_n206;
  t89_n205: return -0.11908424645662308;
  t89_n206: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t89_n210;
  t89_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t89_n209;
  t89_n208: return 0.1290256828069687;
  t89_n209: return 0.15128837525844574;
  t89_n210: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t89_n212;
  t89_n211: return -0.02609185129404068;
  t89_n212: return 0.18150347471237183;
  t89_n213: return 0.06184552237391472;
  t89_n214: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t89_n216;
  t89_n215: return 0.11677627265453339;
  t89_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n220;
  t89_n217: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t89_n219;
  t89_n218: return 0.12260795384645462;
  t89_n219: return -0.3108482360839844;
  t89_n220: return 0.041516054421663284;
  t89_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t89_n229;
  t89_n222: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n226;
  t89_n223: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t89_n225;
  t89_n224: return 0.04237937182188034;
  t89_n225: return 0.11047250777482986;
  t89_n226: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t89_n228;
  t89_n227: return 0.08285442739725113;
  t89_n228: return -0.03728536143898964;
  t89_n229: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t89_n231;
  t89_n230: return -0.1029222160577774;
  t89_n231: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t89_n233;
  t89_n232: return 0.10821566730737686;
  t89_n233: return 0.024359581992030144;
  t89_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t89_n236;
  t89_n235: return -0.008312092162668705;
  t89_n236: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t89_n254;
  t89_n237: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t89_n249;
  t89_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t89_n248;
  t89_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t89_n243;
  t89_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t89_n242;
  t89_n241: return 0.05020986497402191;
  t89_n242: return -0.026255596429109573;
  t89_n243: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t89_n245;
  t89_n244: return 0.024695435538887978;
  t89_n245: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t89_n247;
  t89_n246: return -0.018348129466176033;
  t89_n247: return -0.2151045948266983;
  t89_n248: return 0.013299467973411083;
  t89_n249: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t89_n251;
  t89_n250: return 0.02374059148132801;
  t89_n251: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t89_n253;
  t89_n252: return 0.093622587621212;
  t89_n253: return 0.031102754175662994;
  t89_n254: return 0.005307594779878855;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree90(const Example& E) {
  t90_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t90_n144;
  t90_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n85;
  t90_n2: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t90_n4;
  t90_n3: return -0.013580617494881153;
  t90_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t90_n66;
  t90_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t90_n7;
  t90_n6: return -0.059374257922172546;
  t90_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t90_n49;
  t90_n8: if (E.getNumReferences() >= 3290275840 /*630.5*/) goto t90_n10;
  t90_n9: return -0.035215526819229126;
  t90_n10: if (E.getNumReferences() >= 3290652672 /*653.5*/) goto t90_n16;
  t90_n11: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t90_n15;
  t90_n12: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t90_n14;
  t90_n13: return 0.19147568941116333;
  t90_n14: return -0.10127517580986023;
  t90_n15: return 0.12894918024539948;
  t90_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t90_n18;
  t90_n17: return -0.012752394191920757;
  t90_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n42;
  t90_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n23;
  t90_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n22;
  t90_n21: return 0.11819326877593994;
  t90_n22: return 0.09578695148229599;
  t90_n23: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t90_n39;
  t90_n24: if (E.getNumReferences() >= 3335799808 /*27170.0*/) goto t90_n38;
  t90_n25: if (E.getNumReferences() >= 3313870848 /*4277.0*/) goto t90_n31;
  t90_n26: if (E.getNumReferences() >= 3291906048 /*730.0*/) goto t90_n30;
  t90_n27: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t90_n29;
  t90_n28: return 0.9211122393608093;
  t90_n29: return 0.1883297562599182;
  t90_n30: return 0.0985427126288414;
  t90_n31: if (E.getNumReferences() >= 3317499904 /*6049.0*/) goto t90_n37;
  t90_n32: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t90_n36;
  t90_n33: if (E.getNumReferences() >= 3316636672 /*5627.5*/) goto t90_n35;
  t90_n34: return 0.12644195556640625;
  t90_n35: return 0.1107402890920639;
  t90_n36: return 0.18488024175167084;
  t90_n37: return 0.10645310580730438;
  t90_n38: return -0.002886181930080056;
  t90_n39: if (E.getNumReferences() >= 3308324864 /*2832.5*/) goto t90_n41;
  t90_n40: return 0.11613450199365616;
  t90_n41: return 0.09608709067106247;
  t90_n42: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t90_n44;
  t90_n43: return -0.01831178367137909;
  t90_n44: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t90_n48;
  t90_n45: if (E.getNumReferences() >= 3342540544 /*47903.0*/) goto t90_n47;
  t90_n46: return -0.1540508270263672;
  t90_n47: return 0.14355674386024475;
  t90_n48: return 0.059776149690151215;
  t90_n49: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t90_n51;
  t90_n50: return 0.006201054435223341;
  t90_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n53;
  t90_n52: return -0.11050742864608765;
  t90_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t90_n57;
  t90_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n56;
  t90_n55: return 0.05747659131884575;
  t90_n56: return 0.008104918524622917;
  t90_n57: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t90_n65;
  t90_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n64;
  t90_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t90_n61;
  t90_n60: return 0.11586341261863708;
  t90_n61: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t90_n63;
  t90_n62: return 0.11935010552406311;
  t90_n63: return 0.09404871612787247;
  t90_n64: return 0.08846642076969147;
  t90_n65: return -0.04923927038908005;
  t90_n66: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t90_n74;
  t90_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n73;
  t90_n68: if (E.getNumReferences() >= 3282698240 /*340.0*/) goto t90_n70;
  t90_n69: return -0.10822812467813492;
  t90_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n72;
  t90_n71: return -0.056660041213035583;
  t90_n72: return 0.09581486880779266;
  t90_n73: return 0.012565921992063522;
  t90_n74: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t90_n84;
  t90_n75: if (E.getNumReferences() >= 3309207552 /*3048.0*/) goto t90_n79;
  t90_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n78;
  t90_n77: return -0.2446068376302719;
  t90_n78: return -0.02512669749557972;
  t90_n79: if (E.getNumReferences() >= 3315111936 /*4883.0*/) goto t90_n83;
  t90_n80: if (E.getNumReferences() >= 3312928768 /*3956.5*/) goto t90_n82;
  t90_n81: return 0.15614217519760132;
  t90_n82: return 0.12262754887342453;
  t90_n83: return 0.042528651654720306;
  t90_n84: return 0.09625217318534851;
  t90_n85: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t90_n143;
  t90_n86: if (E.getNumReferences() >= 3324968960 /*11200.0*/) goto t90_n116;
  t90_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t90_n113;
  t90_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n90;
  t90_n89: return 0.0040460205636918545;
  t90_n90: if (E.getNumReferences() >= 3314489344 /*4579.0*/) goto t90_n112;
  t90_n91: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t90_n99;
  t90_n92: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t90_n94;
  t90_n93: return -0.04241906851530075;
  t90_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t90_n96;
  t90_n95: return -0.011248396709561348;
  t90_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n98;
  t90_n97: return 0.06944935768842697;
  t90_n98: return 0.09185092151165009;
  t90_n99: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t90_n111;
  t90_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t90_n104;
  t90_n101: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t90_n103;
  t90_n102: return 0.09248754382133484;
  t90_n103: return -0.043285686522722244;
  t90_n104: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n110;
  t90_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n107;
  t90_n106: return 0.08801829814910889;
  t90_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t90_n109;
  t90_n108: return 0.016699358820915222;
  t90_n109: return 0.0593419224023819;
  t90_n110: return 0.01918037422001362;
  t90_n111: return -0.11933251470327377;
  t90_n112: return 0.10553932189941406;
  t90_n113: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t90_n115;
  t90_n114: return 0.0230697114020586;
  t90_n115: return 0.07310432940721512;
  t90_n116: if (E.getNumReferences() >= 3325080064 /*11308.5*/) goto t90_n128;
  t90_n117: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t90_n123;
  t90_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n120;
  t90_n119: return 0.26612141728401184;
  t90_n120: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t90_n122;
  t90_n121: return -0.014952074736356735;
  t90_n122: return 0.17621654272079468;
  t90_n123: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t90_n125;
  t90_n124: return 0.06439662724733353;
  t90_n125: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t90_n127;
  t90_n126: return 0.14220748841762543;
  t90_n127: return -0.15012559294700623;
  t90_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n130;
  t90_n129: return 0.01756623201072216;
  t90_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t90_n134;
  t90_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t90_n133;
  t90_n132: return 0.019044263288378716;
  t90_n133: return -0.11388136446475983;
  t90_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n136;
  t90_n135: return 0.04712429642677307;
  t90_n136: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t90_n138;
  t90_n137: return 0.06395644694566727;
  t90_n138: if (E.getNumReferences() >= 3334014720 /*23683.5*/) goto t90_n142;
  t90_n139: if (E.getNumReferences() >= 3333541888 /*22760.0*/) goto t90_n141;
  t90_n140: return -0.1415024846792221;
  t90_n141: return 0.1214585080742836;
  t90_n142: return 0.08007388561964035;
  t90_n143: return -0.004380796104669571;
  t90_n144: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t90_n194;
  t90_n145: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t90_n191;
  t90_n146: if (E.getNumReferences() >= 3309051904 /*3010.0*/) goto t90_n188;
  t90_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t90_n183;
  t90_n148: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n178;
  t90_n149: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t90_n167;
  t90_n150: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t90_n154;
  t90_n151: if (E.getNumReferences() >= 3290472448 /*642.5*/) goto t90_n153;
  t90_n152: return -0.027084017172455788;
  t90_n153: return 0.10651377588510513;
  t90_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t90_n160;
  t90_n155: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t90_n157;
  t90_n156: return -0.231122687458992;
  t90_n157: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t90_n159;
  t90_n158: return 0.06391453742980957;
  t90_n159: return -0.07855476438999176;
  t90_n160: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t90_n166;
  t90_n161: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t90_n163;
  t90_n162: return -0.09007439017295837;
  t90_n163: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t90_n165;
  t90_n164: return 0.1156340166926384;
  t90_n165: return 0.017258236184716225;
  t90_n166: return 0.024787049740552902;
  t90_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t90_n169;
  t90_n168: return -0.08947516232728958;
  t90_n169: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t90_n177;
  t90_n170: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t90_n174;
  t90_n171: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t90_n173;
  t90_n172: return 0.03210261091589928;
  t90_n173: return -0.1845853477716446;
  t90_n174: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t90_n176;
  t90_n175: return 0.11707337200641632;
  t90_n176: return 0.00515561830252409;
  t90_n177: return 0.007754121441394091;
  t90_n178: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t90_n180;
  t90_n179: return -0.05402359366416931;
  t90_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t90_n182;
  t90_n181: return 0.10104937106370926;
  t90_n182: return 0.022429220378398895;
  t90_n183: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t90_n185;
  t90_n184: return 0.004281580913811922;
  t90_n185: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t90_n187;
  t90_n186: return -0.08631466329097748;
  t90_n187: return -0.16351714730262756;
  t90_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t90_n190;
  t90_n189: return 0.007555847521871328;
  t90_n190: return 0.02082991413772106;
  t90_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t90_n193;
  t90_n192: return -0.019192008301615715;
  t90_n193: return 0.09920475631952286;
  t90_n194: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t90_n242;
  t90_n195: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t90_n197;
  t90_n196: return 0.005613702815026045;
  t90_n197: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t90_n235;
  t90_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t90_n200;
  t90_n199: return 0.027857426553964615;
  t90_n200: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t90_n232;
  t90_n201: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t90_n207;
  t90_n202: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n204;
  t90_n203: return 0.06003290042281151;
  t90_n204: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t90_n206;
  t90_n205: return 0.11324705928564072;
  t90_n206: return 0.050521232187747955;
  t90_n207: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t90_n209;
  t90_n208: return -0.12928232550621033;
  t90_n209: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t90_n213;
  t90_n210: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t90_n212;
  t90_n211: return -0.306574285030365;
  t90_n212: return 0.12535779178142548;
  t90_n213: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n221;
  t90_n214: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t90_n220;
  t90_n215: if (E.getNumReferences() >= 3283632128 /*368.5*/) goto t90_n217;
  t90_n216: return 0.05132370814681053;
  t90_n217: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t90_n219;
  t90_n218: return 0.12759526073932648;
  t90_n219: return 0.09645063430070877;
  t90_n220: return -0.17243677377700806;
  t90_n221: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t90_n231;
  t90_n222: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t90_n228;
  t90_n223: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t90_n225;
  t90_n224: return -0.3752436935901642;
  t90_n225: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t90_n227;
  t90_n226: return 0.11670508235692978;
  t90_n227: return 0.022201359272003174;
  t90_n228: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t90_n230;
  t90_n229: return 0.05531039834022522;
  t90_n230: return 0.12048698216676712;
  t90_n231: return 0.12163485586643219;
  t90_n232: if (E.getNumReferences() >= 3304148992 /*1930.5*/) goto t90_n234;
  t90_n233: return -0.039114974439144135;
  t90_n234: return 0.10105887055397034;
  t90_n235: if (E.getNumReferences() >= 3335803904 /*27178.0*/) goto t90_n241;
  t90_n236: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t90_n240;
  t90_n237: if (E.getNumReferences() >= 3273981952 /*165.0*/) goto t90_n239;
  t90_n238: return 0.047741279006004333;
  t90_n239: return 0.1576385796070099;
  t90_n240: return 0.014117667451500893;
  t90_n241: return -0.11150164157152176;
  t90_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t90_n254;
  t90_n243: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t90_n245;
  t90_n244: return -0.013865823857486248;
  t90_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t90_n247;
  t90_n246: return 0.013182873837649822;
  t90_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t90_n251;
  t90_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n250;
  t90_n249: return -0.12743327021598816;
  t90_n250: return 0.11295319348573685;
  t90_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t90_n253;
  t90_n252: return -0.08899533003568649;
  t90_n253: return 0.24194617569446564;
  t90_n254: return 0.01101274136453867;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree91(const Example& E) {
  t91_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t91_n152;
  t91_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t91_n123;
  t91_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t91_n72;
  t91_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t91_n9;
  t91_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n6;
  t91_n5: return -0.013788510113954544;
  t91_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t91_n8;
  t91_n7: return -0.07296206057071686;
  t91_n8: return -0.01847437210381031;
  t91_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t91_n21;
  t91_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t91_n12;
  t91_n11: return -0.014842238277196884;
  t91_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n18;
  t91_n13: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t91_n15;
  t91_n14: return -0.0009304710547439754;
  t91_n15: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n17;
  t91_n16: return -0.04397441819310188;
  t91_n17: return 0.08637034147977829;
  t91_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t91_n20;
  t91_n19: return 0.004317864775657654;
  t91_n20: return 0.013207209296524525;
  t91_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t91_n23;
  t91_n22: return -0.09412462264299393;
  t91_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t91_n61;
  t91_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t91_n26;
  t91_n25: return 0.004148660693317652;
  t91_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n58;
  t91_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n43;
  t91_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n36;
  t91_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t91_n31;
  t91_n30: return 0.05443843826651573;
  t91_n31: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n35;
  t91_n32: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n34;
  t91_n33: return 0.17290598154067993;
  t91_n34: return 0.07825901359319687;
  t91_n35: return -0.05948074162006378;
  t91_n36: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n38;
  t91_n37: return 0.01617380790412426;
  t91_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t91_n42;
  t91_n39: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n41;
  t91_n40: return -0.02141495607793331;
  t91_n41: return -0.23517319560050964;
  t91_n42: return -0.02945588156580925;
  t91_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n57;
  t91_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t91_n50;
  t91_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n47;
  t91_n46: return 0.04692159593105316;
  t91_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n49;
  t91_n48: return -0.023437751457095146;
  t91_n49: return 0.019360411912202835;
  t91_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t91_n52;
  t91_n51: return 0.054665274918079376;
  t91_n52: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n54;
  t91_n53: return 0.06286381930112839;
  t91_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n56;
  t91_n55: return 0.11745084822177887;
  t91_n56: return 0.09734552353620529;
  t91_n57: return 0.0027284855023026466;
  t91_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n60;
  t91_n59: return 0.07462718337774277;
  t91_n60: return 0.026147127151489258;
  t91_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t91_n71;
  t91_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n70;
  t91_n63: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n69;
  t91_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t91_n66;
  t91_n65: return 0.1128472164273262;
  t91_n66: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t91_n68;
  t91_n67: return 0.11674876511096954;
  t91_n68: return 0.10526645183563232;
  t91_n69: return 0.0825088769197464;
  t91_n70: return 0.08388973772525787;
  t91_n71: return -0.06385532021522522;
  t91_n72: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t91_n122;
  t91_n73: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t91_n121;
  t91_n74: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t91_n112;
  t91_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t91_n111;
  t91_n76: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t91_n110;
  t91_n77: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t91_n109;
  t91_n78: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n98;
  t91_n79: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n81;
  t91_n80: return 0.0004479917697608471;
  t91_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n83;
  t91_n82: return 0.016367824748158455;
  t91_n83: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t91_n87;
  t91_n84: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t91_n86;
  t91_n85: return 0.02869129739701748;
  t91_n86: return -0.009382812306284904;
  t91_n87: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t91_n89;
  t91_n88: return 0.03665570542216301;
  t91_n89: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t91_n91;
  t91_n90: return 0.03806177154183388;
  t91_n91: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t91_n97;
  t91_n92: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t91_n96;
  t91_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n95;
  t91_n94: return 0.08450638502836227;
  t91_n95: return 0.07180760055780411;
  t91_n96: return 0.008426203392446041;
  t91_n97: return -0.08247287571430206;
  t91_n98: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t91_n106;
  t91_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t91_n103;
  t91_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n102;
  t91_n101: return -0.12166129052639008;
  t91_n102: return -0.008546290919184685;
  t91_n103: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t91_n105;
  t91_n104: return -0.14248333871364594;
  t91_n105: return 0.002229274483397603;
  t91_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t91_n108;
  t91_n107: return -0.023260897025465965;
  t91_n108: return 0.043338533490896225;
  t91_n109: return 0.02839268557727337;
  t91_n110: return -0.039403729140758514;
  t91_n111: return 0.009895702823996544;
  t91_n112: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n114;
  t91_n113: return -0.027316134423017502;
  t91_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t91_n116;
  t91_n115: return 0.0019222995033487678;
  t91_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n120;
  t91_n117: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t91_n119;
  t91_n118: return -0.22237035632133484;
  t91_n119: return 0.07396245002746582;
  t91_n120: return 0.0128756333142519;
  t91_n121: return -0.10856451094150543;
  t91_n122: return -0.0834413543343544;
  t91_n123: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t91_n151;
  t91_n124: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t91_n128;
  t91_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n127;
  t91_n126: return -0.05008958280086517;
  t91_n127: return -0.1557602733373642;
  t91_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t91_n130;
  t91_n129: return 0.005000901874154806;
  t91_n130: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t91_n132;
  t91_n131: return 0.029894618317484856;
  t91_n132: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t91_n142;
  t91_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n137;
  t91_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t91_n136;
  t91_n135: return 0.03750036284327507;
  t91_n136: return 0.09393113851547241;
  t91_n137: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t91_n139;
  t91_n138: return 0.014793389476835728;
  t91_n139: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t91_n141;
  t91_n140: return 0.14446255564689636;
  t91_n141: return 0.13567596673965454;
  t91_n142: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t91_n144;
  t91_n143: return 0.010547094978392124;
  t91_n144: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t91_n150;
  t91_n145: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t91_n147;
  t91_n146: return 0.056524112820625305;
  t91_n147: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t91_n149;
  t91_n148: return -0.0048543307930231094;
  t91_n149: return 0.13118448853492737;
  t91_n150: return -0.01330609992146492;
  t91_n151: return -0.057167090475559235;
  t91_n152: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t91_n208;
  t91_n153: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t91_n207;
  t91_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t91_n156;
  t91_n155: return 0.006293418351560831;
  t91_n156: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t91_n202;
  t91_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t91_n201;
  t91_n158: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t91_n174;
  t91_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t91_n167;
  t91_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t91_n162;
  t91_n161: return 0.015309490263462067;
  t91_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n166;
  t91_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t91_n165;
  t91_n164: return -0.02468269318342209;
  t91_n165: return 0.1160602942109108;
  t91_n166: return 0.023896263912320137;
  t91_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t91_n173;
  t91_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t91_n170;
  t91_n169: return 0.07298608869314194;
  t91_n170: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t91_n172;
  t91_n171: return 0.12685294449329376;
  t91_n172: return -0.024814728647470474;
  t91_n173: return 0.03173251450061798;
  t91_n174: if (E.getNumReferences() >= 3288604672 /*528.5*/) goto t91_n194;
  t91_n175: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t91_n191;
  t91_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t91_n190;
  t91_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t91_n185;
  t91_n178: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t91_n184;
  t91_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t91_n181;
  t91_n180: return 0.04546434432268143;
  t91_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t91_n183;
  t91_n182: return 0.026340385898947716;
  t91_n183: return 0.11230157315731049;
  t91_n184: return 0.05320980027318001;
  t91_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t91_n189;
  t91_n186: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t91_n188;
  t91_n187: return 0.12928026914596558;
  t91_n188: return -0.10333424061536789;
  t91_n189: return -0.14461694657802582;
  t91_n190: return 0.10618496686220169;
  t91_n191: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t91_n193;
  t91_n192: return 0.16305261850357056;
  t91_n193: return 0.06639331579208374;
  t91_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t91_n196;
  t91_n195: return 0.021786028519272804;
  t91_n196: if (E.getNumReferences() >= 3292446720 /*763.0*/) goto t91_n200;
  t91_n197: if (E.getNumReferences() >= 3291512832 /*706.0*/) goto t91_n199;
  t91_n198: return 0.06128747761249542;
  t91_n199: return 0.11121194064617157;
  t91_n200: return 0.05753231421113014;
  t91_n201: return 0.014706859365105629;
  t91_n202: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t91_n206;
  t91_n203: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t91_n205;
  t91_n204: return 0.09167957305908203;
  t91_n205: return 0.14827631413936615;
  t91_n206: return 0.037234168499708176;
  t91_n207: return -0.000315913581289351;
  t91_n208: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t91_n224;
  t91_n209: if (E.getNumReferences() >= 3313614848 /*4152.0*/) goto t91_n221;
  t91_n210: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t91_n212;
  t91_n211: return 0.04092763736844063;
  t91_n212: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t91_n214;
  t91_n213: return 0.032671455293893814;
  t91_n214: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t91_n216;
  t91_n215: return 0.0392797477543354;
  t91_n216: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t91_n220;
  t91_n217: if (E.getNumReferences() >= 3294593024 /*894.0*/) goto t91_n219;
  t91_n218: return 0.11028211563825607;
  t91_n219: return 0.10276346653699875;
  t91_n220: return 0.06535892933607101;
  t91_n221: if (E.getNumReferences() >= 3313630208 /*4159.5*/) goto t91_n223;
  t91_n222: return 0.11298196762800217;
  t91_n223: return 0.03309589996933937;
  t91_n224: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t91_n252;
  t91_n225: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t91_n227;
  t91_n226: return 0.05822230875492096;
  t91_n227: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t91_n229;
  t91_n228: return 0.029945772141218185;
  t91_n229: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t91_n237;
  t91_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t91_n232;
  t91_n231: return -0.0203792043030262;
  t91_n232: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t91_n236;
  t91_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t91_n235;
  t91_n234: return 0.3065938353538513;
  t91_n235: return 0.12786810100078583;
  t91_n236: return 0.11946596205234528;
  t91_n237: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t91_n241;
  t91_n238: if (E.getFilterLength() >= 3250323456 /*23.5*/) goto t91_n240;
  t91_n239: return 0.07541675865650177;
  t91_n240: return 0.11407490819692612;
  t91_n241: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t91_n251;
  t91_n242: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t91_n248;
  t91_n243: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t91_n245;
  t91_n244: return 0.030088525265455246;
  t91_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t91_n247;
  t91_n246: return 0.12218082696199417;
  t91_n247: return 0.12657605111598969;
  t91_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t91_n250;
  t91_n249: return -0.11574426293373108;
  t91_n250: return 0.13077184557914734;
  t91_n251: return 0.05406547337770462;
  t91_n252: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t91_n254;
  t91_n253: return -0.0024476961698383093;
  t91_n254: return 0.12647342681884766;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree92(const Example& E) {
  t92_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t92_n254;
  t92_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t92_n191;
  t92_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t92_n96;
  t92_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t92_n95;
  t92_n4: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t92_n6;
  t92_n5: return 0.0008949688635766506;
  t92_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t92_n14;
  t92_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t92_n9;
  t92_n8: return -0.0015973967965692282;
  t92_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t92_n11;
  t92_n10: return 0.04060117155313492;
  t92_n11: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t92_n13;
  t92_n12: return 0.10576030611991882;
  t92_n13: return 0.10061360150575638;
  t92_n14: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t92_n88;
  t92_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t92_n71;
  t92_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t92_n18;
  t92_n17: return 0.013841344974935055;
  t92_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n20;
  t92_n19: return -0.1486656814813614;
  t92_n20: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t92_n22;
  t92_n21: return 0.02331731654703617;
  t92_n22: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t92_n56;
  t92_n23: if (E.getNumReferences() >= 3285680128 /*431.0*/) goto t92_n31;
  t92_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t92_n26;
  t92_n25: return 0.030328065156936646;
  t92_n26: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t92_n28;
  t92_n27: return 0.049231063574552536;
  t92_n28: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t92_n30;
  t92_n29: return 0.12178874015808105;
  t92_n30: return 0.36823225021362305;
  t92_n31: if (E.getNumReferences() >= 3288621056 /*529.5*/) goto t92_n43;
  t92_n32: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t92_n42;
  t92_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t92_n39;
  t92_n34: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t92_n38;
  t92_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n37;
  t92_n36: return -0.21081885695457458;
  t92_n37: return 0.10641514509916306;
  t92_n38: return 0.08570070564746857;
  t92_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n41;
  t92_n40: return 0.11364197731018066;
  t92_n41: return 0.21358664333820343;
  t92_n42: return 0.14609740674495697;
  t92_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t92_n45;
  t92_n44: return 0.048064108937978745;
  t92_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t92_n51;
  t92_n46: if (E.getNumReferences() >= 3301322752 /*1585.5*/) goto t92_n48;
  t92_n47: return 0.07421763241291046;
  t92_n48: if (E.getNumReferences() >= 3302969344 /*1786.5*/) goto t92_n50;
  t92_n49: return 0.11553750932216644;
  t92_n50: return -0.037890203297138214;
  t92_n51: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t92_n53;
  t92_n52: return -0.2679949998855591;
  t92_n53: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t92_n55;
  t92_n54: return 0.11529235541820526;
  t92_n55: return 0.11342808604240417;
  t92_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t92_n58;
  t92_n57: return 0.02562674507498741;
  t92_n58: if (E.getNumReferences() >= 3281567744 /*305.5*/) goto t92_n64;
  t92_n59: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t92_n63;
  t92_n60: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t92_n62;
  t92_n61: return -0.1309720277786255;
  t92_n62: return 0.11345963180065155;
  t92_n63: return 0.04883890599012375;
  t92_n64: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t92_n70;
  t92_n65: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n69;
  t92_n66: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t92_n68;
  t92_n67: return 0.15797710418701172;
  t92_n68: return 0.30161672830581665;
  t92_n69: return 0.07054007053375244;
  t92_n70: return 0.08094429969787598;
  t92_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t92_n73;
  t92_n72: return -0.03526553884148598;
  t92_n73: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t92_n75;
  t92_n74: return -0.003446470480412245;
  t92_n75: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t92_n87;
  t92_n76: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t92_n78;
  t92_n77: return 0.006171420216560364;
  t92_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t92_n80;
  t92_n79: return 0.05520699545741081;
  t92_n80: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t92_n86;
  t92_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n83;
  t92_n82: return -0.1994556337594986;
  t92_n83: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t92_n85;
  t92_n84: return 0.0663532242178917;
  t92_n85: return 0.1434716433286667;
  t92_n86: return 0.14762425422668457;
  t92_n87: return -0.05013703554868698;
  t92_n88: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t92_n94;
  t92_n89: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t92_n91;
  t92_n90: return 0.09191864728927612;
  t92_n91: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t92_n93;
  t92_n92: return 0.11484480649232864;
  t92_n93: return 0.14864832162857056;
  t92_n94: return 0.04288038611412048;
  t92_n95: return -0.006895779632031918;
  t92_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t92_n98;
  t92_n97: return -0.005131830461323261;
  t92_n98: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t92_n154;
  t92_n99: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t92_n153;
  t92_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t92_n124;
  t92_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t92_n105;
  t92_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n104;
  t92_n103: return 0.015305396169424057;
  t92_n104: return -0.13180115818977356;
  t92_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n111;
  t92_n106: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t92_n110;
  t92_n107: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t92_n109;
  t92_n108: return 0.022459961473941803;
  t92_n109: return 0.07916975021362305;
  t92_n110: return -0.06784339994192123;
  t92_n111: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t92_n113;
  t92_n112: return 0.17121289670467377;
  t92_n113: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t92_n115;
  t92_n114: return 0.01501610316336155;
  t92_n115: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t92_n123;
  t92_n116: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t92_n120;
  t92_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n119;
  t92_n118: return 0.07536257803440094;
  t92_n119: return 0.0629354864358902;
  t92_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n122;
  t92_n121: return -0.11853931844234467;
  t92_n122: return 0.10356291383504868;
  t92_n123: return 0.037342410534620285;
  t92_n124: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t92_n136;
  t92_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n127;
  t92_n126: return -0.04245072603225708;
  t92_n127: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t92_n129;
  t92_n128: return -0.2978592813014984;
  t92_n129: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t92_n131;
  t92_n130: return 0.10778249800205231;
  t92_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t92_n133;
  t92_n132: return -0.023327196016907692;
  t92_n133: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t92_n135;
  t92_n134: return 0.11287417262792587;
  t92_n135: return 0.08378361910581589;
  t92_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n150;
  t92_n137: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t92_n149;
  t92_n138: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t92_n144;
  t92_n139: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t92_n143;
  t92_n140: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t92_n142;
  t92_n141: return 0.09376145899295807;
  t92_n142: return 0.11354996263980865;
  t92_n143: return -0.12357831746339798;
  t92_n144: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t92_n146;
  t92_n145: return 0.11772530525922775;
  t92_n146: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t92_n148;
  t92_n147: return 0.10801851004362106;
  t92_n148: return 0.09457523375749588;
  t92_n149: return 0.0681813508272171;
  t92_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n152;
  t92_n151: return 0.08415437489748001;
  t92_n152: return 0.058708351105451584;
  t92_n153: return 0.013351869769394398;
  t92_n154: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t92_n184;
  t92_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n183;
  t92_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t92_n182;
  t92_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t92_n181;
  t92_n158: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t92_n170;
  t92_n159: if (E.getNumReferences() >= 3347859008 /*71820.5*/) goto t92_n165;
  t92_n160: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t92_n164;
  t92_n161: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t92_n163;
  t92_n162: return -0.26450130343437195;
  t92_n163: return 0.14861264824867249;
  t92_n164: return -0.1390078067779541;
  t92_n165: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t92_n169;
  t92_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t92_n168;
  t92_n167: return -0.014729561284184456;
  t92_n168: return 0.11354831606149673;
  t92_n169: return -0.09384661167860031;
  t92_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t92_n176;
  t92_n171: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t92_n173;
  t92_n172: return -0.3974955081939697;
  t92_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t92_n175;
  t92_n174: return 0.08551622927188873;
  t92_n175: return 0.11142509430646896;
  t92_n176: if (E.getNumReferences() >= 3354468928 /*123460.5*/) goto t92_n180;
  t92_n177: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t92_n179;
  t92_n178: return 0.1122080460190773;
  t92_n179: return 0.1399553418159485;
  t92_n180: return 0.09439373016357422;
  t92_n181: return 0.05195832625031471;
  t92_n182: return -0.11558577418327332;
  t92_n183: return -0.022721845656633377;
  t92_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t92_n186;
  t92_n185: return 0.0074759372510015965;
  t92_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t92_n190;
  t92_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n189;
  t92_n188: return 0.12917599081993103;
  t92_n189: return 0.06629759073257446;
  t92_n190: return 0.16931694746017456;
  t92_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t92_n203;
  t92_n192: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t92_n198;
  t92_n193: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t92_n195;
  t92_n194: return 0.04457317292690277;
  t92_n195: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t92_n197;
  t92_n196: return 0.1280643194913864;
  t92_n197: return 0.05860201269388199;
  t92_n198: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t92_n200;
  t92_n199: return 0.002833856036886573;
  t92_n200: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t92_n202;
  t92_n201: return 0.05684596672654152;
  t92_n202: return -0.21018655598163605;
  t92_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t92_n205;
  t92_n204: return -0.00521433399990201;
  t92_n205: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t92_n253;
  t92_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t92_n210;
  t92_n207: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t92_n209;
  t92_n208: return 0.025125563144683838;
  t92_n209: return -0.09967195242643356;
  t92_n210: if (E.getNumReferences() >= 3315746816 /*5193.0*/) goto t92_n246;
  t92_n211: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t92_n245;
  t92_n212: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t92_n244;
  t92_n213: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t92_n243;
  t92_n214: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t92_n220;
  t92_n215: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t92_n217;
  t92_n216: return -0.008467103354632854;
  t92_n217: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t92_n219;
  t92_n218: return 0.0585981085896492;
  t92_n219: return 0.01362426858395338;
  t92_n220: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t92_n222;
  t92_n221: return 0.02888283133506775;
  t92_n222: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t92_n236;
  t92_n223: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t92_n225;
  t92_n224: return 0.09818050265312195;
  t92_n225: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t92_n231;
  t92_n226: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t92_n230;
  t92_n227: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t92_n229;
  t92_n228: return 0.11051346361637115;
  t92_n229: return 0.012475227005779743;
  t92_n230: return 0.11439338326454163;
  t92_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t92_n235;
  t92_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t92_n234;
  t92_n233: return 0.042005907744169235;
  t92_n234: return 0.1427599936723709;
  t92_n235: return -0.18130718171596527;
  t92_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t92_n238;
  t92_n237: return -0.25049540400505066;
  t92_n238: if (E.getNumReferences() >= 3303845888 /*1893.5*/) goto t92_n242;
  t92_n239: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t92_n241;
  t92_n240: return 0.039611320942640305;
  t92_n241: return 0.11415833979845047;
  t92_n242: return 0.10892347991466522;
  t92_n243: return -0.009709601290524006;
  t92_n244: return -0.10027007013559341;
  t92_n245: return 0.028247559443116188;
  t92_n246: if (E.getNumReferences() >= 3325685760 /*11900.0*/) goto t92_n252;
  t92_n247: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t92_n251;
  t92_n248: if (E.getNumReferences() >= 3318914048 /*6739.5*/) goto t92_n250;
  t92_n249: return 0.07772092521190643;
  t92_n250: return 0.10242249816656113;
  t92_n251: return 0.07754348963499069;
  t92_n252: return 0.04283998906612396;
  t92_n253: return 0.014021537266671658;
  t92_n254: return -0.07212435454130173;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree93(const Example& E) {
  t93_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t93_n164;
  t93_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t93_n73;
  t93_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n4;
  t93_n3: return -0.11479852348566055;
  t93_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n6;
  t93_n5: return -0.003721044398844242;
  t93_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t93_n72;
  t93_n7: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t93_n15;
  t93_n8: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t93_n14;
  t93_n9: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t93_n13;
  t93_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t93_n12;
  t93_n11: return -0.0673687756061554;
  t93_n12: return 0.09403929859399796;
  t93_n13: return -0.026617877185344696;
  t93_n14: return 0.09740018099546432;
  t93_n15: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t93_n23;
  t93_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n22;
  t93_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type))) goto t93_n19;
  t93_n18: return -0.01167472917586565;
  t93_n19: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t93_n21;
  t93_n20: return -0.004734032321721315;
  t93_n21: return 0.02650802582502365;
  t93_n22: return 0.00517780939117074;
  t93_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t93_n39;
  t93_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t93_n38;
  t93_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t93_n27;
  t93_n26: return -0.10258501768112183;
  t93_n27: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t93_n37;
  t93_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t93_n36;
  t93_n29: if (E.getNumReferences() >= 3291078656 /*679.5*/) goto t93_n33;
  t93_n30: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t93_n32;
  t93_n31: return -0.011980799958109856;
  t93_n32: return 0.07872717827558517;
  t93_n33: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t93_n35;
  t93_n34: return 0.11637800931930542;
  t93_n35: return 0.052517808973789215;
  t93_n36: return 0.04334212839603424;
  t93_n37: return 0.01847490668296814;
  t93_n38: return -0.006807100493460894;
  t93_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t93_n67;
  t93_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n42;
  t93_n41: return -0.07523392140865326;
  t93_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t93_n62;
  t93_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n49;
  t93_n44: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t93_n48;
  t93_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t93_n47;
  t93_n46: return -0.004315524827688932;
  t93_n47: return -0.09695594757795334;
  t93_n48: return 0.032706450670957565;
  t93_n49: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t93_n53;
  t93_n50: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t93_n52;
  t93_n51: return -0.1666632890701294;
  t93_n52: return 0.10973430424928665;
  t93_n53: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t93_n59;
  t93_n54: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t93_n56;
  t93_n55: return 0.06388328969478607;
  t93_n56: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t93_n58;
  t93_n57: return 0.10021292418241501;
  t93_n58: return 0.11040150374174118;
  t93_n59: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t93_n61;
  t93_n60: return -0.0037071772385388613;
  t93_n61: return 0.12210948020219803;
  t93_n62: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t93_n64;
  t93_n63: return -0.33195704221725464;
  t93_n64: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t93_n66;
  t93_n65: return 0.10930117219686508;
  t93_n66: return -0.042171068489551544;
  t93_n67: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t93_n71;
  t93_n68: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t93_n70;
  t93_n69: return 0.24892652034759521;
  t93_n70: return 0.12371934205293655;
  t93_n71: return 0.04119263216853142;
  t93_n72: return 0.006216792855411768;
  t93_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n89;
  t93_n74: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t93_n88;
  t93_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t93_n87;
  t93_n76: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t93_n86;
  t93_n77: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n85;
  t93_n78: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t93_n84;
  t93_n79: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t93_n83;
  t93_n80: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t93_n82;
  t93_n81: return -0.03760174289345741;
  t93_n82: return 0.0919179692864418;
  t93_n83: return -0.11926604807376862;
  t93_n84: return 0.07218517363071442;
  t93_n85: return -0.37309083342552185;
  t93_n86: return -0.4272361397743225;
  t93_n87: return 0.019578425213694572;
  t93_n88: return -0.041837263852357864;
  t93_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t93_n139;
  t93_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t93_n110;
  t93_n91: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n103;
  t93_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t93_n98;
  t93_n93: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t93_n95;
  t93_n94: return -0.0947510376572609;
  t93_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t93_n97;
  t93_n96: return -0.04582762345671654;
  t93_n97: return 0.02239491231739521;
  t93_n98: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t93_n102;
  t93_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n101;
  t93_n100: return 0.0607384517788887;
  t93_n101: return 0.16467615962028503;
  t93_n102: return 0.0266953743994236;
  t93_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t93_n105;
  t93_n104: return 0.03793978691101074;
  t93_n105: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t93_n107;
  t93_n106: return 0.020924510434269905;
  t93_n107: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t93_n109;
  t93_n108: return 0.1380591243505478;
  t93_n109: return -0.011907950043678284;
  t93_n110: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t93_n124;
  t93_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t93_n115;
  t93_n112: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t93_n114;
  t93_n113: return -0.21339188516139984;
  t93_n114: return 0.03693077340722084;
  t93_n115: if (E.getNumReferences() >= 3351141632 /*97466.0*/) goto t93_n117;
  t93_n116: return -0.19001269340515137;
  t93_n117: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t93_n119;
  t93_n118: return 0.10599879175424576;
  t93_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t93_n121;
  t93_n120: return -0.020268820226192474;
  t93_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t93_n123;
  t93_n122: return 0.11180479824542999;
  t93_n123: return 0.08106808364391327;
  t93_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t93_n136;
  t93_n125: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t93_n135;
  t93_n126: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t93_n132;
  t93_n127: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t93_n131;
  t93_n128: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t93_n130;
  t93_n129: return 0.09414543956518173;
  t93_n130: return 0.11162246763706207;
  t93_n131: return -0.12437767535448074;
  t93_n132: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t93_n134;
  t93_n133: return 0.11594954878091812;
  t93_n134: return 0.10197126865386963;
  t93_n135: return 0.0649259015917778;
  t93_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t93_n138;
  t93_n137: return 0.08366193622350693;
  t93_n138: return 0.05586916580796242;
  t93_n139: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t93_n141;
  t93_n140: return 0.012182624079287052;
  t93_n141: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t93_n163;
  t93_n142: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t93_n154;
  t93_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t93_n153;
  t93_n144: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t93_n152;
  t93_n145: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t93_n147;
  t93_n146: return 0.059667471796274185;
  t93_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t93_n151;
  t93_n148: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t93_n150;
  t93_n149: return 0.10397393256425858;
  t93_n150: return -0.2402770072221756;
  t93_n151: return 0.053517699241638184;
  t93_n152: return -0.23234470188617706;
  t93_n153: return -0.1325404942035675;
  t93_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t93_n158;
  t93_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t93_n157;
  t93_n156: return 0.11582250893115997;
  t93_n157: return -0.020317936316132545;
  t93_n158: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t93_n160;
  t93_n159: return -0.0044329483062028885;
  t93_n160: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t93_n162;
  t93_n161: return 0.12358897179365158;
  t93_n162: return -0.0047945487312972546;
  t93_n163: return 0.16070875525474548;
  t93_n164: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t93_n232;
  t93_n165: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t93_n227;
  t93_n166: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t93_n222;
  t93_n167: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t93_n209;
  t93_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t93_n170;
  t93_n169: return 0.017966443672776222;
  t93_n170: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t93_n200;
  t93_n171: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t93_n173;
  t93_n172: return 0.0024528319481760263;
  t93_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n183;
  t93_n174: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t93_n176;
  t93_n175: return -0.10025440901517868;
  t93_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t93_n178;
  t93_n177: return 0.021292079240083694;
  t93_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n180;
  t93_n179: return -0.1054961159825325;
  t93_n180: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t93_n182;
  t93_n181: return 0.03797357156872749;
  t93_n182: return -0.15282666683197021;
  t93_n183: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t93_n191;
  t93_n184: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t93_n190;
  t93_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n189;
  t93_n186: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t93_n188;
  t93_n187: return -0.06940817087888718;
  t93_n188: return 0.08258143067359924;
  t93_n189: return 0.021273138001561165;
  t93_n190: return -0.12247439473867416;
  t93_n191: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t93_n197;
  t93_n192: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t93_n194;
  t93_n193: return 0.0032313379924744368;
  t93_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t93_n196;
  t93_n195: return -0.1152707114815712;
  t93_n196: return 0.10931168496608734;
  t93_n197: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t93_n199;
  t93_n198: return -0.038751691579818726;
  t93_n199: return 0.13066869974136353;
  t93_n200: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t93_n208;
  t93_n201: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t93_n207;
  t93_n202: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n206;
  t93_n203: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t93_n205;
  t93_n204: return -0.017695019021630287;
  t93_n205: return -0.16398310661315918;
  t93_n206: return 0.01671292446553707;
  t93_n207: return 0.0258172620087862;
  t93_n208: return 0.032268330454826355;
  t93_n209: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t93_n219;
  t93_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Expression))) goto t93_n218;
  t93_n211: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t93_n213;
  t93_n212: return -0.08867473155260086;
  t93_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n217;
  t93_n214: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t93_n216;
  t93_n215: return 0.019763600081205368;
  t93_n216: return -0.127643883228302;
  t93_n217: return -0.0015345849096775055;
  t93_n218: return 0.013349982909858227;
  t93_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t93_n221;
  t93_n220: return 0.08511164784431458;
  t93_n221: return -0.04264364764094353;
  t93_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t93_n224;
  t93_n223: return -0.04332830011844635;
  t93_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t93_n226;
  t93_n225: return 0.00985138863325119;
  t93_n226: return 0.04874538257718086;
  t93_n227: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t93_n231;
  t93_n228: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t93_n230;
  t93_n229: return 0.1368129402399063;
  t93_n230: return -0.09389715641736984;
  t93_n231: return 0.029042167589068413;
  t93_n232: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t93_n234;
  t93_n233: return -0.0035300496965646744;
  t93_n234: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t93_n252;
  t93_n235: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t93_n237;
  t93_n236: return 0.03294902667403221;
  t93_n237: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t93_n251;
  t93_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t93_n240;
  t93_n239: return -0.05720536783337593;
  t93_n240: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t93_n244;
  t93_n241: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t93_n243;
  t93_n242: return -0.009075917303562164;
  t93_n243: return 0.1075400784611702;
  t93_n244: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t93_n250;
  t93_n245: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t93_n247;
  t93_n246: return 0.07813188433647156;
  t93_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t93_n249;
  t93_n248: return 0.13047564029693604;
  t93_n249: return 0.15127810835838318;
  t93_n250: return 0.05395945906639099;
  t93_n251: return 0.028056930750608444;
  t93_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t93_n254;
  t93_n253: return 0.010475507006049156;
  t93_n254: return -0.1477426439523697;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree94(const Example& E) {
  t94_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t94_n208;
  t94_n1: if (E.getNumReferences() >= 3304779776 /*2007.5*/) goto t94_n3;
  t94_n2: return -0.001733004697598517;
  t94_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t94_n9;
  t94_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t94_n8;
  t94_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t94_n7;
  t94_n6: return 0.012366735376417637;
  t94_n7: return 0.034616198390722275;
  t94_n8: return -0.0038749519735574722;
  t94_n9: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t94_n145;
  t94_n10: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t94_n24;
  t94_n11: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t94_n21;
  t94_n12: if (E.getNumReferences() >= 3319614464 /*7081.5*/) goto t94_n20;
  t94_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t94_n19;
  t94_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t94_n18;
  t94_n15: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t94_n17;
  t94_n16: return 0.09912141412496567;
  t94_n17: return -0.09034749120473862;
  t94_n18: return 0.009906149469316006;
  t94_n19: return 0.025331659242510796;
  t94_n20: return -0.18725897371768951;
  t94_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t94_n23;
  t94_n22: return 0.11671770364046097;
  t94_n23: return 0.10756128281354904;
  t94_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t94_n92;
  t94_n25: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t94_n83;
  t94_n26: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t94_n72;
  t94_n27: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t94_n59;
  t94_n28: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t94_n50;
  t94_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n31;
  t94_n30: return 0.03603930398821831;
  t94_n31: if (E.getNumReferences() >= 3321408512 /*7957.5*/) goto t94_n47;
  t94_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t94_n44;
  t94_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t94_n37;
  t94_n34: if (E.getNumReferences() >= 3319740416 /*7143.0*/) goto t94_n36;
  t94_n35: return 0.07714928686618805;
  t94_n36: return 0.018831027671694756;
  t94_n37: if (E.getNumReferences() >= 3320593408 /*7559.5*/) goto t94_n39;
  t94_n38: return -0.24910682439804077;
  t94_n39: if (E.getNumReferences() >= 3321062400 /*7788.5*/) goto t94_n43;
  t94_n40: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t94_n42;
  t94_n41: return 0.0871027484536171;
  t94_n42: return 0.11215271800756454;
  t94_n43: return 0.07329431921243668;
  t94_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t94_n46;
  t94_n45: return 0.10354229062795639;
  t94_n46: return 0.12285251170396805;
  t94_n47: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t94_n49;
  t94_n48: return 0.03598320856690407;
  t94_n49: return 0.12536191940307617;
  t94_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t94_n58;
  t94_n51: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n53;
  t94_n52: return 0.11929729580879211;
  t94_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n55;
  t94_n54: return 0.11232106387615204;
  t94_n55: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t94_n57;
  t94_n56: return 0.11930999904870987;
  t94_n57: return 0.1648404449224472;
  t94_n58: return 0.1250365972518921;
  t94_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t94_n61;
  t94_n60: return -0.035964928567409515;
  t94_n61: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t94_n63;
  t94_n62: return 0.00816901121288538;
  t94_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t94_n65;
  t94_n64: return 0.039648860692977905;
  t94_n65: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n71;
  t94_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n70;
  t94_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t94_n69;
  t94_n68: return 0.13949017226696014;
  t94_n69: return 0.10902387648820877;
  t94_n70: return 0.11238811910152435;
  t94_n71: return -0.18886145949363708;
  t94_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t94_n74;
  t94_n73: return 0.0334390252828598;
  t94_n74: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t94_n80;
  t94_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t94_n77;
  t94_n76: return -0.05816281586885452;
  t94_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n79;
  t94_n78: return -0.10110381990671158;
  t94_n79: return 0.09806295484304428;
  t94_n80: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t94_n82;
  t94_n81: return 0.11477609723806381;
  t94_n82: return 0.07282514870166779;
  t94_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t94_n85;
  t94_n84: return 0.056231867522001266;
  t94_n85: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t94_n91;
  t94_n86: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n88;
  t94_n87: return 0.10072491317987442;
  t94_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t94_n90;
  t94_n89: return 0.026594502851366997;
  t94_n90: return 0.11430656164884567;
  t94_n91: return -0.05467826500535011;
  t94_n92: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t94_n122;
  t94_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t94_n101;
  t94_n94: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t94_n100;
  t94_n95: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n99;
  t94_n96: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t94_n98;
  t94_n97: return 0.11134249716997147;
  t94_n98: return 0.11514506489038467;
  t94_n99: return 0.07033044844865799;
  t94_n100: return 0.03460197523236275;
  t94_n101: if (E.getNumReferences() >= 3319966720 /*7253.5*/) goto t94_n115;
  t94_n102: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t94_n104;
  t94_n103: return 0.11249333620071411;
  t94_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t94_n110;
  t94_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t94_n107;
  t94_n106: return 0.05990714952349663;
  t94_n107: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t94_n109;
  t94_n108: return 0.11016251891851425;
  t94_n109: return -0.014143023639917374;
  t94_n110: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t94_n114;
  t94_n111: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t94_n113;
  t94_n112: return 0.03922208026051521;
  t94_n113: return 0.10993486642837524;
  t94_n114: return -0.10464143753051758;
  t94_n115: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t94_n117;
  t94_n116: return 0.013363952748477459;
  t94_n117: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t94_n121;
  t94_n118: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n120;
  t94_n119: return 0.11601654440164566;
  t94_n120: return 0.11864498257637024;
  t94_n121: return 0.06609463691711426;
  t94_n122: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t94_n140;
  t94_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t94_n137;
  t94_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t94_n130;
  t94_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t94_n127;
  t94_n126: return 0.05416359379887581;
  t94_n127: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n129;
  t94_n128: return 0.13045498728752136;
  t94_n129: return 0.11935338377952576;
  t94_n130: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t94_n132;
  t94_n131: return 0.04809173569083214;
  t94_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t94_n134;
  t94_n133: return 0.11601338535547256;
  t94_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t94_n136;
  t94_n135: return 0.11044201254844666;
  t94_n136: return -0.10078786313533783;
  t94_n137: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t94_n139;
  t94_n138: return 0.09337002038955688;
  t94_n139: return 0.10487189143896103;
  t94_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t94_n142;
  t94_n141: return 0.0453207828104496;
  t94_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t94_n144;
  t94_n143: return 0.11713400483131409;
  t94_n144: return 0.04731662943959236;
  t94_n145: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t94_n207;
  t94_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t94_n198;
  t94_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t94_n195;
  t94_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t94_n160;
  t94_n149: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t94_n155;
  t94_n150: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t94_n152;
  t94_n151: return -0.07029496878385544;
  t94_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t94_n154;
  t94_n153: return 0.038747843354940414;
  t94_n154: return 0.10758447647094727;
  t94_n155: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t94_n157;
  t94_n156: return 0.020175550132989883;
  t94_n157: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n159;
  t94_n158: return -0.3716188669204712;
  t94_n159: return 0.06937681883573532;
  t94_n160: if (E.getNumReferences() >= 3334946304 /*25503.0*/) goto t94_n162;
  t94_n161: return -0.29144221544265747;
  t94_n162: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t94_n180;
  t94_n163: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t94_n177;
  t94_n164: if (E.getNumReferences() >= 3341362816 /*43302.5*/) goto t94_n176;
  t94_n165: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t94_n169;
  t94_n166: if (E.getNumReferences() >= 3335557632 /*26697.0*/) goto t94_n168;
  t94_n167: return 0.07782597839832306;
  t94_n168: return -0.1102275550365448;
  t94_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t94_n171;
  t94_n170: return 0.05460425093770027;
  t94_n171: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t94_n173;
  t94_n172: return 0.023923341184854507;
  t94_n173: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n175;
  t94_n174: return 0.10758384317159653;
  t94_n175: return 0.10870345681905746;
  t94_n176: return -0.03814368695020676;
  t94_n177: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t94_n179;
  t94_n178: return 0.07708410918712616;
  t94_n179: return 0.03223476931452751;
  t94_n180: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t94_n192;
  t94_n181: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n183;
  t94_n182: return -0.012612951919436455;
  t94_n183: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t94_n191;
  t94_n184: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t94_n190;
  t94_n185: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t94_n187;
  t94_n186: return -0.21905367076396942;
  t94_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n189;
  t94_n188: return -0.39470043778419495;
  t94_n189: return -0.009662180207669735;
  t94_n190: return 0.07373160868883133;
  t94_n191: return 0.04871430993080139;
  t94_n192: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t94_n194;
  t94_n193: return 0.10414925217628479;
  t94_n194: return 0.04827053099870682;
  t94_n195: if (E.getNumReferences() >= 3334582784 /*24793.0*/) goto t94_n197;
  t94_n196: return -0.2640700936317444;
  t94_n197: return 0.0036174727138131857;
  t94_n198: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t94_n206;
  t94_n199: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t94_n203;
  t94_n200: if (E.getNumReferences() >= 3350298560 /*90879.5*/) goto t94_n202;
  t94_n201: return 0.06224977970123291;
  t94_n202: return -0.16030140221118927;
  t94_n203: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t94_n205;
  t94_n204: return 0.11357630789279938;
  t94_n205: return 0.09631999582052231;
  t94_n206: return 0.013134988956153393;
  t94_n207: return 0.07985271513462067;
  t94_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t94_n212;
  t94_n209: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t94_n211;
  t94_n210: return 0.042717549949884415;
  t94_n211: return 0.002333856886252761;
  t94_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t94_n236;
  t94_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t94_n227;
  t94_n214: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t94_n216;
  t94_n215: return 0.004022443201392889;
  t94_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t94_n224;
  t94_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t94_n219;
  t94_n218: return 0.024929264560341835;
  t94_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t94_n223;
  t94_n220: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t94_n222;
  t94_n221: return 0.11010679602622986;
  t94_n222: return 0.0728798359632492;
  t94_n223: return 0.04722195491194725;
  t94_n224: if (E.getNumReferences() >= 3335803904 /*27178.0*/) goto t94_n226;
  t94_n225: return 0.01729859597980976;
  t94_n226: return -0.08759849518537521;
  t94_n227: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t94_n229;
  t94_n228: return -0.28002557158470154;
  t94_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t94_n235;
  t94_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t94_n232;
  t94_n231: return 0.015656789764761925;
  t94_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t94_n234;
  t94_n233: return 0.04030324146151543;
  t94_n234: return 0.09721565991640091;
  t94_n235: return 0.005002337973564863;
  t94_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t94_n248;
  t94_n237: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t94_n239;
  t94_n238: return -0.01006707176566124;
  t94_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t94_n241;
  t94_n240: return 0.015887858346104622;
  t94_n241: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t94_n245;
  t94_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t94_n244;
  t94_n243: return -0.12397295981645584;
  t94_n244: return 0.10655312985181808;
  t94_n245: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t94_n247;
  t94_n246: return -0.08677562326192856;
  t94_n247: return 0.20670545101165771;
  t94_n248: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t94_n250;
  t94_n249: return 0.010961592197418213;
  t94_n250: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t94_n252;
  t94_n251: return 0.03787941858172417;
  t94_n252: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t94_n254;
  t94_n253: return 0.10295313596725464;
  t94_n254: return -0.26055750250816345;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree95(const Example& E) {
  t95_n0: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t95_n250;
  t95_n1: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t95_n171;
  t95_n2: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t95_n72;
  t95_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t95_n71;
  t95_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t95_n28;
  t95_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t95_n7;
  t95_n6: return -0.013831156305968761;
  t95_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t95_n9;
  t95_n8: return -0.05929186940193176;
  t95_n9: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t95_n21;
  t95_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t95_n20;
  t95_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n19;
  t95_n12: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t95_n18;
  t95_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n17;
  t95_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n16;
  t95_n15: return 0.1217043474316597;
  t95_n16: return 0.5627243518829346;
  t95_n17: return 0.18070624768733978;
  t95_n18: return -0.13386061787605286;
  t95_n19: return 0.06994801014661789;
  t95_n20: return 0.044278211891651154;
  t95_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t95_n23;
  t95_n22: return 0.05303248390555382;
  t95_n23: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t95_n27;
  t95_n24: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n26;
  t95_n25: return 0.11188684403896332;
  t95_n26: return -0.022099345922470093;
  t95_n27: return 0.10482917726039886;
  t95_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t95_n70;
  t95_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n47;
  t95_n30: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t95_n34;
  t95_n31: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t95_n33;
  t95_n32: return 0.09279827028512955;
  t95_n33: return -0.008459771983325481;
  t95_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n46;
  t95_n35: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t95_n41;
  t95_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t95_n38;
  t95_n37: return 0.05428609624505043;
  t95_n38: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t95_n40;
  t95_n39: return 0.09833281487226486;
  t95_n40: return 0.09245607256889343;
  t95_n41: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n43;
  t95_n42: return -0.0890953540802002;
  t95_n43: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t95_n45;
  t95_n44: return 0.12932367622852325;
  t95_n45: return -0.34325462579727173;
  t95_n46: return 0.008535853587090969;
  t95_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n65;
  t95_n48: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t95_n64;
  t95_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t95_n53;
  t95_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n52;
  t95_n51: return -0.14471657574176788;
  t95_n52: return -0.03503001853823662;
  t95_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t95_n57;
  t95_n54: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n56;
  t95_n55: return 0.0041875834576785564;
  t95_n56: return -0.06927962601184845;
  t95_n57: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t95_n63;
  t95_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t95_n62;
  t95_n59: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n61;
  t95_n60: return 0.08208933472633362;
  t95_n61: return 0.11114878952503204;
  t95_n62: return 0.05661781504750252;
  t95_n63: return -0.49670857191085815;
  t95_n64: return 0.010245224460959435;
  t95_n65: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t95_n69;
  t95_n66: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t95_n68;
  t95_n67: return 0.06536337733268738;
  t95_n68: return -0.08631843328475952;
  t95_n69: return 0.07712174206972122;
  t95_n70: return -0.15727992355823517;
  t95_n71: return 0.006015333347022533;
  t95_n72: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t95_n82;
  t95_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t95_n75;
  t95_n74: return 0.008522223681211472;
  t95_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t95_n77;
  t95_n76: return 0.038420386612415314;
  t95_n77: if (E.getNumReferences() >= 3276767232 /*207.5*/) goto t95_n79;
  t95_n78: return -0.06995117664337158;
  t95_n79: if (E.getNumReferences() >= 3277684736 /*221.5*/) goto t95_n81;
  t95_n80: return 0.09281417727470398;
  t95_n81: return 0.02748250402510166;
  t95_n82: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t95_n86;
  t95_n83: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t95_n85;
  t95_n84: return -0.14001239836215973;
  t95_n85: return 0.11598854511976242;
  t95_n86: if (E.getNumReferences() >= 3316826112 /*5720.0*/) goto t95_n138;
  t95_n87: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t95_n113;
  t95_n88: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t95_n110;
  t95_n89: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t95_n93;
  t95_n90: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t95_n92;
  t95_n91: return -0.00433632405474782;
  t95_n92: return 0.04320492595434189;
  t95_n93: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t95_n109;
  t95_n94: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t95_n96;
  t95_n95: return 0.04016648605465889;
  t95_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t95_n104;
  t95_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t95_n99;
  t95_n98: return 0.08698327094316483;
  t95_n99: if (E.getNumReferences() >= 3286155264 /*445.5*/) goto t95_n101;
  t95_n100: return 0.028163596987724304;
  t95_n101: if (E.getNumReferences() >= 3292618752 /*773.5*/) goto t95_n103;
  t95_n102: return 0.12430143356323242;
  t95_n103: return 0.17815786600112915;
  t95_n104: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t95_n106;
  t95_n105: return -0.08129426836967468;
  t95_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t95_n108;
  t95_n107: return 0.08975760638713837;
  t95_n108: return 0.12624801695346832;
  t95_n109: return 0.028782052919268608;
  t95_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t95_n112;
  t95_n111: return 0.04911132529377937;
  t95_n112: return 0.030030490830540657;
  t95_n113: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t95_n115;
  t95_n114: return 0.049926720559597015;
  t95_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t95_n121;
  t95_n116: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t95_n118;
  t95_n117: return -0.00496789300814271;
  t95_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t95_n120;
  t95_n119: return 0.06115007773041725;
  t95_n120: return 0.1296716034412384;
  t95_n121: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t95_n129;
  t95_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t95_n124;
  t95_n123: return 0.07205262780189514;
  t95_n124: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t95_n128;
  t95_n125: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t95_n127;
  t95_n126: return 0.1062937006354332;
  t95_n127: return 0.10807464271783829;
  t95_n128: return 0.11970417201519012;
  t95_n129: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t95_n137;
  t95_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t95_n132;
  t95_n131: return 0.09213744848966599;
  t95_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n134;
  t95_n133: return 0.1594967395067215;
  t95_n134: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t95_n136;
  t95_n135: return -0.02165360003709793;
  t95_n136: return 0.10932871699333191;
  t95_n137: return 0.004565135575830936;
  t95_n138: if (E.getNumReferences() >= 3320489984 /*7509.0*/) goto t95_n166;
  t95_n139: if (E.getNumReferences() >= 3319805952 /*7175.0*/) goto t95_n161;
  t95_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t95_n142;
  t95_n141: return 0.009724318981170654;
  t95_n142: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t95_n148;
  t95_n143: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t95_n145;
  t95_n144: return -0.10819146782159805;
  t95_n145: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n147;
  t95_n146: return 0.14307427406311035;
  t95_n147: return 0.13859117031097412;
  t95_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t95_n156;
  t95_n149: if (E.getNumReferences() >= 3319629824 /*7089.0*/) goto t95_n151;
  t95_n150: return -0.014172249473631382;
  t95_n151: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n153;
  t95_n152: return -0.3776301443576813;
  t95_n153: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t95_n155;
  t95_n154: return 0.1087682694196701;
  t95_n155: return 0.07028922438621521;
  t95_n156: if (E.getNumReferences() >= 3317832704 /*6211.5*/) goto t95_n160;
  t95_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t95_n159;
  t95_n158: return -0.21372193098068237;
  t95_n159: return 0.11788588762283325;
  t95_n160: return -0.27586793899536133;
  t95_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t95_n163;
  t95_n162: return -0.016845911741256714;
  t95_n163: if (E.getNumReferences() >= 3320267776 /*7400.5*/) goto t95_n165;
  t95_n164: return 0.11381061375141144;
  t95_n165: return 0.1018018051981926;
  t95_n166: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t95_n168;
  t95_n167: return 0.016363633796572685;
  t95_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n170;
  t95_n169: return 0.1004263237118721;
  t95_n170: return -0.08828537166118622;
  t95_n171: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t95_n173;
  t95_n172: return -0.00015302262909244746;
  t95_n173: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t95_n175;
  t95_n174: return -0.08699578046798706;
  t95_n175: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t95_n225;
  t95_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t95_n178;
  t95_n177: return 0.002956873271614313;
  t95_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t95_n182;
  t95_n179: if (E.getNumReferences() >= 3326358528 /*12557.0*/) goto t95_n181;
  t95_n180: return 0.023394664749503136;
  t95_n181: return 0.1517053097486496;
  t95_n182: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t95_n196;
  t95_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t95_n185;
  t95_n184: return 0.0544055737555027;
  t95_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t95_n187;
  t95_n186: return 0.07710598409175873;
  t95_n187: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t95_n189;
  t95_n188: return 0.12484663724899292;
  t95_n189: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t95_n195;
  t95_n190: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n192;
  t95_n191: return -0.12603355944156647;
  t95_n192: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n194;
  t95_n193: return -0.3184296488761902;
  t95_n194: return 0.10691507905721664;
  t95_n195: return 0.12439411878585815;
  t95_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t95_n212;
  t95_n197: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t95_n201;
  t95_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t95_n200;
  t95_n199: return -0.10416299104690552;
  t95_n200: return 0.1216503456234932;
  t95_n201: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t95_n211;
  t95_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t95_n208;
  t95_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t95_n205;
  t95_n204: return 0.05336939916014671;
  t95_n205: if (E.getNumReferences() >= 3274768384 /*177.0*/) goto t95_n207;
  t95_n206: return -0.12838785350322723;
  t95_n207: return 0.12770839035511017;
  t95_n208: if (E.getNumReferences() >= 3282927616 /*347.0*/) goto t95_n210;
  t95_n209: return 0.5322720408439636;
  t95_n210: return 0.12513364851474762;
  t95_n211: return -0.13621141016483307;
  t95_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t95_n222;
  t95_n213: if (E.getNumReferences() >= 3274637312 /*175.0*/) goto t95_n221;
  t95_n214: if (E.getNumReferences() >= 3273457664 /*157.0*/) goto t95_n218;
  t95_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t95_n217;
  t95_n216: return 0.09234106540679932;
  t95_n217: return 0.10857215523719788;
  t95_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n220;
  t95_n219: return 0.14452813565731049;
  t95_n220: return 0.2710006833076477;
  t95_n221: return 0.06067906320095062;
  t95_n222: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t95_n224;
  t95_n223: return 0.05934165045619011;
  t95_n224: return 0.125169575214386;
  t95_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t95_n227;
  t95_n226: return -0.03517910838127136;
  t95_n227: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t95_n229;
  t95_n228: return -0.02854122780263424;
  t95_n229: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t95_n241;
  t95_n230: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t95_n232;
  t95_n231: return -0.02796221151947975;
  t95_n232: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t95_n238;
  t95_n233: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t95_n237;
  t95_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t95_n236;
  t95_n235: return 0.12765315175056458;
  t95_n236: return -0.009770478121936321;
  t95_n237: return 0.10427777469158173;
  t95_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t95_n240;
  t95_n239: return -0.11298671364784241;
  t95_n240: return 0.12413458526134491;
  t95_n241: if (E.getNumReferences() >= 3317795840 /*6193.5*/) goto t95_n245;
  t95_n242: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t95_n244;
  t95_n243: return 0.04352886602282524;
  t95_n244: return 0.055405404418706894;
  t95_n245: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t95_n249;
  t95_n246: if (E.getNumReferences() >= 3318737920 /*6653.5*/) goto t95_n248;
  t95_n247: return 0.07792850583791733;
  t95_n248: return 0.13090892136096954;
  t95_n249: return 0.05077635496854782;
  t95_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t95_n254;
  t95_n251: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t95_n253;
  t95_n252: return 0.018980972468852997;
  t95_n253: return -0.005057554226368666;
  t95_n254: return 0.016959385946393013;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree96(const Example& E) {
  t96_n0: if (E.getNumReferences() >= 3304886272 /*2020.5*/) goto t96_n92;
  t96_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t96_n43;
  t96_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t96_n4;
  t96_n3: return -0.009348993189632893;
  t96_n4: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t96_n24;
  t96_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t96_n19;
  t96_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n8;
  t96_n7: return 0.013114457949995995;
  t96_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t96_n10;
  t96_n9: return 0.037008609622716904;
  t96_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t96_n12;
  t96_n11: return -0.1042931079864502;
  t96_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t96_n16;
  t96_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t96_n15;
  t96_n14: return -0.04246512055397034;
  t96_n15: return 0.006388157140463591;
  t96_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t96_n18;
  t96_n17: return -0.01506322342902422;
  t96_n18: return 0.0432518795132637;
  t96_n19: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t96_n23;
  t96_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t96_n22;
  t96_n21: return -0.004878230858594179;
  t96_n22: return 0.019177524372935295;
  t96_n23: return 0.02100509963929653;
  t96_n24: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t96_n42;
  t96_n25: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t96_n29;
  t96_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n28;
  t96_n27: return -0.13798484206199646;
  t96_n28: return 0.10638165473937988;
  t96_n29: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t96_n41;
  t96_n30: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n38;
  t96_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t96_n33;
  t96_n32: return 0.030318081378936768;
  t96_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n35;
  t96_n34: return -0.06753135472536087;
  t96_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n37;
  t96_n36: return 0.06571143865585327;
  t96_n37: return 0.03353816643357277;
  t96_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t96_n40;
  t96_n39: return -0.08801247924566269;
  t96_n40: return 0.04145871847867966;
  t96_n41: return 0.023379933089017868;
  t96_n42: return 0.05398033931851387;
  t96_n43: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t96_n45;
  t96_n44: return -0.01294593047350645;
  t96_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t96_n49;
  t96_n46: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t96_n48;
  t96_n47: return -0.10630567371845245;
  t96_n48: return -0.0009884960018098354;
  t96_n49: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t96_n55;
  t96_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t96_n54;
  t96_n51: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t96_n53;
  t96_n52: return -0.07978007197380066;
  t96_n53: return 0.0028004320338368416;
  t96_n54: return 0.010023750364780426;
  t96_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t96_n79;
  t96_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t96_n58;
  t96_n57: return 0.0043716453947126865;
  t96_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t96_n68;
  t96_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n61;
  t96_n60: return 0.06591104716062546;
  t96_n61: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n63;
  t96_n62: return 0.01634824089705944;
  t96_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n67;
  t96_n64: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t96_n66;
  t96_n65: return -0.018574511632323265;
  t96_n66: return -0.18057070672512054;
  t96_n67: return -0.027338214218616486;
  t96_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n78;
  t96_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n71;
  t96_n70: return 0.025426704436540604;
  t96_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t96_n73;
  t96_n72: return 0.052589207887649536;
  t96_n73: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t96_n75;
  t96_n74: return 0.05558105930685997;
  t96_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t96_n77;
  t96_n76: return 0.11321042478084564;
  t96_n77: return 0.09546016156673431;
  t96_n78: return 0.006165622733533382;
  t96_n79: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t96_n91;
  t96_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n90;
  t96_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t96_n85;
  t96_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n84;
  t96_n83: return 0.11078125238418579;
  t96_n84: return 0.0845177099108696;
  t96_n85: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n89;
  t96_n86: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t96_n88;
  t96_n87: return 0.11730778217315674;
  t96_n88: return 0.10567427426576614;
  t96_n89: return 0.0766647458076477;
  t96_n90: return 0.08255369961261749;
  t96_n91: return -0.05936150625348091;
  t96_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t96_n98;
  t96_n93: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t96_n97;
  t96_n94: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t96_n96;
  t96_n95: return 0.012983094900846481;
  t96_n96: return 0.034184008836746216;
  t96_n97: return -0.004477353300899267;
  t96_n98: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t96_n252;
  t96_n99: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t96_n207;
  t96_n100: if (E.getNumReferences() >= 3318231040 /*6406.0*/) goto t96_n104;
  t96_n101: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t96_n103;
  t96_n102: return 0.014971796423196793;
  t96_n103: return 0.08490604907274246;
  t96_n104: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t96_n116;
  t96_n105: if (E.getNumReferences() >= 3318759424 /*6664.0*/) goto t96_n107;
  t96_n106: return 0.08333209156990051;
  t96_n107: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t96_n109;
  t96_n108: return 0.011243491433560848;
  t96_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n111;
  t96_n110: return 0.11891432106494904;
  t96_n111: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n115;
  t96_n112: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t96_n114;
  t96_n113: return 0.14711754024028778;
  t96_n114: return 0.12090428918600082;
  t96_n115: return 0.13721801340579987;
  t96_n116: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t96_n120;
  t96_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t96_n119;
  t96_n118: return -0.019225435331463814;
  t96_n119: return 0.03922232240438461;
  t96_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t96_n122;
  t96_n121: return 0.03421534597873688;
  t96_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t96_n150;
  t96_n123: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t96_n127;
  t96_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t96_n126;
  t96_n125: return 0.11317203938961029;
  t96_n126: return -0.2755536139011383;
  t96_n127: if (E.getNumReferences() >= 3330990592 /*17777.0*/) goto t96_n129;
  t96_n128: return 0.050295665860176086;
  t96_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n149;
  t96_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t96_n136;
  t96_n131: if (E.getNumReferences() >= 3331176192 /*18139.5*/) goto t96_n135;
  t96_n132: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t96_n134;
  t96_n133: return -0.0058528282679617405;
  t96_n134: return 0.12002094089984894;
  t96_n135: return -0.3576519787311554;
  t96_n136: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t96_n138;
  t96_n137: return 0.029911544173955917;
  t96_n138: if (E.getNumReferences() >= 3332047872 /*19842.0*/) goto t96_n142;
  t96_n139: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t96_n141;
  t96_n140: return 0.1142316684126854;
  t96_n141: return 0.10367000848054886;
  t96_n142: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t96_n144;
  t96_n143: return 0.08324839174747467;
  t96_n144: if (E.getNumReferences() >= 3333127936 /*21951.5*/) goto t96_n146;
  t96_n145: return 0.23297597467899323;
  t96_n146: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t96_n148;
  t96_n147: return 0.11400819569826126;
  t96_n148: return 0.07844395190477371;
  t96_n149: return 0.002122376346960664;
  t96_n150: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t96_n152;
  t96_n151: return 0.1139783039689064;
  t96_n152: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t96_n186;
  t96_n153: if (E.getNumReferences() >= 3332440064 /*20608.0*/) goto t96_n185;
  t96_n154: if (E.getNumReferences() >= 3332338944 /*20410.5*/) goto t96_n182;
  t96_n155: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t96_n177;
  t96_n156: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t96_n158;
  t96_n157: return 0.048857733607292175;
  t96_n158: if (E.getNumReferences() >= 3324409856 /*10654.0*/) goto t96_n176;
  t96_n159: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t96_n175;
  t96_n160: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t96_n162;
  t96_n161: return -0.006480421870946884;
  t96_n162: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t96_n170;
  t96_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t96_n165;
  t96_n164: return 0.10594820976257324;
  t96_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t96_n167;
  t96_n166: return 0.08868490904569626;
  t96_n167: if (E.getNumReferences() >= 3319786496 /*7165.5*/) goto t96_n169;
  t96_n168: return 0.10039341449737549;
  t96_n169: return 0.05307450145483017;
  t96_n170: if (E.getNumReferences() >= 3321574400 /*8038.5*/) goto t96_n172;
  t96_n171: return -0.14285019040107727;
  t96_n172: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t96_n174;
  t96_n173: return 0.11261554062366486;
  t96_n174: return 0.09208755940198898;
  t96_n175: return 0.11061122268438339;
  t96_n176: return 0.01783411018550396;
  t96_n177: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t96_n181;
  t96_n178: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t96_n180;
  t96_n179: return 0.11960475891828537;
  t96_n180: return 0.09780517965555191;
  t96_n181: return 0.0440516360104084;
  t96_n182: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t96_n184;
  t96_n183: return 0.11339151859283447;
  t96_n184: return 0.08856186270713806;
  t96_n185: return -0.34723520278930664;
  t96_n186: if (E.getNumReferences() >= 3318970368 /*6767.0*/) goto t96_n188;
  t96_n187: return 0.10904903709888458;
  t96_n188: if (E.getNumReferences() >= 3322122752 /*8420.5*/) goto t96_n190;
  t96_n189: return -0.08665937930345535;
  t96_n190: if (E.getNumReferences() >= 3322210304 /*8506.0*/) goto t96_n192;
  t96_n191: return 0.11486365646123886;
  t96_n192: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t96_n194;
  t96_n193: return 0.031551115214824677;
  t96_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t96_n206;
  t96_n195: if (E.getNumReferences() >= 3322854400 /*9135.0*/) goto t96_n197;
  t96_n196: return 0.11217666417360306;
  t96_n197: if (E.getNumReferences() >= 3329480192 /*15605.5*/) goto t96_n199;
  t96_n198: return 0.10136617720127106;
  t96_n199: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t96_n205;
  t96_n200: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t96_n204;
  t96_n201: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t96_n203;
  t96_n202: return 0.08822064101696014;
  t96_n203: return 0.103655144572258;
  t96_n204: return 0.10398595035076141;
  t96_n205: return -0.015971088781952858;
  t96_n206: return 0.07387425750494003;
  t96_n207: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t96_n251;
  t96_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t96_n250;
  t96_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t96_n249;
  t96_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t96_n212;
  t96_n211: return 0.0004502807860262692;
  t96_n212: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t96_n214;
  t96_n213: return -0.09066782891750336;
  t96_n214: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t96_n220;
  t96_n215: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t96_n217;
  t96_n216: return 0.00709532480686903;
  t96_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t96_n219;
  t96_n218: return -0.0765317976474762;
  t96_n219: return 0.10701580345630646;
  t96_n220: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t96_n234;
  t96_n221: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t96_n233;
  t96_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t96_n232;
  t96_n223: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t96_n227;
  t96_n224: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t96_n226;
  t96_n225: return -0.37269526720046997;
  t96_n226: return 0.04755537584424019;
  t96_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t96_n231;
  t96_n228: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t96_n230;
  t96_n229: return -0.11712319403886795;
  t96_n230: return -0.5047888159751892;
  t96_n231: return -0.24668928980827332;
  t96_n232: return -0.06677182763814926;
  t96_n233: return 0.011428928934037685;
  t96_n234: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t96_n244;
  t96_n235: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t96_n243;
  t96_n236: if (E.getNumReferences() >= 3355504736 /*132033.5*/) goto t96_n242;
  t96_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t96_n239;
  t96_n238: return -0.006774561014026403;
  t96_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t96_n241;
  t96_n240: return 0.013853151351213455;
  t96_n241: return 0.06747904419898987;
  t96_n242: return -0.1272115856409073;
  t96_n243: return 0.03241739794611931;
  t96_n244: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t96_n248;
  t96_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t96_n247;
  t96_n246: return -0.13540565967559814;
  t96_n247: return -0.018798407167196274;
  t96_n248: return 0.003689679317176342;
  t96_n249: return 0.019762221723794937;
  t96_n250: return 0.04650440067052841;
  t96_n251: return 0.0772392600774765;
  t96_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t96_n254;
  t96_n253: return 0.037067752331495285;
  t96_n254: return 0.05485525354743004;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree97(const Example& E) {
  t97_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t97_n154;
  t97_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t97_n3;
  t97_n2: return -0.0012955657439306378;
  t97_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t97_n19;
  t97_n4: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t97_n6;
  t97_n5: return -0.006686662323772907;
  t97_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t97_n14;
  t97_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t97_n9;
  t97_n8: return 0.08943556249141693;
  t97_n9: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t97_n11;
  t97_n10: return 0.028681442141532898;
  t97_n11: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t97_n13;
  t97_n12: return 0.07498548924922943;
  t97_n13: return 0.10622687637805939;
  t97_n14: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t97_n16;
  t97_n15: return 0.10819951444864273;
  t97_n16: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t97_n18;
  t97_n17: return 0.06754162162542343;
  t97_n18: return -0.4916348457336426;
  t97_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t97_n41;
  t97_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t97_n22;
  t97_n21: return 0.021074064075946808;
  t97_n22: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t97_n26;
  t97_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n25;
  t97_n24: return -0.01567552611231804;
  t97_n25: return 0.07361116260290146;
  t97_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n38;
  t97_n27: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t97_n37;
  t97_n28: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n34;
  t97_n29: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t97_n33;
  t97_n30: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t97_n32;
  t97_n31: return 0.09160799533128738;
  t97_n32: return 0.11029797047376633;
  t97_n33: return -0.11968391388654709;
  t97_n34: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t97_n36;
  t97_n35: return 0.11452104151248932;
  t97_n36: return 0.1004658192396164;
  t97_n37: return 0.06394042819738388;
  t97_n38: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n40;
  t97_n39: return 0.07950667291879654;
  t97_n40: return 0.0548374280333519;
  t97_n41: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t97_n123;
  t97_n42: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t97_n118;
  t97_n43: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t97_n109;
  t97_n44: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t97_n108;
  t97_n45: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t97_n87;
  t97_n46: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t97_n86;
  t97_n47: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t97_n67;
  t97_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t97_n50;
  t97_n49: return 0.002060066442936659;
  t97_n50: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t97_n52;
  t97_n51: return 0.12395332008600235;
  t97_n52: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t97_n54;
  t97_n53: return 0.022845828905701637;
  t97_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n66;
  t97_n55: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t97_n59;
  t97_n56: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t97_n58;
  t97_n57: return 0.05083879455924034;
  t97_n58: return 0.12662507593631744;
  t97_n59: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t97_n65;
  t97_n60: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t97_n62;
  t97_n61: return -0.005357729736715555;
  t97_n62: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t97_n64;
  t97_n63: return 0.11771401017904282;
  t97_n64: return 0.10105127841234207;
  t97_n65: return -0.05581415444612503;
  t97_n66: return 0.1540730893611908;
  t97_n67: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t97_n75;
  t97_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t97_n70;
  t97_n69: return -0.08350095897912979;
  t97_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t97_n72;
  t97_n71: return -0.24843968451023102;
  t97_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n74;
  t97_n73: return 0.1318340003490448;
  t97_n74: return 0.09578090906143188;
  t97_n75: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t97_n81;
  t97_n76: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t97_n78;
  t97_n77: return 0.04153922200202942;
  t97_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n80;
  t97_n79: return 0.07976817339658737;
  t97_n80: return 0.10976900160312653;
  t97_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n83;
  t97_n82: return -0.40390539169311523;
  t97_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t97_n85;
  t97_n84: return 0.09059277176856995;
  t97_n85: return -0.04042375832796097;
  t97_n86: return -0.04848996549844742;
  t97_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t97_n95;
  t97_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t97_n90;
  t97_n89: return 0.01580740511417389;
  t97_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t97_n92;
  t97_n91: return -0.1108558252453804;
  t97_n92: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t97_n94;
  t97_n93: return 0.12433090806007385;
  t97_n94: return 0.030416235327720642;
  t97_n95: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t97_n101;
  t97_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t97_n98;
  t97_n97: return -0.008401057682931423;
  t97_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n100;
  t97_n99: return 0.10225042700767517;
  t97_n100: return 0.07429160177707672;
  t97_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t97_n103;
  t97_n102: return -0.12168710678815842;
  t97_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n105;
  t97_n104: return 0.08336204290390015;
  t97_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n107;
  t97_n106: return -0.08480236679315567;
  t97_n107: return 0.05880757048726082;
  t97_n108: return -0.05854702740907669;
  t97_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t97_n111;
  t97_n110: return -0.05852372944355011;
  t97_n111: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t97_n117;
  t97_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t97_n116;
  t97_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t97_n115;
  t97_n114: return -0.03473115339875221;
  t97_n115: return 0.09980129450559616;
  t97_n116: return -0.03566311299800873;
  t97_n117: return 0.014630191028118134;
  t97_n118: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t97_n122;
  t97_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t97_n121;
  t97_n120: return -0.01973024010658264;
  t97_n121: return 0.029583120718598366;
  t97_n122: return -0.15654967725276947;
  t97_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n153;
  t97_n124: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t97_n146;
  t97_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t97_n145;
  t97_n126: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t97_n144;
  t97_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n141;
  t97_n128: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t97_n134;
  t97_n129: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t97_n133;
  t97_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t97_n132;
  t97_n131: return 0.07284697145223618;
  t97_n132: return 0.10881593823432922;
  t97_n133: return 0.008876493200659752;
  t97_n134: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n140;
  t97_n135: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n139;
  t97_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t97_n138;
  t97_n137: return 0.06077319756150246;
  t97_n138: return 0.1110326275229454;
  t97_n139: return 0.09723310172557831;
  t97_n140: return 0.04240293800830841;
  t97_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t97_n143;
  t97_n142: return 0.060080982744693756;
  t97_n143: return 0.10943829268217087;
  t97_n144: return -0.15712396800518036;
  t97_n145: return -0.11772087216377258;
  t97_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t97_n148;
  t97_n147: return -0.011151168495416641;
  t97_n148: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t97_n150;
  t97_n149: return -0.11926619708538055;
  t97_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n152;
  t97_n151: return 0.11866813898086548;
  t97_n152: return 0.03716165944933891;
  t97_n153: return 0.15812315046787262;
  t97_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t97_n158;
  t97_n155: if (E.getNumReferences() >= 3333877504 /*23415.5*/) goto t97_n157;
  t97_n156: return -0.007844231091439724;
  t97_n157: return -0.22879558801651;
  t97_n158: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t97_n234;
  t97_n159: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t97_n171;
  t97_n160: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t97_n168;
  t97_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n163;
  t97_n162: return 0.028998415917158127;
  t97_n163: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t97_n165;
  t97_n164: return 0.009353924542665482;
  t97_n165: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t97_n167;
  t97_n166: return -0.067509725689888;
  t97_n167: return 0.02819921262562275;
  t97_n168: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t97_n170;
  t97_n169: return -0.11658398061990738;
  t97_n170: return 0.01122510526329279;
  t97_n171: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t97_n207;
  t97_n172: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t97_n194;
  t97_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n193;
  t97_n174: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t97_n190;
  t97_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t97_n177;
  t97_n176: return 0.0968620777130127;
  t97_n177: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t97_n181;
  t97_n178: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t97_n180;
  t97_n179: return 0.09543012827634811;
  t97_n180: return 0.12066154927015305;
  t97_n181: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t97_n183;
  t97_n182: return -0.1350410282611847;
  t97_n183: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n187;
  t97_n184: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t97_n186;
  t97_n185: return 0.23547491431236267;
  t97_n186: return -0.11218053847551346;
  t97_n187: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t97_n189;
  t97_n188: return 0.1165308877825737;
  t97_n189: return 0.0;
  t97_n190: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t97_n192;
  t97_n191: return 0.12485598772764206;
  t97_n192: return -0.5664212107658386;
  t97_n193: return -0.04198496788740158;
  t97_n194: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t97_n206;
  t97_n195: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t97_n197;
  t97_n196: return 0.015895724296569824;
  t97_n197: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t97_n205;
  t97_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n204;
  t97_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n201;
  t97_n200: return 0.07101432234048843;
  t97_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t97_n203;
  t97_n202: return 0.1330980360507965;
  t97_n203: return -0.07823740690946579;
  t97_n204: return -0.08844176679849625;
  t97_n205: return 0.06015205383300781;
  t97_n206: return -0.0396139919757843;
  t97_n207: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t97_n213;
  t97_n208: if (E.getNumReferences() >= 3274014720 /*165.5*/) goto t97_n212;
  t97_n209: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t97_n211;
  t97_n210: return -0.08431185781955719;
  t97_n211: return 0.04273049905896187;
  t97_n212: return -0.00959805864840746;
  t97_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n231;
  t97_n214: if (E.getNumReferences() >= 3332089344 /*19923.0*/) goto t97_n226;
  t97_n215: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t97_n219;
  t97_n216: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t97_n218;
  t97_n217: return 0.1161874458193779;
  t97_n218: return 0.05432628467679024;
  t97_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n225;
  t97_n220: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n222;
  t97_n221: return 0.12299942970275879;
  t97_n222: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t97_n224;
  t97_n223: return -0.14065155386924744;
  t97_n224: return 0.12355731427669525;
  t97_n225: return 0.08844872564077377;
  t97_n226: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t97_n228;
  t97_n227: return -0.019143065437674522;
  t97_n228: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t97_n230;
  t97_n229: return 0.08612046390771866;
  t97_n230: return 0.032304901629686356;
  t97_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t97_n233;
  t97_n232: return 0.10843551158905029;
  t97_n233: return -0.05492519587278366;
  t97_n234: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t97_n236;
  t97_n235: return 0.002839708235114813;
  t97_n236: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t97_n254;
  t97_n237: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t97_n253;
  t97_n238: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t97_n240;
  t97_n239: return 0.012806297279894352;
  t97_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t97_n252;
  t97_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t97_n243;
  t97_n242: return 0.03627147525548935;
  t97_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t97_n251;
  t97_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t97_n250;
  t97_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t97_n247;
  t97_n246: return 0.048722900450229645;
  t97_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t97_n249;
  t97_n248: return 0.10171176493167877;
  t97_n249: return 0.085167795419693;
  t97_n250: return 0.10208897292613983;
  t97_n251: return -0.024046888574957848;
  t97_n252: return 0.04687828943133354;
  t97_n253: return 0.01112605631351471;
  t97_n254: return -0.10911855101585388;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree98(const Example& E) {
  t98_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t98_n254;
  t98_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t98_n163;
  t98_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t98_n20;
  t98_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t98_n5;
  t98_n4: return -0.025917746126651764;
  t98_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t98_n7;
  t98_n6: return -0.01079291757196188;
  t98_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n9;
  t98_n8: return 0.001086836215108633;
  t98_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t98_n11;
  t98_n10: return 0.007526696193963289;
  t98_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n13;
  t98_n12: return -0.07394518703222275;
  t98_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t98_n15;
  t98_n14: return 0.024026377126574516;
  t98_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t98_n19;
  t98_n16: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t98_n18;
  t98_n17: return 0.10548684000968933;
  t98_n18: return 0.06628863513469696;
  t98_n19: return -0.05489664897322655;
  t98_n20: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t98_n120;
  t98_n21: if (E.getFileProximityDistance() >= 3212836864 /*1.0*/) goto t98_n23;
  t98_n22: return 0.10188950598239899;
  t98_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n45;
  t98_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t98_n26;
  t98_n25: return -0.011332454159855843;
  t98_n26: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t98_n40;
  t98_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n29;
  t98_n28: return 0.0026240821462124586;
  t98_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n31;
  t98_n30: return 0.039505038410425186;
  t98_n31: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t98_n35;
  t98_n32: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t98_n34;
  t98_n33: return 0.022115956991910934;
  t98_n34: return 0.07103898376226425;
  t98_n35: if (E.getNumReferences() >= 3318872064 /*6719.0*/) goto t98_n39;
  t98_n36: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t98_n38;
  t98_n37: return 0.10624467581510544;
  t98_n38: return 0.13437789678573608;
  t98_n39: return 0.05179215222597122;
  t98_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t98_n42;
  t98_n41: return 0.010144757106900215;
  t98_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n44;
  t98_n43: return 0.023026766255497932;
  t98_n44: return 0.07597558945417404;
  t98_n45: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t98_n119;
  t98_n46: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t98_n72;
  t98_n47: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t98_n71;
  t98_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n50;
  t98_n49: return 0.006477975752204657;
  t98_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n70;
  t98_n51: if (E.getNumReferences() >= 3360148800 /*204597.0*/) goto t98_n53;
  t98_n52: return 0.010408995673060417;
  t98_n53: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t98_n67;
  t98_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n64;
  t98_n55: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t98_n57;
  t98_n56: return 0.07380001991987228;
  t98_n57: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t98_n63;
  t98_n58: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t98_n60;
  t98_n59: return -0.11077883094549179;
  t98_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t98_n62;
  t98_n61: return 0.10890991985797882;
  t98_n62: return 0.12663143873214722;
  t98_n63: return 0.22840331494808197;
  t98_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n66;
  t98_n65: return 0.0883612260222435;
  t98_n66: return 0.06053411588072777;
  t98_n67: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t98_n69;
  t98_n68: return 0.12399494647979736;
  t98_n69: return 0.013496384024620056;
  t98_n70: return 0.05867446959018707;
  t98_n71: return -0.024633320048451424;
  t98_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n114;
  t98_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t98_n89;
  t98_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t98_n82;
  t98_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n79;
  t98_n76: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t98_n78;
  t98_n77: return -0.15405559539794922;
  t98_n78: return -0.4305914640426636;
  t98_n79: if (E.getNumReferences() >= 3301117952 /*1560.5*/) goto t98_n81;
  t98_n80: return -0.025418879464268684;
  t98_n81: return 0.07792146503925323;
  t98_n82: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n84;
  t98_n83: return -0.026885859668254852;
  t98_n84: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t98_n88;
  t98_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n87;
  t98_n86: return -0.5091191530227661;
  t98_n87: return 0.1224827840924263;
  t98_n88: return -0.09435832500457764;
  t98_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n93;
  t98_n90: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t98_n92;
  t98_n91: return -0.3047519624233246;
  t98_n92: return -0.05647498741745949;
  t98_n93: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t98_n97;
  t98_n94: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t98_n96;
  t98_n95: return -0.049984999001026154;
  t98_n96: return -0.04540818929672241;
  t98_n97: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t98_n111;
  t98_n98: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n110;
  t98_n99: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t98_n109;
  t98_n100: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t98_n106;
  t98_n101: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t98_n105;
  t98_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n104;
  t98_n103: return 0.10310680419206619;
  t98_n104: return 0.11385010927915573;
  t98_n105: return -0.039733123034238815;
  t98_n106: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t98_n108;
  t98_n107: return 0.10381212830543518;
  t98_n108: return 0.10555332154035568;
  t98_n109: return -0.1959865838289261;
  t98_n110: return 0.014644855633378029;
  t98_n111: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n113;
  t98_n112: return 0.0034323600120842457;
  t98_n113: return -0.06147900968790054;
  t98_n114: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t98_n118;
  t98_n115: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t98_n117;
  t98_n116: return -0.04275107756257057;
  t98_n117: return 0.012362425215542316;
  t98_n118: return 0.03856726735830307;
  t98_n119: return -0.11621017754077911;
  t98_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t98_n122;
  t98_n121: return -0.11495468765497208;
  t98_n122: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t98_n126;
  t98_n123: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t98_n125;
  t98_n124: return 0.02098282426595688;
  t98_n125: return -0.007571564055979252;
  t98_n126: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t98_n162;
  t98_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t98_n139;
  t98_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n130;
  t98_n129: return 0.048850711435079575;
  t98_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t98_n132;
  t98_n131: return -0.15491527318954468;
  t98_n132: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n138;
  t98_n133: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t98_n135;
  t98_n134: return 0.12212517857551575;
  t98_n135: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n137;
  t98_n136: return 0.12267785519361496;
  t98_n137: return 0.20300018787384033;
  t98_n138: return 0.03669493645429611;
  t98_n139: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n151;
  t98_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n148;
  t98_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t98_n143;
  t98_n142: return 0.04114600270986557;
  t98_n143: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t98_n147;
  t98_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t98_n146;
  t98_n145: return 0.10713643580675125;
  t98_n146: return 0.053401779383420944;
  t98_n147: return -0.13686306774616241;
  t98_n148: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t98_n150;
  t98_n149: return 0.06871869415044785;
  t98_n150: return 0.05125082656741142;
  t98_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t98_n157;
  t98_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t98_n154;
  t98_n153: return 0.06836367398500443;
  t98_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n156;
  t98_n155: return 0.1099194884300232;
  t98_n156: return 0.08650656044483185;
  t98_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n159;
  t98_n158: return 0.10291978716850281;
  t98_n159: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n161;
  t98_n160: return -0.5920601487159729;
  t98_n161: return 0.1010967269539833;
  t98_n162: return -0.076923668384552;
  t98_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t98_n165;
  t98_n164: return -0.007413034792989492;
  t98_n165: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t98_n233;
  t98_n166: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t98_n168;
  t98_n167: return 0.009797945618629456;
  t98_n168: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t98_n212;
  t98_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n209;
  t98_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t98_n186;
  t98_n171: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t98_n183;
  t98_n172: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t98_n176;
  t98_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t98_n175;
  t98_n174: return -0.10612310469150543;
  t98_n175: return 0.11943849921226501;
  t98_n176: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t98_n178;
  t98_n177: return -0.000205879463464953;
  t98_n178: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t98_n180;
  t98_n179: return 0.15955989062786102;
  t98_n180: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t98_n182;
  t98_n181: return 0.11516375094652176;
  t98_n182: return 0.0;
  t98_n183: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t98_n185;
  t98_n184: return 0.12509393692016602;
  t98_n185: return -0.35683441162109375;
  t98_n186: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t98_n188;
  t98_n187: return -0.007131151854991913;
  t98_n188: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t98_n200;
  t98_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n193;
  t98_n190: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t98_n192;
  t98_n191: return 0.02247648872435093;
  t98_n192: return 0.10635615140199661;
  t98_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t98_n199;
  t98_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t98_n198;
  t98_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n197;
  t98_n196: return 0.11125127226114273;
  t98_n197: return 0.015340590849518776;
  t98_n198: return 0.13294824957847595;
  t98_n199: return -0.08084648847579956;
  t98_n200: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t98_n202;
  t98_n201: return 0.007050762884318829;
  t98_n202: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t98_n208;
  t98_n203: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t98_n205;
  t98_n204: return 0.023393461480736732;
  t98_n205: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t98_n207;
  t98_n206: return 0.13868460059165955;
  t98_n207: return 0.028283141553401947;
  t98_n208: return -0.002604513196274638;
  t98_n209: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t98_n211;
  t98_n210: return 0.028850411996245384;
  t98_n211: return -0.08575962483882904;
  t98_n212: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t98_n216;
  t98_n213: if (E.getNumReferences() >= 3274014720 /*165.5*/) goto t98_n215;
  t98_n214: return 0.0339847132563591;
  t98_n215: return -0.008457883261144161;
  t98_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n230;
  t98_n217: if (E.getNumReferences() >= 3332089344 /*19923.0*/) goto t98_n227;
  t98_n218: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t98_n220;
  t98_n219: return 0.05406290292739868;
  t98_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n226;
  t98_n221: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t98_n223;
  t98_n222: return 0.12170353531837463;
  t98_n223: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t98_n225;
  t98_n224: return -0.12483987957239151;
  t98_n225: return 0.11220915615558624;
  t98_n226: return 0.08644632995128632;
  t98_n227: if (E.getNumReferences() >= 3349646912 /*85788.5*/) goto t98_n229;
  t98_n228: return -0.014689773321151733;
  t98_n229: return 0.05197470635175705;
  t98_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t98_n232;
  t98_n231: return 0.10736425966024399;
  t98_n232: return -0.038208816200494766;
  t98_n233: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t98_n235;
  t98_n234: return 0.0033093984238803387;
  t98_n235: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t98_n253;
  t98_n236: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t98_n252;
  t98_n237: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t98_n239;
  t98_n238: return 0.013159465976059437;
  t98_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t98_n251;
  t98_n240: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t98_n250;
  t98_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t98_n249;
  t98_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t98_n244;
  t98_n243: return 0.09914752095937729;
  t98_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t98_n248;
  t98_n245: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t98_n247;
  t98_n246: return 0.09749525785446167;
  t98_n247: return 0.09183991700410843;
  t98_n248: return 0.0576641708612442;
  t98_n249: return 0.04457258805632591;
  t98_n250: return 0.041146740317344666;
  t98_n251: return 0.0498821847140789;
  t98_n252: return 0.00988976750522852;
  t98_n253: return -0.14098307490348816;
  t98_n254: return -0.06599750369787216;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree99(const Example& E) {
  t99_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t99_n186;
  t99_n1: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t99_n119;
  t99_n2: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t99_n72;
  t99_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t99_n7;
  t99_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t99_n6;
  t99_n5: return -0.02247381955385208;
  t99_n6: return -0.0010186482686549425;
  t99_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t99_n9;
  t99_n8: return 0.0040395865216851234;
  t99_n9: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t99_n63;
  t99_n10: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t99_n60;
  t99_n11: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t99_n19;
  t99_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t99_n18;
  t99_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n15;
  t99_n14: return -0.07185455411672592;
  t99_n15: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t99_n17;
  t99_n16: return 0.07881180942058563;
  t99_n17: return -0.08181405067443848;
  t99_n18: return 0.017601244151592255;
  t99_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n21;
  t99_n20: return 0.023444872349500656;
  t99_n21: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t99_n35;
  t99_n22: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t99_n24;
  t99_n23: return -0.0007974344189278781;
  t99_n24: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t99_n32;
  t99_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t99_n27;
  t99_n26: return 0.0015288109425455332;
  t99_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n31;
  t99_n28: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t99_n30;
  t99_n29: return -0.7984578013420105;
  t99_n30: return -0.14531725645065308;
  t99_n31: return -0.09114042669534683;
  t99_n32: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t99_n34;
  t99_n33: return -0.07422271370887756;
  t99_n34: return 0.0656154453754425;
  t99_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t99_n43;
  t99_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t99_n42;
  t99_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n39;
  t99_n38: return -0.10530121624469757;
  t99_n39: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t99_n41;
  t99_n40: return 0.07039990276098251;
  t99_n41: return 0.130899116396904;
  t99_n42: return 0.07713564485311508;
  t99_n43: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t99_n59;
  t99_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n58;
  t99_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t99_n47;
  t99_n46: return 0.012599651701748371;
  t99_n47: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t99_n49;
  t99_n48: return 0.11440284550189972;
  t99_n49: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t99_n51;
  t99_n50: return 0.03276701271533966;
  t99_n51: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t99_n55;
  t99_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t99_n54;
  t99_n53: return 0.07878798246383667;
  t99_n54: return 0.12412294000387192;
  t99_n55: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t99_n57;
  t99_n56: return -0.007857121527194977;
  t99_n57: return 0.11605766415596008;
  t99_n58: return 0.05927050858736038;
  t99_n59: return -0.10728714615106583;
  t99_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t99_n62;
  t99_n61: return 0.022188924252986908;
  t99_n62: return 0.0871528685092926;
  t99_n63: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t99_n65;
  t99_n64: return -0.02852298691868782;
  t99_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n71;
  t99_n66: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t99_n70;
  t99_n67: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t99_n69;
  t99_n68: return -0.13913510739803314;
  t99_n69: return 0.12048380076885223;
  t99_n70: return -0.2039826661348343;
  t99_n71: return 0.007591854780912399;
  t99_n72: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t99_n92;
  t99_n73: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t99_n77;
  t99_n74: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t99_n76;
  t99_n75: return -0.06894463300704956;
  t99_n76: return -0.1517312377691269;
  t99_n77: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t99_n91;
  t99_n78: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t99_n80;
  t99_n79: return 0.0031485450454056263;
  t99_n80: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t99_n82;
  t99_n81: return 0.02794468402862549;
  t99_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t99_n84;
  t99_n83: return 0.04749739542603493;
  t99_n84: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t99_n86;
  t99_n85: return -0.06049901619553566;
  t99_n86: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t99_n90;
  t99_n87: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t99_n89;
  t99_n88: return 0.025920329615473747;
  t99_n89: return 0.12797649204730988;
  t99_n90: return 0.07939422130584717;
  t99_n91: return -0.043427031487226486;
  t99_n92: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t99_n100;
  t99_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n95;
  t99_n94: return 0.001971433637663722;
  t99_n95: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t99_n99;
  t99_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t99_n98;
  t99_n97: return -0.016107380390167236;
  t99_n98: return 0.058954816311597824;
  t99_n99: return -0.009606007486581802;
  t99_n100: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t99_n104;
  t99_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t99_n103;
  t99_n102: return 0.2797718942165375;
  t99_n103: return 0.10791962593793869;
  t99_n104: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t99_n106;
  t99_n105: return -0.0024723787792026997;
  t99_n106: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t99_n118;
  t99_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t99_n109;
  t99_n108: return -0.06927098333835602;
  t99_n109: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t99_n113;
  t99_n110: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t99_n112;
  t99_n111: return 0.2051384299993515;
  t99_n112: return 0.11563803255558014;
  t99_n113: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t99_n117;
  t99_n114: if (E.getNumReferences() >= 3261071360 /*56.0*/) goto t99_n116;
  t99_n115: return 0.09422436356544495;
  t99_n116: return 0.1168687492609024;
  t99_n117: return -0.005000712815672159;
  t99_n118: return -0.18732112646102905;
  t99_n119: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t99_n181;
  t99_n120: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t99_n138;
  t99_n121: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n123;
  t99_n122: return -0.00036497137625701725;
  t99_n123: if (E.getNumReferences() >= 3308374016 /*2844.5*/) goto t99_n131;
  t99_n124: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t99_n130;
  t99_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t99_n127;
  t99_n126: return -0.04315929487347603;
  t99_n127: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t99_n129;
  t99_n128: return 0.03585737943649292;
  t99_n129: return 0.010206790640950203;
  t99_n130: return 0.01155664399266243;
  t99_n131: if (E.getNumReferences() >= 3308460032 /*2865.5*/) goto t99_n135;
  t99_n132: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t99_n134;
  t99_n133: return 0.11798751354217529;
  t99_n134: return -0.016257615759968758;
  t99_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t99_n137;
  t99_n136: return 0.0009885176550596952;
  t99_n137: return 0.03373175114393234;
  t99_n138: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t99_n180;
  t99_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t99_n159;
  t99_n140: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t99_n142;
  t99_n141: return 0.031184017658233643;
  t99_n142: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t99_n144;
  t99_n143: return 0.025544099509716034;
  t99_n144: if (E.getNumReferences() >= 3291381760 /*698.0*/) goto t99_n158;
  t99_n145: if (E.getNumReferences() >= 3289972736 /*612.0*/) goto t99_n157;
  t99_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n156;
  t99_n147: if (E.getNumReferences() >= 3281469440 /*302.5*/) goto t99_n153;
  t99_n148: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t99_n152;
  t99_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t99_n151;
  t99_n150: return -0.15325400233268738;
  t99_n151: return 0.14473523199558258;
  t99_n152: return 0.13363021612167358;
  t99_n153: if (E.getNumReferences() >= 3288203264 /*508.0*/) goto t99_n155;
  t99_n154: return -0.1889498382806778;
  t99_n155: return 0.124358169734478;
  t99_n156: return 0.07142837345600128;
  t99_n157: return 0.12412875145673752;
  t99_n158: return 0.03355098143219948;
  t99_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n169;
  t99_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n162;
  t99_n161: return 0.032486509531736374;
  t99_n162: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t99_n168;
  t99_n163: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t99_n167;
  t99_n164: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t99_n166;
  t99_n165: return 0.1160552054643631;
  t99_n166: return 0.084187351167202;
  t99_n167: return 0.1290033608675003;
  t99_n168: return 0.09017060697078705;
  t99_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n173;
  t99_n170: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t99_n172;
  t99_n171: return 0.09974727779626846;
  t99_n172: return 0.11199299991130829;
  t99_n173: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t99_n175;
  t99_n174: return -0.006517359521239996;
  t99_n175: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t99_n177;
  t99_n176: return 0.04292948916554451;
  t99_n177: if (E.getNumReferences() >= 3279323136 /*246.5*/) goto t99_n179;
  t99_n178: return 0.11488592624664307;
  t99_n179: return 0.09518758207559586;
  t99_n180: return -0.0027210605330765247;
  t99_n181: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t99_n183;
  t99_n182: return 0.04676608741283417;
  t99_n183: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t99_n185;
  t99_n184: return 0.12747275829315186;
  t99_n185: return -4.5000528189120814e-05;
  t99_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t99_n188;
  t99_n187: return -0.007971166633069515;
  t99_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t99_n254;
  t99_n189: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t99_n191;
  t99_n190: return 0.00909496285021305;
  t99_n191: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t99_n249;
  t99_n192: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t99_n242;
  t99_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t99_n209;
  t99_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t99_n196;
  t99_n195: return -0.0017628218047320843;
  t99_n196: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t99_n204;
  t99_n197: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t99_n201;
  t99_n198: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t99_n200;
  t99_n199: return 0.07009056955575943;
  t99_n200: return -0.010552742518484592;
  t99_n201: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t99_n203;
  t99_n202: return 0.10489114373922348;
  t99_n203: return -0.11152854561805725;
  t99_n204: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t99_n206;
  t99_n205: return 0.04147110879421234;
  t99_n206: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t99_n208;
  t99_n207: return 0.16673438251018524;
  t99_n208: return -0.02379838563501835;
  t99_n209: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t99_n211;
  t99_n210: return -0.000609453534707427;
  t99_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n231;
  t99_n212: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t99_n214;
  t99_n213: return 0.012972507625818253;
  t99_n214: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t99_n222;
  t99_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t99_n217;
  t99_n216: return -0.10975341498851776;
  t99_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t99_n221;
  t99_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n220;
  t99_n219: return 0.11503834277391434;
  t99_n220: return 0.12867103517055511;
  t99_n221: return -0.1379668414592743;
  t99_n222: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t99_n228;
  t99_n223: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t99_n227;
  t99_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t99_n226;
  t99_n225: return 0.1247042715549469;
  t99_n226: return 0.10964307188987732;
  t99_n227: return -0.042227547615766525;
  t99_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t99_n230;
  t99_n229: return 0.11286312341690063;
  t99_n230: return -0.14302684366703033;
  t99_n231: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t99_n241;
  t99_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t99_n240;
  t99_n233: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t99_n237;
  t99_n234: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t99_n236;
  t99_n235: return 0.10694599896669388;
  t99_n236: return -0.05581749603152275;
  t99_n237: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t99_n239;
  t99_n238: return 0.15762417018413544;
  t99_n239: return -0.1578037440776825;
  t99_n240: return -0.09201379120349884;
  t99_n241: return -0.5263067483901978;
  t99_n242: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t99_n248;
  t99_n243: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t99_n245;
  t99_n244: return -0.24756969511508942;
  t99_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t99_n247;
  t99_n246: return -0.07257755845785141;
  t99_n247: return 0.09350777417421341;
  t99_n248: return 0.02324744313955307;
  t99_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t99_n253;
  t99_n250: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t99_n252;
  t99_n251: return 0.08859603852033615;
  t99_n252: return -0.15283353626728058;
  t99_n253: return -0.36519134044647217;
  t99_n254: return 0.004929717630147934;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree100(const Example& E) {
  t100_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t100_n72;
  t100_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t100_n35;
  t100_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n4;
  t100_n3: return -0.007117134053260088;
  t100_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t100_n6;
  t100_n5: return -0.05293549224734306;
  t100_n6: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t100_n34;
  t100_n7: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t100_n9;
  t100_n8: return 0.012345990166068077;
  t100_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t100_n11;
  t100_n10: return 0.015419003553688526;
  t100_n11: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t100_n33;
  t100_n12: if (E.getSymbolScopeDistance() >= 3242196992 /*12.0*/) goto t100_n32;
  t100_n13: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t100_n29;
  t100_n14: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t100_n26;
  t100_n15: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t100_n21;
  t100_n16: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t100_n18;
  t100_n17: return 0.10217897593975067;
  t100_n18: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t100_n20;
  t100_n19: return -0.01992705650627613;
  t100_n20: return 0.07454870641231537;
  t100_n21: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n25;
  t100_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n24;
  t100_n23: return 0.21275772154331207;
  t100_n24: return 0.10546477138996124;
  t100_n25: return -0.1588606834411621;
  t100_n26: if (E.getNumReferences() >= 3258974208 /*48.0*/) goto t100_n28;
  t100_n27: return 0.11541157215833664;
  t100_n28: return -0.14072667062282562;
  t100_n29: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t100_n31;
  t100_n30: return -0.19598917663097382;
  t100_n31: return 0.16945552825927734;
  t100_n32: return -0.09042228758335114;
  t100_n33: return 0.04871232062578201;
  t100_n34: return -0.022444788366556168;
  t100_n35: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t100_n39;
  t100_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t100_n38;
  t100_n37: return -0.013316378928720951;
  t100_n38: return 0.0035592929925769567;
  t100_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t100_n41;
  t100_n40: return -0.09663191437721252;
  t100_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t100_n63;
  t100_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t100_n44;
  t100_n43: return 0.004157728049904108;
  t100_n44: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t100_n60;
  t100_n45: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t100_n57;
  t100_n46: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t100_n50;
  t100_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t100_n49;
  t100_n48: return 0.03755262494087219;
  t100_n49: return 0.03683480620384216;
  t100_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n52;
  t100_n51: return 0.017990777269005775;
  t100_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n56;
  t100_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t100_n55;
  t100_n54: return -0.030275627970695496;
  t100_n55: return 0.0506172776222229;
  t100_n56: return -0.0014397840714082122;
  t100_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t100_n59;
  t100_n58: return -0.312025249004364;
  t100_n59: return 0.13761456310749054;
  t100_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n62;
  t100_n61: return 0.0651453360915184;
  t100_n62: return 0.018278302624821663;
  t100_n63: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t100_n71;
  t100_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n70;
  t100_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t100_n69;
  t100_n66: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t100_n68;
  t100_n67: return 0.10979259759187698;
  t100_n68: return 0.0746174305677414;
  t100_n69: return 0.1086866557598114;
  t100_n70: return 0.07953917980194092;
  t100_n71: return -0.04691222310066223;
  t100_n72: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t100_n254;
  t100_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t100_n85;
  t100_n74: if (E.getNumReferences() >= 3308445696 /*2862.0*/) goto t100_n78;
  t100_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t100_n77;
  t100_n76: return 0.0018672461155802011;
  t100_n77: return 0.01334365550428629;
  t100_n78: if (E.getNumReferences() >= 3308460032 /*2865.5*/) goto t100_n80;
  t100_n79: return 0.11986399441957474;
  t100_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n82;
  t100_n81: return 0.009469736367464066;
  t100_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t100_n84;
  t100_n83: return 0.002489333739504218;
  t100_n84: return 0.033587757498025894;
  t100_n85: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t100_n101;
  t100_n86: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t100_n88;
  t100_n87: return 0.008670412003993988;
  t100_n88: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t100_n90;
  t100_n89: return -0.04582163318991661;
  t100_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n92;
  t100_n91: return 0.04069442301988602;
  t100_n92: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t100_n94;
  t100_n93: return 0.04068726301193237;
  t100_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t100_n98;
  t100_n95: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t100_n97;
  t100_n96: return 0.03535458445549011;
  t100_n97: return 0.09370940923690796;
  t100_n98: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t100_n100;
  t100_n99: return 0.12149886786937714;
  t100_n100: return 0.06086256727576256;
  t100_n101: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t100_n131;
  t100_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t100_n120;
  t100_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n105;
  t100_n104: return 0.009929802268743515;
  t100_n105: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t100_n113;
  t100_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t100_n108;
  t100_n107: return 0.029725583270192146;
  t100_n108: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t100_n112;
  t100_n109: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t100_n111;
  t100_n110: return 0.031485386192798615;
  t100_n111: return 0.06803857535123825;
  t100_n112: return 0.09597394615411758;
  t100_n113: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t100_n119;
  t100_n114: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n116;
  t100_n115: return 0.14954912662506104;
  t100_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t100_n118;
  t100_n117: return 0.09676600247621536;
  t100_n118: return 0.11696851253509521;
  t100_n119: return 0.06647340208292007;
  t100_n120: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t100_n122;
  t100_n121: return 0.1290702372789383;
  t100_n122: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t100_n128;
  t100_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t100_n125;
  t100_n124: return 0.07603978365659714;
  t100_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t100_n127;
  t100_n126: return 0.10179658234119415;
  t100_n127: return 0.12063848227262497;
  t100_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t100_n130;
  t100_n129: return 0.07793743908405304;
  t100_n130: return 0.12909574806690216;
  t100_n131: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t100_n133;
  t100_n132: return -0.005256231874227524;
  t100_n133: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t100_n207;
  t100_n134: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t100_n206;
  t100_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t100_n163;
  t100_n136: if (E.getNumReferences() >= 3314422784 /*4546.5*/) goto t100_n138;
  t100_n137: return -0.0056073591113090515;
  t100_n138: if (E.getNumReferences() >= 3324868096 /*11101.5*/) goto t100_n158;
  t100_n139: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t100_n141;
  t100_n140: return 0.0962492972612381;
  t100_n141: if (E.getNumReferences() >= 3319766016 /*7155.5*/) goto t100_n143;
  t100_n142: return 0.03968605399131775;
  t100_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t100_n145;
  t100_n144: return 0.05198945477604866;
  t100_n145: if (E.getNumReferences() >= 3321975808 /*8277.0*/) goto t100_n157;
  t100_n146: if (E.getNumReferences() >= 3321886720 /*8191.0*/) goto t100_n156;
  t100_n147: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t100_n151;
  t100_n148: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t100_n150;
  t100_n149: return 0.10930727422237396;
  t100_n150: return 0.09267087280750275;
  t100_n151: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t100_n153;
  t100_n152: return 0.0594409815967083;
  t100_n153: if (E.getNumReferences() >= 3320559616 /*7543.0*/) goto t100_n155;
  t100_n154: return -0.24785637855529785;
  t100_n155: return 0.11027859151363373;
  t100_n156: return 0.11724935472011566;
  t100_n157: return 0.06381996721029282;
  t100_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t100_n162;
  t100_n159: if (E.getNumReferences() >= 3359963264 /*201698.0*/) goto t100_n161;
  t100_n160: return -0.05548321455717087;
  t100_n161: return 0.04357348382472992;
  t100_n162: return 0.01653965562582016;
  t100_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t100_n177;
  t100_n164: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t100_n176;
  t100_n165: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t100_n173;
  t100_n166: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t100_n172;
  t100_n167: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n171;
  t100_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n170;
  t100_n169: return 0.11039439588785172;
  t100_n170: return -0.43501412868499756;
  t100_n171: return 0.16987191140651703;
  t100_n172: return 0.020682387053966522;
  t100_n173: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t100_n175;
  t100_n174: return 0.1153806820511818;
  t100_n175: return 0.08998896926641464;
  t100_n176: return -0.03576698899269104;
  t100_n177: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t100_n205;
  t100_n178: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t100_n202;
  t100_n179: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n201;
  t100_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t100_n192;
  t100_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t100_n183;
  t100_n182: return 0.07896948605775833;
  t100_n183: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t100_n185;
  t100_n184: return 0.02792362868785858;
  t100_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n189;
  t100_n186: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n188;
  t100_n187: return 0.09542229026556015;
  t100_n188: return -0.12686435878276825;
  t100_n189: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t100_n191;
  t100_n190: return 0.11833813041448593;
  t100_n191: return 0.1436539590358734;
  t100_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n200;
  t100_n193: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t100_n199;
  t100_n194: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t100_n198;
  t100_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t100_n197;
  t100_n196: return -0.10494139790534973;
  t100_n197: return 0.12385237962007523;
  t100_n198: return 0.05558205023407936;
  t100_n199: return 0.0972064658999443;
  t100_n200: return 0.029814274981617928;
  t100_n201: return 0.016677264124155045;
  t100_n202: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t100_n204;
  t100_n203: return 0.11342770606279373;
  t100_n204: return 0.01779657043516636;
  t100_n205: return 0.011396807618439198;
  t100_n206: return -0.0930522084236145;
  t100_n207: if (E.getNumReferences() >= 3283075072 /*351.5*/) goto t100_n249;
  t100_n208: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t100_n248;
  t100_n209: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t100_n247;
  t100_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t100_n216;
  t100_n211: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t100_n213;
  t100_n212: return 0.03233359754085541;
  t100_n213: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t100_n215;
  t100_n214: return 0.058001138269901276;
  t100_n215: return -0.0008437777869403362;
  t100_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t100_n224;
  t100_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t100_n219;
  t100_n218: return -0.05703316256403923;
  t100_n219: if (E.getSymbolScopeDistance() >= 3249012736 /*21.0*/) goto t100_n221;
  t100_n220: return 0.13385875523090363;
  t100_n221: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t100_n223;
  t100_n222: return 0.19728323817253113;
  t100_n223: return 0.09294199198484421;
  t100_n224: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t100_n226;
  t100_n225: return 0.047966182231903076;
  t100_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t100_n234;
  t100_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t100_n229;
  t100_n228: return -0.0042120530270040035;
  t100_n229: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t100_n233;
  t100_n230: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t100_n232;
  t100_n231: return 0.06354061514139175;
  t100_n232: return 0.1053200289607048;
  t100_n233: return 0.017986029386520386;
  t100_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t100_n246;
  t100_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t100_n237;
  t100_n236: return -0.057146620005369186;
  t100_n237: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t100_n245;
  t100_n238: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t100_n242;
  t100_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t100_n241;
  t100_n240: return 0.10424664616584778;
  t100_n241: return 0.10138585418462753;
  t100_n242: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t100_n244;
  t100_n243: return 0.12877249717712402;
  t100_n244: return 0.0740169808268547;
  t100_n245: return 0.012537374161183834;
  t100_n246: return 0.046282269060611725;
  t100_n247: return -0.1268102377653122;
  t100_n248: return -0.0482647605240345;
  t100_n249: if (E.getNumReferences() >= 3283107840 /*352.5*/) goto t100_n253;
  t100_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t100_n252;
  t100_n251: return -0.1031135618686676;
  t100_n252: return 0.12945617735385895;
  t100_n253: return 0.050403159111738205;
  t100_n254: return -0.07678487151861191;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree101(const Example& E) {
  t101_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t101_n206;
  t101_n1: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t101_n3;
  t101_n2: return -0.0012440572027117014;
  t101_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t101_n7;
  t101_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t101_n6;
  t101_n5: return 0.01582495868206024;
  t101_n6: return -0.04496360570192337;
  t101_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t101_n119;
  t101_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t101_n14;
  t101_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t101_n13;
  t101_n10: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t101_n12;
  t101_n11: return -0.04958469048142433;
  t101_n12: return -0.29980868101119995;
  t101_n13: return 0.012938902713358402;
  t101_n14: if (E.getNumReferences() >= 3359435680 /*193454.5*/) goto t101_n56;
  t101_n15: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t101_n55;
  t101_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t101_n28;
  t101_n17: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t101_n19;
  t101_n18: return 0.011307838372886181;
  t101_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t101_n21;
  t101_n20: return -0.005015204194933176;
  t101_n21: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t101_n27;
  t101_n22: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t101_n26;
  t101_n23: if (E.getNumReferences() >= 3351817408 /*102745.5*/) goto t101_n25;
  t101_n24: return 0.1008937805891037;
  t101_n25: return -0.3384712338447571;
  t101_n26: return 0.10382255166769028;
  t101_n27: return -0.10280683636665344;
  t101_n28: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t101_n30;
  t101_n29: return 0.02452937513589859;
  t101_n30: if (E.getNumReferences() >= 3350198272 /*90096.0*/) goto t101_n44;
  t101_n31: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t101_n41;
  t101_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t101_n40;
  t101_n33: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t101_n39;
  t101_n34: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t101_n38;
  t101_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n37;
  t101_n36: return 0.030117487534880638;
  t101_n37: return 0.10336862504482269;
  t101_n38: return 0.11976874619722366;
  t101_n39: return -0.01484035886824131;
  t101_n40: return 0.15699031949043274;
  t101_n41: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t101_n43;
  t101_n42: return 0.11954190582036972;
  t101_n43: return 0.0982334092259407;
  t101_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n46;
  t101_n45: return -0.07316607236862183;
  t101_n46: if (E.getNumReferences() >= 3351190528 /*97848.0*/) goto t101_n50;
  t101_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t101_n49;
  t101_n48: return -0.14016307890415192;
  t101_n49: return 0.08398330956697464;
  t101_n50: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t101_n52;
  t101_n51: return -0.3914627730846405;
  t101_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n54;
  t101_n53: return 0.24901942908763885;
  t101_n54: return 0.1127261072397232;
  t101_n55: return -0.04680676385760307;
  t101_n56: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t101_n62;
  t101_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t101_n59;
  t101_n58: return 0.07139728218317032;
  t101_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n61;
  t101_n60: return 0.0968475267291069;
  t101_n61: return 0.06705089658498764;
  t101_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t101_n66;
  t101_n63: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t101_n65;
  t101_n64: return -0.029753927141427994;
  t101_n65: return -0.22092916071414948;
  t101_n66: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t101_n88;
  t101_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t101_n77;
  t101_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n70;
  t101_n69: return 0.007721350062638521;
  t101_n70: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t101_n74;
  t101_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n73;
  t101_n72: return 0.07054410874843597;
  t101_n73: return 0.04599873721599579;
  t101_n74: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n76;
  t101_n75: return -0.200369730591774;
  t101_n76: return 0.11098639667034149;
  t101_n77: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n83;
  t101_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n82;
  t101_n79: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t101_n81;
  t101_n80: return -0.11556252837181091;
  t101_n81: return 0.01692998595535755;
  t101_n82: return 0.07134341448545456;
  t101_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n87;
  t101_n84: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n86;
  t101_n85: return 0.09148681908845901;
  t101_n86: return 0.023003218695521355;
  t101_n87: return -0.09473346918821335;
  t101_n88: if (E.getNumReferences() >= 3364768256 /*291408.0*/) goto t101_n90;
  t101_n89: return -0.08059588074684143;
  t101_n90: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t101_n114;
  t101_n91: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t101_n103;
  t101_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n94;
  t101_n93: return 0.0416744202375412;
  t101_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t101_n96;
  t101_n95: return -0.013951434753835201;
  t101_n96: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n102;
  t101_n97: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t101_n99;
  t101_n98: return 0.15455769002437592;
  t101_n99: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n101;
  t101_n100: return 0.14147010445594788;
  t101_n101: return 0.1443747580051422;
  t101_n102: return -0.012758830562233925;
  t101_n103: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t101_n113;
  t101_n104: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n108;
  t101_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t101_n107;
  t101_n106: return -0.15648968517780304;
  t101_n107: return 0.10486802458763123;
  t101_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t101_n110;
  t101_n109: return 0.09660053253173828;
  t101_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n112;
  t101_n111: return 0.10908293724060059;
  t101_n112: return 0.1031324565410614;
  t101_n113: return 0.0160165224224329;
  t101_n114: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t101_n116;
  t101_n115: return 0.059442587196826935;
  t101_n116: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t101_n118;
  t101_n117: return 0.045530617237091064;
  t101_n118: return -0.039712049067020416;
  t101_n119: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t101_n149;
  t101_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t101_n142;
  t101_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t101_n135;
  t101_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n126;
  t101_n123: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t101_n125;
  t101_n124: return 0.09490129351615906;
  t101_n125: return 0.024363258853554726;
  t101_n126: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t101_n130;
  t101_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t101_n129;
  t101_n128: return 0.03094087913632393;
  t101_n129: return 0.08568557351827621;
  t101_n130: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t101_n134;
  t101_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n133;
  t101_n132: return -0.11738896369934082;
  t101_n133: return 0.12589004635810852;
  t101_n134: return 0.0675826147198677;
  t101_n135: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t101_n141;
  t101_n136: if (E.getNumReferences() >= 3338840960 /*33451.5*/) goto t101_n138;
  t101_n137: return -0.11109226197004318;
  t101_n138: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t101_n140;
  t101_n139: return 0.15244071185588837;
  t101_n140: return 0.11942431330680847;
  t101_n141: return 0.06459824740886688;
  t101_n142: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t101_n144;
  t101_n143: return 0.11677400022745132;
  t101_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n148;
  t101_n145: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t101_n147;
  t101_n146: return 0.12053272873163223;
  t101_n147: return -0.2594674229621887;
  t101_n148: return 0.036869317293167114;
  t101_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t101_n201;
  t101_n150: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t101_n184;
  t101_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t101_n181;
  t101_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t101_n176;
  t101_n153: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t101_n155;
  t101_n154: return -0.040434423834085464;
  t101_n155: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t101_n163;
  t101_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n160;
  t101_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n159;
  t101_n158: return -0.012133203446865082;
  t101_n159: return 0.15419507026672363;
  t101_n160: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n162;
  t101_n161: return 0.0795866921544075;
  t101_n162: return 0.11543381214141846;
  t101_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t101_n165;
  t101_n164: return -0.001776328426785767;
  t101_n165: if (E.getNumReferences() >= 3362358400 /*239122.0*/) goto t101_n175;
  t101_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n174;
  t101_n167: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t101_n169;
  t101_n168: return 0.009695158340036869;
  t101_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n173;
  t101_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n172;
  t101_n171: return 0.10395672172307968;
  t101_n172: return 0.024867024272680283;
  t101_n173: return 0.1071116104722023;
  t101_n174: return 0.0065217167139053345;
  t101_n175: return 0.013430611230432987;
  t101_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n178;
  t101_n177: return 0.07097947597503662;
  t101_n178: if (E.getNumReferences() >= 3342340992 /*47123.5*/) goto t101_n180;
  t101_n179: return 0.13028131425380707;
  t101_n180: return 0.00934992078691721;
  t101_n181: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t101_n183;
  t101_n182: return 0.09085147827863693;
  t101_n183: return -0.1690252721309662;
  t101_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t101_n186;
  t101_n185: return -0.10428805649280548;
  t101_n186: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t101_n200;
  t101_n187: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t101_n197;
  t101_n188: if (E.getNumReferences() >= 3350328576 /*91114.0*/) goto t101_n196;
  t101_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t101_n193;
  t101_n190: if (E.getNumReferences() >= 3342507520 /*47774.0*/) goto t101_n192;
  t101_n191: return -0.4239223599433899;
  t101_n192: return 0.040283892303705215;
  t101_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n195;
  t101_n194: return 0.10929493606090546;
  t101_n195: return 0.10240104794502258;
  t101_n196: return -0.2216157615184784;
  t101_n197: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n199;
  t101_n198: return 0.08848845958709717;
  t101_n199: return 0.01851079612970352;
  t101_n200: return -0.06970164179801941;
  t101_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t101_n203;
  t101_n202: return -0.041990648955106735;
  t101_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n205;
  t101_n204: return 0.1643776297569275;
  t101_n205: return 0.08238620311021805;
  t101_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t101_n208;
  t101_n207: return -0.007114267908036709;
  t101_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t101_n248;
  t101_n209: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t101_n211;
  t101_n210: return 0.008827933110296726;
  t101_n211: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t101_n247;
  t101_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t101_n218;
  t101_n213: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t101_n215;
  t101_n214: return 0.03754047304391861;
  t101_n215: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t101_n217;
  t101_n216: return 0.10878918319940567;
  t101_n217: return -0.11204543709754944;
  t101_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t101_n220;
  t101_n219: return -0.002691802568733692;
  t101_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t101_n240;
  t101_n221: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t101_n223;
  t101_n222: return 0.014913671649992466;
  t101_n223: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t101_n231;
  t101_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t101_n226;
  t101_n225: return -0.10853876918554306;
  t101_n226: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t101_n230;
  t101_n227: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n229;
  t101_n228: return 0.11506284028291702;
  t101_n229: return 0.1250162273645401;
  t101_n230: return -0.13102753460407257;
  t101_n231: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t101_n237;
  t101_n232: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t101_n236;
  t101_n233: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t101_n235;
  t101_n234: return 0.12051969021558762;
  t101_n235: return 0.10606411844491959;
  t101_n236: return -0.038528237491846085;
  t101_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t101_n239;
  t101_n238: return 0.11090350151062012;
  t101_n239: return -0.14015263319015503;
  t101_n240: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t101_n242;
  t101_n241: return -0.03844604641199112;
  t101_n242: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t101_n246;
  t101_n243: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t101_n245;
  t101_n244: return 0.14754508435726166;
  t101_n245: return 0.20110984146595;
  t101_n246: return -0.10944503545761108;
  t101_n247: return 0.020355118438601494;
  t101_n248: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t101_n250;
  t101_n249: return -0.00024374302302021533;
  t101_n250: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t101_n252;
  t101_n251: return 0.03467272222042084;
  t101_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t101_n254;
  t101_n253: return 0.00905291922390461;
  t101_n254: return -0.10799446702003479;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree102(const Example& E) {
  t102_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t102_n116;
  t102_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t102_n3;
  t102_n2: return -0.0011838588397949934;
  t102_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t102_n7;
  t102_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t102_n6;
  t102_n5: return 0.014944098889827728;
  t102_n6: return -0.04103991389274597;
  t102_n7: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t102_n93;
  t102_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t102_n10;
  t102_n9: return 0.00979319866746664;
  t102_n10: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t102_n92;
  t102_n11: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t102_n77;
  t102_n12: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t102_n76;
  t102_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t102_n41;
  t102_n14: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t102_n30;
  t102_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n29;
  t102_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t102_n18;
  t102_n17: return 0.009811025112867355;
  t102_n18: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t102_n20;
  t102_n19: return -0.03201291337609291;
  t102_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t102_n22;
  t102_n21: return -0.015070863999426365;
  t102_n22: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t102_n24;
  t102_n23: return 0.14341099560260773;
  t102_n24: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t102_n28;
  t102_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n27;
  t102_n26: return 0.12746873497962952;
  t102_n27: return 0.10164807736873627;
  t102_n28: return 0.1052374541759491;
  t102_n29: return 0.13516804575920105;
  t102_n30: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t102_n32;
  t102_n31: return 0.002317418809980154;
  t102_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t102_n34;
  t102_n33: return -0.018146628513932228;
  t102_n34: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t102_n40;
  t102_n35: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t102_n39;
  t102_n36: if (E.getNumReferences() >= 3351817408 /*102745.5*/) goto t102_n38;
  t102_n37: return 0.09609565883874893;
  t102_n38: return -0.25040555000305176;
  t102_n39: return 0.10064955800771713;
  t102_n40: return -0.08909487724304199;
  t102_n41: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t102_n43;
  t102_n42: return 0.12113964557647705;
  t102_n43: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t102_n45;
  t102_n44: return 0.01451033167541027;
  t102_n45: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t102_n57;
  t102_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t102_n50;
  t102_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n49;
  t102_n48: return 0.021332358941435814;
  t102_n49: return 0.09927108138799667;
  t102_n50: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n54;
  t102_n51: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t102_n53;
  t102_n52: return 0.10315650701522827;
  t102_n53: return 0.13931474089622498;
  t102_n54: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t102_n56;
  t102_n55: return 0.10807869583368301;
  t102_n56: return 0.01025224570184946;
  t102_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t102_n75;
  t102_n58: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t102_n74;
  t102_n59: if (E.getNumReferences() >= 3351224064 /*98110.0*/) goto t102_n67;
  t102_n60: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t102_n66;
  t102_n61: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t102_n63;
  t102_n62: return -0.020717384293675423;
  t102_n63: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t102_n65;
  t102_n64: return 0.1129375696182251;
  t102_n65: return 0.08724740147590637;
  t102_n66: return -0.04298752546310425;
  t102_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n69;
  t102_n68: return 0.2564763128757477;
  t102_n69: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t102_n71;
  t102_n70: return -0.11615200340747833;
  t102_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n73;
  t102_n72: return 0.1623276323080063;
  t102_n73: return 0.10515744239091873;
  t102_n74: return -0.33020707964897156;
  t102_n75: return 0.15900665521621704;
  t102_n76: return -0.03410477191209793;
  t102_n77: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t102_n87;
  t102_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t102_n80;
  t102_n79: return 0.060492441058158875;
  t102_n80: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n84;
  t102_n81: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t102_n83;
  t102_n82: return 0.07951805740594864;
  t102_n83: return 0.10748407989740372;
  t102_n84: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n86;
  t102_n85: return 0.08562947809696198;
  t102_n86: return 0.03322446346282959;
  t102_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t102_n91;
  t102_n88: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t102_n90;
  t102_n89: return -0.016260303556919098;
  t102_n90: return -0.14236955344676971;
  t102_n91: return 0.03231178596615791;
  t102_n92: return -0.03934290632605553;
  t102_n93: if (E.getNumReferences() >= 3349002688 /*80755.5*/) goto t102_n105;
  t102_n94: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t102_n104;
  t102_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n103;
  t102_n96: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t102_n98;
  t102_n97: return -0.23184743523597717;
  t102_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n102;
  t102_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t102_n101;
  t102_n100: return 0.2354399561882019;
  t102_n101: return 0.1173439621925354;
  t102_n102: return 0.14972051978111267;
  t102_n103: return 0.009130963124334812;
  t102_n104: return 0.07846727222204208;
  t102_n105: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t102_n109;
  t102_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n108;
  t102_n107: return 0.05656884238123894;
  t102_n108: return -0.10886741429567337;
  t102_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t102_n111;
  t102_n110: return -0.0003044422483071685;
  t102_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t102_n115;
  t102_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n114;
  t102_n113: return 0.12505194544792175;
  t102_n114: return 0.05659672990441322;
  t102_n115: return 0.1502445787191391;
  t102_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t102_n118;
  t102_n117: return -0.006826447322964668;
  t102_n118: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t102_n158;
  t102_n119: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t102_n123;
  t102_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t102_n122;
  t102_n121: return -0.27010029554367065;
  t102_n122: return 0.009607001207768917;
  t102_n123: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t102_n157;
  t102_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t102_n134;
  t102_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t102_n127;
  t102_n126: return -0.005275926552712917;
  t102_n127: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t102_n129;
  t102_n128: return 0.046259574592113495;
  t102_n129: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t102_n131;
  t102_n130: return 0.03234317898750305;
  t102_n131: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t102_n133;
  t102_n132: return 0.15027253329753876;
  t102_n133: return -0.09206608682870865;
  t102_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n156;
  t102_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t102_n137;
  t102_n136: return 0.035841308534145355;
  t102_n137: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t102_n139;
  t102_n138: return 0.07467751950025558;
  t102_n139: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t102_n147;
  t102_n140: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t102_n142;
  t102_n141: return -0.1075061485171318;
  t102_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n146;
  t102_n143: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n145;
  t102_n144: return 0.11236882209777832;
  t102_n145: return 0.12158970534801483;
  t102_n146: return -0.1254243701696396;
  t102_n147: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t102_n153;
  t102_n148: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t102_n152;
  t102_n149: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t102_n151;
  t102_n150: return 0.11664839833974838;
  t102_n151: return 0.10254897177219391;
  t102_n152: return -0.04517650976777077;
  t102_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n155;
  t102_n154: return 0.1102452427148819;
  t102_n155: return -0.13506537675857544;
  t102_n156: return 3.3145453926408663e-05;
  t102_n157: return 0.019790176302194595;
  t102_n158: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t102_n228;
  t102_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t102_n161;
  t102_n160: return -0.055111877620220184;
  t102_n161: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t102_n163;
  t102_n162: return -0.05306835472583771;
  t102_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t102_n165;
  t102_n164: return 0.008050616830587387;
  t102_n165: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t102_n187;
  t102_n166: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t102_n168;
  t102_n167: return 0.036207396537065506;
  t102_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n184;
  t102_n169: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t102_n183;
  t102_n170: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t102_n172;
  t102_n171: return 0.04984699934720993;
  t102_n172: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t102_n182;
  t102_n173: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t102_n175;
  t102_n174: return 0.0960436686873436;
  t102_n175: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t102_n177;
  t102_n176: return 0.06218365952372551;
  t102_n177: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t102_n181;
  t102_n178: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t102_n180;
  t102_n179: return 0.10081823915243149;
  t102_n180: return 0.05935042351484299;
  t102_n181: return 0.1301153600215912;
  t102_n182: return -0.07184682041406631;
  t102_n183: return -0.016873469576239586;
  t102_n184: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t102_n186;
  t102_n185: return 0.024929087609052658;
  t102_n186: return 0.11359627544879913;
  t102_n187: if (E.getNumReferences() >= 3299749888 /*1393.5*/) goto t102_n189;
  t102_n188: return -0.04230913892388344;
  t102_n189: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t102_n191;
  t102_n190: return -0.0027485068421810865;
  t102_n191: if (E.getNumReferences() >= 3317245952 /*5925.0*/) goto t102_n205;
  t102_n192: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t102_n194;
  t102_n193: return 0.0020999261178076267;
  t102_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n202;
  t102_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t102_n201;
  t102_n196: if (E.getNumReferences() >= 3302473728 /*1726.0*/) goto t102_n198;
  t102_n197: return 0.11918458342552185;
  t102_n198: if (E.getNumReferences() >= 3306999808 /*2509.0*/) goto t102_n200;
  t102_n199: return -0.11695261299610138;
  t102_n200: return 0.10421988368034363;
  t102_n201: return -0.2851862907409668;
  t102_n202: if (E.getNumReferences() >= 3300188160 /*1447.0*/) goto t102_n204;
  t102_n203: return 0.08237213641405106;
  t102_n204: return -0.011129891499876976;
  t102_n205: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t102_n213;
  t102_n206: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t102_n210;
  t102_n207: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t102_n209;
  t102_n208: return 0.0434594601392746;
  t102_n209: return 0.11522144824266434;
  t102_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n212;
  t102_n211: return 0.11189568787813187;
  t102_n212: return 0.11886132508516312;
  t102_n213: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t102_n227;
  t102_n214: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t102_n216;
  t102_n215: return 0.024418704211711884;
  t102_n216: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t102_n222;
  t102_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t102_n219;
  t102_n218: return 0.11295975744724274;
  t102_n219: if (E.getNumReferences() >= 3322208768 /*8504.5*/) goto t102_n221;
  t102_n220: return 0.1227223128080368;
  t102_n221: return 0.10614801943302155;
  t102_n222: if (E.getNumReferences() >= 3327465984 /*13638.5*/) goto t102_n224;
  t102_n223: return 0.07305021584033966;
  t102_n224: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t102_n226;
  t102_n225: return 0.10248295962810516;
  t102_n226: return 0.11337672919034958;
  t102_n227: return 0.037182874977588654;
  t102_n228: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t102_n252;
  t102_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t102_n243;
  t102_n230: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t102_n232;
  t102_n231: return 0.014113490469753742;
  t102_n232: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t102_n240;
  t102_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t102_n237;
  t102_n234: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t102_n236;
  t102_n235: return -0.03721721097826958;
  t102_n236: return 0.11208359897136688;
  t102_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t102_n239;
  t102_n238: return 0.12178739905357361;
  t102_n239: return -0.15298570692539215;
  t102_n240: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t102_n242;
  t102_n241: return 0.029831301420927048;
  t102_n242: return 0.12540480494499207;
  t102_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t102_n251;
  t102_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t102_n246;
  t102_n245: return 0.04862911254167557;
  t102_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t102_n248;
  t102_n247: return 0.1315627247095108;
  t102_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t102_n250;
  t102_n249: return -0.24490463733673096;
  t102_n250: return 0.12105496227741241;
  t102_n251: return 0.026949459686875343;
  t102_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t102_n254;
  t102_n253: return 0.00836161244660616;
  t102_n254: return -0.12085988372564316;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree103(const Example& E) {
  t103_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t103_n120;
  t103_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t103_n63;
  t103_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n4;
  t103_n3: return -0.042185228317976;
  t103_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n22;
  t103_n5: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t103_n21;
  t103_n6: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t103_n20;
  t103_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t103_n9;
  t103_n8: return 0.010701197199523449;
  t103_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t103_n17;
  t103_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t103_n12;
  t103_n11: return -0.00481588626280427;
  t103_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t103_n14;
  t103_n13: return 0.0673171654343605;
  t103_n14: if (E.getNumReferences() >= 3285254144 /*418.0*/) goto t103_n16;
  t103_n15: return 0.08710604161024094;
  t103_n16: return 0.1355711966753006;
  t103_n17: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t103_n19;
  t103_n18: return 0.07452519983053207;
  t103_n19: return 0.040551476180553436;
  t103_n20: return 0.0680081844329834;
  t103_n21: return -0.0027918091509491205;
  t103_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t103_n38;
  t103_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t103_n37;
  t103_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t103_n26;
  t103_n25: return -0.10677899420261383;
  t103_n26: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t103_n28;
  t103_n27: return -0.02804029919207096;
  t103_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t103_n30;
  t103_n29: return -0.16148239374160767;
  t103_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n36;
  t103_n31: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t103_n33;
  t103_n32: return -0.2757401466369629;
  t103_n33: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t103_n35;
  t103_n34: return 0.12371722608804703;
  t103_n35: return -1.333760380744934;
  t103_n36: return 0.10395526140928268;
  t103_n37: return -0.016748741269111633;
  t103_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n40;
  t103_n39: return -0.031110500916838646;
  t103_n40: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n62;
  t103_n41: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t103_n61;
  t103_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t103_n52;
  t103_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n47;
  t103_n44: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t103_n46;
  t103_n45: return -0.002564674010500312;
  t103_n46: return -0.2024592161178589;
  t103_n47: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t103_n49;
  t103_n48: return -0.011140267364680767;
  t103_n49: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t103_n51;
  t103_n50: return -0.06289824098348618;
  t103_n51: return 0.09447743743658066;
  t103_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n54;
  t103_n53: return 0.04760001227259636;
  t103_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t103_n56;
  t103_n55: return 0.00272904010489583;
  t103_n56: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t103_n60;
  t103_n57: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t103_n59;
  t103_n58: return 0.06000305712223053;
  t103_n59: return 0.11068055033683777;
  t103_n60: return 0.012675615027546883;
  t103_n61: return -0.08740631490945816;
  t103_n62: return 0.0037470769602805376;
  t103_n63: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t103_n103;
  t103_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n94;
  t103_n65: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t103_n93;
  t103_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n88;
  t103_n67: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n71;
  t103_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t103_n70;
  t103_n69: return -0.09629075974225998;
  t103_n70: return 0.008982470259070396;
  t103_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n87;
  t103_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n74;
  t103_n73: return -0.06560280919075012;
  t103_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t103_n76;
  t103_n75: return 0.019596168771386147;
  t103_n76: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t103_n86;
  t103_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t103_n81;
  t103_n78: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n80;
  t103_n79: return 0.10727059096097946;
  t103_n80: return 0.08093204349279404;
  t103_n81: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t103_n85;
  t103_n82: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n84;
  t103_n83: return 0.11154881119728088;
  t103_n84: return 0.06840565800666809;
  t103_n85: return 0.10132033377885818;
  t103_n86: return 0.114262156188488;
  t103_n87: return 0.022306784987449646;
  t103_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t103_n92;
  t103_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t103_n91;
  t103_n90: return 0.03464723378419876;
  t103_n91: return 0.06985417753458023;
  t103_n92: return 0.09266972541809082;
  t103_n93: return 0.0002477607049513608;
  t103_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t103_n100;
  t103_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n97;
  t103_n96: return 0.0188297126442194;
  t103_n97: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n99;
  t103_n98: return 0.0561443492770195;
  t103_n99: return 0.022976195439696312;
  t103_n100: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n102;
  t103_n101: return 0.12667100131511688;
  t103_n102: return -0.14262613654136658;
  t103_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t103_n105;
  t103_n104: return -0.04986315220594406;
  t103_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t103_n107;
  t103_n106: return 0.007489174138754606;
  t103_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t103_n119;
  t103_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n110;
  t103_n109: return -0.04953548312187195;
  t103_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t103_n114;
  t103_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t103_n113;
  t103_n112: return 0.028880136087536812;
  t103_n113: return 0.046335503458976746;
  t103_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n116;
  t103_n115: return 0.07466606050729752;
  t103_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n118;
  t103_n117: return -0.05368359386920929;
  t103_n118: return 0.024417974054813385;
  t103_n119: return 0.0762549340724945;
  t103_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t103_n168;
  t103_n121: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t103_n161;
  t103_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t103_n144;
  t103_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t103_n125;
  t103_n124: return -0.01043697725981474;
  t103_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t103_n127;
  t103_n126: return -0.04770897701382637;
  t103_n127: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n143;
  t103_n128: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t103_n142;
  t103_n129: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t103_n135;
  t103_n130: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t103_n134;
  t103_n131: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t103_n133;
  t103_n132: return -0.0061611514538526535;
  t103_n133: return -0.11484456062316895;
  t103_n134: return 0.0650709718465805;
  t103_n135: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t103_n141;
  t103_n136: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t103_n138;
  t103_n137: return -0.06003289297223091;
  t103_n138: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t103_n140;
  t103_n139: return -0.02554505132138729;
  t103_n140: return 0.057200320065021515;
  t103_n141: return 0.06494950503110886;
  t103_n142: return 0.002371270675212145;
  t103_n143: return 0.040629059076309204;
  t103_n144: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t103_n150;
  t103_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t103_n149;
  t103_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t103_n148;
  t103_n147: return 0.020603276789188385;
  t103_n148: return 0.08629173040390015;
  t103_n149: return 0.030163820832967758;
  t103_n150: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t103_n154;
  t103_n151: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t103_n153;
  t103_n152: return -0.10628781467676163;
  t103_n153: return -0.22761854529380798;
  t103_n154: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t103_n160;
  t103_n155: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t103_n159;
  t103_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t103_n158;
  t103_n157: return 0.015504053793847561;
  t103_n158: return -0.00015861920837778598;
  t103_n159: return -0.09002165496349335;
  t103_n160: return -0.027552206069231033;
  t103_n161: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t103_n167;
  t103_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t103_n166;
  t103_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t103_n165;
  t103_n164: return 0.039283908903598785;
  t103_n165: return 0.1273079812526703;
  t103_n166: return -0.014452102594077587;
  t103_n167: return -0.03752823919057846;
  t103_n168: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t103_n254;
  t103_n169: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t103_n219;
  t103_n170: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t103_n196;
  t103_n171: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t103_n189;
  t103_n172: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t103_n184;
  t103_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t103_n177;
  t103_n174: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t103_n176;
  t103_n175: return -0.05851195752620697;
  t103_n176: return 0.005624039098620415;
  t103_n177: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t103_n181;
  t103_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t103_n180;
  t103_n179: return 0.05159281566739082;
  t103_n180: return 0.07941049337387085;
  t103_n181: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t103_n183;
  t103_n182: return 0.07999060302972794;
  t103_n183: return 0.10861729085445404;
  t103_n184: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t103_n186;
  t103_n185: return 0.09879297018051147;
  t103_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t103_n188;
  t103_n187: return -1.071420431137085;
  t103_n188: return 0.09658576548099518;
  t103_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n195;
  t103_n190: if (E.getNumReferences() >= 3290103808 /*620.0*/) goto t103_n192;
  t103_n191: return -0.16850419342517853;
  t103_n192: if (E.getNumReferences() >= 3291561984 /*709.0*/) goto t103_n194;
  t103_n193: return 0.11925102025270462;
  t103_n194: return -0.08688531070947647;
  t103_n195: return -0.049725670367479324;
  t103_n196: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t103_n210;
  t103_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n201;
  t103_n198: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t103_n200;
  t103_n199: return -0.08268748223781586;
  t103_n200: return 0.09396366029977798;
  t103_n201: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t103_n209;
  t103_n202: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t103_n206;
  t103_n203: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t103_n205;
  t103_n204: return -0.11106916517019272;
  t103_n205: return 0.11916961520910263;
  t103_n206: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t103_n208;
  t103_n207: return -0.007320157717913389;
  t103_n208: return 0.10553444921970367;
  t103_n209: return 0.01106855645775795;
  t103_n210: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t103_n218;
  t103_n211: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t103_n217;
  t103_n212: if (E.getNumReferences() >= 3337464320 /*30421.0*/) goto t103_n214;
  t103_n213: return 0.1255437582731247;
  t103_n214: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t103_n216;
  t103_n215: return 0.08942023664712906;
  t103_n216: return -0.16132022440433502;
  t103_n217: return 0.03493569418787956;
  t103_n218: return 0.048527900129556656;
  t103_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t103_n223;
  t103_n220: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t103_n222;
  t103_n221: return -0.026188138872385025;
  t103_n222: return 0.0099426144734025;
  t103_n223: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t103_n251;
  t103_n224: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t103_n250;
  t103_n225: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t103_n227;
  t103_n226: return -0.004237275570631027;
  t103_n227: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t103_n239;
  t103_n228: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t103_n238;
  t103_n229: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t103_n237;
  t103_n230: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t103_n234;
  t103_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t103_n233;
  t103_n232: return -0.09073421359062195;
  t103_n233: return 0.12112225592136383;
  t103_n234: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t103_n236;
  t103_n235: return 0.12451893091201782;
  t103_n236: return 0.07112187147140503;
  t103_n237: return 0.021150192245841026;
  t103_n238: return 0.01050643716007471;
  t103_n239: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t103_n241;
  t103_n240: return 0.06595055013895035;
  t103_n241: if (E.getNumReferences() >= 3309293568 /*3069.0*/) goto t103_n243;
  t103_n242: return -0.09508325904607773;
  t103_n243: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t103_n249;
  t103_n244: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t103_n246;
  t103_n245: return 0.04943186044692993;
  t103_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t103_n248;
  t103_n247: return 0.11856953054666519;
  t103_n248: return 0.11336357891559601;
  t103_n249: return 0.017431406304240227;
  t103_n250: return 0.08834793418645859;
  t103_n251: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t103_n253;
  t103_n252: return 0.017910737544298172;
  t103_n253: return -0.5304908156394958;
  t103_n254: return 0.008678754791617393;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree104(const Example& E) {
  t104_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t104_n254;
  t104_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t104_n189;
  t104_n2: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t104_n4;
  t104_n3: return -0.0009289681329391897;
  t104_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t104_n6;
  t104_n5: return 0.01856193318963051;
  t104_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t104_n8;
  t104_n7: return -0.046534985303878784;
  t104_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t104_n114;
  t104_n9: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t104_n113;
  t104_n10: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t104_n76;
  t104_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t104_n13;
  t104_n12: return 0.006384469568729401;
  t104_n13: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n15;
  t104_n14: return -0.1710136979818344;
  t104_n15: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t104_n17;
  t104_n16: return 0.11871505528688431;
  t104_n17: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t104_n75;
  t104_n18: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t104_n26;
  t104_n19: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t104_n21;
  t104_n20: return 0.029803194105625153;
  t104_n21: if (E.getNumReferences() >= 3334795520 /*25208.5*/) goto t104_n25;
  t104_n22: if (E.getNumReferences() >= 3333635072 /*22942.0*/) goto t104_n24;
  t104_n23: return -0.08958547562360764;
  t104_n24: return 0.12849344313144684;
  t104_n25: return 0.06613177061080933;
  t104_n26: if (E.getNumReferences() >= 3349106816 /*81569.0*/) goto t104_n46;
  t104_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t104_n31;
  t104_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n30;
  t104_n29: return -0.00891927257180214;
  t104_n30: return 0.1043766587972641;
  t104_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n37;
  t104_n32: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t104_n34;
  t104_n33: return 0.13349884748458862;
  t104_n34: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t104_n36;
  t104_n35: return 0.131144717335701;
  t104_n36: return 0.0766022726893425;
  t104_n37: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t104_n45;
  t104_n38: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t104_n42;
  t104_n39: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t104_n41;
  t104_n40: return 0.11334292590618134;
  t104_n41: return -0.047848258167505264;
  t104_n42: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n44;
  t104_n43: return 0.11284042149782181;
  t104_n44: return 0.10443861782550812;
  t104_n45: return -0.09874249994754791;
  t104_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n72;
  t104_n47: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t104_n55;
  t104_n48: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t104_n54;
  t104_n49: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t104_n51;
  t104_n50: return -0.04584179446101189;
  t104_n51: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t104_n53;
  t104_n52: return 0.1117437481880188;
  t104_n53: return 0.07134941965341568;
  t104_n54: return -0.015433013439178467;
  t104_n55: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t104_n59;
  t104_n56: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t104_n58;
  t104_n57: return 0.07987043261528015;
  t104_n58: return 0.10335318744182587;
  t104_n59: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t104_n65;
  t104_n60: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t104_n62;
  t104_n61: return -0.21708424389362335;
  t104_n62: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t104_n64;
  t104_n63: return -0.24922360479831696;
  t104_n64: return 0.14832031726837158;
  t104_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t104_n67;
  t104_n66: return -0.1059417650103569;
  t104_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n71;
  t104_n68: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t104_n70;
  t104_n69: return 0.11103113740682602;
  t104_n70: return 0.09023973345756531;
  t104_n71: return -0.01757528819143772;
  t104_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t104_n74;
  t104_n73: return -0.0071242074482142925;
  t104_n74: return 0.07414118200540543;
  t104_n75: return -0.19678598642349243;
  t104_n76: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t104_n112;
  t104_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t104_n101;
  t104_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t104_n80;
  t104_n79: return 0.03592398017644882;
  t104_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n94;
  t104_n81: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t104_n93;
  t104_n82: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t104_n88;
  t104_n83: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t104_n87;
  t104_n84: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t104_n86;
  t104_n85: return 0.00020157913968432695;
  t104_n86: return 0.21681305766105652;
  t104_n87: return -0.0816153809428215;
  t104_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n92;
  t104_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t104_n91;
  t104_n90: return -0.21982485055923462;
  t104_n91: return 0.10296829789876938;
  t104_n92: return 0.10458703339099884;
  t104_n93: return -0.018912298604846;
  t104_n94: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n100;
  t104_n95: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t104_n99;
  t104_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t104_n98;
  t104_n97: return 0.11529261618852615;
  t104_n98: return 0.13200262188911438;
  t104_n99: return -0.07426483184099197;
  t104_n100: return -0.16460104286670685;
  t104_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t104_n111;
  t104_n102: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t104_n110;
  t104_n103: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n109;
  t104_n104: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n108;
  t104_n105: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t104_n107;
  t104_n106: return -0.16118626296520233;
  t104_n107: return -0.07135550677776337;
  t104_n108: return 0.05332639813423157;
  t104_n109: return 0.0013481463538482785;
  t104_n110: return 0.07649628818035126;
  t104_n111: return 0.07082708179950714;
  t104_n112: return -0.14798423647880554;
  t104_n113: return -0.024766206741333008;
  t104_n114: if (E.getNumReferences() >= 3349221056 /*82461.5*/) goto t104_n172;
  t104_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t104_n131;
  t104_n116: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t104_n118;
  t104_n117: return 0.006634552031755447;
  t104_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t104_n126;
  t104_n119: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t104_n121;
  t104_n120: return 0.021277381107211113;
  t104_n121: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t104_n123;
  t104_n122: return 0.00930460263043642;
  t104_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n125;
  t104_n124: return 0.09649540483951569;
  t104_n125: return -0.14996181428432465;
  t104_n126: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t104_n130;
  t104_n127: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t104_n129;
  t104_n128: return 0.08055882900953293;
  t104_n129: return 0.1295280009508133;
  t104_n130: return 0.08751511573791504;
  t104_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n147;
  t104_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t104_n142;
  t104_n133: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n139;
  t104_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n136;
  t104_n135: return -0.22697025537490845;
  t104_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n138;
  t104_n137: return 0.10931986570358276;
  t104_n138: return 0.09130210429430008;
  t104_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t104_n141;
  t104_n140: return 0.10918793827295303;
  t104_n141: return 0.09898052364587784;
  t104_n142: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t104_n144;
  t104_n143: return 0.10228690505027771;
  t104_n144: if (E.getNumReferences() >= 3332281088 /*20297.5*/) goto t104_n146;
  t104_n145: return -0.028839172795414925;
  t104_n146: return 0.12150644510984421;
  t104_n147: if (E.getNumReferences() >= 3348846016 /*79531.5*/) goto t104_n171;
  t104_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t104_n150;
  t104_n149: return -0.3060219883918762;
  t104_n150: if (E.getNumReferences() >= 3347827136 /*71571.5*/) goto t104_n168;
  t104_n151: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t104_n159;
  t104_n152: if (E.getNumReferences() >= 3332189440 /*20118.5*/) goto t104_n154;
  t104_n153: return -0.11941805481910706;
  t104_n154: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t104_n158;
  t104_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t104_n157;
  t104_n156: return 0.06600432097911835;
  t104_n157: return 0.09872758388519287;
  t104_n158: return 0.12577566504478455;
  t104_n159: if (E.getNumReferences() >= 3338536704 /*32515.5*/) goto t104_n161;
  t104_n160: return -0.1938331574201584;
  t104_n161: if (E.getNumReferences() >= 3339882752 /*37521.0*/) goto t104_n167;
  t104_n162: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t104_n164;
  t104_n163: return 0.1301296353340149;
  t104_n164: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t104_n166;
  t104_n165: return 0.12367649376392365;
  t104_n166: return -0.16735132038593292;
  t104_n167: return 0.02398206666111946;
  t104_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n170;
  t104_n169: return 0.09813521057367325;
  t104_n170: return 0.05117286369204521;
  t104_n171: return 0.13992132246494293;
  t104_n172: if (E.getNumReferences() >= 3351224064 /*98110.0*/) goto t104_n178;
  t104_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t104_n175;
  t104_n174: return -0.2312234342098236;
  t104_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t104_n177;
  t104_n176: return -0.11609581857919693;
  t104_n177: return 0.07942131161689758;
  t104_n178: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t104_n184;
  t104_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t104_n181;
  t104_n180: return -0.20245350897312164;
  t104_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t104_n183;
  t104_n182: return 0.08130864053964615;
  t104_n183: return -0.003044578479602933;
  t104_n184: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n188;
  t104_n185: if (E.getNumReferences() >= 3362358400 /*239122.0*/) goto t104_n187;
  t104_n186: return 0.05001106485724449;
  t104_n187: return 0.0077062975615262985;
  t104_n188: return -0.052957482635974884;
  t104_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t104_n191;
  t104_n190: return -0.006834574043750763;
  t104_n191: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t104_n211;
  t104_n192: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t104_n194;
  t104_n193: return 0.008702443912625313;
  t104_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t104_n208;
  t104_n195: if (E.getNumReferences() >= 3332089344 /*19923.0*/) goto t104_n203;
  t104_n196: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t104_n198;
  t104_n197: return 0.04707762971520424;
  t104_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t104_n200;
  t104_n199: return 0.11351481825113297;
  t104_n200: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t104_n202;
  t104_n201: return 0.07038013637065887;
  t104_n202: return 0.1142609640955925;
  t104_n203: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t104_n205;
  t104_n204: return -0.009146607480943203;
  t104_n205: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t104_n207;
  t104_n206: return 0.08656540513038635;
  t104_n207: return 0.02678319625556469;
  t104_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t104_n210;
  t104_n209: return 0.10643021017313004;
  t104_n210: return -0.04354948177933693;
  t104_n211: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t104_n213;
  t104_n212: return 0.0031713033095002174;
  t104_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t104_n215;
  t104_n214: return 0.0059476131573319435;
  t104_n215: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t104_n233;
  t104_n216: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t104_n218;
  t104_n217: return 0.004738321993499994;
  t104_n218: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t104_n220;
  t104_n219: return 0.029832351952791214;
  t104_n220: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t104_n228;
  t104_n221: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t104_n227;
  t104_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n224;
  t104_n223: return 0.09625398367643356;
  t104_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t104_n226;
  t104_n225: return 0.10142505168914795;
  t104_n226: return -0.15410853922367096;
  t104_n227: return 0.14134304225444794;
  t104_n228: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n232;
  t104_n229: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t104_n231;
  t104_n230: return 0.06931784749031067;
  t104_n231: return 0.096028171479702;
  t104_n232: return 0.028019191697239876;
  t104_n233: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t104_n253;
  t104_n234: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t104_n244;
  t104_n235: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t104_n243;
  t104_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t104_n238;
  t104_n237: return 0.10705088078975677;
  t104_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n242;
  t104_n239: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t104_n241;
  t104_n240: return 0.09883067011833191;
  t104_n241: return 0.08383184671401978;
  t104_n242: return 0.06295142322778702;
  t104_n243: return 0.0858079344034195;
  t104_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t104_n246;
  t104_n245: return 0.03337296098470688;
  t104_n246: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t104_n252;
  t104_n247: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t104_n249;
  t104_n248: return 0.08767136931419373;
  t104_n249: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t104_n251;
  t104_n250: return 0.12248013913631439;
  t104_n251: return 0.0990072637796402;
  t104_n252: return 0.04810183867812157;
  t104_n253: return 0.013505439274013042;
  t104_n254: return -0.06067192927002907;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree105(const Example& E) {
  t105_n0: if (E.getNumReferences() >= 3304886272 /*2020.5*/) goto t105_n106;
  t105_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t105_n31;
  t105_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t105_n4;
  t105_n3: return -0.007788688410073519;
  t105_n4: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t105_n24;
  t105_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t105_n13;
  t105_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n8;
  t105_n7: return 0.013405004516243935;
  t105_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t105_n10;
  t105_n9: return 0.034050676971673965;
  t105_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t105_n12;
  t105_n11: return -0.07648354023694992;
  t105_n12: return -0.008871299214661121;
  t105_n13: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t105_n23;
  t105_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t105_n16;
  t105_n15: return -0.0060608950443565845;
  t105_n16: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t105_n18;
  t105_n17: return -0.002165389247238636;
  t105_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t105_n20;
  t105_n19: return 0.056305862963199615;
  t105_n20: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t105_n22;
  t105_n21: return 0.07774948328733444;
  t105_n22: return 0.11672227084636688;
  t105_n23: return 0.015802696347236633;
  t105_n24: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t105_n30;
  t105_n25: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t105_n29;
  t105_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n28;
  t105_n27: return -0.13395079970359802;
  t105_n28: return 0.10395882278680801;
  t105_n29: return 0.02694077603518963;
  t105_n30: return 0.052502017468214035;
  t105_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t105_n33;
  t105_n32: return -0.00014951032062526792;
  t105_n33: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t105_n35;
  t105_n34: return -0.07939160615205765;
  t105_n35: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t105_n87;
  t105_n36: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t105_n58;
  t105_n37: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t105_n39;
  t105_n38: return -0.002696667332202196;
  t105_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t105_n55;
  t105_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t105_n42;
  t105_n41: return 0.014232191257178783;
  t105_n42: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t105_n46;
  t105_n43: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t105_n45;
  t105_n44: return 0.12270987778902054;
  t105_n45: return -0.1265888810157776;
  t105_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t105_n52;
  t105_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t105_n51;
  t105_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n50;
  t105_n49: return -0.12304666638374329;
  t105_n50: return 0.11885473877191544;
  t105_n51: return -0.08941136300563812;
  t105_n52: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t105_n54;
  t105_n53: return -0.04929902032017708;
  t105_n54: return 0.12217466533184052;
  t105_n55: if (E.getNumReferences() >= 3304820736 /*2012.5*/) goto t105_n57;
  t105_n56: return 0.03565646708011627;
  t105_n57: return 0.12057453393936157;
  t105_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n68;
  t105_n59: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t105_n61;
  t105_n60: return -0.13271227478981018;
  t105_n61: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t105_n67;
  t105_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t105_n64;
  t105_n63: return -0.19046631455421448;
  t105_n64: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t105_n66;
  t105_n65: return 0.106477752327919;
  t105_n66: return -0.05341760814189911;
  t105_n67: return -0.03848855197429657;
  t105_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t105_n70;
  t105_n69: return -0.012423812411725521;
  t105_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t105_n76;
  t105_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n73;
  t105_n72: return -0.0470740869641304;
  t105_n73: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t105_n75;
  t105_n74: return -0.0502253994345665;
  t105_n75: return 0.11296150088310242;
  t105_n76: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t105_n86;
  t105_n77: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t105_n85;
  t105_n78: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t105_n82;
  t105_n79: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t105_n81;
  t105_n80: return 0.12487678974866867;
  t105_n81: return 0.05821298435330391;
  t105_n82: if (E.getNumReferences() >= 3267231744 /*95.0*/) goto t105_n84;
  t105_n83: return 0.13251127302646637;
  t105_n84: return 0.04829929396510124;
  t105_n85: return 0.056051578372716904;
  t105_n86: return -0.009598449803888798;
  t105_n87: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t105_n93;
  t105_n88: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n90;
  t105_n89: return 0.009926979430019855;
  t105_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t105_n92;
  t105_n91: return -0.0700167864561081;
  t105_n92: return -0.043501824140548706;
  t105_n93: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t105_n97;
  t105_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t105_n96;
  t105_n95: return -0.0031936331652104855;
  t105_n96: return 0.055333785712718964;
  t105_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t105_n101;
  t105_n98: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t105_n100;
  t105_n99: return 0.009865050204098225;
  t105_n100: return 0.04063059762120247;
  t105_n101: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t105_n103;
  t105_n102: return 0.05831661447882652;
  t105_n103: if (E.getNumReferences() >= 3292938240 /*793.0*/) goto t105_n105;
  t105_n104: return 0.10580356419086456;
  t105_n105: return 0.05903429538011551;
  t105_n106: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t105_n110;
  t105_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t105_n109;
  t105_n108: return 0.012441953644156456;
  t105_n109: return 0.030501404777169228;
  t105_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t105_n112;
  t105_n111: return -0.004227975383400917;
  t105_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t105_n210;
  t105_n113: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t105_n195;
  t105_n114: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t105_n170;
  t105_n115: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t105_n149;
  t105_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n118;
  t105_n117: return -0.1430446356534958;
  t105_n118: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t105_n142;
  t105_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t105_n133;
  t105_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t105_n122;
  t105_n121: return -0.020358938723802567;
  t105_n122: if (E.getNumReferences() >= 3326231552 /*12433.0*/) goto t105_n128;
  t105_n123: if (E.getNumReferences() >= 3305193472 /*2068.0*/) goto t105_n127;
  t105_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n126;
  t105_n125: return 0.11899462342262268;
  t105_n126: return -0.11161234974861145;
  t105_n127: return 0.05138365551829338;
  t105_n128: if (E.getNumReferences() >= 3326755840 /*12945.0*/) goto t105_n132;
  t105_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t105_n131;
  t105_n130: return -0.10412328690290451;
  t105_n131: return 0.11087366938591003;
  t105_n132: return 0.09396158158779144;
  t105_n133: if (E.getNumReferences() >= 3327097344 /*13278.5*/) goto t105_n137;
  t105_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t105_n136;
  t105_n135: return 0.07876740396022797;
  t105_n136: return 0.09252890199422836;
  t105_n137: if (E.getNumReferences() >= 3327775744 /*13941.0*/) goto t105_n141;
  t105_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t105_n140;
  t105_n139: return 0.1527901142835617;
  t105_n140: return 0.10873042047023773;
  t105_n141: return 0.01585688628256321;
  t105_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n148;
  t105_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t105_n145;
  t105_n144: return 0.02688354067504406;
  t105_n145: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t105_n147;
  t105_n146: return 0.06906077265739441;
  t105_n147: return 0.11140982806682587;
  t105_n148: return -0.038522932678461075;
  t105_n149: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t105_n169;
  t105_n150: if (E.getNumReferences() >= 3315700736 /*5170.5*/) goto t105_n152;
  t105_n151: return 0.0020612869411706924;
  t105_n152: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t105_n160;
  t105_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t105_n159;
  t105_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t105_n156;
  t105_n155: return 0.1454029679298401;
  t105_n156: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t105_n158;
  t105_n157: return 0.15530863404273987;
  t105_n158: return 0.09645993262529373;
  t105_n159: return -0.14520186185836792;
  t105_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t105_n162;
  t105_n161: return 0.03372582793235779;
  t105_n162: if (E.getNumReferences() >= 3324623872 /*10863.0*/) goto t105_n164;
  t105_n163: return 0.08944890648126602;
  t105_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t105_n168;
  t105_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t105_n167;
  t105_n166: return -0.22785353660583496;
  t105_n167: return 0.11590453237295151;
  t105_n168: return -0.12272772938013077;
  t105_n169: return 0.0487816147506237;
  t105_n170: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t105_n180;
  t105_n171: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t105_n179;
  t105_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t105_n174;
  t105_n173: return 0.02706941030919552;
  t105_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t105_n176;
  t105_n175: return 0.05000874027609825;
  t105_n176: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t105_n178;
  t105_n177: return 0.13843663036823273;
  t105_n178: return 0.0937054306268692;
  t105_n179: return 0.12029501795768738;
  t105_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t105_n182;
  t105_n181: return 0.029018374159932137;
  t105_n182: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t105_n188;
  t105_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t105_n187;
  t105_n184: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t105_n186;
  t105_n185: return 0.108202263712883;
  t105_n186: return 0.10220872610807419;
  t105_n187: return -0.1023048609495163;
  t105_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t105_n190;
  t105_n189: return 0.032953280955553055;
  t105_n190: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t105_n194;
  t105_n191: if (E.getNumReferences() >= 3332825344 /*21360.5*/) goto t105_n193;
  t105_n192: return 0.0951329916715622;
  t105_n193: return 0.12123959511518478;
  t105_n194: return 0.05651164799928665;
  t105_n195: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t105_n197;
  t105_n196: return -0.013260744512081146;
  t105_n197: if (E.getNumReferences() >= 3334782720 /*25183.5*/) goto t105_n199;
  t105_n198: return -0.22555093467235565;
  t105_n199: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t105_n209;
  t105_n200: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t105_n202;
  t105_n201: return 0.01810896024107933;
  t105_n202: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t105_n206;
  t105_n203: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n205;
  t105_n204: return 0.08177301287651062;
  t105_n205: return 0.10224281251430511;
  t105_n206: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t105_n208;
  t105_n207: return -0.016408536583185196;
  t105_n208: return 0.06436483561992645;
  t105_n209: return 0.011893359012901783;
  t105_n210: if (E.getNumReferences() >= 3315990528 /*5312.0*/) goto t105_n222;
  t105_n211: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t105_n219;
  t105_n212: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t105_n214;
  t105_n213: return -0.0046730306930840015;
  t105_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t105_n216;
  t105_n215: return 0.06700523942708969;
  t105_n216: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t105_n218;
  t105_n217: return 0.10438089072704315;
  t105_n218: return 0.06518982350826263;
  t105_n219: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t105_n221;
  t105_n220: return 0.10926511883735657;
  t105_n221: return 0.05589936301112175;
  t105_n222: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t105_n254;
  t105_n223: if (E.getNumReferences() >= 3329614848 /*15737.0*/) goto t105_n251;
  t105_n224: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t105_n236;
  t105_n225: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t105_n235;
  t105_n226: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t105_n228;
  t105_n227: return -0.27834317088127136;
  t105_n228: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t105_n234;
  t105_n229: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t105_n233;
  t105_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t105_n232;
  t105_n231: return 0.07432638853788376;
  t105_n232: return 0.11097238212823868;
  t105_n233: return 0.10854888707399368;
  t105_n234: return -0.1456984132528305;
  t105_n235: return 0.004755386151373386;
  t105_n236: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t105_n238;
  t105_n237: return 0.008960643783211708;
  t105_n238: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t105_n244;
  t105_n239: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t105_n243;
  t105_n240: if (E.getNumReferences() >= 3317903360 /*6246.0*/) goto t105_n242;
  t105_n241: return 0.05898597091436386;
  t105_n242: return 0.1066913828253746;
  t105_n243: return -0.002046253066509962;
  t105_n244: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t105_n250;
  t105_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t105_n247;
  t105_n246: return 0.11190854012966156;
  t105_n247: if (E.getNumReferences() >= 3322208768 /*8504.5*/) goto t105_n249;
  t105_n248: return 0.11981604993343353;
  t105_n249: return 0.08379321545362473;
  t105_n250: return 0.0835183784365654;
  t105_n251: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t105_n253;
  t105_n252: return 0.12048683315515518;
  t105_n253: return 0.10880772024393082;
  t105_n254: return 0.03534606844186783;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree106(const Example& E) {
  t106_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t106_n176;
  t106_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t106_n171;
  t106_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n4;
  t106_n3: return -0.04785056784749031;
  t106_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t106_n132;
  t106_n5: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t106_n53;
  t106_n6: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t106_n52;
  t106_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t106_n9;
  t106_n8: return 0.009708650410175323;
  t106_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t106_n33;
  t106_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t106_n12;
  t106_n11: return -0.004570034332573414;
  t106_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n14;
  t106_n13: return 0.08249277621507645;
  t106_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t106_n32;
  t106_n15: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t106_n25;
  t106_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n18;
  t106_n17: return 0.039481088519096375;
  t106_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n20;
  t106_n19: return 0.14259478449821472;
  t106_n20: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t106_n22;
  t106_n21: return 0.08145890384912491;
  t106_n22: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t106_n24;
  t106_n23: return 0.114497110247612;
  t106_n24: return 0.05085068568587303;
  t106_n25: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t106_n27;
  t106_n26: return 0.13134460151195526;
  t106_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t106_n29;
  t106_n28: return 0.08095571398735046;
  t106_n29: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t106_n31;
  t106_n30: return 0.060030870139598846;
  t106_n31: return 0.12802273035049438;
  t106_n32: return 0.04130691662430763;
  t106_n33: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t106_n51;
  t106_n34: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t106_n50;
  t106_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t106_n45;
  t106_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n42;
  t106_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n39;
  t106_n38: return -0.2318306267261505;
  t106_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n41;
  t106_n40: return 0.11692235618829727;
  t106_n41: return 0.2570885717868805;
  t106_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t106_n44;
  t106_n43: return 0.056478265672922134;
  t106_n44: return 0.0845155119895935;
  t106_n45: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t106_n47;
  t106_n46: return -0.01956467516720295;
  t106_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t106_n49;
  t106_n48: return 0.05905607342720032;
  t106_n49: return 0.34317854046821594;
  t106_n50: return 0.03932579606771469;
  t106_n51: return 0.03152317553758621;
  t106_n52: return 0.06625720113515854;
  t106_n53: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t106_n55;
  t106_n54: return -0.0044729867950081825;
  t106_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n57;
  t106_n56: return -7.155397179303691e-05;
  t106_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t106_n121;
  t106_n58: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t106_n120;
  t106_n59: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t106_n91;
  t106_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t106_n82;
  t106_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n63;
  t106_n62: return 0.012542271986603737;
  t106_n63: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t106_n79;
  t106_n64: if (E.getNumReferences() >= 3356105632 /*141422.5*/) goto t106_n78;
  t106_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t106_n67;
  t106_n66: return 0.040358226746320724;
  t106_n67: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t106_n77;
  t106_n68: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t106_n74;
  t106_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t106_n71;
  t106_n70: return -0.12222806364297867;
  t106_n71: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t106_n73;
  t106_n72: return 0.07532041519880295;
  t106_n73: return -0.05745209753513336;
  t106_n74: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t106_n76;
  t106_n75: return 0.003855479648336768;
  t106_n76: return 0.09996771812438965;
  t106_n77: return 0.04191618412733078;
  t106_n78: return -0.17104406654834747;
  t106_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t106_n81;
  t106_n80: return 0.010229206643998623;
  t106_n81: return 0.0968141034245491;
  t106_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t106_n90;
  t106_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t106_n85;
  t106_n84: return -0.0001448967377655208;
  t106_n85: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t106_n89;
  t106_n86: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t106_n88;
  t106_n87: return 0.09906568378210068;
  t106_n88: return 0.03595336526632309;
  t106_n89: return 0.04814495891332626;
  t106_n90: return -0.04443389177322388;
  t106_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t106_n103;
  t106_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t106_n94;
  t106_n93: return 0.005958489142358303;
  t106_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t106_n96;
  t106_n95: return 0.018779592588543892;
  t106_n96: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t106_n102;
  t106_n97: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t106_n99;
  t106_n98: return 0.03427806496620178;
  t106_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n101;
  t106_n100: return 0.0838421955704689;
  t106_n101: return 0.11868129670619965;
  t106_n102: return 0.016380347311496735;
  t106_n103: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t106_n115;
  t106_n104: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t106_n112;
  t106_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t106_n107;
  t106_n106: return 0.013757285661995411;
  t106_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n111;
  t106_n108: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t106_n110;
  t106_n109: return 0.07703737914562225;
  t106_n110: return 0.10693497210741043;
  t106_n111: return 0.07498978078365326;
  t106_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n114;
  t106_n113: return -0.1139008179306984;
  t106_n114: return 0.04829062521457672;
  t106_n115: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t106_n119;
  t106_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t106_n118;
  t106_n117: return 0.10891387611627579;
  t106_n118: return 0.015617492608726025;
  t106_n119: return 0.13774359226226807;
  t106_n120: return -0.0007430011173710227;
  t106_n121: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t106_n127;
  t106_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n124;
  t106_n123: return 0.10966711491346359;
  t106_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t106_n126;
  t106_n125: return 0.049170807003974915;
  t106_n126: return 0.13933788239955902;
  t106_n127: if (E.getNumReferences() >= 3359549600 /*195234.5*/) goto t106_n129;
  t106_n128: return -0.06047673895955086;
  t106_n129: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t106_n131;
  t106_n130: return 0.06309337913990021;
  t106_n131: return 0.00720797386020422;
  t106_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t106_n150;
  t106_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t106_n147;
  t106_n134: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t106_n136;
  t106_n135: return -0.13663624227046967;
  t106_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t106_n138;
  t106_n137: return -0.04353566840291023;
  t106_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t106_n140;
  t106_n139: return -0.09547986090183258;
  t106_n140: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t106_n144;
  t106_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n143;
  t106_n142: return -0.29213473200798035;
  t106_n143: return 0.10142052173614502;
  t106_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t106_n146;
  t106_n145: return 0.11981692910194397;
  t106_n146: return -0.13571247458457947;
  t106_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n149;
  t106_n148: return -0.026337696239352226;
  t106_n149: return 0.04286905378103256;
  t106_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n170;
  t106_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t106_n163;
  t106_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n154;
  t106_n153: return -0.05294749513268471;
  t106_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t106_n156;
  t106_n155: return -0.01409140508621931;
  t106_n156: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t106_n162;
  t106_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n159;
  t106_n158: return 0.14442895352840424;
  t106_n159: if (E.getNumReferences() >= 3309338624 /*3080.0*/) goto t106_n161;
  t106_n160: return 0.06063510850071907;
  t106_n161: return -0.05853123590350151;
  t106_n162: return -0.11845360696315765;
  t106_n163: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t106_n169;
  t106_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n166;
  t106_n165: return 0.10873198509216309;
  t106_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n168;
  t106_n167: return 0.058722663670778275;
  t106_n168: return 0.02208235114812851;
  t106_n169: return -0.12534137070178986;
  t106_n170: return 0.003916068933904171;
  t106_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other))) goto t106_n175;
  t106_n172: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t106_n174;
  t106_n173: return 0.00613601366057992;
  t106_n174: return -0.01579728163778782;
  t106_n175: return 0.025972774252295494;
  t106_n176: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t106_n226;
  t106_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t106_n225;
  t106_n178: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t106_n222;
  t106_n179: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t106_n215;
  t106_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n204;
  t106_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t106_n185;
  t106_n182: if (E.getNumReferences() >= 3298205696 /*1205.0*/) goto t106_n184;
  t106_n183: return -0.05470952019095421;
  t106_n184: return 0.09017197042703629;
  t106_n185: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t106_n201;
  t106_n186: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t106_n198;
  t106_n187: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t106_n197;
  t106_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n190;
  t106_n189: return -0.07259299606084824;
  t106_n190: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t106_n192;
  t106_n191: return -0.04833535850048065;
  t106_n192: if (E.getNumReferences() >= 3288637440 /*530.5*/) goto t106_n196;
  t106_n193: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t106_n195;
  t106_n194: return 0.014673135243356228;
  t106_n195: return 0.07529710233211517;
  t106_n196: return 0.09669049829244614;
  t106_n197: return -0.14001460373401642;
  t106_n198: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t106_n200;
  t106_n199: return 0.12141679227352142;
  t106_n200: return -0.19695548713207245;
  t106_n201: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t106_n203;
  t106_n202: return -0.04244104400277138;
  t106_n203: return 0.10963378846645355;
  t106_n204: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t106_n214;
  t106_n205: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t106_n213;
  t106_n206: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t106_n210;
  t106_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t106_n209;
  t106_n208: return -0.06050409376621246;
  t106_n209: return 0.02801145613193512;
  t106_n210: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t106_n212;
  t106_n211: return 0.10331157594919205;
  t106_n212: return 0.06952841579914093;
  t106_n213: return -0.07759001106023788;
  t106_n214: return -0.004621441010385752;
  t106_n215: if (E.getNumReferences() >= 3367232976 /*368430.5*/) goto t106_n221;
  t106_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t106_n218;
  t106_n217: return 0.04943685606122017;
  t106_n218: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t106_n220;
  t106_n219: return 0.12108432501554489;
  t106_n220: return 0.0898384377360344;
  t106_n221: return -0.0010953607270494103;
  t106_n222: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t106_n224;
  t106_n223: return -0.07752253115177155;
  t106_n224: return -0.1498555690050125;
  t106_n225: return 0.005041930824518204;
  t106_n226: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t106_n230;
  t106_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n229;
  t106_n228: return -0.02833806723356247;
  t106_n229: return 0.009162032045423985;
  t106_n230: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t106_n250;
  t106_n231: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t106_n243;
  t106_n232: if (E.getNumReferences() >= 3290226688 /*627.5*/) goto t106_n240;
  t106_n233: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t106_n239;
  t106_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t106_n238;
  t106_n235: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t106_n237;
  t106_n236: return -0.13133689761161804;
  t106_n237: return -0.27364352345466614;
  t106_n238: return -0.01906738430261612;
  t106_n239: return 0.0020744232460856438;
  t106_n240: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t106_n242;
  t106_n241: return 0.12791068851947784;
  t106_n242: return 0.032701525837183;
  t106_n243: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t106_n249;
  t106_n244: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t106_n246;
  t106_n245: return -0.013597841374576092;
  t106_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t106_n248;
  t106_n247: return -0.00495989341288805;
  t106_n248: return 0.023651864379644394;
  t106_n249: return 0.011781160719692707;
  t106_n250: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t106_n254;
  t106_n251: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t106_n253;
  t106_n252: return 0.02233525738120079;
  t106_n253: return 0.007045858073979616;
  t106_n254: return -0.4977693557739258;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree107(const Example& E) {
  t107_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t107_n254;
  t107_n1: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t107_n3;
  t107_n2: return -0.0011864107800647616;
  t107_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t107_n49;
  t107_n4: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t107_n44;
  t107_n5: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t107_n29;
  t107_n6: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t107_n8;
  t107_n7: return 0.021495457738637924;
  t107_n8: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t107_n16;
  t107_n9: if (E.getFileProximityDistance() >= 3250061312 /*23.0*/) goto t107_n15;
  t107_n10: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n12;
  t107_n11: return -0.06634462624788284;
  t107_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n14;
  t107_n13: return 0.028809456154704094;
  t107_n14: return -0.06773534417152405;
  t107_n15: return 0.1062864437699318;
  t107_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n22;
  t107_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t107_n19;
  t107_n18: return 0.018690209835767746;
  t107_n19: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t107_n21;
  t107_n20: return 0.11605633050203323;
  t107_n21: return 0.07785113155841827;
  t107_n22: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t107_n26;
  t107_n23: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n25;
  t107_n24: return 0.06501712650060654;
  t107_n25: return 0.04209334775805473;
  t107_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n28;
  t107_n27: return 0.1011669784784317;
  t107_n28: return 0.02818835899233818;
  t107_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n43;
  t107_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n34;
  t107_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t107_n33;
  t107_n32: return -0.2496727555990219;
  t107_n33: return 0.0036502915900200605;
  t107_n34: if (E.getNumReferences() >= 3365683120 /*319997.5*/) goto t107_n42;
  t107_n35: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t107_n37;
  t107_n36: return -0.15738345682621002;
  t107_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t107_n39;
  t107_n38: return -0.018823981285095215;
  t107_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n41;
  t107_n40: return 0.11374856531620026;
  t107_n41: return -0.2082132250070572;
  t107_n42: return -0.35492002964019775;
  t107_n43: return 0.11869043111801147;
  t107_n44: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t107_n46;
  t107_n45: return 0.024709295481443405;
  t107_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n48;
  t107_n47: return 0.09035299718379974;
  t107_n48: return 0.08440802246332169;
  t107_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t107_n51;
  t107_n50: return -0.04593776911497116;
  t107_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t107_n187;
  t107_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t107_n130;
  t107_n53: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t107_n129;
  t107_n54: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t107_n104;
  t107_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t107_n57;
  t107_n56: return 0.010842700488865376;
  t107_n57: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t107_n59;
  t107_n58: return -0.14066019654273987;
  t107_n59: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t107_n61;
  t107_n60: return 0.018799014389514923;
  t107_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t107_n99;
  t107_n62: if (E.getNumReferences() >= 3332023808 /*19795.0*/) goto t107_n68;
  t107_n63: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t107_n65;
  t107_n64: return -0.2310979813337326;
  t107_n65: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t107_n67;
  t107_n66: return 0.2359764575958252;
  t107_n67: return 0.1225743442773819;
  t107_n68: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t107_n70;
  t107_n69: return 0.005425779614597559;
  t107_n70: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t107_n80;
  t107_n71: if (E.getNumReferences() >= 3347948160 /*72517.0*/) goto t107_n73;
  t107_n72: return 0.07143858820199966;
  t107_n73: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t107_n77;
  t107_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n76;
  t107_n75: return 0.11575417965650558;
  t107_n76: return 0.07873411476612091;
  t107_n77: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t107_n79;
  t107_n78: return 0.08009658753871918;
  t107_n79: return -0.27135276794433594;
  t107_n80: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t107_n94;
  t107_n81: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t107_n83;
  t107_n82: return 0.0031867406796664;
  t107_n83: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t107_n85;
  t107_n84: return -0.20625366270542145;
  t107_n85: if (E.getNumReferences() >= 3355904736 /*138283.5*/) goto t107_n93;
  t107_n86: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t107_n90;
  t107_n87: if (E.getNumReferences() >= 3351190528 /*97848.0*/) goto t107_n89;
  t107_n88: return -0.14722071588039398;
  t107_n89: return 0.16456453502178192;
  t107_n90: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t107_n92;
  t107_n91: return 0.123024582862854;
  t107_n92: return 0.1724221110343933;
  t107_n93: return -0.2910914421081543;
  t107_n94: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t107_n98;
  t107_n95: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t107_n97;
  t107_n96: return 0.08884187042713165;
  t107_n97: return 0.10001213103532791;
  t107_n98: return -0.14643965661525726;
  t107_n99: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t107_n101;
  t107_n100: return -0.34476831555366516;
  t107_n101: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n103;
  t107_n102: return 0.1482323706150055;
  t107_n103: return -0.10469603538513184;
  t107_n104: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t107_n120;
  t107_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t107_n107;
  t107_n106: return -0.0638386681675911;
  t107_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n119;
  t107_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t107_n110;
  t107_n109: return 0.10144755244255066;
  t107_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t107_n112;
  t107_n111: return 0.07199988514184952;
  t107_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t107_n118;
  t107_n113: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n115;
  t107_n114: return 0.11527804285287857;
  t107_n115: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n117;
  t107_n116: return 0.13333705067634583;
  t107_n117: return 0.12869073450565338;
  t107_n118: return -0.1619233936071396;
  t107_n119: return 0.05924098566174507;
  t107_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t107_n122;
  t107_n121: return -0.05902828276157379;
  t107_n122: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t107_n124;
  t107_n123: return 0.02349097654223442;
  t107_n124: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t107_n128;
  t107_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t107_n127;
  t107_n126: return -0.015393403358757496;
  t107_n127: return 0.09602778404951096;
  t107_n128: return 0.039311494678258896;
  t107_n129: return -0.021023863926529884;
  t107_n130: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t107_n146;
  t107_n131: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t107_n143;
  t107_n132: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t107_n138;
  t107_n133: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t107_n135;
  t107_n134: return 0.00504118949174881;
  t107_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t107_n137;
  t107_n136: return 0.058641474694013596;
  t107_n137: return 0.10427017509937286;
  t107_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t107_n142;
  t107_n139: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t107_n141;
  t107_n140: return 0.09535340964794159;
  t107_n141: return 0.02815033495426178;
  t107_n142: return 0.11268886923789978;
  t107_n143: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t107_n145;
  t107_n144: return 0.1087355986237526;
  t107_n145: return 0.07090120017528534;
  t107_n146: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t107_n158;
  t107_n147: if (E.getNumReferences() >= 3336654336 /*28839.0*/) goto t107_n157;
  t107_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n150;
  t107_n149: return -0.1450883001089096;
  t107_n150: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t107_n156;
  t107_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t107_n153;
  t107_n152: return 0.04356779530644417;
  t107_n153: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t107_n155;
  t107_n154: return 0.10755644738674164;
  t107_n155: return 0.07835857570171356;
  t107_n156: return -0.030450092628598213;
  t107_n157: return -0.40433546900749207;
  t107_n158: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t107_n186;
  t107_n159: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t107_n181;
  t107_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n162;
  t107_n161: return -0.080263152718544;
  t107_n162: if (E.getNumReferences() >= 3340289792 /*39111.0*/) goto t107_n166;
  t107_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t107_n165;
  t107_n164: return -0.14431680738925934;
  t107_n165: return 0.01892254874110222;
  t107_n166: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t107_n180;
  t107_n167: if (E.getNumReferences() >= 3341381632 /*43376.0*/) goto t107_n173;
  t107_n168: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t107_n170;
  t107_n169: return 0.026556771248579025;
  t107_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t107_n172;
  t107_n171: return 0.2498188465833664;
  t107_n172: return 0.10678518563508987;
  t107_n173: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t107_n177;
  t107_n174: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t107_n176;
  t107_n175: return 0.09647145122289658;
  t107_n176: return 0.11529389768838882;
  t107_n177: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t107_n179;
  t107_n178: return 0.014966145157814026;
  t107_n179: return 0.10689843446016312;
  t107_n180: return 0.021364666521549225;
  t107_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t107_n183;
  t107_n182: return -0.07742533832788467;
  t107_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t107_n185;
  t107_n184: return 0.11009593307971954;
  t107_n185: return 0.10385629534721375;
  t107_n186: return -0.028690198436379433;
  t107_n187: if (E.getNumReferences() >= 3349221056 /*82461.5*/) goto t107_n243;
  t107_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t107_n204;
  t107_n189: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t107_n191;
  t107_n190: return 0.007161872927099466;
  t107_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t107_n199;
  t107_n192: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t107_n194;
  t107_n193: return 0.013468941673636436;
  t107_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n196;
  t107_n195: return 0.007944093085825443;
  t107_n196: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n198;
  t107_n197: return 0.09349934011697769;
  t107_n198: return -0.12217191606760025;
  t107_n199: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t107_n203;
  t107_n200: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t107_n202;
  t107_n201: return 0.07794244587421417;
  t107_n202: return 0.12814059853553772;
  t107_n203: return 0.08466757088899612;
  t107_n204: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t107_n220;
  t107_n205: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t107_n215;
  t107_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t107_n212;
  t107_n207: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t107_n209;
  t107_n208: return -0.208570659160614;
  t107_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t107_n211;
  t107_n210: return 0.10807225108146667;
  t107_n211: return 0.08861587941646576;
  t107_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t107_n214;
  t107_n213: return 0.10802551358938217;
  t107_n214: return 0.0921211689710617;
  t107_n215: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t107_n217;
  t107_n216: return 0.09253481775522232;
  t107_n217: if (E.getNumReferences() >= 3332281088 /*20297.5*/) goto t107_n219;
  t107_n218: return -0.031965140253305435;
  t107_n219: return 0.11936970055103302;
  t107_n220: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t107_n242;
  t107_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t107_n223;
  t107_n222: return -0.2286827117204666;
  t107_n223: if (E.getNumReferences() >= 3347827136 /*71571.5*/) goto t107_n239;
  t107_n224: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t107_n232;
  t107_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t107_n231;
  t107_n226: if (E.getNumReferences() >= 3332189440 /*20118.5*/) goto t107_n228;
  t107_n227: return -0.07205896824598312;
  t107_n228: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t107_n230;
  t107_n229: return 0.057704564183950424;
  t107_n230: return 0.12920553982257843;
  t107_n231: return 0.09820074588060379;
  t107_n232: if (E.getNumReferences() >= 3338536704 /*32515.5*/) goto t107_n234;
  t107_n233: return -0.17930996417999268;
  t107_n234: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t107_n238;
  t107_n235: if (E.getNumReferences() >= 3339772928 /*37092.0*/) goto t107_n237;
  t107_n236: return 0.12344493716955185;
  t107_n237: return 0.07734917849302292;
  t107_n238: return 0.01562989316880703;
  t107_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t107_n241;
  t107_n240: return 0.09180352836847305;
  t107_n241: return 0.04594188928604126;
  t107_n242: return 0.13584855198860168;
  t107_n243: if (E.getNumReferences() >= 3351224064 /*98110.0*/) goto t107_n245;
  t107_n244: return -0.0778931975364685;
  t107_n245: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t107_n249;
  t107_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t107_n248;
  t107_n247: return -0.20342952013015747;
  t107_n248: return 0.06714117527008057;
  t107_n249: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t107_n253;
  t107_n250: if (E.getNumReferences() >= 3362358400 /*239122.0*/) goto t107_n252;
  t107_n251: return 0.04644278064370155;
  t107_n252: return 0.007845095358788967;
  t107_n253: return -0.05083240941166878;
  t107_n254: return 0.005349564831703901;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree108(const Example& E) {
  t108_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t108_n254;
  t108_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t108_n9;
  t108_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t108_n6;
  t108_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n5;
  t108_n4: return -0.11286461353302002;
  t108_n5: return -0.0004231093334965408;
  t108_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t108_n8;
  t108_n7: return 0.004917247220873833;
  t108_n8: return 0.015857910737395287;
  t108_n9: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t108_n251;
  t108_n10: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t108_n134;
  t108_n11: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t108_n85;
  t108_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n20;
  t108_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t108_n15;
  t108_n14: return 0.02001996710896492;
  t108_n15: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t108_n19;
  t108_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n18;
  t108_n17: return -0.010568060912191868;
  t108_n18: return -0.03835008665919304;
  t108_n19: return 0.0021702470257878304;
  t108_n20: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t108_n84;
  t108_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n83;
  t108_n22: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t108_n72;
  t108_n23: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t108_n71;
  t108_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n28;
  t108_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t108_n27;
  t108_n26: return -0.06894336640834808;
  t108_n27: return -0.005926181096583605;
  t108_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t108_n66;
  t108_n29: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t108_n35;
  t108_n30: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t108_n34;
  t108_n31: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t108_n33;
  t108_n32: return 0.08131766319274902;
  t108_n33: return 0.10653312504291534;
  t108_n34: return 0.004689754452556372;
  t108_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t108_n37;
  t108_n36: return -0.00722834188491106;
  t108_n37: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t108_n49;
  t108_n38: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t108_n46;
  t108_n39: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t108_n41;
  t108_n40: return -0.13848648965358734;
  t108_n41: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t108_n43;
  t108_n42: return 0.1486824005842209;
  t108_n43: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t108_n45;
  t108_n44: return 0.2039068043231964;
  t108_n45: return -0.2122068852186203;
  t108_n46: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t108_n48;
  t108_n47: return 0.1412477046251297;
  t108_n48: return 1.436333179473877;
  t108_n49: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t108_n55;
  t108_n50: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t108_n54;
  t108_n51: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t108_n53;
  t108_n52: return 0.13134203851222992;
  t108_n53: return -0.012662292458117008;
  t108_n54: return -0.03216436132788658;
  t108_n55: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t108_n65;
  t108_n56: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n60;
  t108_n57: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t108_n59;
  t108_n58: return 0.09296421706676483;
  t108_n59: return 0.10961701720952988;
  t108_n60: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t108_n62;
  t108_n61: return -0.026104167103767395;
  t108_n62: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t108_n64;
  t108_n63: return 0.09895900636911392;
  t108_n64: return -0.47973594069480896;
  t108_n65: return 0.11285216361284256;
  t108_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t108_n70;
  t108_n67: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t108_n69;
  t108_n68: return -0.06850721687078476;
  t108_n69: return -0.3885495960712433;
  t108_n70: return 0.022898536175489426;
  t108_n71: return -0.1283421367406845;
  t108_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n74;
  t108_n73: return -0.02876734547317028;
  t108_n74: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t108_n76;
  t108_n75: return 0.027097651734948158;
  t108_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t108_n82;
  t108_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n79;
  t108_n78: return -0.008023513481020927;
  t108_n79: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t108_n81;
  t108_n80: return -0.024795671924948692;
  t108_n81: return 0.10434582829475403;
  t108_n82: return -0.12785930931568146;
  t108_n83: return 0.002751260297372937;
  t108_n84: return 0.017354683950543404;
  t108_n85: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t108_n119;
  t108_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n88;
  t108_n87: return 0.07925828546285629;
  t108_n88: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t108_n118;
  t108_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t108_n91;
  t108_n90: return -0.12387900799512863;
  t108_n91: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t108_n95;
  t108_n92: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t108_n94;
  t108_n93: return -0.12524938583374023;
  t108_n94: return 0.15380461513996124;
  t108_n95: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t108_n117;
  t108_n96: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t108_n116;
  t108_n97: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t108_n105;
  t108_n98: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t108_n100;
  t108_n99: return 0.0019125292310491204;
  t108_n100: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n104;
  t108_n101: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n103;
  t108_n102: return 0.109049953520298;
  t108_n103: return -0.10451656579971313;
  t108_n104: return 0.050562236458063126;
  t108_n105: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t108_n109;
  t108_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n108;
  t108_n107: return -0.11698174476623535;
  t108_n108: return 0.12051878869533539;
  t108_n109: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t108_n111;
  t108_n110: return -0.24358947575092316;
  t108_n111: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n113;
  t108_n112: return 0.09129749983549118;
  t108_n113: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t108_n115;
  t108_n114: return 0.1294027715921402;
  t108_n115: return 0.08857088536024094;
  t108_n116: return 0.02349686250090599;
  t108_n117: return -0.04005490615963936;
  t108_n118: return 0.10881628841161728;
  t108_n119: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t108_n127;
  t108_n120: if (E.getNumReferences() >= 3290554368 /*647.5*/) goto t108_n124;
  t108_n121: if (E.getNumReferences() >= 3290251264 /*629.0*/) goto t108_n123;
  t108_n122: return 0.02390304021537304;
  t108_n123: return 0.10446184873580933;
  t108_n124: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t108_n126;
  t108_n125: return 0.1151149794459343;
  t108_n126: return -0.01782059296965599;
  t108_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t108_n131;
  t108_n128: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t108_n130;
  t108_n129: return 0.11329609900712967;
  t108_n130: return 0.027472611516714096;
  t108_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n133;
  t108_n132: return 0.10556893050670624;
  t108_n133: return -0.035918813198804855;
  t108_n134: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t108_n210;
  t108_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t108_n137;
  t108_n136: return -0.04231291636824608;
  t108_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n139;
  t108_n138: return -0.006549580488353968;
  t108_n139: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t108_n171;
  t108_n140: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t108_n170;
  t108_n141: if (E.getNumReferences() >= 3322049024 /*8348.5*/) goto t108_n165;
  t108_n142: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t108_n144;
  t108_n143: return 0.02096213959157467;
  t108_n144: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t108_n146;
  t108_n145: return -0.031219016760587692;
  t108_n146: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t108_n164;
  t108_n147: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t108_n157;
  t108_n148: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t108_n156;
  t108_n149: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t108_n155;
  t108_n150: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n152;
  t108_n151: return 0.07417061924934387;
  t108_n152: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n154;
  t108_n153: return 0.13540907204151154;
  t108_n154: return -0.3198298513889313;
  t108_n155: return 0.07219202071428299;
  t108_n156: return -0.01198350265622139;
  t108_n157: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t108_n159;
  t108_n158: return 0.119319848716259;
  t108_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n161;
  t108_n160: return 0.01752832904458046;
  t108_n161: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t108_n163;
  t108_n162: return -0.09485418349504471;
  t108_n163: return 0.133169025182724;
  t108_n164: return 0.06414017826318741;
  t108_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n167;
  t108_n166: return 0.05112353339791298;
  t108_n167: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t108_n169;
  t108_n168: return 0.11191870272159576;
  t108_n169: return 0.031302209943532944;
  t108_n170: return -0.03888939321041107;
  t108_n171: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t108_n187;
  t108_n172: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t108_n174;
  t108_n173: return 0.02802443690598011;
  t108_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t108_n186;
  t108_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n183;
  t108_n176: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t108_n178;
  t108_n177: return 0.03216920793056488;
  t108_n178: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t108_n182;
  t108_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t108_n181;
  t108_n180: return -0.030569706112146378;
  t108_n181: return 0.07147342711687088;
  t108_n182: return -0.0674576461315155;
  t108_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t108_n185;
  t108_n184: return -0.012197661213576794;
  t108_n185: return 0.06482543796300888;
  t108_n186: return -0.013482295908033848;
  t108_n187: if (E.getNumReferences() >= 3299196928 /*1326.0*/) goto t108_n189;
  t108_n188: return -0.0418480783700943;
  t108_n189: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n191;
  t108_n190: return -0.007612803019583225;
  t108_n191: if (E.getNumReferences() >= 3316736000 /*5676.0*/) goto t108_n203;
  t108_n192: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t108_n194;
  t108_n193: return 0.004056120291352272;
  t108_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t108_n202;
  t108_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t108_n201;
  t108_n196: if (E.getNumReferences() >= 3301761024 /*1639.0*/) goto t108_n198;
  t108_n197: return -0.10528569668531418;
  t108_n198: if (E.getNumReferences() >= 3304402944 /*1961.5*/) goto t108_n200;
  t108_n199: return 0.11899376660585403;
  t108_n200: return 0.10090307891368866;
  t108_n201: return -0.25037792325019836;
  t108_n202: return 0.030549556016921997;
  t108_n203: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t108_n209;
  t108_n204: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t108_n208;
  t108_n205: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t108_n207;
  t108_n206: return 0.07166364043951035;
  t108_n207: return 0.11133620142936707;
  t108_n208: return 0.07071349024772644;
  t108_n209: return 0.034006621688604355;
  t108_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t108_n212;
  t108_n211: return 0.007082744967192411;
  t108_n212: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t108_n232;
  t108_n213: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t108_n215;
  t108_n214: return 0.003062926232814789;
  t108_n215: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t108_n217;
  t108_n216: return 0.027561094611883163;
  t108_n217: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t108_n227;
  t108_n218: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t108_n226;
  t108_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n223;
  t108_n220: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t108_n222;
  t108_n221: return 0.07324222475290298;
  t108_n222: return 0.10848125070333481;
  t108_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t108_n225;
  t108_n224: return 0.10166443139314651;
  t108_n225: return -0.14526525139808655;
  t108_n226: return 0.13681469857692719;
  t108_n227: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t108_n231;
  t108_n228: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t108_n230;
  t108_n229: return 0.0703771561384201;
  t108_n230: return 0.0943087711930275;
  t108_n231: return 0.02510892041027546;
  t108_n232: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t108_n244;
  t108_n233: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t108_n243;
  t108_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t108_n242;
  t108_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t108_n237;
  t108_n236: return 0.09268385916948318;
  t108_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n241;
  t108_n238: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t108_n240;
  t108_n239: return 0.09668228775262833;
  t108_n240: return 0.09301890432834625;
  t108_n241: return 0.024385154247283936;
  t108_n242: return 0.04367486760020256;
  t108_n243: return 0.03794324770569801;
  t108_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t108_n246;
  t108_n245: return 0.025433795526623726;
  t108_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t108_n248;
  t108_n247: return 0.0943824052810669;
  t108_n248: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t108_n250;
  t108_n249: return 0.0603717565536499;
  t108_n250: return -0.07878647744655609;
  t108_n251: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t108_n253;
  t108_n252: return -0.019522352144122124;
  t108_n253: return 0.03792057931423187;
  t108_n254: return -0.058125562965869904;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree109(const Example& E) {
  t109_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t109_n2;
  t109_n1: return -0.0021486016921699047;
  t109_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t109_n200;
  t109_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t109_n185;
  t109_n4: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t109_n184;
  t109_n5: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t109_n47;
  t109_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n18;
  t109_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n9;
  t109_n8: return -0.00914754904806614;
  t109_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t109_n11;
  t109_n10: return -0.0027786889113485813;
  t109_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t109_n15;
  t109_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n14;
  t109_n13: return -0.04379050061106682;
  t109_n14: return 0.01061689481139183;
  t109_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t109_n17;
  t109_n16: return 0.0411078967154026;
  t109_n17: return 0.04908469691872597;
  t109_n18: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t109_n38;
  t109_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t109_n23;
  t109_n20: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t109_n22;
  t109_n21: return -0.17292429506778717;
  t109_n22: return -0.02869286946952343;
  t109_n23: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t109_n37;
  t109_n24: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t109_n26;
  t109_n25: return 0.02904873713850975;
  t109_n26: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t109_n28;
  t109_n27: return 0.04533325880765915;
  t109_n28: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t109_n34;
  t109_n29: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t109_n31;
  t109_n30: return 0.1063987985253334;
  t109_n31: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t109_n33;
  t109_n32: return -0.06161653995513916;
  t109_n33: return 0.08574696630239487;
  t109_n34: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t109_n36;
  t109_n35: return 0.16330155730247498;
  t109_n36: return 0.11397112905979156;
  t109_n37: return 0.0022759686689823866;
  t109_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t109_n40;
  t109_n39: return -0.025402335450053215;
  t109_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n46;
  t109_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n43;
  t109_n42: return -0.11161887645721436;
  t109_n43: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t109_n45;
  t109_n44: return 0.14575417339801788;
  t109_n45: return -0.6579122543334961;
  t109_n46: return 0.07166557013988495;
  t109_n47: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t109_n123;
  t109_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t109_n72;
  t109_n49: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t109_n65;
  t109_n50: if (E.getNumReferences() >= 3355694624 /*135000.5*/) goto t109_n64;
  t109_n51: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t109_n59;
  t109_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t109_n58;
  t109_n53: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t109_n55;
  t109_n54: return -0.18354587256908417;
  t109_n55: if (E.getNumReferences() >= 3292332032 /*756.0*/) goto t109_n57;
  t109_n56: return -0.031764689832925797;
  t109_n57: return -0.24469487369060516;
  t109_n58: return -0.0030498960986733437;
  t109_n59: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t109_n61;
  t109_n60: return 0.023000987246632576;
  t109_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t109_n63;
  t109_n62: return 0.009211068041622639;
  t109_n63: return 0.07607362419366837;
  t109_n64: return -0.16039152443408966;
  t109_n65: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t109_n71;
  t109_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t109_n70;
  t109_n67: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t109_n69;
  t109_n68: return 0.0219977218657732;
  t109_n69: return 0.11656370759010315;
  t109_n70: return -0.008634855039417744;
  t109_n71: return -0.01036047749221325;
  t109_n72: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t109_n88;
  t109_n73: if (E.getNumReferences() >= 3278012416 /*226.5*/) goto t109_n79;
  t109_n74: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t109_n78;
  t109_n75: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t109_n77;
  t109_n76: return 0.10310908406972885;
  t109_n77: return 0.021762220188975334;
  t109_n78: return 0.018263839185237885;
  t109_n79: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t109_n83;
  t109_n80: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t109_n82;
  t109_n81: return 0.1128055527806282;
  t109_n82: return 0.13696610927581787;
  t109_n83: if (E.getNumReferences() >= 3290841088 /*665.0*/) goto t109_n85;
  t109_n84: return -0.034045834094285965;
  t109_n85: if (E.getNumReferences() >= 3294789632 /*906.0*/) goto t109_n87;
  t109_n86: return 0.11583797633647919;
  t109_n87: return 0.053477950394153595;
  t109_n88: if (E.getNumReferences() >= 3314442240 /*4556.0*/) goto t109_n108;
  t109_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t109_n91;
  t109_n90: return 0.008678211830556393;
  t109_n91: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t109_n101;
  t109_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n100;
  t109_n93: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t109_n95;
  t109_n94: return 0.00562353665009141;
  t109_n95: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t109_n97;
  t109_n96: return 0.04967578500509262;
  t109_n97: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t109_n99;
  t109_n98: return 0.12216942757368088;
  t109_n99: return -0.10023592412471771;
  t109_n100: return 0.056046903133392334;
  t109_n101: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t109_n107;
  t109_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n104;
  t109_n103: return 0.1235121637582779;
  t109_n104: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t109_n106;
  t109_n105: return -0.11600305885076523;
  t109_n106: return 0.11414606124162674;
  t109_n107: return 0.05135686695575714;
  t109_n108: if (E.getNumReferences() >= 3315382272 /*5015.0*/) goto t109_n122;
  t109_n109: if (E.getNumReferences() >= 3314929664 /*4794.0*/) goto t109_n113;
  t109_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n112;
  t109_n111: return 0.04129163175821304;
  t109_n112: return 0.1101246178150177;
  t109_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n121;
  t109_n114: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t109_n116;
  t109_n115: return 0.12729109823703766;
  t109_n116: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t109_n120;
  t109_n117: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n119;
  t109_n118: return 0.12789525091648102;
  t109_n119: return 0.12602843344211578;
  t109_n120: return 0.108506940305233;
  t109_n121: return -0.06353357434272766;
  t109_n122: return 0.02155785821378231;
  t109_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t109_n179;
  t109_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n144;
  t109_n125: if (E.getNumReferences() >= 3281764352 /*311.5*/) goto t109_n127;
  t109_n126: return -0.12375829368829727;
  t109_n127: if (E.getNumReferences() >= 3293585408 /*832.5*/) goto t109_n137;
  t109_n128: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t109_n130;
  t109_n129: return -0.024436306208372116;
  t109_n130: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t109_n136;
  t109_n131: if (E.getNumReferences() >= 3283877888 /*376.0*/) goto t109_n133;
  t109_n132: return 0.1231277585029602;
  t109_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n135;
  t109_n134: return 0.10412620007991791;
  t109_n135: return -0.3206042945384979;
  t109_n136: return -0.007147527765482664;
  t109_n137: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t109_n139;
  t109_n138: return -0.046179525554180145;
  t109_n139: if (E.getNumReferences() >= 3347921344 /*72307.5*/) goto t109_n143;
  t109_n140: if (E.getNumReferences() >= 3332248320 /*20233.5*/) goto t109_n142;
  t109_n141: return 0.06290004402399063;
  t109_n142: return 0.0966353714466095;
  t109_n143: return 0.021205324679613113;
  t109_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n146;
  t109_n145: return -0.14170636236667633;
  t109_n146: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t109_n160;
  t109_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n157;
  t109_n148: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t109_n150;
  t109_n149: return -0.0782509595155716;
  t109_n150: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t109_n152;
  t109_n151: return 0.08922497928142548;
  t109_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t109_n154;
  t109_n153: return -0.011631588451564312;
  t109_n154: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t109_n156;
  t109_n155: return 0.06881436705589294;
  t109_n156: return 0.1092655137181282;
  t109_n157: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t109_n159;
  t109_n158: return -0.1667409986257553;
  t109_n159: return 0.10809878259897232;
  t109_n160: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t109_n162;
  t109_n161: return -0.10926590114831924;
  t109_n162: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t109_n164;
  t109_n163: return -0.004843577276915312;
  t109_n164: if (E.getNumReferences() >= 3318893568 /*6729.5*/) goto t109_n178;
  t109_n165: if (E.getNumReferences() >= 3292364800 /*758.0*/) goto t109_n171;
  t109_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t109_n168;
  t109_n167: return -0.012438679113984108;
  t109_n168: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t109_n170;
  t109_n169: return 0.11655660718679428;
  t109_n170: return -0.022940317168831825;
  t109_n171: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t109_n173;
  t109_n172: return 0.10687104612588882;
  t109_n173: if (E.getNumReferences() >= 3309690880 /*3166.0*/) goto t109_n175;
  t109_n174: return -0.10342381149530411;
  t109_n175: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t109_n177;
  t109_n176: return 0.09019176661968231;
  t109_n177: return 0.12167365849018097;
  t109_n178: return -0.022723637521266937;
  t109_n179: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t109_n181;
  t109_n180: return 0.12215733528137207;
  t109_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t109_n183;
  t109_n182: return 0.06778787076473236;
  t109_n183: return 0.04998055100440979;
  t109_n184: return -0.03715747967362404;
  t109_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t109_n187;
  t109_n186: return -0.04412158206105232;
  t109_n187: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t109_n189;
  t109_n188: return -0.11603259295225143;
  t109_n189: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t109_n197;
  t109_n190: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t109_n192;
  t109_n191: return 0.028491264209151268;
  t109_n192: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t109_n196;
  t109_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t109_n195;
  t109_n194: return 0.050153303891420364;
  t109_n195: return 0.10589256137609482;
  t109_n196: return 0.041616689413785934;
  t109_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t109_n199;
  t109_n198: return -0.2590908408164978;
  t109_n199: return -0.008438258431851864;
  t109_n200: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t109_n216;
  t109_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t109_n205;
  t109_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t109_n204;
  t109_n203: return -0.012624423950910568;
  t109_n204: return 0.005651253275573254;
  t109_n205: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t109_n215;
  t109_n206: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t109_n210;
  t109_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t109_n209;
  t109_n208: return 0.018332235515117645;
  t109_n209: return 0.03206348791718483;
  t109_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag))) goto t109_n212;
  t109_n211: return 0.015267196111381054;
  t109_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t109_n214;
  t109_n213: return -0.10699521750211716;
  t109_n214: return 0.09125234931707382;
  t109_n215: return -0.07831739634275436;
  t109_n216: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t109_n222;
  t109_n217: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t109_n221;
  t109_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t109_n220;
  t109_n219: return -0.04804547503590584;
  t109_n220: return -0.1946006864309311;
  t109_n221: return 0.0013157717185094953;
  t109_n222: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t109_n252;
  t109_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t109_n225;
  t109_n224: return -0.19159355759620667;
  t109_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t109_n247;
  t109_n226: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t109_n236;
  t109_n227: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t109_n229;
  t109_n228: return 0.011982613243162632;
  t109_n229: if (E.getNumReferences() >= 3255566336 /*35.0*/) goto t109_n233;
  t109_n230: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t109_n232;
  t109_n231: return 0.07709824293851852;
  t109_n232: return 0.14488309621810913;
  t109_n233: if (E.getNumReferences() >= 3263692800 /*68.0*/) goto t109_n235;
  t109_n234: return 0.11579592525959015;
  t109_n235: return 0.08614420145750046;
  t109_n236: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t109_n246;
  t109_n237: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t109_n245;
  t109_n238: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t109_n240;
  t109_n239: return 0.08186691254377365;
  t109_n240: if (E.getNumReferences() >= 3257925632 /*44.0*/) goto t109_n244;
  t109_n241: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t109_n243;
  t109_n242: return 0.32141992449760437;
  t109_n243: return 0.1328524947166443;
  t109_n244: return 0.11991830915212631;
  t109_n245: return -0.0370052307844162;
  t109_n246: return 0.08417563140392303;
  t109_n247: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t109_n251;
  t109_n248: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t109_n250;
  t109_n249: return 0.2096516638994217;
  t109_n250: return 0.19620658457279205;
  t109_n251: return -0.060512106865644455;
  t109_n252: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t109_n254;
  t109_n253: return 0.07599984854459763;
  t109_n254: return -0.059132590889930725;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree110(const Example& E) {
  t110_n0: if (E.getNumReferences() >= 3305437184 /*2127.5*/) goto t110_n18;
  t110_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t110_n3;
  t110_n2: return 0.005317645613104105;
  t110_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t110_n5;
  t110_n4: return -0.00020123773720115423;
  t110_n5: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t110_n7;
  t110_n6: return -0.08294682204723358;
  t110_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t110_n11;
  t110_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t110_n10;
  t110_n9: return -0.006481718737632036;
  t110_n10: return 0.02434486895799637;
  t110_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t110_n13;
  t110_n12: return -0.028117772191762924;
  t110_n13: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t110_n17;
  t110_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t110_n16;
  t110_n15: return -0.0021343333646655083;
  t110_n16: return 0.04880533367395401;
  t110_n17: return 0.04057788848876953;
  t110_n18: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t110_n22;
  t110_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t110_n21;
  t110_n20: return 0.012561727315187454;
  t110_n21: return 0.029484158381819725;
  t110_n22: if (E.getNumReferences() >= 3305449472 /*2130.5*/) goto t110_n28;
  t110_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t110_n27;
  t110_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n26;
  t110_n25: return -0.10578509420156479;
  t110_n26: return 0.10798432677984238;
  t110_n27: return 0.3837612569332123;
  t110_n28: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t110_n30;
  t110_n29: return -0.004263578914105892;
  t110_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t110_n254;
  t110_n31: if (E.getNumReferences() >= 3345503360 /*59476.5*/) goto t110_n237;
  t110_n32: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t110_n94;
  t110_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t110_n37;
  t110_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n36;
  t110_n35: return -0.11677894741296768;
  t110_n36: return -0.012557084672152996;
  t110_n37: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t110_n71;
  t110_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t110_n40;
  t110_n39: return -0.2117966264486313;
  t110_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n70;
  t110_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n49;
  t110_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n44;
  t110_n43: return 0.06509707123041153;
  t110_n44: if (E.getNumReferences() >= 3322947584 /*9226.0*/) goto t110_n46;
  t110_n45: return 0.10077022761106491;
  t110_n46: if (E.getNumReferences() >= 3325011456 /*11241.5*/) goto t110_n48;
  t110_n47: return 0.12778158485889435;
  t110_n48: return 0.1015375480055809;
  t110_n49: if (E.getNumReferences() >= 3309021184 /*3002.5*/) goto t110_n51;
  t110_n50: return 0.03176850453019142;
  t110_n51: if (E.getNumReferences() >= 3309780992 /*3188.0*/) goto t110_n53;
  t110_n52: return 0.1080024391412735;
  t110_n53: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t110_n65;
  t110_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t110_n62;
  t110_n55: if (E.getNumReferences() >= 3316458496 /*5540.5*/) goto t110_n57;
  t110_n56: return 0.15401476621627808;
  t110_n57: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t110_n59;
  t110_n58: return 0.13474881649017334;
  t110_n59: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t110_n61;
  t110_n60: return 0.08033127337694168;
  t110_n61: return 0.10190572589635849;
  t110_n62: if (E.getNumReferences() >= 3317139456 /*5873.0*/) goto t110_n64;
  t110_n63: return 0.11761501431465149;
  t110_n64: return -0.14179201424121857;
  t110_n65: if (E.getNumReferences() >= 3313203200 /*4023.5*/) goto t110_n69;
  t110_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n68;
  t110_n67: return -0.014653726480901241;
  t110_n68: return 0.11140505969524384;
  t110_n69: return 0.04833702743053436;
  t110_n70: return -0.02306232787668705;
  t110_n71: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t110_n93;
  t110_n72: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t110_n74;
  t110_n73: return -0.14871132373809814;
  t110_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n78;
  t110_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t110_n77;
  t110_n76: return 0.02349746786057949;
  t110_n77: return 0.09320134669542313;
  t110_n78: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t110_n84;
  t110_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t110_n81;
  t110_n80: return 0.1316251903772354;
  t110_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t110_n83;
  t110_n82: return -0.10939975827932358;
  t110_n83: return 0.13278700411319733;
  t110_n84: if (E.getNumReferences() >= 3333771776 /*23209.0*/) goto t110_n88;
  t110_n85: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t110_n87;
  t110_n86: return 0.10099005699157715;
  t110_n87: return 0.10597929358482361;
  t110_n88: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t110_n90;
  t110_n89: return 0.04541635885834694;
  t110_n90: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n92;
  t110_n91: return 0.06703097373247147;
  t110_n92: return 0.09012176096439362;
  t110_n93: return -0.0062019401229918;
  t110_n94: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t110_n150;
  t110_n95: if (E.getNumReferences() >= 3315700736 /*5170.5*/) goto t110_n97;
  t110_n96: return 0.0012076976709067822;
  t110_n97: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t110_n105;
  t110_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t110_n104;
  t110_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t110_n103;
  t110_n100: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t110_n102;
  t110_n101: return 0.14447811245918274;
  t110_n102: return 0.09312889724969864;
  t110_n103: return 0.13257001340389252;
  t110_n104: return -0.13818100094795227;
  t110_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t110_n125;
  t110_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n108;
  t110_n107: return -0.03425498679280281;
  t110_n108: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t110_n122;
  t110_n109: if (E.getNumReferences() >= 3334660864 /*24945.5*/) goto t110_n121;
  t110_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t110_n112;
  t110_n111: return 0.03265966847538948;
  t110_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t110_n120;
  t110_n113: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n115;
  t110_n114: return 0.2236657440662384;
  t110_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n119;
  t110_n116: if (E.getNumReferences() >= 3316636672 /*5627.5*/) goto t110_n118;
  t110_n117: return 0.11472438275814056;
  t110_n118: return 0.10362329334020615;
  t110_n119: return 0.11049258708953857;
  t110_n120: return -0.12358719855546951;
  t110_n121: return -0.056997403502464294;
  t110_n122: if (E.getNumReferences() >= 3342583296 /*48070.0*/) goto t110_n124;
  t110_n123: return 0.07422259449958801;
  t110_n124: return -0.03426699340343475;
  t110_n125: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t110_n129;
  t110_n126: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t110_n128;
  t110_n127: return 0.10822981595993042;
  t110_n128: return 0.028454042971134186;
  t110_n129: if (E.getNumReferences() >= 3327446528 /*13619.5*/) goto t110_n137;
  t110_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n132;
  t110_n131: return 0.03616912290453911;
  t110_n132: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t110_n134;
  t110_n133: return 0.07340879738330841;
  t110_n134: if (E.getNumReferences() >= 3324406784 /*10651.0*/) goto t110_n136;
  t110_n135: return 0.1265668272972107;
  t110_n136: return 0.23877140879631042;
  t110_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t110_n143;
  t110_n138: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t110_n142;
  t110_n139: if (E.getNumReferences() >= 3340394880 /*39521.5*/) goto t110_n141;
  t110_n140: return 0.06306152045726776;
  t110_n141: return 0.11021175980567932;
  t110_n142: return -0.05491824075579643;
  t110_n143: if (E.getNumReferences() >= 3331176192 /*18139.5*/) goto t110_n149;
  t110_n144: if (E.getNumReferences() >= 3330760192 /*17327.0*/) goto t110_n148;
  t110_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n147;
  t110_n146: return -0.2186264842748642;
  t110_n147: return 0.10904200375080109;
  t110_n148: return 0.11915002018213272;
  t110_n149: return 0.06163695827126503;
  t110_n150: if (E.getNumReferences() >= 3305697280 /*2191.0*/) goto t110_n166;
  t110_n151: if (E.getNumReferences() >= 3305539584 /*2152.5*/) goto t110_n153;
  t110_n152: return -0.08360258489847183;
  t110_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t110_n163;
  t110_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n160;
  t110_n155: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t110_n157;
  t110_n156: return 0.004528628196567297;
  t110_n157: if (E.getNumReferences() >= 3305564160 /*2158.5*/) goto t110_n159;
  t110_n158: return -0.10050200670957565;
  t110_n159: return 0.11461639404296875;
  t110_n160: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t110_n162;
  t110_n161: return 0.11815992742776871;
  t110_n162: return -0.101721853017807;
  t110_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t110_n165;
  t110_n164: return 0.12280648946762085;
  t110_n165: return 0.13700160384178162;
  t110_n166: if (E.getNumReferences() >= 3318252544 /*6416.5*/) goto t110_n188;
  t110_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t110_n169;
  t110_n168: return 0.021815961226820946;
  t110_n169: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t110_n187;
  t110_n170: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t110_n186;
  t110_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t110_n181;
  t110_n172: if (E.getNumReferences() >= 3306842112 /*2470.5*/) goto t110_n176;
  t110_n173: if (E.getNumReferences() >= 3306567680 /*2403.5*/) goto t110_n175;
  t110_n174: return -0.024765130132436752;
  t110_n175: return 0.11812925338745117;
  t110_n176: if (E.getNumReferences() >= 3313252352 /*4035.5*/) goto t110_n178;
  t110_n177: return 0.005925746634602547;
  t110_n178: if (E.getNumReferences() >= 3313448960 /*4083.5*/) goto t110_n180;
  t110_n179: return 0.11895076930522919;
  t110_n180: return 0.07719963788986206;
  t110_n181: if (E.getNumReferences() >= 3308484608 /*2871.5*/) goto t110_n183;
  t110_n182: return 0.12250781059265137;
  t110_n183: if (E.getNumReferences() >= 3314669568 /*4667.0*/) goto t110_n185;
  t110_n184: return 0.046414852142333984;
  t110_n185: return 0.14402572810649872;
  t110_n186: return -0.11015762388706207;
  t110_n187: return -0.13976331055164337;
  t110_n188: if (E.getNumReferences() >= 3318256640 /*6418.5*/) goto t110_n192;
  t110_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t110_n191;
  t110_n190: return -0.07657530903816223;
  t110_n191: return 0.126930370926857;
  t110_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t110_n204;
  t110_n193: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t110_n195;
  t110_n194: return 0.03308549523353577;
  t110_n195: if (E.getNumReferences() >= 3344355328 /*54992.0*/) goto t110_n197;
  t110_n196: return 0.1251550167798996;
  t110_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n201;
  t110_n198: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t110_n200;
  t110_n199: return -0.0806415006518364;
  t110_n200: return 0.09630706906318665;
  t110_n201: if (E.getNumReferences() >= 3344562560 /*55801.5*/) goto t110_n203;
  t110_n202: return 0.102473683655262;
  t110_n203: return -0.08492956310510635;
  t110_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t110_n206;
  t110_n205: return 0.04810589179396629;
  t110_n206: if (E.getNumReferences() >= 3319788544 /*7166.5*/) goto t110_n212;
  t110_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t110_n211;
  t110_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t110_n210;
  t110_n209: return 0.1012040376663208;
  t110_n210: return -0.1655595898628235;
  t110_n211: return 0.11846832931041718;
  t110_n212: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t110_n230;
  t110_n213: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t110_n229;
  t110_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t110_n226;
  t110_n215: if (E.getNumReferences() >= 3323776512 /*10035.5*/) goto t110_n225;
  t110_n216: if (E.getNumReferences() >= 3322122752 /*8420.5*/) goto t110_n218;
  t110_n217: return -0.0013777143321931362;
  t110_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t110_n220;
  t110_n219: return 0.0960787683725357;
  t110_n220: if (E.getNumReferences() >= 3322854400 /*9135.0*/) goto t110_n222;
  t110_n221: return 0.11316104233264923;
  t110_n222: if (E.getNumReferences() >= 3323401216 /*9669.0*/) goto t110_n224;
  t110_n223: return 0.21430489420890808;
  t110_n224: return 0.19095195829868317;
  t110_n225: return 0.06095360964536667;
  t110_n226: if (E.getNumReferences() >= 3325309440 /*11532.5*/) goto t110_n228;
  t110_n227: return -0.26250696182250977;
  t110_n228: return 0.10755648463964462;
  t110_n229: return 0.1023545116186142;
  t110_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t110_n232;
  t110_n231: return -0.02139846608042717;
  t110_n232: if (E.getNumReferences() >= 3336401664 /*28345.5*/) goto t110_n234;
  t110_n233: return -0.0861520916223526;
  t110_n234: if (E.getNumReferences() >= 3340569472 /*40203.5*/) goto t110_n236;
  t110_n235: return 0.10691935569047928;
  t110_n236: return 0.0831514298915863;
  t110_n237: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t110_n249;
  t110_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t110_n244;
  t110_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t110_n243;
  t110_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t110_n242;
  t110_n241: return -0.0144036915153265;
  t110_n242: return -0.27576884627342224;
  t110_n243: return -0.08865491300821304;
  t110_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t110_n246;
  t110_n245: return 0.11837565153837204;
  t110_n246: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t110_n248;
  t110_n247: return -0.09891572594642639;
  t110_n248: return 0.05489999055862427;
  t110_n249: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t110_n251;
  t110_n250: return 0.108639195561409;
  t110_n251: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t110_n253;
  t110_n252: return -0.016935251653194427;
  t110_n253: return 0.016510747373104095;
  t110_n254: return 0.046243034303188324;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree111(const Example& E) {
  t111_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t111_n254;
  t111_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t111_n3;
  t111_n2: return -0.08620188385248184;
  t111_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t111_n9;
  t111_n4: if (E.getNumReferences() >= 3310407680 /*3341.0*/) goto t111_n6;
  t111_n5: return 0.003410970326513052;
  t111_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t111_n8;
  t111_n7: return 0.012890883721411228;
  t111_n8: return 0.029902594164013863;
  t111_n9: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t111_n109;
  t111_n10: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t111_n60;
  t111_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t111_n17;
  t111_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t111_n16;
  t111_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t111_n15;
  t111_n14: return -0.16420885920524597;
  t111_n15: return -0.06669827550649643;
  t111_n16: return -0.003591548651456833;
  t111_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t111_n19;
  t111_n18: return 0.005133422091603279;
  t111_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t111_n23;
  t111_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t111_n22;
  t111_n21: return -0.01763959601521492;
  t111_n22: return 0.010446936823427677;
  t111_n23: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n33;
  t111_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t111_n26;
  t111_n25: return 0.02308523841202259;
  t111_n26: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t111_n30;
  t111_n27: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t111_n29;
  t111_n28: return 0.04917636513710022;
  t111_n29: return -0.012932147830724716;
  t111_n30: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t111_n32;
  t111_n31: return 0.11087167263031006;
  t111_n32: return -0.01868957281112671;
  t111_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n59;
  t111_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n36;
  t111_n35: return 0.08883478492498398;
  t111_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t111_n52;
  t111_n37: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t111_n43;
  t111_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t111_n42;
  t111_n39: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t111_n41;
  t111_n40: return -0.0451643243432045;
  t111_n41: return 0.10201218724250793;
  t111_n42: return 0.14656488597393036;
  t111_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t111_n51;
  t111_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t111_n48;
  t111_n45: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t111_n47;
  t111_n46: return -0.15709197521209717;
  t111_n47: return 0.07912632077932358;
  t111_n48: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t111_n50;
  t111_n49: return 0.11461324244737625;
  t111_n50: return 0.042461100965738297;
  t111_n51: return 0.3237234950065613;
  t111_n52: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t111_n54;
  t111_n53: return 0.020142626017332077;
  t111_n54: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n58;
  t111_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n57;
  t111_n56: return 0.1295635998249054;
  t111_n57: return 0.07518229633569717;
  t111_n58: return 0.034956205636262894;
  t111_n59: return 0.005187667906284332;
  t111_n60: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n70;
  t111_n61: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t111_n63;
  t111_n62: return -0.023294156417250633;
  t111_n63: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t111_n69;
  t111_n64: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t111_n68;
  t111_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t111_n67;
  t111_n66: return -0.15322239696979523;
  t111_n67: return -0.0456671379506588;
  t111_n68: return 0.041583046317100525;
  t111_n69: return -0.05385706573724747;
  t111_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t111_n74;
  t111_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t111_n73;
  t111_n72: return -0.33518022298812866;
  t111_n73: return 0.04852826148271561;
  t111_n74: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t111_n84;
  t111_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t111_n81;
  t111_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t111_n78;
  t111_n77: return -0.003388351295143366;
  t111_n78: if (E.getNumReferences() >= 3281731584 /*310.5*/) goto t111_n80;
  t111_n79: return 0.10409659892320633;
  t111_n80: return -0.47908294200897217;
  t111_n81: if (E.getNumReferences() >= 3287973888 /*501.0*/) goto t111_n83;
  t111_n82: return -0.05049615353345871;
  t111_n83: return 0.10929498076438904;
  t111_n84: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n104;
  t111_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n93;
  t111_n86: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t111_n92;
  t111_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t111_n89;
  t111_n88: return 0.05257877707481384;
  t111_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t111_n91;
  t111_n90: return 0.12676474452018738;
  t111_n91: return 0.08171453326940536;
  t111_n92: return -0.00863591581583023;
  t111_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n101;
  t111_n94: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t111_n96;
  t111_n95: return -0.008191796019673347;
  t111_n96: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t111_n100;
  t111_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n99;
  t111_n98: return 0.15910173952579498;
  t111_n99: return 0.09332653880119324;
  t111_n100: return 0.10142143815755844;
  t111_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t111_n103;
  t111_n102: return 0.013872805051505566;
  t111_n103: return 0.11392500251531601;
  t111_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t111_n106;
  t111_n105: return 0.0011513129575178027;
  t111_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t111_n108;
  t111_n107: return 0.11531469970941544;
  t111_n108: return 0.030993463471531868;
  t111_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t111_n201;
  t111_n110: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t111_n112;
  t111_n111: return -0.007182210683822632;
  t111_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t111_n114;
  t111_n113: return -0.0006674834876321256;
  t111_n114: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t111_n184;
  t111_n115: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t111_n183;
  t111_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t111_n150;
  t111_n117: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n149;
  t111_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t111_n138;
  t111_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t111_n131;
  t111_n120: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t111_n124;
  t111_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n123;
  t111_n122: return 0.03686348721385002;
  t111_n123: return -0.022123750299215317;
  t111_n124: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n126;
  t111_n125: return -0.051720030605793;
  t111_n126: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n128;
  t111_n127: return 0.12636888027191162;
  t111_n128: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t111_n130;
  t111_n129: return -0.06252571940422058;
  t111_n130: return 0.1122167780995369;
  t111_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t111_n133;
  t111_n132: return 0.009810473769903183;
  t111_n133: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t111_n135;
  t111_n134: return 0.09114436060190201;
  t111_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n137;
  t111_n136: return 0.1433493047952652;
  t111_n137: return 0.1154501885175705;
  t111_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t111_n140;
  t111_n139: return -0.09438508003950119;
  t111_n140: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t111_n142;
  t111_n141: return 0.05667519569396973;
  t111_n142: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n148;
  t111_n143: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n145;
  t111_n144: return 0.08388188481330872;
  t111_n145: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t111_n147;
  t111_n146: return 0.12357982993125916;
  t111_n147: return 0.024879496544599533;
  t111_n148: return 0.06289323419332504;
  t111_n149: return -0.020869020372629166;
  t111_n150: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t111_n152;
  t111_n151: return -0.0799277275800705;
  t111_n152: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n182;
  t111_n153: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t111_n155;
  t111_n154: return 0.059885166585445404;
  t111_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n181;
  t111_n156: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t111_n164;
  t111_n157: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t111_n163;
  t111_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t111_n162;
  t111_n159: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t111_n161;
  t111_n160: return 0.10863477736711502;
  t111_n161: return 0.06224352493882179;
  t111_n162: return 0.09158165007829666;
  t111_n163: return 0.010302817448973656;
  t111_n164: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t111_n180;
  t111_n165: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t111_n169;
  t111_n166: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t111_n168;
  t111_n167: return 0.12738406658172607;
  t111_n168: return 0.015530858188867569;
  t111_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t111_n171;
  t111_n170: return 0.10218239575624466;
  t111_n171: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t111_n179;
  t111_n172: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n176;
  t111_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t111_n175;
  t111_n174: return 0.11110081523656845;
  t111_n175: return 0.15051768720149994;
  t111_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t111_n178;
  t111_n177: return 0.15140852332115173;
  t111_n178: return 0.13161130249500275;
  t111_n179: return 0.18770064413547516;
  t111_n180: return 0.07041681557893753;
  t111_n181: return 0.041398659348487854;
  t111_n182: return -0.013327161781489849;
  t111_n183: return -0.001569500076584518;
  t111_n184: if (E.getNumReferences() >= 3297198080 /*1082.0*/) goto t111_n188;
  t111_n185: if (E.getNumReferences() >= 3297153024 /*1076.5*/) goto t111_n187;
  t111_n186: return 0.10303439944982529;
  t111_n187: return 0.12197224050760269;
  t111_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t111_n190;
  t111_n189: return 0.04123164713382721;
  t111_n190: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n198;
  t111_n191: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t111_n197;
  t111_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n196;
  t111_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t111_n195;
  t111_n194: return 0.0801309198141098;
  t111_n195: return 0.1076282486319542;
  t111_n196: return 0.1174749881029129;
  t111_n197: return 0.1109902486205101;
  t111_n198: if (E.getNumReferences() >= 3301470208 /*1603.5*/) goto t111_n200;
  t111_n199: return 0.11309792101383209;
  t111_n200: return 0.020040906965732574;
  t111_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t111_n215;
  t111_n202: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t111_n212;
  t111_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t111_n211;
  t111_n204: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t111_n210;
  t111_n205: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t111_n207;
  t111_n206: return 0.04404567554593086;
  t111_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n209;
  t111_n208: return -0.10222906619310379;
  t111_n209: return 0.11454859375953674;
  t111_n210: return 0.010678659193217754;
  t111_n211: return -0.27696582674980164;
  t111_n212: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t111_n214;
  t111_n213: return 0.04443143680691719;
  t111_n214: return -0.15075655281543732;
  t111_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t111_n243;
  t111_n216: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t111_n240;
  t111_n217: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t111_n229;
  t111_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n224;
  t111_n219: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t111_n221;
  t111_n220: return 0.03609981760382652;
  t111_n221: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t111_n223;
  t111_n222: return 0.08250903338193893;
  t111_n223: return 0.14168347418308258;
  t111_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t111_n226;
  t111_n225: return 0.05914967507123947;
  t111_n226: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t111_n228;
  t111_n227: return 0.08855459839105606;
  t111_n228: return 0.1558709740638733;
  t111_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t111_n235;
  t111_n230: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t111_n232;
  t111_n231: return 0.07122772932052612;
  t111_n232: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t111_n234;
  t111_n233: return 0.07952980697154999;
  t111_n234: return 0.1303512156009674;
  t111_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t111_n237;
  t111_n236: return -0.00648451829329133;
  t111_n237: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t111_n239;
  t111_n238: return 0.01730351895093918;
  t111_n239: return 0.04129362851381302;
  t111_n240: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t111_n242;
  t111_n241: return 0.011659188196063042;
  t111_n242: return 0.061720408499240875;
  t111_n243: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t111_n247;
  t111_n244: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t111_n246;
  t111_n245: return 0.05701494961977005;
  t111_n246: return 0.09789404273033142;
  t111_n247: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t111_n253;
  t111_n248: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t111_n250;
  t111_n249: return 0.1325892210006714;
  t111_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t111_n252;
  t111_n251: return 0.0849018469452858;
  t111_n252: return 0.12424824386835098;
  t111_n253: return 0.08074268698692322;
  t111_n254: return -0.09555252641439438;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree112(const Example& E) {
  t112_n0: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t112_n112;
  t112_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t112_n5;
  t112_n2: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t112_n4;
  t112_n3: return -0.0008065446163527668;
  t112_n4: return -0.13900481164455414;
  t112_n5: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t112_n111;
  t112_n6: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t112_n104;
  t112_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t112_n9;
  t112_n8: return -0.006996885873377323;
  t112_n9: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t112_n89;
  t112_n10: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t112_n24;
  t112_n11: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t112_n13;
  t112_n12: return 0.008728818036615849;
  t112_n13: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t112_n17;
  t112_n14: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t112_n16;
  t112_n15: return -0.01304757222533226;
  t112_n16: return -0.1143481507897377;
  t112_n17: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t112_n23;
  t112_n18: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t112_n20;
  t112_n19: return -0.1993517428636551;
  t112_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n22;
  t112_n21: return -0.15541763603687286;
  t112_n22: return 0.13538798689842224;
  t112_n23: return 0.021079471334815025;
  t112_n24: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t112_n84;
  t112_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n35;
  t112_n26: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n28;
  t112_n27: return 0.05628621205687523;
  t112_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t112_n30;
  t112_n29: return -0.04073021188378334;
  t112_n30: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t112_n32;
  t112_n31: return 0.11027254164218903;
  t112_n32: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t112_n34;
  t112_n33: return -0.07132728397846222;
  t112_n34: return 0.10432092100381851;
  t112_n35: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t112_n43;
  t112_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n42;
  t112_n37: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t112_n39;
  t112_n38: return 0.01704433746635914;
  t112_n39: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t112_n41;
  t112_n40: return -0.09796152263879776;
  t112_n41: return 0.1274372637271881;
  t112_n42: return -0.13342837989330292;
  t112_n43: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t112_n79;
  t112_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t112_n72;
  t112_n45: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t112_n53;
  t112_n46: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t112_n48;
  t112_n47: return -0.02250647358596325;
  t112_n48: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t112_n52;
  t112_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n51;
  t112_n50: return 0.08428172767162323;
  t112_n51: return 0.13165420293807983;
  t112_n52: return -0.12727296352386475;
  t112_n53: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t112_n65;
  t112_n54: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t112_n64;
  t112_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t112_n57;
  t112_n56: return 0.05720401927828789;
  t112_n57: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t112_n59;
  t112_n58: return -0.10260824859142303;
  t112_n59: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t112_n63;
  t112_n60: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t112_n62;
  t112_n61: return 0.10811829566955566;
  t112_n62: return -0.13913118839263916;
  t112_n63: return 0.08031418174505234;
  t112_n64: return 0.03547518700361252;
  t112_n65: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t112_n67;
  t112_n66: return 0.06160707771778107;
  t112_n67: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t112_n71;
  t112_n68: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t112_n70;
  t112_n69: return 0.05377751588821411;
  t112_n70: return 0.14869418740272522;
  t112_n71: return -0.16388049721717834;
  t112_n72: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n78;
  t112_n73: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t112_n77;
  t112_n74: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t112_n76;
  t112_n75: return -0.16454166173934937;
  t112_n76: return 0.1335010528564453;
  t112_n77: return -0.04134251922369003;
  t112_n78: return 0.08837078511714935;
  t112_n79: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t112_n81;
  t112_n80: return -0.07967275381088257;
  t112_n81: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t112_n83;
  t112_n82: return 0.10763800889253616;
  t112_n83: return -0.10952768474817276;
  t112_n84: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t112_n86;
  t112_n85: return -0.096590057015419;
  t112_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t112_n88;
  t112_n87: return 0.018568027764558792;
  t112_n88: return -0.3833959400653839;
  t112_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n91;
  t112_n90: return -0.0005437724175862968;
  t112_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t112_n95;
  t112_n92: if (E.getNumReferences() >= 3350564160 /*92954.5*/) goto t112_n94;
  t112_n93: return 0.001686161500401795;
  t112_n94: return 0.16425560414791107;
  t112_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n103;
  t112_n96: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t112_n102;
  t112_n97: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n99;
  t112_n98: return 0.053870271891355515;
  t112_n99: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n101;
  t112_n100: return 0.1250665932893753;
  t112_n101: return 0.10089994221925735;
  t112_n102: return 0.03598732128739357;
  t112_n103: return 0.010322781279683113;
  t112_n104: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n108;
  t112_n105: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t112_n107;
  t112_n106: return 0.12284120917320251;
  t112_n107: return 0.07134249061346054;
  t112_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t112_n110;
  t112_n109: return 0.10076242685317993;
  t112_n110: return 0.11095788329839706;
  t112_n111: return -0.22941994667053223;
  t112_n112: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t112_n166;
  t112_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t112_n139;
  t112_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t112_n116;
  t112_n115: return -0.14019393920898438;
  t112_n116: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n118;
  t112_n117: return 0.05402511730790138;
  t112_n118: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t112_n122;
  t112_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n121;
  t112_n120: return 0.0008328949916176498;
  t112_n121: return 0.06893834471702576;
  t112_n122: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t112_n138;
  t112_n123: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n125;
  t112_n124: return 0.018171342089772224;
  t112_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t112_n129;
  t112_n126: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n128;
  t112_n127: return 0.12089342623949051;
  t112_n128: return 0.13694706559181213;
  t112_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t112_n131;
  t112_n130: return 0.08143304288387299;
  t112_n131: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t112_n133;
  t112_n132: return 0.14756588637828827;
  t112_n133: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t112_n137;
  t112_n134: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t112_n136;
  t112_n135: return 0.11300187557935715;
  t112_n136: return 0.10897821187973022;
  t112_n137: return 0.05106695368885994;
  t112_n138: return -0.009715267457067966;
  t112_n139: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t112_n141;
  t112_n140: return -0.1642022281885147;
  t112_n141: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t112_n157;
  t112_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t112_n150;
  t112_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t112_n145;
  t112_n144: return 0.028491321951150894;
  t112_n145: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t112_n149;
  t112_n146: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t112_n148;
  t112_n147: return 0.06302149593830109;
  t112_n148: return -0.003003341844305396;
  t112_n149: return 0.04213697090744972;
  t112_n150: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t112_n156;
  t112_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n155;
  t112_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n154;
  t112_n153: return 0.12486748397350311;
  t112_n154: return 0.08539526164531708;
  t112_n155: return 0.0647084191441536;
  t112_n156: return -0.11117464303970337;
  t112_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n161;
  t112_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t112_n160;
  t112_n159: return 0.08102285861968994;
  t112_n160: return 0.09832008928060532;
  t112_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t112_n163;
  t112_n162: return 0.03549456596374512;
  t112_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n165;
  t112_n164: return 0.09519558399915695;
  t112_n165: return 0.05702663213014603;
  t112_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t112_n168;
  t112_n167: return -0.0034813794773072004;
  t112_n168: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t112_n208;
  t112_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t112_n171;
  t112_n170: return -0.11219514161348343;
  t112_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n181;
  t112_n172: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t112_n174;
  t112_n173: return 0.07879224419593811;
  t112_n174: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n180;
  t112_n175: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n177;
  t112_n176: return -0.1100250706076622;
  t112_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t112_n179;
  t112_n178: return 0.10824315994977951;
  t112_n179: return 0.12235153466463089;
  t112_n180: return 0.2070373296737671;
  t112_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n207;
  t112_n182: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t112_n206;
  t112_n183: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t112_n193;
  t112_n184: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t112_n186;
  t112_n185: return 0.0605517253279686;
  t112_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t112_n188;
  t112_n187: return -0.31475841999053955;
  t112_n188: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t112_n190;
  t112_n189: return -0.1188344657421112;
  t112_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t112_n192;
  t112_n191: return 0.12576936185359955;
  t112_n192: return 0.12239545583724976;
  t112_n193: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t112_n203;
  t112_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t112_n198;
  t112_n195: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t112_n197;
  t112_n196: return 0.08511008322238922;
  t112_n197: return 0.005017453338950872;
  t112_n198: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t112_n200;
  t112_n199: return 0.1079002171754837;
  t112_n200: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t112_n202;
  t112_n201: return 0.06177927553653717;
  t112_n202: return 0.11697910726070404;
  t112_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t112_n205;
  t112_n204: return 0.025920357555150986;
  t112_n205: return -0.39547955989837646;
  t112_n206: return 0.13680638372898102;
  t112_n207: return 0.04789825528860092;
  t112_n208: if (E.getNumReferences() >= 3364277024 /*276057.0*/) goto t112_n210;
  t112_n209: return -0.1405039280653;
  t112_n210: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t112_n216;
  t112_n211: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t112_n213;
  t112_n212: return 0.1258837729692459;
  t112_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t112_n215;
  t112_n214: return -0.8602725267410278;
  t112_n215: return 0.09653224796056747;
  t112_n216: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t112_n252;
  t112_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t112_n229;
  t112_n218: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t112_n220;
  t112_n219: return 0.012423806823790073;
  t112_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t112_n228;
  t112_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t112_n225;
  t112_n222: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t112_n224;
  t112_n223: return 0.01851225085556507;
  t112_n224: return 0.11032824218273163;
  t112_n225: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t112_n227;
  t112_n226: return 0.0985206812620163;
  t112_n227: return -0.2322947382926941;
  t112_n228: return 0.010065220296382904;
  t112_n229: if (E.getNumReferences() >= 3365247648 /*306389.0*/) goto t112_n249;
  t112_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t112_n242;
  t112_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t112_n235;
  t112_n232: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t112_n234;
  t112_n233: return -0.42937013506889343;
  t112_n234: return 0.11495418846607208;
  t112_n235: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t112_n237;
  t112_n236: return 0.02179361693561077;
  t112_n237: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t112_n239;
  t112_n238: return -0.10391581803560257;
  t112_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t112_n241;
  t112_n240: return 0.1116829663515091;
  t112_n241: return 0.12063923478126526;
  t112_n242: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t112_n246;
  t112_n243: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t112_n245;
  t112_n244: return 0.06295417249202728;
  t112_n245: return -0.09457431733608246;
  t112_n246: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t112_n248;
  t112_n247: return -0.5742807388305664;
  t112_n248: return 0.08474238961935043;
  t112_n249: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t112_n251;
  t112_n250: return 0.03159073740243912;
  t112_n251: return -0.10252464562654495;
  t112_n252: if (E.getNumReferences() >= 3364286400 /*276350.0*/) goto t112_n254;
  t112_n253: return 0.252142071723938;
  t112_n254: return -0.10188305377960205;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree113(const Example& E) {
  t113_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t113_n128;
  t113_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t113_n3;
  t113_n2: return -0.0010125640546903014;
  t113_n3: if (E.getNumReferences() >= 3338172416 /*31804.0*/) goto t113_n127;
  t113_n4: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t113_n118;
  t113_n5: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t113_n91;
  t113_n6: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t113_n82;
  t113_n7: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t113_n25;
  t113_n8: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t113_n16;
  t113_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t113_n11;
  t113_n10: return 0.006387209054082632;
  t113_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t113_n13;
  t113_n12: return -0.014286782592535019;
  t113_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t113_n15;
  t113_n14: return -0.27079764008522034;
  t113_n15: return -0.12903989851474762;
  t113_n16: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t113_n18;
  t113_n17: return 0.016281381249427795;
  t113_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t113_n22;
  t113_n19: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t113_n21;
  t113_n20: return 0.06901571154594421;
  t113_n21: return -0.482233464717865;
  t113_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n24;
  t113_n23: return 0.10714308172464371;
  t113_n24: return -0.26747438311576843;
  t113_n25: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t113_n47;
  t113_n26: if (E.getNumReferences() >= 3324139520 /*10390.0*/) goto t113_n46;
  t113_n27: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t113_n29;
  t113_n28: return -0.001508801244199276;
  t113_n29: if (E.getNumReferences() >= 3320516608 /*7522.0*/) goto t113_n33;
  t113_n30: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n32;
  t113_n31: return 0.11240744590759277;
  t113_n32: return 0.1301344782114029;
  t113_n33: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n39;
  t113_n34: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n36;
  t113_n35: return -0.33932971954345703;
  t113_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t113_n38;
  t113_n37: return 0.09756802022457123;
  t113_n38: return 0.06855101883411407;
  t113_n39: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t113_n41;
  t113_n40: return -0.03824267163872719;
  t113_n41: if (E.getNumReferences() >= 3322734080 /*9017.5*/) goto t113_n43;
  t113_n42: return 0.11597266048192978;
  t113_n43: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t113_n45;
  t113_n44: return -0.023975253105163574;
  t113_n45: return 0.0907072052359581;
  t113_n46: return -0.07160011678934097;
  t113_n47: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t113_n81;
  t113_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n52;
  t113_n49: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t113_n51;
  t113_n50: return 0.058742549270391464;
  t113_n51: return -0.09067855030298233;
  t113_n52: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t113_n54;
  t113_n53: return 0.000416527152992785;
  t113_n54: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t113_n68;
  t113_n55: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n57;
  t113_n56: return -0.04691549018025398;
  t113_n57: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t113_n61;
  t113_n58: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t113_n60;
  t113_n59: return 0.002574129495769739;
  t113_n60: return 0.09928228706121445;
  t113_n61: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t113_n67;
  t113_n62: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n64;
  t113_n63: return 0.12263872474431992;
  t113_n64: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t113_n66;
  t113_n65: return 0.11794767528772354;
  t113_n66: return 0.1211668998003006;
  t113_n67: return 0.05154416710138321;
  t113_n68: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t113_n70;
  t113_n69: return -0.12504494190216064;
  t113_n70: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t113_n80;
  t113_n71: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t113_n73;
  t113_n72: return -0.09526936709880829;
  t113_n73: if (E.getNumReferences() >= 3277455360 /*218.0*/) goto t113_n79;
  t113_n74: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t113_n78;
  t113_n75: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t113_n77;
  t113_n76: return 0.10859335958957672;
  t113_n77: return 0.003606262383982539;
  t113_n78: return 0.12852397561073303;
  t113_n79: return -0.2207106351852417;
  t113_n80: return 0.05059683695435524;
  t113_n81: return 0.00623049633577466;
  t113_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n84;
  t113_n83: return -0.02655532956123352;
  t113_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t113_n86;
  t113_n85: return 0.009329966269433498;
  t113_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n90;
  t113_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t113_n89;
  t113_n88: return 0.0804581344127655;
  t113_n89: return 0.05343931168317795;
  t113_n90: return 0.024355309084057808;
  t113_n91: if (E.getNumReferences() >= 3331936768 /*19625.0*/) goto t113_n117;
  t113_n92: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t113_n114;
  t113_n93: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t113_n113;
  t113_n94: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t113_n108;
  t113_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t113_n105;
  t113_n96: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n100;
  t113_n97: if (E.getNumReferences() >= 3329347072 /*15475.5*/) goto t113_n99;
  t113_n98: return 0.11205584555864334;
  t113_n99: return -0.40139591693878174;
  t113_n100: if (E.getNumReferences() >= 3328519680 /*14667.5*/) goto t113_n102;
  t113_n101: return 0.07295110076665878;
  t113_n102: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t113_n104;
  t113_n103: return 0.13506537675857544;
  t113_n104: return 0.10988235473632812;
  t113_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n107;
  t113_n106: return 0.10595739632844925;
  t113_n107: return 0.0653110221028328;
  t113_n108: if (E.getNumReferences() >= 3327952896 /*14114.0*/) goto t113_n110;
  t113_n109: return 0.11752846837043762;
  t113_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t113_n112;
  t113_n111: return -0.34471866488456726;
  t113_n112: return 0.10445758700370789;
  t113_n113: return 0.009184540249407291;
  t113_n114: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t113_n116;
  t113_n115: return 0.12422611564397812;
  t113_n116: return -0.013448969461023808;
  t113_n117: return -0.005782031454145908;
  t113_n118: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t113_n120;
  t113_n119: return 0.048628486692905426;
  t113_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t113_n124;
  t113_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t113_n123;
  t113_n122: return 0.09917844831943512;
  t113_n123: return 0.10494117438793182;
  t113_n124: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t113_n126;
  t113_n125: return 0.06387092173099518;
  t113_n126: return 0.09917286038398743;
  t113_n127: return -0.05729765444993973;
  t113_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t113_n162;
  t113_n129: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t113_n141;
  t113_n130: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t113_n138;
  t113_n131: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t113_n137;
  t113_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n134;
  t113_n133: return -0.1557353436946869;
  t113_n134: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t113_n136;
  t113_n135: return -0.6296876668930054;
  t113_n136: return 0.05655486509203911;
  t113_n137: return 0.014629537239670753;
  t113_n138: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t113_n140;
  t113_n139: return -0.044955186545848846;
  t113_n140: return -0.09794137626886368;
  t113_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t113_n157;
  t113_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t113_n144;
  t113_n143: return 0.10855557769536972;
  t113_n144: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t113_n146;
  t113_n145: return 0.08255819976329803;
  t113_n146: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t113_n148;
  t113_n147: return -0.16658300161361694;
  t113_n148: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t113_n152;
  t113_n149: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t113_n151;
  t113_n150: return 0.009928634390234947;
  t113_n151: return 0.08218076080083847;
  t113_n152: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t113_n154;
  t113_n153: return 0.1141527071595192;
  t113_n154: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t113_n156;
  t113_n155: return 0.09291860461235046;
  t113_n156: return -0.20640332996845245;
  t113_n157: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t113_n161;
  t113_n158: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n160;
  t113_n159: return 0.10036206245422363;
  t113_n160: return 0.0782063752412796;
  t113_n161: return -0.23426400125026703;
  t113_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t113_n204;
  t113_n163: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t113_n179;
  t113_n164: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t113_n178;
  t113_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t113_n169;
  t113_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n168;
  t113_n167: return -0.09612645208835602;
  t113_n168: return 0.24563412368297577;
  t113_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n177;
  t113_n170: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t113_n176;
  t113_n171: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n175;
  t113_n172: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t113_n174;
  t113_n173: return 0.10848600417375565;
  t113_n174: return 0.11031470447778702;
  t113_n175: return 0.0952845886349678;
  t113_n176: return -0.006218523718416691;
  t113_n177: return -0.15308377146720886;
  t113_n178: return 0.008147881366312504;
  t113_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t113_n203;
  t113_n180: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n202;
  t113_n181: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t113_n191;
  t113_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t113_n190;
  t113_n183: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t113_n189;
  t113_n184: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t113_n186;
  t113_n185: return -0.11020471155643463;
  t113_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t113_n188;
  t113_n187: return 0.24473735690116882;
  t113_n188: return 0.11070398986339569;
  t113_n189: return -0.1384427398443222;
  t113_n190: return -0.029445869848132133;
  t113_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t113_n197;
  t113_n192: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t113_n196;
  t113_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t113_n195;
  t113_n194: return 0.044512104243040085;
  t113_n195: return 0.09421112388372421;
  t113_n196: return 0.00914801936596632;
  t113_n197: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t113_n199;
  t113_n198: return 0.07628295570611954;
  t113_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n201;
  t113_n200: return 0.12132339924573898;
  t113_n201: return -0.04599607735872269;
  t113_n202: return -0.11876823753118515;
  t113_n203: return 0.1331397294998169;
  t113_n204: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t113_n224;
  t113_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n223;
  t113_n206: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t113_n208;
  t113_n207: return -0.017426103353500366;
  t113_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t113_n210;
  t113_n209: return -0.0006043873145245016;
  t113_n210: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t113_n212;
  t113_n211: return -0.07946711778640747;
  t113_n212: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t113_n214;
  t113_n213: return -0.15265709161758423;
  t113_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t113_n222;
  t113_n215: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t113_n217;
  t113_n216: return 0.2837183177471161;
  t113_n217: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t113_n221;
  t113_n218: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t113_n220;
  t113_n219: return 0.12435115873813629;
  t113_n220: return 0.11202605068683624;
  t113_n221: return 0.18021486699581146;
  t113_n222: return 0.06458580493927002;
  t113_n223: return 0.12451539188623428;
  t113_n224: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t113_n234;
  t113_n225: if (E.getNumReferences() >= 3346697088 /*64139.5*/) goto t113_n227;
  t113_n226: return -0.0012357158120721579;
  t113_n227: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t113_n229;
  t113_n228: return -0.04871062934398651;
  t113_n229: if (E.getNumReferences() >= 3347118592 /*66036.0*/) goto t113_n233;
  t113_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n232;
  t113_n231: return -0.8626901507377625;
  t113_n232: return 0.11538844555616379;
  t113_n233: return -0.007814529351890087;
  t113_n234: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t113_n254;
  t113_n235: if (E.getNumReferences() >= 3348846016 /*79531.5*/) goto t113_n253;
  t113_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t113_n238;
  t113_n237: return 0.022406887263059616;
  t113_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t113_n244;
  t113_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t113_n241;
  t113_n240: return -0.19007530808448792;
  t113_n241: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t113_n243;
  t113_n242: return 0.08444316685199738;
  t113_n243: return -0.19789764285087585;
  t113_n244: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t113_n250;
  t113_n245: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t113_n247;
  t113_n246: return 0.10549017786979675;
  t113_n247: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t113_n249;
  t113_n248: return 0.09716090559959412;
  t113_n249: return 0.0031175604090094566;
  t113_n250: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t113_n252;
  t113_n251: return 0.07852393388748169;
  t113_n252: return -1.251798391342163;
  t113_n253: return 0.14666397869586945;
  t113_n254: return 0.01769060268998146;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree114(const Example& E) {
  t114_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t114_n254;
  t114_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t114_n243;
  t114_n2: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t114_n240;
  t114_n3: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t114_n5;
  t114_n4: return -0.003150621661916375;
  t114_n5: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t114_n227;
  t114_n6: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t114_n50;
  t114_n7: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t114_n39;
  t114_n8: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t114_n24;
  t114_n9: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t114_n21;
  t114_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t114_n12;
  t114_n11: return -0.017162611708045006;
  t114_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t114_n16;
  t114_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t114_n15;
  t114_n14: return 0.03853083401918411;
  t114_n15: return 0.07846973091363907;
  t114_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n18;
  t114_n17: return 0.11184865236282349;
  t114_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t114_n20;
  t114_n19: return -0.19601069390773773;
  t114_n20: return 0.15201710164546967;
  t114_n21: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t114_n23;
  t114_n22: return 0.10509020835161209;
  t114_n23: return 0.0002386351698078215;
  t114_n24: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t114_n36;
  t114_n25: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t114_n31;
  t114_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n30;
  t114_n27: if (E.getNumReferences() >= 3328268288 /*14422.0*/) goto t114_n29;
  t114_n28: return -0.11523876339197159;
  t114_n29: return 0.08320096135139465;
  t114_n30: return -0.0612543523311615;
  t114_n31: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t114_n35;
  t114_n32: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t114_n34;
  t114_n33: return -0.15366512537002563;
  t114_n34: return 0.09287429600954056;
  t114_n35: return 0.12245729565620422;
  t114_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t114_n38;
  t114_n37: return -0.18620739877223969;
  t114_n38: return 0.10191267728805542;
  t114_n39: if (E.getNumReferences() >= 3332248320 /*20233.5*/) goto t114_n47;
  t114_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n42;
  t114_n41: return -0.031018264591693878;
  t114_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n46;
  t114_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t114_n45;
  t114_n44: return -0.023875288665294647;
  t114_n45: return 0.03039623610675335;
  t114_n46: return -0.015151089057326317;
  t114_n47: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t114_n49;
  t114_n48: return 0.12631113827228546;
  t114_n49: return -0.017374740913510323;
  t114_n50: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t114_n210;
  t114_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t114_n159;
  t114_n52: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t114_n132;
  t114_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n97;
  t114_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n56;
  t114_n55: return 0.003760918276384473;
  t114_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t114_n94;
  t114_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t114_n89;
  t114_n58: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t114_n88;
  t114_n59: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t114_n71;
  t114_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t114_n62;
  t114_n61: return 0.01788526400923729;
  t114_n62: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n70;
  t114_n63: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n65;
  t114_n64: return 0.05401628464460373;
  t114_n65: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t114_n69;
  t114_n66: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t114_n68;
  t114_n67: return 0.08827493339776993;
  t114_n68: return 0.12328046560287476;
  t114_n69: return 0.044398821890354156;
  t114_n70: return -0.14483153820037842;
  t114_n71: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n73;
  t114_n72: return 0.09516153484582901;
  t114_n73: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t114_n85;
  t114_n74: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t114_n84;
  t114_n75: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t114_n77;
  t114_n76: return 0.11024614423513412;
  t114_n77: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n81;
  t114_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t114_n80;
  t114_n79: return 0.20131881535053253;
  t114_n80: return 0.14974242448806763;
  t114_n81: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t114_n83;
  t114_n82: return -0.12215574085712433;
  t114_n83: return 0.11920485645532608;
  t114_n84: return 0.04098328948020935;
  t114_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n87;
  t114_n86: return -0.12049750983715057;
  t114_n87: return 0.18518200516700745;
  t114_n88: return -0.004625359084457159;
  t114_n89: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t114_n93;
  t114_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t114_n92;
  t114_n91: return 0.0632224753499031;
  t114_n92: return 0.12544265389442444;
  t114_n93: return 0.1349276602268219;
  t114_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t114_n96;
  t114_n95: return -0.03740733861923218;
  t114_n96: return 0.07623527944087982;
  t114_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n105;
  t114_n98: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n100;
  t114_n99: return -0.1681453287601471;
  t114_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t114_n104;
  t114_n101: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n103;
  t114_n102: return -0.0372917503118515;
  t114_n103: return -0.20203034579753876;
  t114_n104: return 0.047615960240364075;
  t114_n105: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t114_n111;
  t114_n106: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t114_n108;
  t114_n107: return -0.015973152592778206;
  t114_n108: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n110;
  t114_n109: return -0.1013803705573082;
  t114_n110: return -0.018689323216676712;
  t114_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t114_n113;
  t114_n112: return -0.14697137475013733;
  t114_n113: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t114_n115;
  t114_n114: return 0.008571074344217777;
  t114_n115: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n117;
  t114_n116: return 0.03429441526532173;
  t114_n117: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t114_n131;
  t114_n118: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t114_n130;
  t114_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t114_n129;
  t114_n120: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t114_n128;
  t114_n121: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t114_n127;
  t114_n122: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n126;
  t114_n123: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t114_n125;
  t114_n124: return -0.13640296459197998;
  t114_n125: return 0.12711597979068756;
  t114_n126: return -0.007454232778400183;
  t114_n127: return -0.12286550551652908;
  t114_n128: return 0.12470043450593948;
  t114_n129: return -0.2114323228597641;
  t114_n130: return 0.10057158768177032;
  t114_n131: return 0.02732250839471817;
  t114_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t114_n156;
  t114_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n135;
  t114_n134: return -0.11398661136627197;
  t114_n135: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t114_n147;
  t114_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n144;
  t114_n137: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t114_n139;
  t114_n138: return 0.16377362608909607;
  t114_n139: if (E.getNumReferences() >= 3281485824 /*303.0*/) goto t114_n141;
  t114_n140: return -0.09577084332704544;
  t114_n141: if (E.getNumReferences() >= 3289022464 /*554.0*/) goto t114_n143;
  t114_n142: return 0.1317494660615921;
  t114_n143: return 0.023664403706789017;
  t114_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t114_n146;
  t114_n145: return -0.02085653692483902;
  t114_n146: return 0.07650510966777802;
  t114_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t114_n155;
  t114_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t114_n154;
  t114_n149: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t114_n151;
  t114_n150: return -0.26414334774017334;
  t114_n151: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t114_n153;
  t114_n152: return -0.21028836071491241;
  t114_n153: return 0.1153070405125618;
  t114_n154: return 0.10848581790924072;
  t114_n155: return 0.11938705295324326;
  t114_n156: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n158;
  t114_n157: return 0.03214200586080551;
  t114_n158: return 0.11588671058416367;
  t114_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n167;
  t114_n160: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t114_n164;
  t114_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t114_n163;
  t114_n162: return -0.22044311463832855;
  t114_n163: return -0.06514474004507065;
  t114_n164: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t114_n166;
  t114_n165: return 0.0385587215423584;
  t114_n166: return -0.03707956150174141;
  t114_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t114_n205;
  t114_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t114_n176;
  t114_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n175;
  t114_n170: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t114_n174;
  t114_n171: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t114_n173;
  t114_n172: return -0.14222098886966705;
  t114_n173: return 0.035740867257118225;
  t114_n174: return -0.2493657022714615;
  t114_n175: return -0.039664167910814285;
  t114_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t114_n200;
  t114_n177: if (E.getNumReferences() >= 3290136576 /*622.0*/) goto t114_n197;
  t114_n178: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t114_n184;
  t114_n179: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t114_n181;
  t114_n180: return -0.019519802182912827;
  t114_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n183;
  t114_n182: return -0.46303850412368774;
  t114_n183: return -0.03427404910326004;
  t114_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other))) goto t114_n186;
  t114_n185: return -0.01851538009941578;
  t114_n186: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t114_n196;
  t114_n187: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t114_n193;
  t114_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t114_n192;
  t114_n189: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n191;
  t114_n190: return 0.08622743934392929;
  t114_n191: return -0.04486977681517601;
  t114_n192: return -0.04147372767329216;
  t114_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t114_n195;
  t114_n194: return 0.01115089375525713;
  t114_n195: return 0.14565102756023407;
  t114_n196: return 0.10625141113996506;
  t114_n197: if (E.getNumReferences() >= 3291693056 /*717.0*/) goto t114_n199;
  t114_n198: return 0.15308640897274017;
  t114_n199: return -0.013808679766952991;
  t114_n200: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t114_n202;
  t114_n201: return 0.006992613431066275;
  t114_n202: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t114_n204;
  t114_n203: return 0.07568813860416412;
  t114_n204: return -0.014681723900139332;
  t114_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t114_n207;
  t114_n206: return -0.1355845332145691;
  t114_n207: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t114_n209;
  t114_n208: return -0.03529350087046623;
  t114_n209: return 0.012154833413660526;
  t114_n210: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t114_n212;
  t114_n211: return 0.014329912140965462;
  t114_n212: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t114_n216;
  t114_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t114_n215;
  t114_n214: return -0.03336598351597786;
  t114_n215: return 0.0076484279707074165;
  t114_n216: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t114_n220;
  t114_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t114_n219;
  t114_n218: return 0.0034265476278960705;
  t114_n219: return 0.006132943090051413;
  t114_n220: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t114_n224;
  t114_n221: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n223;
  t114_n222: return 0.10771755874156952;
  t114_n223: return 0.09699947386980057;
  t114_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t114_n226;
  t114_n225: return -0.2380194365978241;
  t114_n226: return 0.07308954000473022;
  t114_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t114_n239;
  t114_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t114_n234;
  t114_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t114_n233;
  t114_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t114_n232;
  t114_n231: return -0.04567265510559082;
  t114_n232: return -0.11566118896007538;
  t114_n233: return -0.023499606177210808;
  t114_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t114_n236;
  t114_n235: return -0.010456474497914314;
  t114_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t114_n238;
  t114_n237: return 0.03379111364483833;
  t114_n238: return 0.10181237757205963;
  t114_n239: return 0.08772274106740952;
  t114_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t114_n242;
  t114_n241: return -0.00528799369931221;
  t114_n242: return 0.014611350372433662;
  t114_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t114_n245;
  t114_n244: return -0.0063942852430045605;
  t114_n245: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t114_n249;
  t114_n246: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t114_n248;
  t114_n247: return 0.0077834222465753555;
  t114_n248: return 0.02095988392829895;
  t114_n249: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t114_n251;
  t114_n250: return 0.0015454816166311502;
  t114_n251: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t114_n253;
  t114_n252: return 0.015036865137517452;
  t114_n253: return -0.12344242632389069;
  t114_n254: return -0.05403263121843338;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree115(const Example& E) {
  t115_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t115_n128;
  t115_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t115_n67;
  t115_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t115_n4;
  t115_n3: return -0.006456674076616764;
  t115_n4: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t115_n6;
  t115_n5: return -0.07311305403709412;
  t115_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t115_n66;
  t115_n7: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t115_n65;
  t115_n8: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t115_n42;
  t115_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t115_n41;
  t115_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t115_n40;
  t115_n11: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t115_n39;
  t115_n12: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t115_n30;
  t115_n13: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t115_n15;
  t115_n14: return 0.00035164266591891646;
  t115_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n17;
  t115_n16: return 0.01534357201308012;
  t115_n17: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t115_n19;
  t115_n18: return 0.0070784566923975945;
  t115_n19: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t115_n21;
  t115_n20: return 0.030532974749803543;
  t115_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n29;
  t115_n22: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t115_n28;
  t115_n23: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t115_n25;
  t115_n24: return 0.047558125108480453;
  t115_n25: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t115_n27;
  t115_n26: return 0.07455472648143768;
  t115_n27: return -0.03035913035273552;
  t115_n28: return -0.01678524911403656;
  t115_n29: return 0.0188948642462492;
  t115_n30: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t115_n32;
  t115_n31: return -0.0013855349970981479;
  t115_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t115_n34;
  t115_n33: return -0.01999022625386715;
  t115_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t115_n38;
  t115_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t115_n37;
  t115_n36: return 0.061730463057756424;
  t115_n37: return 0.037862733006477356;
  t115_n38: return -0.007171624340116978;
  t115_n39: return 0.02437194623053074;
  t115_n40: return -0.03504323214292526;
  t115_n41: return 0.007943084463477135;
  t115_n42: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t115_n50;
  t115_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t115_n45;
  t115_n44: return -0.02915671095252037;
  t115_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t115_n49;
  t115_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t115_n48;
  t115_n47: return 0.006036481354385614;
  t115_n48: return 0.04336726665496826;
  t115_n49: return 0.08187226206064224;
  t115_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t115_n52;
  t115_n51: return 0.00020567956380546093;
  t115_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n64;
  t115_n53: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t115_n55;
  t115_n54: return -0.20699025690555573;
  t115_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t115_n57;
  t115_n56: return 0.059680432081222534;
  t115_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t115_n63;
  t115_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n62;
  t115_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t115_n61;
  t115_n60: return 0.10109574347734451;
  t115_n61: return 0.07421503961086273;
  t115_n62: return -0.18166087567806244;
  t115_n63: return -0.2719360888004303;
  t115_n64: return 0.006292193196713924;
  t115_n65: return -0.10496051609516144;
  t115_n66: return -0.07067995518445969;
  t115_n67: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t115_n71;
  t115_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t115_n70;
  t115_n69: return -0.05811729282140732;
  t115_n70: return -0.13179101049900055;
  t115_n71: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t115_n117;
  t115_n72: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t115_n74;
  t115_n73: return 0.002048746682703495;
  t115_n74: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t115_n78;
  t115_n75: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t115_n77;
  t115_n76: return 0.021725911647081375;
  t115_n77: return 0.013924548402428627;
  t115_n78: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t115_n112;
  t115_n79: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t115_n81;
  t115_n80: return 0.030475087463855743;
  t115_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t115_n83;
  t115_n82: return -0.024879157543182373;
  t115_n83: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n85;
  t115_n84: return 0.08393609523773193;
  t115_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t115_n103;
  t115_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t115_n88;
  t115_n87: return 0.07716289162635803;
  t115_n88: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t115_n98;
  t115_n89: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t115_n91;
  t115_n90: return 0.06821141391992569;
  t115_n91: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t115_n95;
  t115_n92: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t115_n94;
  t115_n93: return 0.10393726825714111;
  t115_n94: return -0.10805223137140274;
  t115_n95: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t115_n97;
  t115_n96: return 0.09368650615215302;
  t115_n97: return 0.13888642191886902;
  t115_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t115_n100;
  t115_n99: return 0.03768331930041313;
  t115_n100: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t115_n102;
  t115_n101: return 0.10805825144052505;
  t115_n102: return 0.07787485420703888;
  t115_n103: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t115_n111;
  t115_n104: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t115_n110;
  t115_n105: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t115_n109;
  t115_n106: if (E.getFilterLength() >= 3246391296 /*16.0*/) goto t115_n108;
  t115_n107: return 0.08691719174385071;
  t115_n108: return 0.13870282471179962;
  t115_n109: return 0.12872569262981415;
  t115_n110: return 0.043844521045684814;
  t115_n111: return 0.11952745914459229;
  t115_n112: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t115_n116;
  t115_n113: if (E.getFileProximityDistance() >= 3238002688 /*8.0*/) goto t115_n115;
  t115_n114: return -0.14129507541656494;
  t115_n115: return 0.10988131910562515;
  t115_n116: return 0.06512820720672607;
  t115_n117: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t115_n119;
  t115_n118: return 0.006834635976701975;
  t115_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t115_n121;
  t115_n120: return -0.07833348214626312;
  t115_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t115_n123;
  t115_n122: return 0.033059488981962204;
  t115_n123: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t115_n127;
  t115_n124: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t115_n126;
  t115_n125: return 0.07007820159196854;
  t115_n126: return 0.10905271023511887;
  t115_n127: return 0.0719507709145546;
  t115_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t115_n192;
  t115_n129: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t115_n191;
  t115_n130: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t115_n132;
  t115_n131: return 0.004455015063285828;
  t115_n132: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t115_n184;
  t115_n133: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t115_n183;
  t115_n134: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t115_n156;
  t115_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t115_n137;
  t115_n136: return 0.0025757020339369774;
  t115_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t115_n151;
  t115_n138: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t115_n140;
  t115_n139: return 0.021717682480812073;
  t115_n140: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t115_n144;
  t115_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t115_n143;
  t115_n142: return 0.11317528784275055;
  t115_n143: return -0.016980228945612907;
  t115_n144: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n146;
  t115_n145: return 0.10018628090620041;
  t115_n146: if (E.getNumReferences() >= 3277193216 /*214.0*/) goto t115_n148;
  t115_n147: return -0.0069372509606182575;
  t115_n148: if (E.getNumReferences() >= 3277520896 /*219.0*/) goto t115_n150;
  t115_n149: return 0.14864863455295563;
  t115_n150: return 0.06920699030160904;
  t115_n151: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t115_n153;
  t115_n152: return -0.030843539163470268;
  t115_n153: if (E.getNumReferences() >= 3268542464 /*105.0*/) goto t115_n155;
  t115_n154: return 0.12858526408672333;
  t115_n155: return 0.09504850953817368;
  t115_n156: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t115_n172;
  t115_n157: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t115_n171;
  t115_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t115_n170;
  t115_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t115_n167;
  t115_n160: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t115_n166;
  t115_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t115_n165;
  t115_n162: if (E.getNumReferences() >= 3287220224 /*478.0*/) goto t115_n164;
  t115_n163: return 0.06090166047215462;
  t115_n164: return 0.11550191044807434;
  t115_n165: return 0.014572307467460632;
  t115_n166: return 0.05603950098156929;
  t115_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n169;
  t115_n168: return 0.11461571604013443;
  t115_n169: return -0.11478004604578018;
  t115_n170: return 0.10128585994243622;
  t115_n171: return 0.13415813446044922;
  t115_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t115_n174;
  t115_n173: return 0.01927989348769188;
  t115_n174: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t115_n182;
  t115_n175: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t115_n177;
  t115_n176: return -0.25848814845085144;
  t115_n177: if (E.getNumReferences() >= 3292217344 /*749.0*/) goto t115_n179;
  t115_n178: return 0.04927382245659828;
  t115_n179: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t115_n181;
  t115_n180: return 0.11611510068178177;
  t115_n181: return 0.13657540082931519;
  t115_n182: return 0.020958280190825462;
  t115_n183: return 0.012774044647812843;
  t115_n184: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t115_n190;
  t115_n185: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t115_n187;
  t115_n186: return 0.07971300184726715;
  t115_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t115_n189;
  t115_n188: return 0.11044172197580338;
  t115_n189: return 0.12576310336589813;
  t115_n190: return 0.029450125992298126;
  t115_n191: return -0.0006151639390736818;
  t115_n192: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t115_n194;
  t115_n193: return 0.027731457725167274;
  t115_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t115_n196;
  t115_n195: return 0.024797143414616585;
  t115_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t115_n232;
  t115_n197: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t115_n231;
  t115_n198: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t115_n200;
  t115_n199: return 0.01220737025141716;
  t115_n200: if (E.getNumReferences() >= 3271589888 /*128.5*/) goto t115_n220;
  t115_n201: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t115_n219;
  t115_n202: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t115_n208;
  t115_n203: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t115_n207;
  t115_n204: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t115_n206;
  t115_n205: return 0.09749031811952591;
  t115_n206: return 0.10870536416769028;
  t115_n207: return 0.11189619451761246;
  t115_n208: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t115_n210;
  t115_n209: return 0.09114079177379608;
  t115_n210: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t115_n212;
  t115_n211: return 0.118137426674366;
  t115_n212: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t115_n218;
  t115_n213: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t115_n215;
  t115_n214: return 0.045995794236660004;
  t115_n215: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t115_n217;
  t115_n216: return 0.1180589348077774;
  t115_n217: return 0.08795364201068878;
  t115_n218: return 0.11126367002725601;
  t115_n219: return 0.09317993372678757;
  t115_n220: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t115_n226;
  t115_n221: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t115_n223;
  t115_n222: return 0.08323357254266739;
  t115_n223: if (E.getNumReferences() >= 3283353600 /*360.0*/) goto t115_n225;
  t115_n224: return -0.06789899617433548;
  t115_n225: return 0.12319473177194595;
  t115_n226: if (E.getNumReferences() >= 3309076480 /*3016.0*/) goto t115_n228;
  t115_n227: return -0.06452896445989609;
  t115_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t115_n230;
  t115_n229: return 0.06855525076389313;
  t115_n230: return 0.10843657702207565;
  t115_n231: return 0.09731343388557434;
  t115_n232: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t115_n242;
  t115_n233: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t115_n239;
  t115_n234: if (E.getNumReferences() >= 3318737920 /*6653.5*/) goto t115_n236;
  t115_n235: return -0.009049820713698864;
  t115_n236: if (E.getNumReferences() >= 3319312384 /*6934.0*/) goto t115_n238;
  t115_n237: return 0.1264542192220688;
  t115_n238: return 0.047953490167856216;
  t115_n239: if (E.getNumReferences() >= 3267100672 /*94.0*/) goto t115_n241;
  t115_n240: return 0.11310163140296936;
  t115_n241: return -0.041396696120500565;
  t115_n242: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t115_n254;
  t115_n243: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t115_n253;
  t115_n244: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t115_n252;
  t115_n245: if (E.getNumReferences() >= 3265265664 /*80.0*/) goto t115_n251;
  t115_n246: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t115_n250;
  t115_n247: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t115_n249;
  t115_n248: return -0.13457639515399933;
  t115_n249: return 0.13173462450504303;
  t115_n250: return -0.23131859302520752;
  t115_n251: return 0.12128722667694092;
  t115_n252: return 0.04333626106381416;
  t115_n253: return 0.11538258194923401;
  t115_n254: return 0.05902184545993805;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree116(const Example& E) {
  t116_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t116_n178;
  t116_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t116_n3;
  t116_n2: return -0.0009391837520524859;
  t116_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t116_n5;
  t116_n4: return 0.004171603824943304;
  t116_n5: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t116_n27;
  t116_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n8;
  t116_n7: return 0.021995363757014275;
  t116_n8: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t116_n16;
  t116_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n15;
  t116_n10: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t116_n14;
  t116_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n13;
  t116_n12: return 0.30967360734939575;
  t116_n13: return 0.19098018109798431;
  t116_n14: return 0.09920673072338104;
  t116_n15: return -0.5464823246002197;
  t116_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n26;
  t116_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n23;
  t116_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t116_n20;
  t116_n19: return 0.19555127620697021;
  t116_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n22;
  t116_n21: return 0.13427451252937317;
  t116_n22: return 0.0640413910150528;
  t116_n23: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t116_n25;
  t116_n24: return 0.15103015303611755;
  t116_n25: return 0.1875970959663391;
  t116_n26: return 0.11586011946201324;
  t116_n27: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t116_n51;
  t116_n28: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t116_n50;
  t116_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n31;
  t116_n30: return 0.005708937533199787;
  t116_n31: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t116_n45;
  t116_n32: if (E.getNumReferences() >= 3346253184 /*62405.5*/) goto t116_n40;
  t116_n33: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t116_n35;
  t116_n34: return 0.025847727432847023;
  t116_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t116_n37;
  t116_n36: return 0.05325540900230408;
  t116_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n39;
  t116_n38: return 0.10347405076026917;
  t116_n39: return 0.13496030867099762;
  t116_n40: if (E.getNumReferences() >= 3347118592 /*66036.0*/) goto t116_n42;
  t116_n41: return -0.2528097927570343;
  t116_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n44;
  t116_n43: return -0.041449300944805145;
  t116_n44: return 0.03703747317194939;
  t116_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n47;
  t116_n46: return 0.06104596331715584;
  t116_n47: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t116_n49;
  t116_n48: return 0.0974324569106102;
  t116_n49: return 0.13552266359329224;
  t116_n50: return -0.14977924525737762;
  t116_n51: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t116_n69;
  t116_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n60;
  t116_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t116_n55;
  t116_n54: return 0.022186893969774246;
  t116_n55: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t116_n59;
  t116_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n58;
  t116_n57: return 0.0967201516032219;
  t116_n58: return 0.05556899681687355;
  t116_n59: return -0.2648533284664154;
  t116_n60: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t116_n62;
  t116_n61: return -0.01705847680568695;
  t116_n62: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t116_n66;
  t116_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t116_n65;
  t116_n64: return 0.06402237713336945;
  t116_n65: return 0.04296813905239105;
  t116_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n68;
  t116_n67: return 0.0932050570845604;
  t116_n68: return 0.032075949013233185;
  t116_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t116_n177;
  t116_n70: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t116_n132;
  t116_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t116_n73;
  t116_n72: return -0.07501518726348877;
  t116_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n121;
  t116_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t116_n100;
  t116_n75: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t116_n77;
  t116_n76: return -0.01087980903685093;
  t116_n77: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t116_n83;
  t116_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n80;
  t116_n79: return 0.0546102300286293;
  t116_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t116_n82;
  t116_n81: return -0.2953689992427826;
  t116_n82: return 0.014308429323136806;
  t116_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t116_n91;
  t116_n84: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n90;
  t116_n85: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t116_n89;
  t116_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n88;
  t116_n87: return -1.3626515865325928;
  t116_n88: return -0.08388447016477585;
  t116_n89: return -0.1631462424993515;
  t116_n90: return 0.027509959414601326;
  t116_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n99;
  t116_n92: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n98;
  t116_n93: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t116_n95;
  t116_n94: return -0.23234741389751434;
  t116_n95: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t116_n97;
  t116_n96: return 0.10499978065490723;
  t116_n97: return 0.08016661554574966;
  t116_n98: return 0.12221740186214447;
  t116_n99: return -0.025420568883419037;
  t116_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n106;
  t116_n101: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t116_n103;
  t116_n102: return 0.15128906071186066;
  t116_n103: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t116_n105;
  t116_n104: return 0.11962801963090897;
  t116_n105: return -0.017092343419790268;
  t116_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n120;
  t116_n107: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n111;
  t116_n108: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t116_n110;
  t116_n109: return 0.07589557021856308;
  t116_n110: return -0.6387305855751038;
  t116_n111: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t116_n119;
  t116_n112: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n118;
  t116_n113: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n117;
  t116_n114: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t116_n116;
  t116_n115: return -0.11680411547422409;
  t116_n116: return 0.12291338294744492;
  t116_n117: return 0.07854059338569641;
  t116_n118: return 0.0750964805483818;
  t116_n119: return 0.1334635466337204;
  t116_n120: return 0.01271007303148508;
  t116_n121: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t116_n125;
  t116_n122: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n124;
  t116_n123: return -0.6476038694381714;
  t116_n124: return -0.07126330584287643;
  t116_n125: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t116_n131;
  t116_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n130;
  t116_n127: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t116_n129;
  t116_n128: return 0.029594380408525467;
  t116_n129: return 0.1043812483549118;
  t116_n130: return 0.07019782811403275;
  t116_n131: return -0.1664157211780548;
  t116_n132: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t116_n134;
  t116_n133: return -0.12225186079740524;
  t116_n134: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t116_n174;
  t116_n135: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t116_n143;
  t116_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n140;
  t116_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n139;
  t116_n138: return -0.07830388844013214;
  t116_n139: return 0.038949307054281235;
  t116_n140: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t116_n142;
  t116_n141: return 0.008233723230659962;
  t116_n142: return 0.08869510143995285;
  t116_n143: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n173;
  t116_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t116_n166;
  t116_n145: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n155;
  t116_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n154;
  t116_n147: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t116_n153;
  t116_n148: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t116_n150;
  t116_n149: return 0.10684318095445633;
  t116_n150: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t116_n152;
  t116_n151: return 0.06349701434373856;
  t116_n152: return 0.03706282749772072;
  t116_n153: return -0.11418171972036362;
  t116_n154: return 0.032101623713970184;
  t116_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t116_n161;
  t116_n156: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t116_n160;
  t116_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n159;
  t116_n158: return 0.09912935644388199;
  t116_n159: return 0.06933202594518661;
  t116_n160: return -0.749660849571228;
  t116_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t116_n163;
  t116_n162: return 0.02147522196173668;
  t116_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n165;
  t116_n164: return 0.1099315732717514;
  t116_n165: return 0.1028478592634201;
  t116_n166: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t116_n172;
  t116_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n169;
  t116_n168: return 0.09760476648807526;
  t116_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t116_n171;
  t116_n170: return 0.08528729528188705;
  t116_n171: return 0.2818364202976227;
  t116_n172: return 0.030236467719078064;
  t116_n173: return -0.024779390543699265;
  t116_n174: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t116_n176;
  t116_n175: return 0.027164394035935402;
  t116_n176: return -0.01689852774143219;
  t116_n177: return -0.059355732053518295;
  t116_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t116_n180;
  t116_n179: return -0.005826101638376713;
  t116_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t116_n254;
  t116_n181: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t116_n183;
  t116_n182: return 0.006944065447896719;
  t116_n183: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t116_n189;
  t116_n184: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t116_n186;
  t116_n185: return -0.1264275461435318;
  t116_n186: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n188;
  t116_n187: return -1.9493842124938965;
  t116_n188: return 0.08172906190156937;
  t116_n189: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t116_n215;
  t116_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t116_n192;
  t116_n191: return 0.03631755709648132;
  t116_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t116_n194;
  t116_n193: return -0.00605006655678153;
  t116_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t116_n210;
  t116_n195: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n201;
  t116_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t116_n198;
  t116_n197: return 0.04270866513252258;
  t116_n198: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t116_n200;
  t116_n199: return 0.10954464226961136;
  t116_n200: return 0.059360578656196594;
  t116_n201: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t116_n207;
  t116_n202: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t116_n204;
  t116_n203: return -0.1765878051519394;
  t116_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n206;
  t116_n205: return 0.10782850533723831;
  t116_n206: return 0.11239052563905716;
  t116_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n209;
  t116_n208: return 0.0962611734867096;
  t116_n209: return -0.06763017177581787;
  t116_n210: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t116_n214;
  t116_n211: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t116_n213;
  t116_n212: return -0.23107755184173584;
  t116_n213: return 0.09154658764600754;
  t116_n214: return -0.05417567864060402;
  t116_n215: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t116_n235;
  t116_n216: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t116_n218;
  t116_n217: return 0.010602716356515884;
  t116_n218: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t116_n230;
  t116_n219: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t116_n229;
  t116_n220: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t116_n222;
  t116_n221: return 0.05538333207368851;
  t116_n222: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t116_n224;
  t116_n223: return 0.0885487049818039;
  t116_n224: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t116_n228;
  t116_n225: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t116_n227;
  t116_n226: return -0.010000121779739857;
  t116_n227: return 0.1304931491613388;
  t116_n228: return 0.13460467755794525;
  t116_n229: return 0.02741134725511074;
  t116_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t116_n234;
  t116_n231: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t116_n233;
  t116_n232: return 0.13379478454589844;
  t116_n233: return -0.009069147519767284;
  t116_n234: return 0.044629599899053574;
  t116_n235: if (E.getNumReferences() >= 3331945984 /*19643.0*/) goto t116_n247;
  t116_n236: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t116_n242;
  t116_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t116_n239;
  t116_n238: return 0.05351872742176056;
  t116_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t116_n241;
  t116_n240: return 0.10168880224227905;
  t116_n241: return 0.06761809438467026;
  t116_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t116_n244;
  t116_n243: return 0.10833635181188583;
  t116_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t116_n246;
  t116_n245: return 0.06300561130046844;
  t116_n246: return 0.10511960834264755;
  t116_n247: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t116_n249;
  t116_n248: return -0.01232527568936348;
  t116_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t116_n251;
  t116_n250: return -0.452093243598938;
  t116_n251: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t116_n253;
  t116_n252: return 0.08088917285203934;
  t116_n253: return 0.024667711928486824;
  t116_n254: return 0.004104897379875183;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree117(const Example& E) {
  t117_n0: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t117_n146;
  t117_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t117_n29;
  t117_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t117_n4;
  t117_n3: return -0.004875313024967909;
  t117_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t117_n14;
  t117_n5: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t117_n13;
  t117_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t117_n8;
  t117_n7: return 0.00629357760772109;
  t117_n8: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n12;
  t117_n9: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t117_n11;
  t117_n10: return -0.14502909779548645;
  t117_n11: return 0.0352114662528038;
  t117_n12: return -0.0013329193461686373;
  t117_n13: return -0.023563191294670105;
  t117_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n16;
  t117_n15: return 0.018107272684574127;
  t117_n16: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t117_n22;
  t117_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t117_n19;
  t117_n18: return 0.0042839874513447285;
  t117_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n21;
  t117_n20: return 0.02655239962041378;
  t117_n21: return 0.07478447258472443;
  t117_n22: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t117_n24;
  t117_n23: return 0.04927981272339821;
  t117_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n28;
  t117_n25: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t117_n27;
  t117_n26: return 0.053067468106746674;
  t117_n27: return -0.07643654197454453;
  t117_n28: return 0.06167517602443695;
  t117_n29: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t117_n145;
  t117_n30: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t117_n142;
  t117_n31: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t117_n139;
  t117_n32: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t117_n80;
  t117_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n79;
  t117_n34: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t117_n72;
  t117_n35: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t117_n67;
  t117_n36: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t117_n60;
  t117_n37: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t117_n59;
  t117_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t117_n58;
  t117_n39: if (E.getNumReferences() >= 3268280320 /*103.0*/) goto t117_n57;
  t117_n40: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t117_n56;
  t117_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t117_n47;
  t117_n42: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t117_n44;
  t117_n43: return -0.013708589598536491;
  t117_n44: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t117_n46;
  t117_n45: return -0.14925259351730347;
  t117_n46: return 0.20089603960514069;
  t117_n47: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t117_n55;
  t117_n48: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t117_n50;
  t117_n49: return 0.006674222648143768;
  t117_n50: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t117_n54;
  t117_n51: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t117_n53;
  t117_n52: return 0.1350673884153366;
  t117_n53: return 0.09321553260087967;
  t117_n54: return 0.006629837676882744;
  t117_n55: return -0.20074060559272766;
  t117_n56: return 0.11149752140045166;
  t117_n57: return -0.24772772192955017;
  t117_n58: return 0.07559092342853546;
  t117_n59: return 0.0962860956788063;
  t117_n60: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t117_n62;
  t117_n61: return -0.05647876113653183;
  t117_n62: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t117_n66;
  t117_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t117_n65;
  t117_n64: return -0.0013512055156752467;
  t117_n65: return 0.08431249111890793;
  t117_n66: return 0.0974838063120842;
  t117_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n71;
  t117_n68: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t117_n70;
  t117_n69: return -0.0745190978050232;
  t117_n70: return 0.08423719555139542;
  t117_n71: return -0.005177449434995651;
  t117_n72: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t117_n78;
  t117_n73: if (E.getNumReferences() >= 3337464320 /*30421.0*/) goto t117_n75;
  t117_n74: return 0.12306182831525803;
  t117_n75: if (E.getNumReferences() >= 3343861504 /*53063.0*/) goto t117_n77;
  t117_n76: return -0.08574552834033966;
  t117_n77: return 0.10130751132965088;
  t117_n78: return 0.050735291093587875;
  t117_n79: return 0.005108850542455912;
  t117_n80: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t117_n82;
  t117_n81: return 0.007298256736248732;
  t117_n82: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t117_n136;
  t117_n83: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t117_n125;
  t117_n84: if (E.getNumReferences() >= 3290226688 /*627.5*/) goto t117_n122;
  t117_n85: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t117_n95;
  t117_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n88;
  t117_n87: return -0.05127602815628052;
  t117_n88: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t117_n90;
  t117_n89: return -0.013796835206449032;
  t117_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n94;
  t117_n91: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t117_n93;
  t117_n92: return -0.07319074869155884;
  t117_n93: return -0.17400586605072021;
  t117_n94: return -0.016905928030610085;
  t117_n95: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t117_n97;
  t117_n96: return -0.01413580309599638;
  t117_n97: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t117_n99;
  t117_n98: return 0.012268472462892532;
  t117_n99: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t117_n121;
  t117_n100: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t117_n120;
  t117_n101: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t117_n119;
  t117_n102: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t117_n104;
  t117_n103: return 0.06491345912218094;
  t117_n104: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t117_n114;
  t117_n105: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t117_n113;
  t117_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n108;
  t117_n107: return 0.30617135763168335;
  t117_n108: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t117_n112;
  t117_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t117_n111;
  t117_n110: return 0.09939441084861755;
  t117_n111: return 0.10560627281665802;
  t117_n112: return 0.07141008228063583;
  t117_n113: return -0.03378999978303909;
  t117_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n116;
  t117_n115: return -0.16470052301883698;
  t117_n116: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t117_n118;
  t117_n117: return 0.14450904726982117;
  t117_n118: return 0.025639265775680542;
  t117_n119: return -0.012141813524067402;
  t117_n120: return -0.08485142886638641;
  t117_n121: return -0.0062081776559352875;
  t117_n122: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t117_n124;
  t117_n123: return 0.1423717439174652;
  t117_n124: return 0.03384258598089218;
  t117_n125: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t117_n133;
  t117_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t117_n132;
  t117_n127: if (E.getNumReferences() >= 3346232448 /*62324.5*/) goto t117_n131;
  t117_n128: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t117_n130;
  t117_n129: return -0.08926289528608322;
  t117_n130: return -0.015647156164050102;
  t117_n131: return 0.07102817296981812;
  t117_n132: return 0.010965506546199322;
  t117_n133: if (E.getNumReferences() >= 3336505344 /*28548.0*/) goto t117_n135;
  t117_n134: return -0.01312785129994154;
  t117_n135: return -0.07199972122907639;
  t117_n136: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t117_n138;
  t117_n137: return 0.018686166033148766;
  t117_n138: return -0.4901137053966522;
  t117_n139: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t117_n141;
  t117_n140: return 0.060563825070858;
  t117_n141: return 0.13395613431930542;
  t117_n142: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t117_n144;
  t117_n143: return 0.11169620603322983;
  t117_n144: return 0.06816107779741287;
  t117_n145: return -0.08650375157594681;
  t117_n146: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t117_n200;
  t117_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t117_n163;
  t117_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t117_n150;
  t117_n149: return -0.1313246339559555;
  t117_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n152;
  t117_n151: return 0.049539219588041306;
  t117_n152: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t117_n156;
  t117_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t117_n155;
  t117_n154: return -0.008281872607767582;
  t117_n155: return 0.06587288528680801;
  t117_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n158;
  t117_n157: return 0.0884166732430458;
  t117_n158: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t117_n160;
  t117_n159: return 0.07131265103816986;
  t117_n160: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t117_n162;
  t117_n161: return 0.1253790408372879;
  t117_n162: return 0.06563864648342133;
  t117_n163: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t117_n165;
  t117_n164: return -0.14514237642288208;
  t117_n165: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t117_n181;
  t117_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n176;
  t117_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t117_n169;
  t117_n168: return 0.01678081788122654;
  t117_n169: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t117_n175;
  t117_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n172;
  t117_n171: return 0.11766556650400162;
  t117_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t117_n174;
  t117_n173: return 0.06828994303941727;
  t117_n174: return 0.017045272514224052;
  t117_n175: return -0.1068769097328186;
  t117_n176: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t117_n180;
  t117_n177: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t117_n179;
  t117_n178: return 0.05874117836356163;
  t117_n179: return 0.0038949844893068075;
  t117_n180: return 0.04530695825815201;
  t117_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t117_n197;
  t117_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n192;
  t117_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t117_n189;
  t117_n184: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t117_n188;
  t117_n185: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t117_n187;
  t117_n186: return 0.05272065848112106;
  t117_n187: return 0.08760230988264084;
  t117_n188: return 0.015415901318192482;
  t117_n189: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t117_n191;
  t117_n190: return 0.08654134720563889;
  t117_n191: return 0.10204149782657623;
  t117_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t117_n194;
  t117_n193: return 0.05464540421962738;
  t117_n194: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t117_n196;
  t117_n195: return 0.09228751063346863;
  t117_n196: return 0.05856413021683693;
  t117_n197: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t117_n199;
  t117_n198: return -0.48829278349876404;
  t117_n199: return 0.0791824534535408;
  t117_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t117_n202;
  t117_n201: return -0.0033793780021369457;
  t117_n202: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t117_n236;
  t117_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t117_n205;
  t117_n204: return -0.10493304580450058;
  t117_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n215;
  t117_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t117_n208;
  t117_n207: return 0.043948907405138016;
  t117_n208: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t117_n214;
  t117_n209: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t117_n211;
  t117_n210: return -0.1082763597369194;
  t117_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t117_n213;
  t117_n212: return 0.10775347799062729;
  t117_n213: return 0.11732577532529831;
  t117_n214: return 0.17318879067897797;
  t117_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t117_n235;
  t117_n216: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t117_n224;
  t117_n217: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t117_n219;
  t117_n218: return 0.05666393041610718;
  t117_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n221;
  t117_n220: return -0.2925950884819031;
  t117_n221: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t117_n223;
  t117_n222: return -0.11537104099988937;
  t117_n223: return 0.11785241216421127;
  t117_n224: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t117_n232;
  t117_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t117_n227;
  t117_n226: return 0.07410643994808197;
  t117_n227: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t117_n231;
  t117_n228: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t117_n230;
  t117_n229: return 0.05707468464970589;
  t117_n230: return 0.11625943332910538;
  t117_n231: return 0.10651259869337082;
  t117_n232: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t117_n234;
  t117_n233: return 0.011081867851316929;
  t117_n234: return 0.10344342887401581;
  t117_n235: return 0.041815903037786484;
  t117_n236: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t117_n238;
  t117_n237: return 0.0011512425262480974;
  t117_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t117_n252;
  t117_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t117_n247;
  t117_n240: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t117_n244;
  t117_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t117_n243;
  t117_n242: return -0.19879376888275146;
  t117_n243: return 0.07299237698316574;
  t117_n244: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t117_n246;
  t117_n245: return -0.20096111297607422;
  t117_n246: return 0.12253524363040924;
  t117_n247: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t117_n249;
  t117_n248: return 0.10540606826543808;
  t117_n249: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t117_n251;
  t117_n250: return 0.06916607916355133;
  t117_n251: return -0.20177848637104034;
  t117_n252: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t117_n254;
  t117_n253: return 0.01062485110014677;
  t117_n254: return -0.29301878809928894;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree118(const Example& E) {
  t118_n0: if (E.getNumReferences() >= 3326663680 /*12855.0*/) goto t118_n228;
  t118_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t118_n73;
  t118_n2: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t118_n6;
  t118_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t118_n5;
  t118_n4: return 0.008813892491161823;
  t118_n5: return -0.004455797374248505;
  t118_n6: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t118_n20;
  t118_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t118_n11;
  t118_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t118_n10;
  t118_n9: return 0.00981551967561245;
  t118_n10: return 0.025349218398332596;
  t118_n11: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t118_n15;
  t118_n12: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t118_n14;
  t118_n13: return -0.1372603476047516;
  t118_n14: return 0.10658054798841476;
  t118_n15: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t118_n17;
  t118_n16: return 0.048506226390600204;
  t118_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t118_n19;
  t118_n18: return 0.25934943556785583;
  t118_n19: return 0.00705204252153635;
  t118_n20: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t118_n22;
  t118_n21: return 0.11044688522815704;
  t118_n22: if (E.getNumReferences() >= 3319647232 /*7097.5*/) goto t118_n60;
  t118_n23: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t118_n57;
  t118_n24: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t118_n30;
  t118_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t118_n29;
  t118_n26: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t118_n28;
  t118_n27: return -0.04948277026414871;
  t118_n28: return 0.004917928017675877;
  t118_n29: return 0.03702174127101898;
  t118_n30: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t118_n50;
  t118_n31: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t118_n33;
  t118_n32: return 0.07715199887752533;
  t118_n33: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t118_n49;
  t118_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t118_n36;
  t118_n35: return 0.0891265794634819;
  t118_n36: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t118_n48;
  t118_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t118_n45;
  t118_n38: if (E.getNumReferences() >= 3280551936 /*274.5*/) goto t118_n44;
  t118_n39: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t118_n43;
  t118_n40: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t118_n42;
  t118_n41: return 0.15378323197364807;
  t118_n42: return 0.050687164068222046;
  t118_n43: return 0.12276605516672134;
  t118_n44: return 0.09754334390163422;
  t118_n45: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t118_n47;
  t118_n46: return 0.08803266286849976;
  t118_n47: return 0.12451596558094025;
  t118_n48: return 0.05658352002501488;
  t118_n49: return 0.06104641780257225;
  t118_n50: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t118_n52;
  t118_n51: return 0.024967852979898453;
  t118_n52: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t118_n56;
  t118_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t118_n55;
  t118_n54: return 0.10946809500455856;
  t118_n55: return -0.204900860786438;
  t118_n56: return -0.1653704047203064;
  t118_n57: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t118_n59;
  t118_n58: return 0.027295725420117378;
  t118_n59: return 0.04367908835411072;
  t118_n60: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t118_n72;
  t118_n61: if (E.getNumReferences() >= 3319813120 /*7178.5*/) goto t118_n67;
  t118_n62: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t118_n66;
  t118_n63: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t118_n65;
  t118_n64: return 0.11092821508646011;
  t118_n65: return 0.0487385131418705;
  t118_n66: return 0.003724399022758007;
  t118_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t118_n69;
  t118_n68: return -0.2130768597126007;
  t118_n69: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t118_n71;
  t118_n70: return 0.11107797920703888;
  t118_n71: return 0.09241697192192078;
  t118_n72: return 0.0538821667432785;
  t118_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t118_n75;
  t118_n74: return -0.00029140725382603705;
  t118_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t118_n77;
  t118_n76: return -0.03409666195511818;
  t118_n77: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t118_n147;
  t118_n78: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t118_n106;
  t118_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t118_n81;
  t118_n80: return -0.06014958769083023;
  t118_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t118_n83;
  t118_n82: return 0.005980978719890118;
  t118_n83: if (E.getNumReferences() >= 3326358528 /*12557.0*/) goto t118_n103;
  t118_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t118_n100;
  t118_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t118_n87;
  t118_n86: return 0.020877448841929436;
  t118_n87: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t118_n89;
  t118_n88: return 0.03225495666265488;
  t118_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t118_n91;
  t118_n90: return 0.07340915501117706;
  t118_n91: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t118_n99;
  t118_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t118_n94;
  t118_n93: return 0.6714432239532471;
  t118_n94: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t118_n96;
  t118_n95: return 0.10469558835029602;
  t118_n96: if (E.getNumReferences() >= 3281387520 /*300.0*/) goto t118_n98;
  t118_n97: return 0.40318959951400757;
  t118_n98: return 0.16106769442558289;
  t118_n99: return 0.1534224897623062;
  t118_n100: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t118_n102;
  t118_n101: return 0.025558246299624443;
  t118_n102: return 0.07364863157272339;
  t118_n103: if (E.getNumReferences() >= 3326422016 /*12619.0*/) goto t118_n105;
  t118_n104: return 0.11768218874931335;
  t118_n105: return 0.35770490765571594;
  t118_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t118_n122;
  t118_n107: if (E.getNumReferences() >= 3281829888 /*313.5*/) goto t118_n119;
  t118_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t118_n110;
  t118_n109: return -0.0908157154917717;
  t118_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t118_n118;
  t118_n111: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t118_n113;
  t118_n112: return 0.006041351705789566;
  t118_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t118_n117;
  t118_n114: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t118_n116;
  t118_n115: return 0.13916151225566864;
  t118_n116: return 0.0702851414680481;
  t118_n117: return -0.6602993011474609;
  t118_n118: return -0.14572398364543915;
  t118_n119: if (E.getNumReferences() >= 3282157568 /*323.5*/) goto t118_n121;
  t118_n120: return 0.1195901483297348;
  t118_n121: return -0.022094568237662315;
  t118_n122: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t118_n146;
  t118_n123: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t118_n129;
  t118_n124: if (E.getNumReferences() >= 3276144640 /*198.0*/) goto t118_n128;
  t118_n125: if (E.getNumReferences() >= 3274375168 /*171.0*/) goto t118_n127;
  t118_n126: return 0.030894450843334198;
  t118_n127: return 0.09772448241710663;
  t118_n128: return -0.23181003332138062;
  t118_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t118_n131;
  t118_n130: return -0.01166196446865797;
  t118_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t118_n137;
  t118_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t118_n134;
  t118_n133: return 0.01815449260175228;
  t118_n134: if (E.getNumReferences() >= 3293626368 /*835.0*/) goto t118_n136;
  t118_n135: return 0.11426651477813721;
  t118_n136: return -0.020585540682077408;
  t118_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t118_n139;
  t118_n138: return 0.09065687656402588;
  t118_n139: if (E.getNumReferences() >= 3256614912 /*39.0*/) goto t118_n141;
  t118_n140: return -0.018791818991303444;
  t118_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n145;
  t118_n142: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t118_n144;
  t118_n143: return 0.10511317849159241;
  t118_n144: return 0.10873588174581528;
  t118_n145: return 0.15018628537654877;
  t118_n146: return -0.11852744966745377;
  t118_n147: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t118_n149;
  t118_n148: return -0.06501361727714539;
  t118_n149: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t118_n151;
  t118_n150: return -0.03629907965660095;
  t118_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t118_n209;
  t118_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t118_n154;
  t118_n153: return -0.36782392859458923;
  t118_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t118_n156;
  t118_n155: return -0.0004780296585522592;
  t118_n156: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t118_n158;
  t118_n157: return -0.0526997409760952;
  t118_n158: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t118_n192;
  t118_n159: if (E.getNumReferences() >= 3326102016 /*12306.5*/) goto t118_n189;
  t118_n160: if (E.getNumReferences() >= 3289284608 /*570.0*/) goto t118_n172;
  t118_n161: if (E.getNumReferences() >= 3280551936 /*274.5*/) goto t118_n171;
  t118_n162: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n170;
  t118_n163: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t118_n165;
  t118_n164: return 0.02775774896144867;
  t118_n165: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t118_n167;
  t118_n166: return 0.11161285638809204;
  t118_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t118_n169;
  t118_n168: return -0.24901629984378815;
  t118_n169: return 0.07662933319807053;
  t118_n170: return -0.09548220783472061;
  t118_n171: return -0.12383008003234863;
  t118_n172: if (E.getNumReferences() >= 3293069312 /*801.0*/) goto t118_n182;
  t118_n173: if (E.getNumReferences() >= 3292192768 /*747.5*/) goto t118_n181;
  t118_n174: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t118_n176;
  t118_n175: return -0.036423586308956146;
  t118_n176: if (E.getNumReferences() >= 3290480640 /*643.0*/) goto t118_n180;
  t118_n177: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t118_n179;
  t118_n178: return 0.1162264421582222;
  t118_n179: return 0.09013713151216507;
  t118_n180: return 0.06116314232349396;
  t118_n181: return 0.10376159101724625;
  t118_n182: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n184;
  t118_n183: return 0.003754277480766177;
  t118_n184: if (E.getNumReferences() >= 3316855808 /*5734.5*/) goto t118_n188;
  t118_n185: if (E.getNumReferences() >= 3314754560 /*4708.5*/) goto t118_n187;
  t118_n186: return 0.07590613514184952;
  t118_n187: return 0.13562436401844025;
  t118_n188: return 0.037133049219846725;
  t118_n189: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t118_n191;
  t118_n190: return 0.11279448121786118;
  t118_n191: return -0.011394676752388477;
  t118_n192: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t118_n206;
  t118_n193: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t118_n199;
  t118_n194: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t118_n198;
  t118_n195: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t118_n197;
  t118_n196: return 0.021849697455763817;
  t118_n197: return 0.22660233080387115;
  t118_n198: return -0.07446306198835373;
  t118_n199: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t118_n205;
  t118_n200: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t118_n204;
  t118_n201: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t118_n203;
  t118_n202: return 0.1169624775648117;
  t118_n203: return 0.11849658191204071;
  t118_n204: return 0.09597093611955643;
  t118_n205: return 0.10122110694646835;
  t118_n206: if (E.getNumReferences() >= 3325940736 /*12149.0*/) goto t118_n208;
  t118_n207: return 0.021371984854340553;
  t118_n208: return -0.3908306658267975;
  t118_n209: if (E.getNumReferences() >= 3307579392 /*2650.5*/) goto t118_n217;
  t118_n210: if (E.getNumReferences() >= 3283140608 /*353.5*/) goto t118_n212;
  t118_n211: return 0.06842711567878723;
  t118_n212: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t118_n214;
  t118_n213: return -0.10689559578895569;
  t118_n214: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t118_n216;
  t118_n215: return 0.11973344534635544;
  t118_n216: return 0.03538462147116661;
  t118_n217: if (E.getNumReferences() >= 3310143488 /*3276.5*/) goto t118_n221;
  t118_n218: if (E.getNumReferences() >= 3309223936 /*3052.0*/) goto t118_n220;
  t118_n219: return 0.08247756212949753;
  t118_n220: return 0.11286861449480057;
  t118_n221: if (E.getNumReferences() >= 3325050880 /*11280.0*/) goto t118_n227;
  t118_n222: if (E.getNumReferences() >= 3322876928 /*9157.0*/) goto t118_n226;
  t118_n223: if (E.getNumReferences() >= 3322330112 /*8623.0*/) goto t118_n225;
  t118_n224: return 0.09703976660966873;
  t118_n225: return 0.1365666538476944;
  t118_n226: return 0.01763412170112133;
  t118_n227: return 0.11357587575912476;
  t118_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t118_n230;
  t118_n229: return 0.0029706789646297693;
  t118_n230: if (E.getNumReferences() >= 3327319040 /*13495.0*/) goto t118_n252;
  t118_n231: if (E.getNumReferences() >= 3327291904 /*13468.5*/) goto t118_n251;
  t118_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t118_n240;
  t118_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t118_n239;
  t118_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t118_n236;
  t118_n235: return 0.06015996262431145;
  t118_n236: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t118_n238;
  t118_n237: return 0.10588925331830978;
  t118_n238: return -0.01354050263762474;
  t118_n239: return -0.4640491306781769;
  t118_n240: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t118_n250;
  t118_n241: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t118_n249;
  t118_n242: if (E.getNumReferences() >= 3326945792 /*13130.5*/) goto t118_n248;
  t118_n243: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t118_n247;
  t118_n244: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t118_n246;
  t118_n245: return 0.05963708087801933;
  t118_n246: return 0.10309398919343948;
  t118_n247: return -0.09578441083431244;
  t118_n248: return 0.004259220324456692;
  t118_n249: return 0.09853137284517288;
  t118_n250: return 0.12132924050092697;
  t118_n251: return 0.2794002592563629;
  t118_n252: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t118_n254;
  t118_n253: return 0.014615865424275398;
  t118_n254: return -0.3203522562980652;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree119(const Example& E) {
  t119_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t119_n232;
  t119_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t119_n3;
  t119_n2: return -0.08368232101202011;
  t119_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t119_n151;
  t119_n4: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t119_n54;
  t119_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t119_n7;
  t119_n6: return 0.0059097143821418285;
  t119_n7: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t119_n13;
  t119_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t119_n10;
  t119_n9: return 0.0006743604899384081;
  t119_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t119_n12;
  t119_n11: return 0.07651519775390625;
  t119_n12: return -0.015455747954547405;
  t119_n13: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t119_n31;
  t119_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n18;
  t119_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t119_n17;
  t119_n16: return 0.08815103769302368;
  t119_n17: return 0.1245064064860344;
  t119_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t119_n20;
  t119_n19: return 0.11373381316661835;
  t119_n20: if (E.getNumReferences() >= 3288834048 /*542.5*/) goto t119_n28;
  t119_n21: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n23;
  t119_n22: return 0.04673929512500763;
  t119_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t119_n25;
  t119_n24: return 0.09726834297180176;
  t119_n25: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t119_n27;
  t119_n26: return 0.11278121918439865;
  t119_n27: return 0.12714868783950806;
  t119_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t119_n30;
  t119_n29: return 0.07269325852394104;
  t119_n30: return 0.12096067517995834;
  t119_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t119_n33;
  t119_n32: return 0.050599001348018646;
  t119_n33: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t119_n43;
  t119_n34: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t119_n36;
  t119_n35: return 0.04713740199804306;
  t119_n36: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t119_n42;
  t119_n37: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t119_n39;
  t119_n38: return 0.07611840963363647;
  t119_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n41;
  t119_n40: return -0.22943854331970215;
  t119_n41: return 0.1515735238790512;
  t119_n42: return 0.13534995913505554;
  t119_n43: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t119_n45;
  t119_n44: return -0.0642678439617157;
  t119_n45: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t119_n49;
  t119_n46: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t119_n48;
  t119_n47: return 0.08786381036043167;
  t119_n48: return 0.12260088324546814;
  t119_n49: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t119_n53;
  t119_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n52;
  t119_n51: return 0.10123966634273529;
  t119_n52: return 0.0702512338757515;
  t119_n53: return -0.008419912308454514;
  t119_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t119_n56;
  t119_n55: return -0.0289535541087389;
  t119_n56: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t119_n72;
  t119_n57: if (E.getNumReferences() >= 3310407680 /*3341.0*/) goto t119_n71;
  t119_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n60;
  t119_n59: return -0.01432056725025177;
  t119_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t119_n64;
  t119_n61: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t119_n63;
  t119_n62: return -0.023590756580233574;
  t119_n63: return 0.0171373151242733;
  t119_n64: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t119_n70;
  t119_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t119_n67;
  t119_n66: return -0.131847083568573;
  t119_n67: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t119_n69;
  t119_n68: return 0.02586863376200199;
  t119_n69: return -0.11445274204015732;
  t119_n70: return -0.02822856418788433;
  t119_n71: return 0.023558620363473892;
  t119_n72: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t119_n76;
  t119_n73: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t119_n75;
  t119_n74: return 0.013722056522965431;
  t119_n75: return -0.058147333562374115;
  t119_n76: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t119_n78;
  t119_n77: return -0.007446447387337685;
  t119_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t119_n80;
  t119_n79: return 0.002117577474564314;
  t119_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t119_n96;
  t119_n81: if (E.getNumReferences() >= 3283075072 /*351.5*/) goto t119_n91;
  t119_n82: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t119_n90;
  t119_n83: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t119_n89;
  t119_n84: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t119_n88;
  t119_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t119_n87;
  t119_n86: return 0.042672932147979736;
  t119_n87: return 0.04898682236671448;
  t119_n88: return -0.12040358781814575;
  t119_n89: return 0.04461628198623657;
  t119_n90: return -0.049301356077194214;
  t119_n91: if (E.getNumReferences() >= 3283107840 /*352.5*/) goto t119_n95;
  t119_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t119_n94;
  t119_n93: return 0.12389284372329712;
  t119_n94: return -0.10222271829843521;
  t119_n95: return 0.04521864652633667;
  t119_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t119_n98;
  t119_n97: return -0.10866522043943405;
  t119_n98: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t119_n150;
  t119_n99: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t119_n111;
  t119_n100: if (E.getNumReferences() >= 3286712320 /*462.5*/) goto t119_n102;
  t119_n101: return 0.06224014610052109;
  t119_n102: if (E.getNumReferences() >= 3287318528 /*481.0*/) goto t119_n104;
  t119_n103: return 0.12236981093883514;
  t119_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t119_n106;
  t119_n105: return 0.025570763275027275;
  t119_n106: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t119_n110;
  t119_n107: if (E.getNumReferences() >= 3299962880 /*1419.5*/) goto t119_n109;
  t119_n108: return 0.11836866289377213;
  t119_n109: return 0.07487404346466064;
  t119_n110: return 0.034864820539951324;
  t119_n111: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t119_n149;
  t119_n112: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t119_n144;
  t119_n113: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n143;
  t119_n114: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t119_n122;
  t119_n115: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t119_n117;
  t119_n116: return 0.0975308045744896;
  t119_n117: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t119_n119;
  t119_n118: return 0.009906069375574589;
  t119_n119: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t119_n121;
  t119_n120: return 0.09420853108167648;
  t119_n121: return 0.009428651072084904;
  t119_n122: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t119_n142;
  t119_n123: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t119_n131;
  t119_n124: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t119_n130;
  t119_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t119_n129;
  t119_n126: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t119_n128;
  t119_n127: return 0.1385149508714676;
  t119_n128: return 0.08573047816753387;
  t119_n129: return 0.12233884632587433;
  t119_n130: return 0.007401027716696262;
  t119_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t119_n139;
  t119_n132: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t119_n134;
  t119_n133: return 0.062471531331539154;
  t119_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n138;
  t119_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t119_n137;
  t119_n136: return 0.1140805333852768;
  t119_n137: return 0.12391635030508041;
  t119_n138: return 0.17225034534931183;
  t119_n139: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n141;
  t119_n140: return 0.14514626562595367;
  t119_n141: return 0.1645526885986328;
  t119_n142: return -0.05554990842938423;
  t119_n143: return 0.052207838743925095;
  t119_n144: if (E.getNumReferences() >= 3312433152 /*3835.5*/) goto t119_n146;
  t119_n145: return -0.009851234033703804;
  t119_n146: if (E.getNumReferences() >= 3312824320 /*3931.0*/) goto t119_n148;
  t119_n147: return 0.10180730372667313;
  t119_n148: return 0.0781218409538269;
  t119_n149: return -0.10411331802606583;
  t119_n150: return 0.0055674174800515175;
  t119_n151: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t119_n177;
  t119_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t119_n164;
  t119_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t119_n163;
  t119_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n158;
  t119_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t119_n157;
  t119_n156: return -0.0874096006155014;
  t119_n157: return -0.014483263716101646;
  t119_n158: if (E.getNumReferences() >= 3291414528 /*700.0*/) goto t119_n160;
  t119_n159: return -0.02694448083639145;
  t119_n160: if (E.getNumReferences() >= 3292438528 /*762.5*/) goto t119_n162;
  t119_n161: return 0.13632509112358093;
  t119_n162: return -0.006801556330174208;
  t119_n163: return 0.00796998105943203;
  t119_n164: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n176;
  t119_n165: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n171;
  t119_n166: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n168;
  t119_n167: return 0.08451105654239655;
  t119_n168: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t119_n170;
  t119_n169: return 0.0807809829711914;
  t119_n170: return -0.1588355004787445;
  t119_n171: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t119_n173;
  t119_n172: return 0.03031376376748085;
  t119_n173: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t119_n175;
  t119_n174: return 0.07636731117963791;
  t119_n175: return -0.13260450959205627;
  t119_n176: return -0.02397395856678486;
  t119_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t119_n201;
  t119_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t119_n186;
  t119_n179: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n185;
  t119_n180: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t119_n184;
  t119_n181: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t119_n183;
  t119_n182: return -0.032753318548202515;
  t119_n183: return 0.1063629612326622;
  t119_n184: return -0.023107165470719337;
  t119_n185: return -0.04030613973736763;
  t119_n186: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t119_n188;
  t119_n187: return -0.06691868603229523;
  t119_n188: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t119_n190;
  t119_n189: return 0.0019041515188291669;
  t119_n190: if (E.getNumReferences() >= 3333190144 /*22073.0*/) goto t119_n192;
  t119_n191: return 0.07211173325777054;
  t119_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n194;
  t119_n193: return 0.008774415589869022;
  t119_n194: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t119_n200;
  t119_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t119_n197;
  t119_n196: return 0.028570514172315598;
  t119_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n199;
  t119_n198: return 0.08369462937116623;
  t119_n199: return 0.01860407181084156;
  t119_n200: return 0.0064019509591162205;
  t119_n201: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t119_n205;
  t119_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t119_n204;
  t119_n203: return -0.066767618060112;
  t119_n204: return 0.006491901818662882;
  t119_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t119_n219;
  t119_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t119_n208;
  t119_n207: return 0.004431404173374176;
  t119_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n212;
  t119_n209: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t119_n211;
  t119_n210: return 0.03360496461391449;
  t119_n211: return 0.03437560796737671;
  t119_n212: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n216;
  t119_n213: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t119_n215;
  t119_n214: return 0.017077088356018066;
  t119_n215: return 0.08726978302001953;
  t119_n216: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n218;
  t119_n217: return -0.02178242988884449;
  t119_n218: return 0.003296775044873357;
  t119_n219: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t119_n231;
  t119_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t119_n230;
  t119_n221: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t119_n225;
  t119_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n224;
  t119_n223: return 0.10537099093198776;
  t119_n224: return 0.07580988854169846;
  t119_n225: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t119_n229;
  t119_n226: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t119_n228;
  t119_n227: return 0.11023791879415512;
  t119_n228: return 0.05206086114048958;
  t119_n229: return 0.08104458451271057;
  t119_n230: return 0.07408168166875839;
  t119_n231: return -0.048481062054634094;
  t119_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t119_n236;
  t119_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t119_n235;
  t119_n234: return -0.29013216495513916;
  t119_n235: return 0.0054184976033866405;
  t119_n236: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t119_n242;
  t119_n237: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t119_n241;
  t119_n238: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t119_n240;
  t119_n239: return -0.11665145307779312;
  t119_n240: return 0.0914924219250679;
  t119_n241: return -0.7106292843818665;
  t119_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t119_n244;
  t119_n243: return -0.12035848200321198;
  t119_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t119_n254;
  t119_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t119_n251;
  t119_n246: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t119_n248;
  t119_n247: return 0.014660126529633999;
  t119_n248: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t119_n250;
  t119_n249: return 0.06525640934705734;
  t119_n250: return 0.10126413404941559;
  t119_n251: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t119_n253;
  t119_n252: return 0.10471587628126144;
  t119_n253: return 0.0928502306342125;
  t119_n254: return 0.033176589757204056;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree120(const Example& E) {
  t120_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t120_n230;
  t120_n1: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t120_n167;
  t120_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t120_n4;
  t120_n3: return -0.0018479072023183107;
  t120_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t120_n154;
  t120_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t120_n121;
  t120_n6: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t120_n112;
  t120_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t120_n25;
  t120_n8: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n12;
  t120_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t120_n11;
  t120_n10: return -0.07208352535963058;
  t120_n11: return -0.004859523382037878;
  t120_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n14;
  t120_n13: return -0.017543643712997437;
  t120_n14: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n24;
  t120_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t120_n21;
  t120_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t120_n20;
  t120_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t120_n19;
  t120_n18: return -0.15574558079242706;
  t120_n19: return -0.3764133155345917;
  t120_n20: return 0.07249245792627335;
  t120_n21: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t120_n23;
  t120_n22: return 0.09605144709348679;
  t120_n23: return 0.12000320851802826;
  t120_n24: return -0.018199052661657333;
  t120_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t120_n91;
  t120_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t120_n28;
  t120_n27: return -0.025444669649004936;
  t120_n28: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t120_n30;
  t120_n29: return -0.001676475745625794;
  t120_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n76;
  t120_n31: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n75;
  t120_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t120_n50;
  t120_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n47;
  t120_n34: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t120_n46;
  t120_n35: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t120_n41;
  t120_n36: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t120_n38;
  t120_n37: return 0.027955397963523865;
  t120_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n40;
  t120_n39: return 0.08588802069425583;
  t120_n40: return -0.027408583089709282;
  t120_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n45;
  t120_n42: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t120_n44;
  t120_n43: return 0.12428901344537735;
  t120_n44: return 0.10975395888090134;
  t120_n45: return 0.00036917137913405895;
  t120_n46: return 0.0219903364777565;
  t120_n47: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t120_n49;
  t120_n48: return 0.09341812878847122;
  t120_n49: return 0.021439313888549805;
  t120_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n52;
  t120_n51: return -0.059933654963970184;
  t120_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t120_n74;
  t120_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t120_n71;
  t120_n54: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t120_n56;
  t120_n55: return -0.37892812490463257;
  t120_n56: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t120_n58;
  t120_n57: return 0.10259576886892319;
  t120_n58: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t120_n60;
  t120_n59: return -0.03999272361397743;
  t120_n60: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t120_n62;
  t120_n61: return 0.09768949449062347;
  t120_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n64;
  t120_n63: return -0.13378335535526276;
  t120_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n70;
  t120_n65: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t120_n67;
  t120_n66: return 0.08537545055150986;
  t120_n67: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t120_n69;
  t120_n68: return -0.0053179142996668816;
  t120_n69: return 0.11812304705381393;
  t120_n70: return 0.07574526220560074;
  t120_n71: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t120_n73;
  t120_n72: return 0.05839142948389053;
  t120_n73: return 0.10823224484920502;
  t120_n74: return -0.03699526935815811;
  t120_n75: return -0.01602153666317463;
  t120_n76: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t120_n86;
  t120_n77: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t120_n83;
  t120_n78: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t120_n80;
  t120_n79: return -0.03382200747728348;
  t120_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n82;
  t120_n81: return -0.13605482876300812;
  t120_n82: return 0.11663958430290222;
  t120_n83: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t120_n85;
  t120_n84: return 0.11296091973781586;
  t120_n85: return 0.08183750510215759;
  t120_n86: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t120_n88;
  t120_n87: return -0.030233316123485565;
  t120_n88: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t120_n90;
  t120_n89: return -0.2189343273639679;
  t120_n90: return -0.0017865264089778066;
  t120_n91: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n111;
  t120_n92: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t120_n110;
  t120_n93: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n109;
  t120_n94: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n96;
  t120_n95: return 0.05839492753148079;
  t120_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n98;
  t120_n97: return 0.006333892233669758;
  t120_n98: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t120_n108;
  t120_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n105;
  t120_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t120_n104;
  t120_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n103;
  t120_n102: return 0.10722570866346359;
  t120_n103: return 0.10348476469516754;
  t120_n104: return 0.08462608605623245;
  t120_n105: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t120_n107;
  t120_n106: return 0.002971793757751584;
  t120_n107: return 0.0967206135392189;
  t120_n108: return -0.13129979372024536;
  t120_n109: return 0.03278029337525368;
  t120_n110: return -0.07339786738157272;
  t120_n111: return -0.027242233976721764;
  t120_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n120;
  t120_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n119;
  t120_n114: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t120_n116;
  t120_n115: return 0.028971469029784203;
  t120_n116: if (E.getNumReferences() >= 3275325440 /*185.5*/) goto t120_n118;
  t120_n117: return 0.17112332582473755;
  t120_n118: return -0.5840075612068176;
  t120_n119: return 0.0262122955173254;
  t120_n120: return -0.04572742432355881;
  t120_n121: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t120_n123;
  t120_n122: return -0.004067303147166967;
  t120_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n153;
  t120_n124: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t120_n146;
  t120_n125: if (E.getNumReferences() >= 3292086272 /*741.0*/) goto t120_n145;
  t120_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n130;
  t120_n127: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t120_n129;
  t120_n128: return 0.09434956312179565;
  t120_n129: return -0.15151894092559814;
  t120_n130: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t120_n136;
  t120_n131: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t120_n133;
  t120_n132: return -0.003968546167016029;
  t120_n133: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t120_n135;
  t120_n134: return 0.1129620149731636;
  t120_n135: return 0.0457441583275795;
  t120_n136: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t120_n144;
  t120_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n139;
  t120_n138: return 0.034896619617938995;
  t120_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n141;
  t120_n140: return 0.055127136409282684;
  t120_n141: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t120_n143;
  t120_n142: return 0.10213568061590195;
  t120_n143: return 0.12004516273736954;
  t120_n144: return 0.011731973849236965;
  t120_n145: return 0.08691812306642532;
  t120_n146: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t120_n150;
  t120_n147: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t120_n149;
  t120_n148: return -0.0060467179864645;
  t120_n149: return 0.09290796518325806;
  t120_n150: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n152;
  t120_n151: return 0.02969115413725376;
  t120_n152: return 0.04323728382587433;
  t120_n153: return 0.02039957605302334;
  t120_n154: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t120_n156;
  t120_n155: return 0.06029253453016281;
  t120_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t120_n160;
  t120_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n159;
  t120_n158: return 0.0944695770740509;
  t120_n159: return -0.09528782218694687;
  t120_n160: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t120_n166;
  t120_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n163;
  t120_n162: return 0.12947039306163788;
  t120_n163: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t120_n165;
  t120_n164: return 0.08186306059360504;
  t120_n165: return 0.12464483082294464;
  t120_n166: return 0.08722574263811111;
  t120_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t120_n227;
  t120_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t120_n224;
  t120_n169: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t120_n173;
  t120_n170: if (E.getNumReferences() >= 3354165120 /*121087.0*/) goto t120_n172;
  t120_n171: return 0.008673684671521187;
  t120_n172: return -0.438306599855423;
  t120_n173: if (E.getNumReferences() >= 3356582432 /*148872.5*/) goto t120_n177;
  t120_n174: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n176;
  t120_n175: return 0.10905773937702179;
  t120_n176: return 0.038543619215488434;
  t120_n177: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t120_n191;
  t120_n178: if (E.getNumReferences() >= 3360096736 /*203783.5*/) goto t120_n180;
  t120_n179: return 0.0013266172027215362;
  t120_n180: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t120_n184;
  t120_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n183;
  t120_n182: return 0.03497501462697983;
  t120_n183: return -0.2998804450035095;
  t120_n184: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t120_n188;
  t120_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n187;
  t120_n186: return 0.05076202005147934;
  t120_n187: return -0.27877554297447205;
  t120_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n190;
  t120_n189: return 0.07733647525310516;
  t120_n190: return 0.0865892767906189;
  t120_n191: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t120_n211;
  t120_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t120_n194;
  t120_n193: return -0.09183484315872192;
  t120_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t120_n208;
  t120_n195: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t120_n197;
  t120_n196: return -0.7563222050666809;
  t120_n197: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t120_n203;
  t120_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t120_n202;
  t120_n199: if (E.getNumReferences() >= 3362887008 /*247381.5*/) goto t120_n201;
  t120_n200: return 0.05256318673491478;
  t120_n201: return -0.2505616247653961;
  t120_n202: return -0.8039416074752808;
  t120_n203: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t120_n207;
  t120_n204: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t120_n206;
  t120_n205: return 0.10732876509428024;
  t120_n206: return 0.06386164575815201;
  t120_n207: return -0.1285344958305359;
  t120_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t120_n210;
  t120_n209: return -0.11319008469581604;
  t120_n210: return 0.014427142217755318;
  t120_n211: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t120_n215;
  t120_n212: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t120_n214;
  t120_n213: return -0.14910481870174408;
  t120_n214: return -0.38791555166244507;
  t120_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t120_n221;
  t120_n216: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t120_n218;
  t120_n217: return -0.25990962982177734;
  t120_n218: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t120_n220;
  t120_n219: return 0.07601949572563171;
  t120_n220: return -0.028281722217798233;
  t120_n221: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t120_n223;
  t120_n222: return -0.20468683540821075;
  t120_n223: return 0.11132701486349106;
  t120_n224: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t120_n226;
  t120_n225: return 0.026827316731214523;
  t120_n226: return -0.36314263939857483;
  t120_n227: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t120_n229;
  t120_n228: return -0.010091566480696201;
  t120_n229: return 0.009399627335369587;
  t120_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t120_n234;
  t120_n231: if (E.getNumReferences() >= 3333877504 /*23415.5*/) goto t120_n233;
  t120_n232: return -0.004786872770637274;
  t120_n233: return -0.21210457384586334;
  t120_n234: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t120_n250;
  t120_n235: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t120_n237;
  t120_n236: return 0.006775474641472101;
  t120_n237: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t120_n243;
  t120_n238: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t120_n240;
  t120_n239: return 0.03821006044745445;
  t120_n240: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t120_n242;
  t120_n241: return 0.10676880925893784;
  t120_n242: return -0.12504830956459045;
  t120_n243: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t120_n249;
  t120_n244: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t120_n246;
  t120_n245: return -0.1903197318315506;
  t120_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t120_n248;
  t120_n247: return -0.2535499334335327;
  t120_n248: return 0.07757803052663803;
  t120_n249: return 0.01717926561832428;
  t120_n250: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t120_n252;
  t120_n251: return -9.784966096049175e-05;
  t120_n252: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t120_n254;
  t120_n253: return 0.028064146637916565;
  t120_n254: return 0.0058842371217906475;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree121(const Example& E) {
  t121_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t121_n10;
  t121_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t121_n3;
  t121_n2: return -0.0008136239484883845;
  t121_n3: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t121_n9;
  t121_n4: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t121_n6;
  t121_n5: return 0.004330262541770935;
  t121_n6: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t121_n8;
  t121_n7: return 0.06120527535676956;
  t121_n8: return 0.11150621622800827;
  t121_n9: return -0.0923863872885704;
  t121_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t121_n22;
  t121_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t121_n21;
  t121_n12: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t121_n18;
  t121_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n17;
  t121_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t121_n16;
  t121_n15: return 0.06472869217395782;
  t121_n16: return 0.07488028705120087;
  t121_n17: return -0.6716023683547974;
  t121_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n20;
  t121_n19: return -0.22609955072402954;
  t121_n20: return 0.009677066467702389;
  t121_n21: return 0.016843924298882484;
  t121_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t121_n24;
  t121_n23: return -0.02322203479707241;
  t121_n24: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t121_n184;
  t121_n25: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t121_n135;
  t121_n26: if (E.getNumReferences() >= 3354631552 /*124731.0*/) goto t121_n134;
  t121_n27: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t121_n115;
  t121_n28: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t121_n48;
  t121_n29: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t121_n47;
  t121_n30: if (E.getNumReferences() >= 3350448512 /*92051.0*/) goto t121_n46;
  t121_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t121_n37;
  t121_n32: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t121_n34;
  t121_n33: return 0.027038993313908577;
  t121_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n36;
  t121_n35: return -0.24666623771190643;
  t121_n36: return 0.21157829463481903;
  t121_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n41;
  t121_n38: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t121_n40;
  t121_n39: return 0.10980738699436188;
  t121_n40: return -0.1068832129240036;
  t121_n41: if (E.getNumReferences() >= 3350267136 /*90634.0*/) goto t121_n45;
  t121_n42: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t121_n44;
  t121_n43: return 0.025846485048532486;
  t121_n44: return 0.07789076119661331;
  t121_n45: return -0.9663264155387878;
  t121_n46: return -0.03287314996123314;
  t121_n47: return -0.1342821717262268;
  t121_n48: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t121_n56;
  t121_n49: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t121_n51;
  t121_n50: return -0.06185571849346161;
  t121_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n53;
  t121_n52: return -0.2520313262939453;
  t121_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n55;
  t121_n54: return 0.1324869692325592;
  t121_n55: return 0.09376392513513565;
  t121_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n114;
  t121_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t121_n75;
  t121_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t121_n70;
  t121_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n61;
  t121_n60: return -0.05740068852901459;
  t121_n61: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t121_n69;
  t121_n62: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t121_n64;
  t121_n63: return 0.08846881240606308;
  t121_n64: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t121_n68;
  t121_n65: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n67;
  t121_n66: return 0.1077990010380745;
  t121_n67: return 0.10843516141176224;
  t121_n68: return 0.0561409629881382;
  t121_n69: return 0.04634026437997818;
  t121_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t121_n72;
  t121_n71: return -0.0009094633278436959;
  t121_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t121_n74;
  t121_n73: return -0.1857205480337143;
  t121_n74: return 0.06546047329902649;
  t121_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t121_n83;
  t121_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t121_n78;
  t121_n77: return 0.015834052115678787;
  t121_n78: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t121_n82;
  t121_n79: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t121_n81;
  t121_n80: return 0.10408013314008713;
  t121_n81: return 0.05321686714887619;
  t121_n82: return -0.1417713612318039;
  t121_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n85;
  t121_n84: return -0.1791583150625229;
  t121_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n111;
  t121_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n106;
  t121_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t121_n95;
  t121_n88: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t121_n90;
  t121_n89: return 0.04253807291388512;
  t121_n90: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t121_n92;
  t121_n91: return 0.11148002743721008;
  t121_n92: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t121_n94;
  t121_n93: return -0.29272690415382385;
  t121_n94: return 0.11758869141340256;
  t121_n95: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t121_n103;
  t121_n96: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t121_n102;
  t121_n97: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t121_n99;
  t121_n98: return 0.04537766054272652;
  t121_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n101;
  t121_n100: return -0.10286005586385727;
  t121_n101: return 0.1183018833398819;
  t121_n102: return 0.04269244149327278;
  t121_n103: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t121_n105;
  t121_n104: return 0.1604272425174713;
  t121_n105: return 0.1307855248451233;
  t121_n106: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t121_n110;
  t121_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t121_n109;
  t121_n108: return 0.0761164128780365;
  t121_n109: return 0.11299784481525421;
  t121_n110: return -0.1063123345375061;
  t121_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t121_n113;
  t121_n112: return 0.09216956794261932;
  t121_n113: return 0.09162356704473495;
  t121_n114: return -0.09706656634807587;
  t121_n115: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t121_n131;
  t121_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n124;
  t121_n117: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n119;
  t121_n118: return 0.11880061775445938;
  t121_n119: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t121_n121;
  t121_n120: return 0.07099207490682602;
  t121_n121: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t121_n123;
  t121_n122: return 0.14416183531284332;
  t121_n123: return -0.050913408398628235;
  t121_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t121_n128;
  t121_n125: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t121_n127;
  t121_n126: return -0.11439347267150879;
  t121_n127: return 0.10489355772733688;
  t121_n128: if (E.getNumReferences() >= 3350564160 /*92954.5*/) goto t121_n130;
  t121_n129: return 0.13999700546264648;
  t121_n130: return 0.061929695308208466;
  t121_n131: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t121_n133;
  t121_n132: return -0.1958032101392746;
  t121_n133: return 0.11129455268383026;
  t121_n134: return -0.02224287949502468;
  t121_n135: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t121_n151;
  t121_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t121_n138;
  t121_n137: return -0.11286065727472305;
  t121_n138: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t121_n150;
  t121_n139: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t121_n141;
  t121_n140: return 0.02464512176811695;
  t121_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n147;
  t121_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t121_n146;
  t121_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n145;
  t121_n144: return 0.11873649805784225;
  t121_n145: return 0.0834541916847229;
  t121_n146: return 0.10146079957485199;
  t121_n147: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n149;
  t121_n148: return 0.06413096934556961;
  t121_n149: return 0.12104043364524841;
  t121_n150: return -0.018144046887755394;
  t121_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t121_n153;
  t121_n152: return -0.0016389169031754136;
  t121_n153: if (E.getNumReferences() >= 3360662464 /*212623.0*/) goto t121_n157;
  t121_n154: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t121_n156;
  t121_n155: return -0.34024569392204285;
  t121_n156: return 0.06982045620679855;
  t121_n157: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t121_n171;
  t121_n158: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t121_n170;
  t121_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n165;
  t121_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t121_n164;
  t121_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n163;
  t121_n162: return -0.5412164330482483;
  t121_n163: return -0.2057962715625763;
  t121_n164: return -0.11200535297393799;
  t121_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n167;
  t121_n166: return -0.23994584381580353;
  t121_n167: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t121_n169;
  t121_n168: return 0.08757229149341583;
  t121_n169: return 0.014109600335359573;
  t121_n170: return 0.09727024286985397;
  t121_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t121_n173;
  t121_n172: return 0.028992824256420135;
  t121_n173: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t121_n183;
  t121_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n182;
  t121_n175: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t121_n181;
  t121_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t121_n180;
  t121_n177: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t121_n179;
  t121_n178: return -0.11376678198575974;
  t121_n179: return 0.11779148131608963;
  t121_n180: return 0.0597439780831337;
  t121_n181: return 0.06451418250799179;
  t121_n182: return -0.24703523516654968;
  t121_n183: return 0.12592624127864838;
  t121_n184: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t121_n188;
  t121_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t121_n187;
  t121_n186: return -0.1496889889240265;
  t121_n187: return -0.37038150429725647;
  t121_n188: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t121_n202;
  t121_n189: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n191;
  t121_n190: return -0.0651002749800682;
  t121_n191: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t121_n201;
  t121_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n200;
  t121_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n197;
  t121_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t121_n196;
  t121_n195: return -0.1417653113603592;
  t121_n196: return 0.14596281945705414;
  t121_n197: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t121_n199;
  t121_n198: return 0.09223441034555435;
  t121_n199: return 0.12854520976543427;
  t121_n200: return 0.094652459025383;
  t121_n201: return 0.04612626135349274;
  t121_n202: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t121_n204;
  t121_n203: return -0.12916016578674316;
  t121_n204: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t121_n232;
  t121_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t121_n207;
  t121_n206: return -0.07494128495454788;
  t121_n207: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t121_n215;
  t121_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n214;
  t121_n209: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t121_n211;
  t121_n210: return 0.0645519569516182;
  t121_n211: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t121_n213;
  t121_n212: return 0.09753041714429855;
  t121_n213: return -0.058912813663482666;
  t121_n214: return 0.05158914625644684;
  t121_n215: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t121_n221;
  t121_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n218;
  t121_n217: return -0.1017947718501091;
  t121_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n220;
  t121_n219: return 0.12631365656852722;
  t121_n220: return 0.057765062898397446;
  t121_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n231;
  t121_n222: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t121_n230;
  t121_n223: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t121_n225;
  t121_n224: return -0.02531570754945278;
  t121_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t121_n227;
  t121_n226: return -0.5223464965820312;
  t121_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n229;
  t121_n228: return -0.17357368767261505;
  t121_n229: return 0.05359027162194252;
  t121_n230: return 0.0968577116727829;
  t121_n231: return 0.17067889869213104;
  t121_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t121_n248;
  t121_n233: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t121_n235;
  t121_n234: return -0.03846646100282669;
  t121_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t121_n239;
  t121_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t121_n238;
  t121_n237: return -0.08720789849758148;
  t121_n238: return 0.009532937780022621;
  t121_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t121_n241;
  t121_n240: return 0.07080162316560745;
  t121_n241: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t121_n245;
  t121_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t121_n244;
  t121_n243: return 0.07263907045125961;
  t121_n244: return 0.11601392179727554;
  t121_n245: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t121_n247;
  t121_n246: return 0.09541334211826324;
  t121_n247: return -0.4360460042953491;
  t121_n248: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t121_n254;
  t121_n249: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t121_n253;
  t121_n250: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t121_n252;
  t121_n251: return -0.005449157208204269;
  t121_n252: return -0.21968968212604523;
  t121_n253: return 0.06720120459794998;
  t121_n254: return -0.08902497589588165;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree122(const Example& E) {
  t122_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t122_n224;
  t122_n1: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t122_n223;
  t122_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t122_n220;
  t122_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t122_n5;
  t122_n4: return -0.00337641267105937;
  t122_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t122_n27;
  t122_n6: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t122_n8;
  t122_n7: return -0.00714267510920763;
  t122_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t122_n10;
  t122_n9: return -0.002955490490421653;
  t122_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t122_n24;
  t122_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t122_n23;
  t122_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n14;
  t122_n13: return -0.09943527728319168;
  t122_n14: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t122_n22;
  t122_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t122_n17;
  t122_n16: return -0.6717197299003601;
  t122_n17: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t122_n19;
  t122_n18: return 0.04343970865011215;
  t122_n19: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t122_n21;
  t122_n20: return 0.11318942904472351;
  t122_n21: return 0.027382833883166313;
  t122_n22: return -0.10678087174892426;
  t122_n23: return -0.11919289082288742;
  t122_n24: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t122_n26;
  t122_n25: return -0.007768396288156509;
  t122_n26: return 0.1125953271985054;
  t122_n27: if (E.getNumReferences() >= 3305189376 /*2067.0*/) goto t122_n183;
  t122_n28: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t122_n56;
  t122_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n35;
  t122_n30: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n34;
  t122_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n33;
  t122_n32: return -0.05049632489681244;
  t122_n33: return 0.02280276268720627;
  t122_n34: return -0.1050126850605011;
  t122_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t122_n37;
  t122_n36: return -0.01992836780846119;
  t122_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t122_n55;
  t122_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n54;
  t122_n39: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t122_n41;
  t122_n40: return 0.03742225840687752;
  t122_n41: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t122_n43;
  t122_n42: return 0.032055992633104324;
  t122_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n53;
  t122_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n46;
  t122_n45: return -0.14418353140354156;
  t122_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n48;
  t122_n47: return 0.08994279056787491;
  t122_n48: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t122_n50;
  t122_n49: return -0.007478195242583752;
  t122_n50: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t122_n52;
  t122_n51: return 0.1088041365146637;
  t122_n52: return 0.019433530047535896;
  t122_n53: return 0.020367048680782318;
  t122_n54: return 0.0031054047867655754;
  t122_n55: return -0.0005766264512203634;
  t122_n56: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t122_n58;
  t122_n57: return 0.0016097330953925848;
  t122_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t122_n132;
  t122_n59: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t122_n113;
  t122_n60: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t122_n64;
  t122_n61: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t122_n63;
  t122_n62: return -0.03559311479330063;
  t122_n63: return 0.033557191491127014;
  t122_n64: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t122_n100;
  t122_n65: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n67;
  t122_n66: return 0.006152387708425522;
  t122_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t122_n69;
  t122_n68: return 0.07722695171833038;
  t122_n69: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t122_n95;
  t122_n70: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n90;
  t122_n71: if (E.getNumReferences() >= 3292233728 /*750.0*/) goto t122_n87;
  t122_n72: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t122_n80;
  t122_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t122_n75;
  t122_n74: return 0.031015891581773758;
  t122_n75: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t122_n77;
  t122_n76: return 0.7931569814682007;
  t122_n77: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n79;
  t122_n78: return 0.1165679544210434;
  t122_n79: return 0.10827359557151794;
  t122_n80: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t122_n82;
  t122_n81: return 0.05242413282394409;
  t122_n82: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t122_n84;
  t122_n83: return 0.032918531447649;
  t122_n84: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t122_n86;
  t122_n85: return 0.10960261523723602;
  t122_n86: return 0.05541666969656944;
  t122_n87: if (E.getNumReferences() >= 3294003200 /*858.0*/) goto t122_n89;
  t122_n88: return 0.10163227468729019;
  t122_n89: return 0.07892747968435287;
  t122_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n92;
  t122_n91: return 0.14040090143680573;
  t122_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n94;
  t122_n93: return -1.0735070705413818;
  t122_n94: return 0.11057841777801514;
  t122_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t122_n99;
  t122_n96: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t122_n98;
  t122_n97: return -0.06271082907915115;
  t122_n98: return 0.11679618060588837;
  t122_n99: return 0.1127442717552185;
  t122_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t122_n102;
  t122_n101: return 0.005813293159008026;
  t122_n102: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t122_n112;
  t122_n103: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t122_n105;
  t122_n104: return 0.0008484457503072917;
  t122_n105: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n109;
  t122_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t122_n108;
  t122_n107: return 0.06664413213729858;
  t122_n108: return -0.06389165669679642;
  t122_n109: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n111;
  t122_n110: return 0.1130666509270668;
  t122_n111: return -0.1170116513967514;
  t122_n112: return 0.11095526069402695;
  t122_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n115;
  t122_n114: return -0.10202369093894958;
  t122_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n117;
  t122_n116: return -0.04994477704167366;
  t122_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n131;
  t122_n118: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t122_n130;
  t122_n119: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t122_n123;
  t122_n120: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t122_n122;
  t122_n121: return 0.12147916853427887;
  t122_n122: return 0.06767110526561737;
  t122_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t122_n125;
  t122_n124: return -2.4678449630737305;
  t122_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t122_n127;
  t122_n126: return -0.4913688600063324;
  t122_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n129;
  t122_n128: return 0.1068556010723114;
  t122_n129: return 0.06659799069166183;
  t122_n130: return 0.11450798809528351;
  t122_n131: return 0.02210543118417263;
  t122_n132: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t122_n176;
  t122_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t122_n135;
  t122_n134: return -0.017749695107340813;
  t122_n135: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n171;
  t122_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t122_n166;
  t122_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n141;
  t122_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n140;
  t122_n139: return -0.014384492300450802;
  t122_n140: return 0.02366306632757187;
  t122_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t122_n157;
  t122_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n144;
  t122_n143: return 0.05689803883433342;
  t122_n144: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t122_n154;
  t122_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n147;
  t122_n146: return 0.08411693572998047;
  t122_n147: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t122_n149;
  t122_n148: return -0.9293398261070251;
  t122_n149: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t122_n151;
  t122_n150: return 0.11945788562297821;
  t122_n151: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t122_n153;
  t122_n152: return 0.10121826082468033;
  t122_n153: return 0.10770061612129211;
  t122_n154: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t122_n156;
  t122_n155: return -0.16368988156318665;
  t122_n156: return 0.09389559924602509;
  t122_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t122_n159;
  t122_n158: return -0.04501825198531151;
  t122_n159: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t122_n163;
  t122_n160: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t122_n162;
  t122_n161: return -0.06695260852575302;
  t122_n162: return 0.07605402916669846;
  t122_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t122_n165;
  t122_n164: return 0.15924040973186493;
  t122_n165: return 0.12300436943769455;
  t122_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n168;
  t122_n167: return 0.13843730092048645;
  t122_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n170;
  t122_n169: return 0.01110445149242878;
  t122_n170: return 0.027091018855571747;
  t122_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t122_n173;
  t122_n172: return -0.06890305876731873;
  t122_n173: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t122_n175;
  t122_n174: return 0.04273722320795059;
  t122_n175: return -0.041676148772239685;
  t122_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n182;
  t122_n177: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n181;
  t122_n178: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t122_n180;
  t122_n179: return -0.26468273997306824;
  t122_n180: return 0.09720201790332794;
  t122_n181: return -0.021195635199546814;
  t122_n182: return 0.025617223232984543;
  t122_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n187;
  t122_n184: if (E.getNumReferences() >= 3305881600 /*2236.0*/) goto t122_n186;
  t122_n185: return 0.09719738364219666;
  t122_n186: return -0.0016825146740302444;
  t122_n187: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t122_n215;
  t122_n188: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t122_n198;
  t122_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t122_n191;
  t122_n190: return 0.0795573741197586;
  t122_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n197;
  t122_n192: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n194;
  t122_n193: return 0.11495033651590347;
  t122_n194: if (E.getNumReferences() >= 3359900416 /*200716.0*/) goto t122_n196;
  t122_n195: return 0.190157949924469;
  t122_n196: return 0.10336281359195709;
  t122_n197: return 0.08167044073343277;
  t122_n198: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t122_n214;
  t122_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t122_n201;
  t122_n200: return 0.049247000366449356;
  t122_n201: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t122_n213;
  t122_n202: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t122_n204;
  t122_n203: return -0.18549659848213196;
  t122_n204: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t122_n208;
  t122_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n207;
  t122_n206: return 0.11528391391038895;
  t122_n207: return 0.10224338620901108;
  t122_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n210;
  t122_n209: return -0.10058716684579849;
  t122_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t122_n212;
  t122_n211: return 0.10524145513772964;
  t122_n212: return 0.08453644067049026;
  t122_n213: return 0.013556082732975483;
  t122_n214: return 0.013235291466116905;
  t122_n215: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t122_n217;
  t122_n216: return 0.0162896066904068;
  t122_n217: if (E.getNumReferences() >= 3342575744 /*48040.5*/) goto t122_n219;
  t122_n218: return 0.0681162178516388;
  t122_n219: return 0.11754170805215836;
  t122_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t122_n222;
  t122_n221: return -0.00567244179546833;
  t122_n222: return 0.006785525009036064;
  t122_n223: return -0.04794328287243843;
  t122_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t122_n236;
  t122_n225: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t122_n231;
  t122_n226: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t122_n230;
  t122_n227: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n229;
  t122_n228: return -0.030524635687470436;
  t122_n229: return 0.07403313368558884;
  t122_n230: return -0.01143946684896946;
  t122_n231: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t122_n235;
  t122_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t122_n234;
  t122_n233: return -0.005234685726463795;
  t122_n234: return 0.036914221942424774;
  t122_n235: return -0.025341080501675606;
  t122_n236: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t122_n242;
  t122_n237: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t122_n239;
  t122_n238: return 0.0871398001909256;
  t122_n239: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t122_n241;
  t122_n240: return -0.20487385988235474;
  t122_n241: return 0.09269776940345764;
  t122_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t122_n244;
  t122_n243: return -0.09408969432115555;
  t122_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t122_n254;
  t122_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t122_n251;
  t122_n246: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t122_n250;
  t122_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t122_n249;
  t122_n248: return 0.0028658187948167324;
  t122_n249: return 0.06656645238399506;
  t122_n250: return 0.07479199022054672;
  t122_n251: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t122_n253;
  t122_n252: return 0.10331472754478455;
  t122_n253: return 0.09081719815731049;
  t122_n254: return 0.030133714899420738;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree123(const Example& E) {
  t123_n0: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t123_n128;
  t123_n1: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t123_n127;
  t123_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n44;
  t123_n3: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t123_n5;
  t123_n4: return -0.00433315709233284;
  t123_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t123_n9;
  t123_n6: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t123_n8;
  t123_n7: return 0.0060534849762916565;
  t123_n8: return -0.019019780680537224;
  t123_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n11;
  t123_n10: return 0.020910656079649925;
  t123_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t123_n43;
  t123_n12: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t123_n16;
  t123_n13: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t123_n15;
  t123_n14: return 0.21037757396697998;
  t123_n15: return 0.11434727907180786;
  t123_n16: if (E.getFileProximityDistance() >= 3254255616 /*31.0*/) goto t123_n34;
  t123_n17: if (E.getNumReferences() >= 3332877056 /*21461.5*/) goto t123_n33;
  t123_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t123_n20;
  t123_n19: return -0.01605822704732418;
  t123_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t123_n26;
  t123_n21: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t123_n25;
  t123_n22: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t123_n24;
  t123_n23: return -0.1514359712600708;
  t123_n24: return -1.7857098579406738;
  t123_n25: return 0.12753848731517792;
  t123_n26: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n32;
  t123_n27: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t123_n29;
  t123_n28: return 0.1105390191078186;
  t123_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n31;
  t123_n30: return 0.07874608784914017;
  t123_n31: return -0.2027072161436081;
  t123_n32: return 0.037151310592889786;
  t123_n33: return 0.051518380641937256;
  t123_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t123_n38;
  t123_n35: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t123_n37;
  t123_n36: return -0.059207573533058167;
  t123_n37: return 0.04294084385037422;
  t123_n38: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t123_n42;
  t123_n39: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t123_n41;
  t123_n40: return 0.08230346441268921;
  t123_n41: return 0.1068190187215805;
  t123_n42: return 0.018338076770305634;
  t123_n43: return -0.00967724621295929;
  t123_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t123_n116;
  t123_n45: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t123_n85;
  t123_n46: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t123_n48;
  t123_n47: return -0.023467110469937325;
  t123_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t123_n54;
  t123_n49: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t123_n53;
  t123_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t123_n52;
  t123_n51: return -0.09306753426790237;
  t123_n52: return -0.17064695060253143;
  t123_n53: return -0.0008029698510654271;
  t123_n54: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t123_n84;
  t123_n55: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t123_n79;
  t123_n56: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t123_n58;
  t123_n57: return 0.02530818246304989;
  t123_n58: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t123_n60;
  t123_n59: return -0.16064460575580597;
  t123_n60: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t123_n78;
  t123_n61: if (E.getNumReferences() >= 3273162752 /*152.5*/) goto t123_n77;
  t123_n62: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t123_n72;
  t123_n63: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t123_n67;
  t123_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t123_n66;
  t123_n65: return -0.0659472644329071;
  t123_n66: return -0.6103721857070923;
  t123_n67: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t123_n71;
  t123_n68: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t123_n70;
  t123_n69: return 0.08934111148118973;
  t123_n70: return 0.17515027523040771;
  t123_n71: return -0.07875999808311462;
  t123_n72: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t123_n74;
  t123_n73: return 0.13051164150238037;
  t123_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n76;
  t123_n75: return 0.07344110310077667;
  t123_n76: return -0.03118104487657547;
  t123_n77: return -0.19536727666854858;
  t123_n78: return 0.09703115373849869;
  t123_n79: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t123_n81;
  t123_n80: return 0.11384545266628265;
  t123_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n83;
  t123_n82: return -0.3516378402709961;
  t123_n83: return 0.09441978484392166;
  t123_n84: return 0.0022419202141463757;
  t123_n85: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t123_n113;
  t123_n86: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t123_n90;
  t123_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n89;
  t123_n88: return -0.041483502835035324;
  t123_n89: return -0.010422604158520699;
  t123_n90: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t123_n92;
  t123_n91: return -0.094046451151371;
  t123_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t123_n96;
  t123_n93: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t123_n95;
  t123_n94: return 0.12640592455863953;
  t123_n95: return 0.03581729531288147;
  t123_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t123_n100;
  t123_n97: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t123_n99;
  t123_n98: return -0.418911337852478;
  t123_n99: return 0.09272754192352295;
  t123_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n102;
  t123_n101: return -0.757485568523407;
  t123_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t123_n112;
  t123_n103: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t123_n109;
  t123_n104: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t123_n106;
  t123_n105: return 0.008663039654493332;
  t123_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n108;
  t123_n107: return 0.1215401366353035;
  t123_n108: return -2.746586799621582;
  t123_n109: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t123_n111;
  t123_n110: return 0.11229239404201508;
  t123_n111: return 0.07403956353664398;
  t123_n112: return 0.08508092910051346;
  t123_n113: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t123_n115;
  t123_n114: return -0.4396460950374603;
  t123_n115: return -0.0713634192943573;
  t123_n116: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t123_n126;
  t123_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n119;
  t123_n118: return -0.0037201433442533016;
  t123_n119: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t123_n121;
  t123_n120: return 0.004021233879029751;
  t123_n121: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t123_n123;
  t123_n122: return 0.017264163121581078;
  t123_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t123_n125;
  t123_n124: return 0.08247751742601395;
  t123_n125: return -0.0005136454710736871;
  t123_n126: return 0.00654307845979929;
  t123_n127: return -0.14226825535297394;
  t123_n128: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t123_n164;
  t123_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t123_n131;
  t123_n130: return -0.07721345871686935;
  t123_n131: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t123_n133;
  t123_n132: return -0.05203079804778099;
  t123_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t123_n139;
  t123_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t123_n136;
  t123_n135: return 0.03911077231168747;
  t123_n136: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t123_n138;
  t123_n137: return 0.10357656329870224;
  t123_n138: return 0.08463110774755478;
  t123_n139: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t123_n161;
  t123_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n152;
  t123_n141: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t123_n151;
  t123_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n150;
  t123_n143: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t123_n145;
  t123_n144: return 0.06611701101064682;
  t123_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n147;
  t123_n146: return 0.08438672870397568;
  t123_n147: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t123_n149;
  t123_n148: return 0.10443763434886932;
  t123_n149: return -0.026957539841532707;
  t123_n150: return 0.03477137163281441;
  t123_n151: return 0.04489578679203987;
  t123_n152: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t123_n154;
  t123_n153: return -0.3026442229747772;
  t123_n154: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t123_n160;
  t123_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n157;
  t123_n156: return 0.08983970433473587;
  t123_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n159;
  t123_n158: return 0.10500462353229523;
  t123_n159: return 0.10696935653686523;
  t123_n160: return 0.048522576689720154;
  t123_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n163;
  t123_n162: return -0.062332961708307266;
  t123_n163: return 0.06915168464183807;
  t123_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t123_n166;
  t123_n165: return -0.0064353072084486485;
  t123_n166: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t123_n210;
  t123_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n209;
  t123_n168: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t123_n202;
  t123_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t123_n171;
  t123_n170: return -0.011273867450654507;
  t123_n171: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t123_n173;
  t123_n172: return -0.13726706802845;
  t123_n173: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t123_n185;
  t123_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n182;
  t123_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n177;
  t123_n176: return 0.045721907168626785;
  t123_n177: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t123_n179;
  t123_n178: return 0.013118487782776356;
  t123_n179: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t123_n181;
  t123_n180: return 0.08190584182739258;
  t123_n181: return -0.02778971567749977;
  t123_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t123_n184;
  t123_n183: return -0.12755027413368225;
  t123_n184: return 0.10317441821098328;
  t123_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n199;
  t123_n186: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t123_n198;
  t123_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n189;
  t123_n188: return 0.015019144862890244;
  t123_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t123_n197;
  t123_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t123_n194;
  t123_n191: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t123_n193;
  t123_n192: return 0.08207014203071594;
  t123_n193: return -0.2383783459663391;
  t123_n194: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t123_n196;
  t123_n195: return 0.11371021717786789;
  t123_n196: return -0.25231125950813293;
  t123_n197: return 0.001285133883357048;
  t123_n198: return -0.3856939971446991;
  t123_n199: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n201;
  t123_n200: return 0.09294728934764862;
  t123_n201: return 0.06019655615091324;
  t123_n202: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t123_n208;
  t123_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t123_n207;
  t123_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t123_n206;
  t123_n205: return 0.09138273447751999;
  t123_n206: return 0.11163540929555893;
  t123_n207: return -0.002461845986545086;
  t123_n208: return 0.09895333647727966;
  t123_n209: return -0.07402161508798599;
  t123_n210: if (E.getNumReferences() >= 3364768256 /*291408.0*/) goto t123_n212;
  t123_n211: return -0.009782373905181885;
  t123_n212: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t123_n240;
  t123_n213: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t123_n237;
  t123_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t123_n226;
  t123_n215: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t123_n225;
  t123_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n224;
  t123_n217: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t123_n219;
  t123_n218: return 0.06270851939916611;
  t123_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t123_n221;
  t123_n220: return -0.0383063405752182;
  t123_n221: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t123_n223;
  t123_n222: return 0.007637991104274988;
  t123_n223: return 0.08539023995399475;
  t123_n224: return -0.06285233795642853;
  t123_n225: return 0.027267057448625565;
  t123_n226: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t123_n230;
  t123_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t123_n229;
  t123_n228: return -0.6029350161552429;
  t123_n229: return -0.025518380105495453;
  t123_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t123_n232;
  t123_n231: return 0.011735408566892147;
  t123_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t123_n234;
  t123_n233: return -0.2548428177833557;
  t123_n234: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t123_n236;
  t123_n235: return 0.1071246862411499;
  t123_n236: return 0.08277123421430588;
  t123_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t123_n239;
  t123_n238: return 0.1004863977432251;
  t123_n239: return 0.10207395255565643;
  t123_n240: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t123_n244;
  t123_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t123_n243;
  t123_n242: return -0.014967148192226887;
  t123_n243: return -0.2570604383945465;
  t123_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t123_n252;
  t123_n245: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t123_n247;
  t123_n246: return 0.08351768553256989;
  t123_n247: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t123_n249;
  t123_n248: return 0.017161648720502853;
  t123_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t123_n251;
  t123_n250: return 0.06853078305721283;
  t123_n251: return 0.09682799875736237;
  t123_n252: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t123_n254;
  t123_n253: return -0.001434783567674458;
  t123_n254: return 0.02996240369975567;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree124(const Example& E) {
  t124_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t124_n130;
  t124_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t124_n3;
  t124_n2: return -0.020896567031741142;
  t124_n3: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t124_n109;
  t124_n4: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t124_n6;
  t124_n5: return -0.0050608813762664795;
  t124_n6: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t124_n12;
  t124_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t124_n11;
  t124_n8: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t124_n10;
  t124_n9: return -0.0995188057422638;
  t124_n10: return 0.09981288015842438;
  t124_n11: return 0.036035697907209396;
  t124_n12: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t124_n52;
  t124_n13: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t124_n15;
  t124_n14: return 0.010122710838913918;
  t124_n15: if (E.getNumReferences() >= 3347692736 /*70521.5*/) goto t124_n51;
  t124_n16: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t124_n18;
  t124_n17: return 0.0069194938987493515;
  t124_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t124_n42;
  t124_n19: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t124_n35;
  t124_n20: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t124_n22;
  t124_n21: return 0.030142972245812416;
  t124_n22: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t124_n26;
  t124_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n25;
  t124_n24: return 0.10956933349370956;
  t124_n25: return -0.060833752155303955;
  t124_n26: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t124_n28;
  t124_n27: return 0.14408306777477264;
  t124_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n34;
  t124_n29: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t124_n31;
  t124_n30: return 0.03991539403796196;
  t124_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t124_n33;
  t124_n32: return 0.11306992918252945;
  t124_n33: return 0.09016381204128265;
  t124_n34: return 0.04929221048951149;
  t124_n35: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t124_n39;
  t124_n36: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t124_n38;
  t124_n37: return 0.09571623057126999;
  t124_n38: return 0.14735710620880127;
  t124_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t124_n41;
  t124_n40: return -0.010509354993700981;
  t124_n41: return 0.11881177127361298;
  t124_n42: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t124_n50;
  t124_n43: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t124_n45;
  t124_n44: return -0.034161560237407684;
  t124_n45: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t124_n49;
  t124_n46: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t124_n48;
  t124_n47: return 0.11967784911394119;
  t124_n48: return -0.15275612473487854;
  t124_n49: return 0.034412916749715805;
  t124_n50: return -0.10339276492595673;
  t124_n51: return 0.11865227669477463;
  t124_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n100;
  t124_n53: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n85;
  t124_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n56;
  t124_n55: return -0.037345144897699356;
  t124_n56: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t124_n80;
  t124_n57: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t124_n73;
  t124_n58: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t124_n70;
  t124_n59: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t124_n61;
  t124_n60: return 0.07193496823310852;
  t124_n61: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t124_n63;
  t124_n62: return 0.02121904492378235;
  t124_n63: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t124_n69;
  t124_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t124_n68;
  t124_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n67;
  t124_n66: return 0.1085951179265976;
  t124_n67: return 0.13527730107307434;
  t124_n68: return 0.04856189340353012;
  t124_n69: return 0.10202700644731522;
  t124_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n72;
  t124_n71: return -2.5147597789764404;
  t124_n72: return 0.014663285575807095;
  t124_n73: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t124_n75;
  t124_n74: return 0.10377860814332962;
  t124_n75: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t124_n79;
  t124_n76: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t124_n78;
  t124_n77: return 0.627682626247406;
  t124_n78: return 0.09140121191740036;
  t124_n79: return 0.11427227407693863;
  t124_n80: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n84;
  t124_n81: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t124_n83;
  t124_n82: return 0.12068520486354828;
  t124_n83: return -0.25836411118507385;
  t124_n84: return -0.014673622325062752;
  t124_n85: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t124_n99;
  t124_n86: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t124_n88;
  t124_n87: return 0.06720764189958572;
  t124_n88: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t124_n96;
  t124_n89: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t124_n95;
  t124_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n92;
  t124_n91: return -0.10185080766677856;
  t124_n92: if (E.getNumReferences() >= 3279060992 /*242.5*/) goto t124_n94;
  t124_n93: return 1.642093539237976;
  t124_n94: return 0.11695287376642227;
  t124_n95: return -0.11335495859384537;
  t124_n96: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t124_n98;
  t124_n97: return 0.13075275719165802;
  t124_n98: return 0.06508241593837738;
  t124_n99: return -0.11348243057727814;
  t124_n100: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t124_n102;
  t124_n101: return -0.042523618787527084;
  t124_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n108;
  t124_n103: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n107;
  t124_n104: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t124_n106;
  t124_n105: return 0.18056900799274445;
  t124_n106: return 0.1251317411661148;
  t124_n107: return 0.07032786309719086;
  t124_n108: return 0.02277163229882717;
  t124_n109: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t124_n111;
  t124_n110: return 0.0032555803190916777;
  t124_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t124_n113;
  t124_n112: return -0.07034942507743835;
  t124_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t124_n121;
  t124_n114: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t124_n116;
  t124_n115: return 0.014294841326773167;
  t124_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t124_n120;
  t124_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n119;
  t124_n118: return 0.014823627658188343;
  t124_n119: return 0.042839791625738144;
  t124_n120: return 0.006180221680551767;
  t124_n121: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n129;
  t124_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n128;
  t124_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n127;
  t124_n124: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t124_n126;
  t124_n125: return 0.10382474958896637;
  t124_n126: return 0.07655324786901474;
  t124_n127: return 0.10333442687988281;
  t124_n128: return 0.07403696328401566;
  t124_n129: return -0.042834147810935974;
  t124_n130: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t124_n132;
  t124_n131: return -0.05767954885959625;
  t124_n132: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t124_n254;
  t124_n133: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t124_n253;
  t124_n134: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t124_n196;
  t124_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t124_n137;
  t124_n136: return 0.0021232357248663902;
  t124_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t124_n139;
  t124_n138: return 0.0004246726748533547;
  t124_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t124_n141;
  t124_n140: return 0.010111787356436253;
  t124_n141: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t124_n149;
  t124_n142: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t124_n148;
  t124_n143: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t124_n145;
  t124_n144: return -0.011212768033146858;
  t124_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t124_n147;
  t124_n146: return -0.08199531584978104;
  t124_n147: return -0.01922149956226349;
  t124_n148: return 0.014394101686775684;
  t124_n149: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t124_n153;
  t124_n150: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t124_n152;
  t124_n151: return -0.02703022211790085;
  t124_n152: return 0.08627358824014664;
  t124_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t124_n187;
  t124_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t124_n158;
  t124_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t124_n157;
  t124_n156: return -0.026787525042891502;
  t124_n157: return 0.047638073563575745;
  t124_n158: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t124_n160;
  t124_n159: return 0.07336004078388214;
  t124_n160: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t124_n186;
  t124_n161: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t124_n167;
  t124_n162: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t124_n166;
  t124_n163: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t124_n165;
  t124_n164: return 0.08559101819992065;
  t124_n165: return 0.12411387264728546;
  t124_n166: return -0.0674724131822586;
  t124_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n185;
  t124_n168: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t124_n184;
  t124_n169: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t124_n179;
  t124_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t124_n172;
  t124_n171: return -0.13514874875545502;
  t124_n172: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t124_n174;
  t124_n173: return 0.12346110492944717;
  t124_n174: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t124_n176;
  t124_n175: return 0.03196222335100174;
  t124_n176: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t124_n178;
  t124_n177: return 0.12407013028860092;
  t124_n178: return -0.13480322062969208;
  t124_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t124_n181;
  t124_n180: return 0.14051911234855652;
  t124_n181: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t124_n183;
  t124_n182: return 0.1343545764684677;
  t124_n183: return 0.15086470544338226;
  t124_n184: return -0.05078578740358353;
  t124_n185: return 0.0901794359087944;
  t124_n186: return 0.010290198028087616;
  t124_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n195;
  t124_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t124_n190;
  t124_n189: return -0.03247556462883949;
  t124_n190: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t124_n192;
  t124_n191: return 0.09683816134929657;
  t124_n192: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t124_n194;
  t124_n193: return -0.011684909462928772;
  t124_n194: return 0.11404728889465332;
  t124_n195: return 0.013109708204865456;
  t124_n196: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t124_n198;
  t124_n197: return -0.017045004293322563;
  t124_n198: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t124_n214;
  t124_n199: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t124_n213;
  t124_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t124_n202;
  t124_n201: return -0.060662347823381424;
  t124_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t124_n204;
  t124_n203: return 0.0045723142102360725;
  t124_n204: if (E.getNumReferences() >= 3314682880 /*4673.5*/) goto t124_n206;
  t124_n205: return 0.013563672080636024;
  t124_n206: if (E.getNumReferences() >= 3315159040 /*4906.0*/) goto t124_n212;
  t124_n207: if (E.getNumReferences() >= 3315124224 /*4889.0*/) goto t124_n209;
  t124_n208: return 0.07269328832626343;
  t124_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n211;
  t124_n210: return 0.10784521698951721;
  t124_n211: return 0.12461785227060318;
  t124_n212: return 0.02735866978764534;
  t124_n213: return -0.0028372874949127436;
  t124_n214: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t124_n250;
  t124_n215: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t124_n249;
  t124_n216: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t124_n230;
  t124_n217: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t124_n219;
  t124_n218: return -0.022033998742699623;
  t124_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t124_n225;
  t124_n220: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t124_n224;
  t124_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t124_n223;
  t124_n222: return 0.029283858835697174;
  t124_n223: return 0.09068386256694794;
  t124_n224: return 0.0527169331908226;
  t124_n225: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t124_n229;
  t124_n226: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t124_n228;
  t124_n227: return -0.35043972730636597;
  t124_n228: return 0.13569721579551697;
  t124_n229: return 0.06926409155130386;
  t124_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t124_n236;
  t124_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t124_n233;
  t124_n232: return 0.05748164281249046;
  t124_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t124_n235;
  t124_n234: return 0.0911215990781784;
  t124_n235: return 0.11589568853378296;
  t124_n236: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t124_n238;
  t124_n237: return 0.05178854614496231;
  t124_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t124_n240;
  t124_n239: return -0.07367116957902908;
  t124_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t124_n246;
  t124_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t124_n245;
  t124_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t124_n244;
  t124_n243: return -0.6372920870780945;
  t124_n244: return 0.10688463598489761;
  t124_n245: return 0.11981471627950668;
  t124_n246: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t124_n248;
  t124_n247: return 0.08757530152797699;
  t124_n248: return 0.12087096273899078;
  t124_n249: return -0.022800562903285027;
  t124_n250: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t124_n252;
  t124_n251: return 0.05286682769656181;
  t124_n252: return 0.0337362177670002;
  t124_n253: return -0.09848681092262268;
  t124_n254: return -0.06376885622739792;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree125(const Example& E) {
  t125_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t125_n2;
  t125_n1: return -0.0005637154681608081;
  t125_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t125_n12;
  t125_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t125_n5;
  t125_n4: return 0.009199585765600204;
  t125_n5: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t125_n7;
  t125_n6: return -0.010147254914045334;
  t125_n7: if (E.getNumReferences() >= 3300937728 /*1538.5*/) goto t125_n11;
  t125_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t125_n10;
  t125_n9: return -0.11384525150060654;
  t125_n10: return 0.1334943026304245;
  t125_n11: return 0.027145465835928917;
  t125_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t125_n14;
  t125_n13: return -0.00973731279373169;
  t125_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t125_n62;
  t125_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t125_n61;
  t125_n16: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t125_n54;
  t125_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n25;
  t125_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t125_n24;
  t125_n19: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t125_n21;
  t125_n20: return 0.10878061503171921;
  t125_n21: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t125_n23;
  t125_n22: return -0.07899052649736404;
  t125_n23: return -0.40743541717529297;
  t125_n24: return 0.00523192435503006;
  t125_n25: if (E.getNumReferences() >= 3349697792 /*86186.0*/) goto t125_n49;
  t125_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t125_n28;
  t125_n27: return 0.011177174746990204;
  t125_n28: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t125_n48;
  t125_n29: if (E.getNumReferences() >= 3300868096 /*1530.0*/) goto t125_n35;
  t125_n30: if (E.getNumReferences() >= 3299028992 /*1305.5*/) goto t125_n32;
  t125_n31: return -0.1261858344078064;
  t125_n32: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t125_n34;
  t125_n33: return 0.10915057361125946;
  t125_n34: return 0.1331447958946228;
  t125_n35: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t125_n39;
  t125_n36: if (E.getNumReferences() >= 3344932992 /*57248.5*/) goto t125_n38;
  t125_n37: return -0.008332254365086555;
  t125_n38: return 0.14137254655361176;
  t125_n39: if (E.getNumReferences() >= 3322808320 /*9090.0*/) goto t125_n43;
  t125_n40: if (E.getNumReferences() >= 3307612160 /*2658.5*/) goto t125_n42;
  t125_n41: return -0.5645287036895752;
  t125_n42: return 0.11575573682785034;
  t125_n43: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t125_n47;
  t125_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t125_n46;
  t125_n45: return -0.052750058472156525;
  t125_n46: return 0.09290187805891037;
  t125_n47: return -0.27792230248451233;
  t125_n48: return 0.0011099730618298054;
  t125_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t125_n53;
  t125_n50: if (E.getNumReferences() >= 3350811072 /*94883.5*/) goto t125_n52;
  t125_n51: return 0.09590713679790497;
  t125_n52: return 0.02781890332698822;
  t125_n53: return 0.11022662371397018;
  t125_n54: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t125_n60;
  t125_n55: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t125_n57;
  t125_n56: return -0.04730561003088951;
  t125_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t125_n59;
  t125_n58: return -0.10182526707649231;
  t125_n59: return 0.02003094181418419;
  t125_n60: return 0.016195302829146385;
  t125_n61: return 0.0562780387699604;
  t125_n62: if (E.getNumReferences() >= 3360630592 /*212125.0*/) goto t125_n252;
  t125_n63: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t125_n251;
  t125_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t125_n74;
  t125_n65: if (E.getNumReferences() >= 3332134144 /*20010.5*/) goto t125_n67;
  t125_n66: return -0.012733710929751396;
  t125_n67: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t125_n71;
  t125_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t125_n70;
  t125_n69: return -0.28092533349990845;
  t125_n70: return 0.11567599326372147;
  t125_n71: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t125_n73;
  t125_n72: return 0.03243936598300934;
  t125_n73: return 0.004524259362369776;
  t125_n74: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t125_n244;
  t125_n75: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t125_n241;
  t125_n76: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t125_n78;
  t125_n77: return 0.009753653779625893;
  t125_n78: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t125_n88;
  t125_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t125_n85;
  t125_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t125_n82;
  t125_n81: return -0.1499626636505127;
  t125_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n84;
  t125_n83: return 0.11693571507930756;
  t125_n84: return -0.13528883457183838;
  t125_n85: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t125_n87;
  t125_n86: return 0.10011856257915497;
  t125_n87: return 0.13095353543758392;
  t125_n88: if (E.getNumReferences() >= 3333845504 /*23353.0*/) goto t125_n170;
  t125_n89: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t125_n125;
  t125_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t125_n92;
  t125_n91: return 0.024829713627696037;
  t125_n92: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t125_n96;
  t125_n93: if (E.getNumReferences() >= 3321171968 /*7842.0*/) goto t125_n95;
  t125_n94: return 0.13847936689853668;
  t125_n95: return -0.4016248881816864;
  t125_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t125_n116;
  t125_n97: if (E.getNumReferences() >= 3318849536 /*6708.0*/) goto t125_n105;
  t125_n98: if (E.getNumReferences() >= 3318293504 /*6436.5*/) goto t125_n104;
  t125_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n101;
  t125_n100: return 0.08662443608045578;
  t125_n101: if (E.getNumReferences() >= 3317264384 /*5934.0*/) goto t125_n103;
  t125_n102: return 0.12218739837408066;
  t125_n103: return 0.051246099174022675;
  t125_n104: return 0.10669324547052383;
  t125_n105: if (E.getNumReferences() >= 3327376384 /*13551.0*/) goto t125_n107;
  t125_n106: return -0.020247332751750946;
  t125_n107: if (E.getNumReferences() >= 3327536128 /*13707.0*/) goto t125_n109;
  t125_n108: return 0.1267378330230713;
  t125_n109: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t125_n111;
  t125_n110: return -0.3748004734516144;
  t125_n111: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t125_n113;
  t125_n112: return 0.11210978031158447;
  t125_n113: if (E.getNumReferences() >= 3329434624 /*15561.0*/) goto t125_n115;
  t125_n114: return -0.4744958281517029;
  t125_n115: return 0.1408231556415558;
  t125_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n118;
  t125_n117: return 0.019836166873574257;
  t125_n118: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t125_n124;
  t125_n119: if (E.getNumReferences() >= 3324154880 /*10405.0*/) goto t125_n121;
  t125_n120: return 0.11084577441215515;
  t125_n121: if (E.getNumReferences() >= 3326979584 /*13163.5*/) goto t125_n123;
  t125_n122: return 0.13542814552783966;
  t125_n123: return 0.27585968375205994;
  t125_n124: return 0.049238838255405426;
  t125_n125: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t125_n133;
  t125_n126: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t125_n132;
  t125_n127: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t125_n131;
  t125_n128: if (E.getNumReferences() >= 3331533568 /*18837.5*/) goto t125_n130;
  t125_n129: return 0.12329771369695663;
  t125_n130: return -0.009945327416062355;
  t125_n131: return 0.0789128765463829;
  t125_n132: return 0.12166270613670349;
  t125_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t125_n161;
  t125_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t125_n150;
  t125_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t125_n137;
  t125_n136: return -0.013954248279333115;
  t125_n137: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t125_n139;
  t125_n138: return 0.037484701722860336;
  t125_n139: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t125_n141;
  t125_n140: return 0.04978246986865997;
  t125_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n149;
  t125_n142: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t125_n148;
  t125_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n145;
  t125_n144: return 0.073585644364357;
  t125_n145: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t125_n147;
  t125_n146: return 0.10740593820810318;
  t125_n147: return 0.1326887309551239;
  t125_n148: return 0.055981989949941635;
  t125_n149: return 0.11343348771333694;
  t125_n150: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t125_n160;
  t125_n151: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t125_n159;
  t125_n152: if (E.getNumReferences() >= 3332141568 /*20025.0*/) goto t125_n154;
  t125_n153: return -0.022221030667424202;
  t125_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n156;
  t125_n155: return 0.051976364105939865;
  t125_n156: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n158;
  t125_n157: return 0.18335220217704773;
  t125_n158: return 0.1581178456544876;
  t125_n159: return 0.11904427409172058;
  t125_n160: return 0.03777940198779106;
  t125_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n163;
  t125_n162: return 0.07177601009607315;
  t125_n163: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t125_n165;
  t125_n164: return 0.10323023796081543;
  t125_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t125_n167;
  t125_n166: return -0.5143533945083618;
  t125_n167: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t125_n169;
  t125_n168: return 0.11588083207607269;
  t125_n169: return 0.02650080807507038;
  t125_n170: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t125_n172;
  t125_n171: return -0.035940416157245636;
  t125_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t125_n196;
  t125_n173: if (E.getNumReferences() >= 3339403904 /*35650.5*/) goto t125_n193;
  t125_n174: if (E.getNumReferences() >= 3339274880 /*35146.5*/) goto t125_n188;
  t125_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t125_n177;
  t125_n176: return 0.0008422802784480155;
  t125_n177: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t125_n187;
  t125_n178: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t125_n186;
  t125_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t125_n185;
  t125_n180: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t125_n182;
  t125_n181: return -0.34606438875198364;
  t125_n182: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t125_n184;
  t125_n183: return 0.046466197818517685;
  t125_n184: return 0.11699489504098892;
  t125_n185: return 0.11950990557670593;
  t125_n186: return 0.11798810213804245;
  t125_n187: return 0.028896372765302658;
  t125_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n192;
  t125_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t125_n191;
  t125_n190: return 0.08272868394851685;
  t125_n191: return 0.12919901311397552;
  t125_n192: return -0.04765400290489197;
  t125_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t125_n195;
  t125_n194: return -0.13993413746356964;
  t125_n195: return -0.017008209601044655;
  t125_n196: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t125_n198;
  t125_n197: return -0.05489268898963928;
  t125_n198: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t125_n236;
  t125_n199: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t125_n225;
  t125_n200: if (E.getNumReferences() >= 3341306880 /*43084.0*/) goto t125_n204;
  t125_n201: if (E.getNumReferences() >= 3339235072 /*34991.0*/) goto t125_n203;
  t125_n202: return 0.06792664527893066;
  t125_n203: return -0.15654367208480835;
  t125_n204: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t125_n216;
  t125_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t125_n215;
  t125_n206: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t125_n214;
  t125_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t125_n209;
  t125_n208: return 0.10032469779253006;
  t125_n209: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n211;
  t125_n210: return 0.11447910964488983;
  t125_n211: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n213;
  t125_n212: return 0.10599382221698761;
  t125_n213: return 0.09464733302593231;
  t125_n214: return 0.08089105039834976;
  t125_n215: return -0.1366194784641266;
  t125_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t125_n220;
  t125_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t125_n219;
  t125_n218: return -0.0724717453122139;
  t125_n219: return 0.08580578863620758;
  t125_n220: if (E.getNumReferences() >= 3343171712 /*50368.5*/) goto t125_n222;
  t125_n221: return -0.11405692249536514;
  t125_n222: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n224;
  t125_n223: return 0.1087941974401474;
  t125_n224: return 0.09851793199777603;
  t125_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t125_n227;
  t125_n226: return -0.010892890393733978;
  t125_n227: if (E.getNumReferences() >= 3345871872 /*60916.0*/) goto t125_n229;
  t125_n228: return -0.024018313735723495;
  t125_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t125_n235;
  t125_n230: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n234;
  t125_n231: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t125_n233;
  t125_n232: return 0.16506510972976685;
  t125_n233: return 0.09420420974493027;
  t125_n234: return 0.10135547071695328;
  t125_n235: return 0.10685014724731445;
  t125_n236: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t125_n238;
  t125_n237: return 0.019714215770363808;
  t125_n238: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n240;
  t125_n239: return 0.12278103828430176;
  t125_n240: return 0.08661378920078278;
  t125_n241: if (E.getNumReferences() >= 3348207616 /*74544.0*/) goto t125_n243;
  t125_n242: return -0.07601060718297958;
  t125_n243: return -0.010367942973971367;
  t125_n244: if (E.getNumReferences() >= 3306448896 /*2374.5*/) goto t125_n246;
  t125_n245: return 0.005952934268862009;
  t125_n246: if (E.getNumReferences() >= 3306622976 /*2417.0*/) goto t125_n250;
  t125_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t125_n249;
  t125_n248: return 0.1136278435587883;
  t125_n249: return 0.03851057589054108;
  t125_n250: return 0.04403729736804962;
  t125_n251: return 0.03749065101146698;
  t125_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t125_n254;
  t125_n253: return 0.0006489047082141042;
  t125_n254: return -0.042307689785957336;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree126(const Example& E) {
  t126_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t126_n216;
  t126_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t126_n61;
  t126_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t126_n48;
  t126_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n47;
  t126_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n6;
  t126_n5: return -0.008822734467685223;
  t126_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n8;
  t126_n7: return 0.008846553973853588;
  t126_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t126_n42;
  t126_n9: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t126_n41;
  t126_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t126_n14;
  t126_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t126_n13;
  t126_n12: return 0.009785561822354794;
  t126_n13: return 0.0405304953455925;
  t126_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t126_n16;
  t126_n15: return -0.15780645608901978;
  t126_n16: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t126_n40;
  t126_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t126_n31;
  t126_n18: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t126_n30;
  t126_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n23;
  t126_n20: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t126_n22;
  t126_n21: return 0.07260951399803162;
  t126_n22: return 0.097422756254673;
  t126_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n29;
  t126_n24: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t126_n28;
  t126_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t126_n27;
  t126_n26: return 0.07412230223417282;
  t126_n27: return 0.09212172776460648;
  t126_n28: return -0.0080293333157897;
  t126_n29: return -0.04144708812236786;
  t126_n30: return 0.12174052745103836;
  t126_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t126_n33;
  t126_n32: return 0.05874788761138916;
  t126_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n39;
  t126_n34: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n36;
  t126_n35: return -0.06616085022687912;
  t126_n36: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t126_n38;
  t126_n37: return 0.13623753190040588;
  t126_n38: return -0.3684638440608978;
  t126_n39: return 0.058814018964767456;
  t126_n40: return 0.049112532287836075;
  t126_n41: return 0.03658365458250046;
  t126_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t126_n44;
  t126_n43: return -0.049485862255096436;
  t126_n44: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t126_n46;
  t126_n45: return -0.00630435673519969;
  t126_n46: return 0.03133440762758255;
  t126_n47: return -0.005568749736994505;
  t126_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t126_n54;
  t126_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t126_n51;
  t126_n50: return 0.005894300527870655;
  t126_n51: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t126_n53;
  t126_n52: return -0.1420665681362152;
  t126_n53: return 0.025000395253300667;
  t126_n54: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t126_n56;
  t126_n55: return 0.10747992992401123;
  t126_n56: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n60;
  t126_n57: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t126_n59;
  t126_n58: return 0.02434244565665722;
  t126_n59: return 0.03864603117108345;
  t126_n60: return 0.043412238359451294;
  t126_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t126_n63;
  t126_n62: return -0.008928303606808186;
  t126_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t126_n103;
  t126_n64: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t126_n102;
  t126_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t126_n71;
  t126_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t126_n68;
  t126_n67: return -0.04737340286374092;
  t126_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t126_n70;
  t126_n69: return -0.2939850091934204;
  t126_n70: return -0.001827917993068695;
  t126_n71: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t126_n91;
  t126_n72: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t126_n90;
  t126_n73: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t126_n89;
  t126_n74: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t126_n78;
  t126_n75: if (E.getNumReferences() >= 3287728128 /*493.5*/) goto t126_n77;
  t126_n76: return 0.037169985473155975;
  t126_n77: return -0.5693904161453247;
  t126_n78: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t126_n88;
  t126_n79: if (E.getNumReferences() >= 3292397568 /*760.0*/) goto t126_n87;
  t126_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n86;
  t126_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t126_n83;
  t126_n82: return -0.04541948810219765;
  t126_n83: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t126_n85;
  t126_n84: return 0.1534135937690735;
  t126_n85: return 0.05904470384120941;
  t126_n86: return 0.0964607298374176;
  t126_n87: return 0.10287586599588394;
  t126_n88: return 0.06046068295836449;
  t126_n89: return -0.11164644360542297;
  t126_n90: return -0.013682711869478226;
  t126_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n93;
  t126_n92: return 0.027389662340283394;
  t126_n93: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t126_n101;
  t126_n94: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t126_n100;
  t126_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t126_n97;
  t126_n96: return 0.07272951304912567;
  t126_n97: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t126_n99;
  t126_n98: return 0.11706756055355072;
  t126_n99: return -0.04786892980337143;
  t126_n100: return 0.11768224090337753;
  t126_n101: return 0.04524023458361626;
  t126_n102: return -0.01273490022867918;
  t126_n103: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t126_n205;
  t126_n104: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t126_n106;
  t126_n105: return 0.0013430019607767463;
  t126_n106: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t126_n134;
  t126_n107: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t126_n115;
  t126_n108: if (E.getNumReferences() >= 3331557888 /*18885.0*/) goto t126_n110;
  t126_n109: return -0.023148639127612114;
  t126_n110: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t126_n114;
  t126_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n113;
  t126_n112: return 0.12388382107019424;
  t126_n113: return -0.02188846468925476;
  t126_n114: return 0.03868130221962929;
  t126_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t126_n117;
  t126_n116: return 0.02076449990272522;
  t126_n117: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n123;
  t126_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n120;
  t126_n119: return 0.04106396436691284;
  t126_n120: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n122;
  t126_n121: return 0.05658723786473274;
  t126_n122: return 0.16305339336395264;
  t126_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t126_n125;
  t126_n124: return 0.00611960981041193;
  t126_n125: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n127;
  t126_n126: return 0.07506255805492401;
  t126_n127: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t126_n133;
  t126_n128: if (E.getNumReferences() >= 3283468288 /*363.5*/) goto t126_n132;
  t126_n129: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t126_n131;
  t126_n130: return 0.19970528781414032;
  t126_n131: return 0.0738551914691925;
  t126_n132: return 0.008960568346083164;
  t126_n133: return 0.10164233297109604;
  t126_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t126_n136;
  t126_n135: return -0.0015841034473851323;
  t126_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n146;
  t126_n137: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t126_n145;
  t126_n138: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t126_n140;
  t126_n139: return -0.02359459176659584;
  t126_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t126_n142;
  t126_n141: return 0.020251663401722908;
  t126_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t126_n144;
  t126_n143: return 0.0756794661283493;
  t126_n144: return -0.06176726520061493;
  t126_n145: return 0.03235805407166481;
  t126_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t126_n160;
  t126_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t126_n149;
  t126_n148: return -0.022706588730216026;
  t126_n149: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t126_n159;
  t126_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n158;
  t126_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n153;
  t126_n152: return 0.16093343496322632;
  t126_n153: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n157;
  t126_n154: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t126_n156;
  t126_n155: return -0.23073598742485046;
  t126_n156: return 0.1353970319032669;
  t126_n157: return 0.05437649041414261;
  t126_n158: return 0.03750879317522049;
  t126_n159: return 0.020173873752355576;
  t126_n160: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t126_n196;
  t126_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n171;
  t126_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n164;
  t126_n163: return 0.05262317508459091;
  t126_n164: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t126_n170;
  t126_n165: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n167;
  t126_n166: return 0.048346493393182755;
  t126_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n169;
  t126_n168: return 0.11784671992063522;
  t126_n169: return -0.008896072395145893;
  t126_n170: return 0.07161793112754822;
  t126_n171: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t126_n185;
  t126_n172: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t126_n174;
  t126_n173: return 0.017685966566205025;
  t126_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t126_n182;
  t126_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t126_n177;
  t126_n176: return 0.06472183018922806;
  t126_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n181;
  t126_n178: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n180;
  t126_n179: return 0.10013968497514725;
  t126_n180: return 0.022990647703409195;
  t126_n181: return 0.0682075172662735;
  t126_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t126_n184;
  t126_n183: return 0.057042196393013;
  t126_n184: return 0.10493331402540207;
  t126_n185: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t126_n187;
  t126_n186: return 0.04050278291106224;
  t126_n187: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t126_n195;
  t126_n188: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t126_n194;
  t126_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t126_n193;
  t126_n190: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t126_n192;
  t126_n191: return 0.09187858551740646;
  t126_n192: return 0.111749567091465;
  t126_n193: return 0.08488841354846954;
  t126_n194: return 0.11326152086257935;
  t126_n195: return -0.14818908274173737;
  t126_n196: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t126_n198;
  t126_n197: return -0.012756812386214733;
  t126_n198: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t126_n200;
  t126_n199: return 0.12274686992168427;
  t126_n200: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t126_n202;
  t126_n201: return 0.05110799893736839;
  t126_n202: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n204;
  t126_n203: return 0.11167322844266891;
  t126_n204: return -0.062261443585157394;
  t126_n205: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t126_n213;
  t126_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n208;
  t126_n207: return -0.10066234320402145;
  t126_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t126_n210;
  t126_n209: return 0.10792338848114014;
  t126_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n212;
  t126_n211: return 0.10199138522148132;
  t126_n212: return 0.01883263885974884;
  t126_n213: if (E.getNumReferences() >= 3338536704 /*32515.5*/) goto t126_n215;
  t126_n214: return -0.1252259463071823;
  t126_n215: return 0.07133835554122925;
  t126_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t126_n218;
  t126_n217: return 0.00367922754958272;
  t126_n218: if (E.getNumReferences() >= 3342384384 /*47293.0*/) goto t126_n242;
  t126_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t126_n221;
  t126_n220: return 0.018727563321590424;
  t126_n221: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t126_n231;
  t126_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n224;
  t126_n223: return 0.04908359795808792;
  t126_n224: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t126_n230;
  t126_n225: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t126_n227;
  t126_n226: return 0.10542458295822144;
  t126_n227: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t126_n229;
  t126_n228: return 0.17628929018974304;
  t126_n229: return 0.11563727259635925;
  t126_n230: return 0.08340660482645035;
  t126_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t126_n241;
  t126_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t126_n238;
  t126_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t126_n235;
  t126_n234: return 0.18736298382282257;
  t126_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n237;
  t126_n236: return 0.12762442231178284;
  t126_n237: return 0.05347271263599396;
  t126_n238: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t126_n240;
  t126_n239: return 0.1298864483833313;
  t126_n240: return 0.177943155169487;
  t126_n241: return 0.11456988751888275;
  t126_n242: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t126_n244;
  t126_n243: return 0.00509154237806797;
  t126_n244: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t126_n254;
  t126_n245: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t126_n247;
  t126_n246: return 0.02673785388469696;
  t126_n247: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t126_n251;
  t126_n248: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t126_n250;
  t126_n249: return 0.11059890687465668;
  t126_n250: return 0.07374662160873413;
  t126_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t126_n253;
  t126_n252: return -0.03276846185326576;
  t126_n253: return 0.1078302413225174;
  t126_n254: return 0.007208246737718582;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree127(const Example& E) {
  t127_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t127_n242;
  t127_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t127_n181;
  t127_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t127_n102;
  t127_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t127_n5;
  t127_n4: return -0.05422738939523697;
  t127_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t127_n7;
  t127_n6: return -0.07048683613538742;
  t127_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t127_n9;
  t127_n8: return -0.016828810796141624;
  t127_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t127_n71;
  t127_n10: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t127_n14;
  t127_n11: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n13;
  t127_n12: return 0.0027640073094516993;
  t127_n13: return -0.08297746628522873;
  t127_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t127_n22;
  t127_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n17;
  t127_n16: return 0.09661374241113663;
  t127_n17: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t127_n21;
  t127_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t127_n20;
  t127_n19: return 0.022709861397743225;
  t127_n20: return 0.10967832803726196;
  t127_n21: return 0.05946961045265198;
  t127_n22: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t127_n66;
  t127_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n55;
  t127_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n48;
  t127_n25: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t127_n43;
  t127_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n28;
  t127_n27: return -0.30071479082107544;
  t127_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n30;
  t127_n29: return 0.055070456117391586;
  t127_n30: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n42;
  t127_n31: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t127_n33;
  t127_n32: return 0.07263805717229843;
  t127_n33: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t127_n35;
  t127_n34: return 0.11922219395637512;
  t127_n35: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t127_n37;
  t127_n36: return 0.1306476593017578;
  t127_n37: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t127_n39;
  t127_n38: return -0.1288345605134964;
  t127_n39: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t127_n41;
  t127_n40: return 0.0483977384865284;
  t127_n41: return 0.1072768047451973;
  t127_n42: return 0.03366093337535858;
  t127_n43: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n47;
  t127_n44: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t127_n46;
  t127_n45: return 0.037131838500499725;
  t127_n46: return -0.13605868816375732;
  t127_n47: return 0.07532640546560287;
  t127_n48: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t127_n50;
  t127_n49: return -0.0032845884561538696;
  t127_n50: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t127_n54;
  t127_n51: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t127_n53;
  t127_n52: return 0.11161372065544128;
  t127_n53: return 0.1183457300066948;
  t127_n54: return 0.0431731753051281;
  t127_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n59;
  t127_n56: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t127_n58;
  t127_n57: return 0.05898178368806839;
  t127_n58: return -0.5843892693519592;
  t127_n59: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t127_n61;
  t127_n60: return 0.0010973496828228235;
  t127_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n65;
  t127_n62: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t127_n64;
  t127_n63: return 0.15549711883068085;
  t127_n64: return -0.012947706505656242;
  t127_n65: return -0.11956842988729477;
  t127_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t127_n70;
  t127_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n69;
  t127_n68: return -0.013398624956607819;
  t127_n69: return 0.019384577870368958;
  t127_n70: return -0.039001934230327606;
  t127_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t127_n91;
  t127_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n86;
  t127_n73: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t127_n85;
  t127_n74: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t127_n84;
  t127_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t127_n77;
  t127_n76: return 0.031251393258571625;
  t127_n77: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t127_n79;
  t127_n78: return 0.046755533665418625;
  t127_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t127_n83;
  t127_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n82;
  t127_n81: return 0.058441318571567535;
  t127_n82: return -0.05314752459526062;
  t127_n83: return 0.06480571627616882;
  t127_n84: return 0.07780595123767853;
  t127_n85: return 0.05466768145561218;
  t127_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n88;
  t127_n87: return 0.013061321340501308;
  t127_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t127_n90;
  t127_n89: return -0.029706981033086777;
  t127_n90: return 0.0008772704168222845;
  t127_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t127_n101;
  t127_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n100;
  t127_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n99;
  t127_n94: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n96;
  t127_n95: return 0.10119357705116272;
  t127_n96: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n98;
  t127_n97: return 0.10621928423643112;
  t127_n98: return 0.10030637681484222;
  t127_n99: return 0.06524621695280075;
  t127_n100: return 0.07354927808046341;
  t127_n101: return -0.04423133283853531;
  t127_n102: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n180;
  t127_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t127_n105;
  t127_n104: return 0.0014856281923130155;
  t127_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t127_n107;
  t127_n106: return -0.0011221299646422267;
  t127_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n109;
  t127_n108: return 0.008709805086255074;
  t127_n109: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t127_n113;
  t127_n110: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t127_n112;
  t127_n111: return -0.016332441940903664;
  t127_n112: return 0.01289936900138855;
  t127_n113: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t127_n117;
  t127_n114: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t127_n116;
  t127_n115: return -0.02270347811281681;
  t127_n116: return 0.08250240981578827;
  t127_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t127_n139;
  t127_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t127_n122;
  t127_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t127_n121;
  t127_n120: return -0.028481846675276756;
  t127_n121: return 0.040446601808071136;
  t127_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t127_n124;
  t127_n123: return 0.06189781054854393;
  t127_n124: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n138;
  t127_n125: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t127_n137;
  t127_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n136;
  t127_n127: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n131;
  t127_n128: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t127_n130;
  t127_n129: return 0.07174193114042282;
  t127_n130: return 0.0993870422244072;
  t127_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t127_n133;
  t127_n132: return 0.029433585703372955;
  t127_n133: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t127_n135;
  t127_n134: return 0.10577358305454254;
  t127_n135: return 0.11528288573026657;
  t127_n136: return 0.07377087324857712;
  t127_n137: return -0.10452565550804138;
  t127_n138: return 0.003777815494686365;
  t127_n139: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t127_n179;
  t127_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n176;
  t127_n141: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t127_n149;
  t127_n142: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t127_n148;
  t127_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t127_n145;
  t127_n144: return -0.13743169605731964;
  t127_n145: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n147;
  t127_n146: return 0.10013304650783539;
  t127_n147: return -0.03956957161426544;
  t127_n148: return 0.011656754650175571;
  t127_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t127_n151;
  t127_n150: return -0.031949084252119064;
  t127_n151: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t127_n155;
  t127_n152: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t127_n154;
  t127_n153: return 0.1280033141374588;
  t127_n154: return 0.06160049885511398;
  t127_n155: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t127_n161;
  t127_n156: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t127_n160;
  t127_n157: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n159;
  t127_n158: return 0.08969153463840485;
  t127_n159: return 0.047046806663274765;
  t127_n160: return 0.01157862413674593;
  t127_n161: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t127_n175;
  t127_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t127_n166;
  t127_n163: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t127_n165;
  t127_n164: return 0.10557664930820465;
  t127_n165: return 0.08195451647043228;
  t127_n166: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t127_n172;
  t127_n167: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n169;
  t127_n168: return 0.1287168264389038;
  t127_n169: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t127_n171;
  t127_n170: return 0.12299631536006927;
  t127_n171: return 0.08464450389146805;
  t127_n172: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t127_n174;
  t127_n173: return 0.13471311330795288;
  t127_n174: return 0.13825483620166779;
  t127_n175: return 0.019043762236833572;
  t127_n176: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t127_n178;
  t127_n177: return 0.032184481620788574;
  t127_n178: return -0.1731066107749939;
  t127_n179: return -0.10475355386734009;
  t127_n180: return -0.06754317879676819;
  t127_n181: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t127_n239;
  t127_n182: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t127_n186;
  t127_n183: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t127_n185;
  t127_n184: return -0.03854561224579811;
  t127_n185: return -0.12401048094034195;
  t127_n186: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t127_n196;
  t127_n187: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t127_n195;
  t127_n188: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n190;
  t127_n189: return 0.0035606706514954567;
  t127_n190: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t127_n192;
  t127_n191: return 0.028551191091537476;
  t127_n192: if (E.getNumReferences() >= 3290800128 /*662.5*/) goto t127_n194;
  t127_n193: return 0.11445698887109756;
  t127_n194: return -0.15344519913196564;
  t127_n195: return 0.015302308835089207;
  t127_n196: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t127_n200;
  t127_n197: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t127_n199;
  t127_n198: return 0.023947078734636307;
  t127_n199: return 0.00852191261947155;
  t127_n200: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t127_n236;
  t127_n201: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t127_n235;
  t127_n202: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t127_n210;
  t127_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t127_n207;
  t127_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t127_n206;
  t127_n205: return 0.1283305138349533;
  t127_n206: return -0.013218902051448822;
  t127_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t127_n209;
  t127_n208: return -0.10420950502157211;
  t127_n209: return 0.13114315271377563;
  t127_n210: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t127_n212;
  t127_n211: return 0.03403455391526222;
  t127_n212: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t127_n232;
  t127_n213: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t127_n225;
  t127_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t127_n222;
  t127_n215: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t127_n221;
  t127_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t127_n218;
  t127_n217: return 0.023044511675834656;
  t127_n218: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n220;
  t127_n219: return -0.37912628054618835;
  t127_n220: return 0.13337060809135437;
  t127_n221: return 0.06631387025117874;
  t127_n222: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t127_n224;
  t127_n223: return -0.062318556010723114;
  t127_n224: return 0.14634741842746735;
  t127_n225: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t127_n227;
  t127_n226: return 0.05160817503929138;
  t127_n227: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t127_n229;
  t127_n228: return 0.08877972513437271;
  t127_n229: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t127_n231;
  t127_n230: return 0.11619845032691956;
  t127_n231: return 0.1200096532702446;
  t127_n232: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t127_n234;
  t127_n233: return -0.13350805640220642;
  t127_n234: return 0.11391918361186981;
  t127_n235: return -0.004362533800303936;
  t127_n236: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t127_n238;
  t127_n237: return 0.06096503511071205;
  t127_n238: return 0.04986904188990593;
  t127_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t127_n241;
  t127_n240: return -0.04113997519016266;
  t127_n241: return -0.02806910127401352;
  t127_n242: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t127_n252;
  t127_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t127_n245;
  t127_n244: return 0.008860036730766296;
  t127_n245: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t127_n247;
  t127_n246: return -0.008322239853441715;
  t127_n247: if (E.getNumReferences() >= 3300937728 /*1538.5*/) goto t127_n251;
  t127_n248: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t127_n250;
  t127_n249: return -0.11209427565336227;
  t127_n250: return 0.13109566271305084;
  t127_n251: return 0.026091426610946655;
  t127_n252: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t127_n254;
  t127_n253: return -0.009172139689326286;
  t127_n254: return 0.009060784243047237;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree128(const Example& E) {
  t128_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t128_n204;
  t128_n1: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t128_n55;
  t128_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t128_n4;
  t128_n3: return -0.00015902244194876403;
  t128_n4: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t128_n54;
  t128_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t128_n15;
  t128_n6: if (E.getNumReferences() >= 3317725184 /*6159.0*/) goto t128_n8;
  t128_n7: return 0.011330310255289078;
  t128_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t128_n12;
  t128_n9: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t128_n11;
  t128_n10: return 0.1111166849732399;
  t128_n11: return 0.023510359227657318;
  t128_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n14;
  t128_n13: return 0.10327266901731491;
  t128_n14: return -0.013657504692673683;
  t128_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n17;
  t128_n16: return 0.010089710354804993;
  t128_n17: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t128_n39;
  t128_n18: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t128_n20;
  t128_n19: return -0.0022073364816606045;
  t128_n20: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t128_n30;
  t128_n21: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n29;
  t128_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n28;
  t128_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n25;
  t128_n24: return -0.008823536336421967;
  t128_n25: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n27;
  t128_n26: return -0.10186967253684998;
  t128_n27: return 0.10385872423648834;
  t128_n28: return 0.06966374069452286;
  t128_n29: return -0.005219741724431515;
  t128_n30: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t128_n36;
  t128_n31: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t128_n35;
  t128_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n34;
  t128_n33: return 0.11049573123455048;
  t128_n34: return 0.037248704582452774;
  t128_n35: return 0.1273273080587387;
  t128_n36: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t128_n38;
  t128_n37: return 0.0862593874335289;
  t128_n38: return 0.0216072928160429;
  t128_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n51;
  t128_n40: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n48;
  t128_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t128_n43;
  t128_n42: return 0.06766404211521149;
  t128_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n47;
  t128_n44: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t128_n46;
  t128_n45: return 0.09923706948757172;
  t128_n46: return 0.09146406501531601;
  t128_n47: return 0.04765641316771507;
  t128_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t128_n50;
  t128_n49: return 0.06822864711284637;
  t128_n50: return 0.22095943987369537;
  t128_n51: if (E.getNumReferences() >= 3287121920 /*475.0*/) goto t128_n53;
  t128_n52: return 0.00347784161567688;
  t128_n53: return 0.08352558314800262;
  t128_n54: return 0.00013891924754716456;
  t128_n55: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t128_n65;
  t128_n56: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t128_n58;
  t128_n57: return -0.19301681220531464;
  t128_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n60;
  t128_n59: return 0.02651609666645527;
  t128_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t128_n62;
  t128_n61: return -0.02786865271627903;
  t128_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t128_n64;
  t128_n63: return 0.12716445326805115;
  t128_n64: return -0.011153320781886578;
  t128_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t128_n67;
  t128_n66: return -0.029334690421819687;
  t128_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t128_n187;
  t128_n68: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t128_n172;
  t128_n69: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t128_n85;
  t128_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t128_n84;
  t128_n71: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n73;
  t128_n72: return 0.0072152563370764256;
  t128_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n83;
  t128_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n76;
  t128_n75: return 0.27110031247138977;
  t128_n76: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n82;
  t128_n77: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t128_n81;
  t128_n78: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t128_n80;
  t128_n79: return 0.1360194981098175;
  t128_n80: return 0.12327463924884796;
  t128_n81: return 0.6690322160720825;
  t128_n82: return 0.05652303248643875;
  t128_n83: return 0.07710374891757965;
  t128_n84: return -0.09964330494403839;
  t128_n85: if (E.getNumReferences() >= 3264217088 /*72.0*/) goto t128_n167;
  t128_n86: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t128_n148;
  t128_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n89;
  t128_n88: return -0.027512043714523315;
  t128_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t128_n135;
  t128_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n92;
  t128_n91: return 0.09890950471162796;
  t128_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t128_n118;
  t128_n93: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t128_n113;
  t128_n94: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t128_n112;
  t128_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n105;
  t128_n96: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n104;
  t128_n97: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t128_n99;
  t128_n98: return 0.08737918734550476;
  t128_n99: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t128_n101;
  t128_n100: return -0.13280943036079407;
  t128_n101: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t128_n103;
  t128_n102: return 0.12385116517543793;
  t128_n103: return 0.0749073326587677;
  t128_n104: return 0.050544336438179016;
  t128_n105: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t128_n111;
  t128_n106: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n108;
  t128_n107: return 0.13585436344146729;
  t128_n108: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t128_n110;
  t128_n109: return 0.13491596281528473;
  t128_n110: return 0.07420816272497177;
  t128_n111: return -0.19481852650642395;
  t128_n112: return -0.004661059007048607;
  t128_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n115;
  t128_n114: return 0.008821586146950722;
  t128_n115: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n117;
  t128_n116: return 0.14105838537216187;
  t128_n117: return 0.0465388223528862;
  t128_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t128_n120;
  t128_n119: return -0.8048356771469116;
  t128_n120: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t128_n124;
  t128_n121: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t128_n123;
  t128_n122: return 0.022077729925513268;
  t128_n123: return 0.1368601769208908;
  t128_n124: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t128_n134;
  t128_n125: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n127;
  t128_n126: return -0.5372982621192932;
  t128_n127: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t128_n129;
  t128_n128: return 0.12958396971225739;
  t128_n129: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t128_n133;
  t128_n130: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t128_n132;
  t128_n131: return 0.08321269601583481;
  t128_n132: return 0.10969071835279465;
  t128_n133: return 0.017842065542936325;
  t128_n134: return 0.02464677393436432;
  t128_n135: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t128_n137;
  t128_n136: return 0.03597107157111168;
  t128_n137: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n147;
  t128_n138: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t128_n146;
  t128_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t128_n145;
  t128_n140: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t128_n142;
  t128_n141: return -0.528736412525177;
  t128_n142: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n144;
  t128_n143: return 0.02766071818768978;
  t128_n144: return 0.11291050910949707;
  t128_n145: return 0.25306209921836853;
  t128_n146: return 0.1126372218132019;
  t128_n147: return 0.04580110311508179;
  t128_n148: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t128_n150;
  t128_n149: return 0.1125451996922493;
  t128_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t128_n158;
  t128_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n153;
  t128_n152: return -0.18597392737865448;
  t128_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t128_n157;
  t128_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n156;
  t128_n155: return -0.11089203506708145;
  t128_n156: return 0.16411824524402618;
  t128_n157: return -0.14211556315422058;
  t128_n158: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t128_n160;
  t128_n159: return 0.1046842485666275;
  t128_n160: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t128_n164;
  t128_n161: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t128_n163;
  t128_n162: return 0.2239556908607483;
  t128_n163: return -0.011268915608525276;
  t128_n164: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n166;
  t128_n165: return 0.05609806999564171;
  t128_n166: return 0.11201556026935577;
  t128_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n171;
  t128_n168: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t128_n170;
  t128_n169: return 0.551651120185852;
  t128_n170: return 0.08897928893566132;
  t128_n171: return -0.022844547405838966;
  t128_n172: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t128_n174;
  t128_n173: return -0.060091521590948105;
  t128_n174: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t128_n182;
  t128_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t128_n179;
  t128_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n178;
  t128_n177: return -0.10154004395008087;
  t128_n178: return 0.1148194670677185;
  t128_n179: if (E.getNumReferences() >= 3272343552 /*140.0*/) goto t128_n181;
  t128_n180: return 0.39715927839279175;
  t128_n181: return -0.2383345365524292;
  t128_n182: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t128_n184;
  t128_n183: return 0.1668335646390915;
  t128_n184: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n186;
  t128_n185: return 0.07968764007091522;
  t128_n186: return -0.12976323068141937;
  t128_n187: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t128_n195;
  t128_n188: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t128_n194;
  t128_n189: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n191;
  t128_n190: return 0.13778620958328247;
  t128_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n193;
  t128_n192: return -0.12792856991291046;
  t128_n193: return 0.19353531301021576;
  t128_n194: return -0.02724071405827999;
  t128_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n201;
  t128_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t128_n200;
  t128_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n199;
  t128_n198: return 0.180546373128891;
  t128_n199: return 0.12238924950361252;
  t128_n200: return 0.06792907416820526;
  t128_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n203;
  t128_n202: return -0.3112095594406128;
  t128_n203: return 0.10983582586050034;
  t128_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t128_n234;
  t128_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t128_n229;
  t128_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n208;
  t128_n207: return 0.12025420367717743;
  t128_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t128_n210;
  t128_n209: return -0.2309470921754837;
  t128_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t128_n228;
  t128_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t128_n219;
  t128_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n214;
  t128_n213: return -0.1080026850104332;
  t128_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t128_n218;
  t128_n215: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t128_n217;
  t128_n216: return 0.06882044672966003;
  t128_n217: return -0.0023249133955687284;
  t128_n218: return -0.46891945600509644;
  t128_n219: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t128_n223;
  t128_n220: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t128_n222;
  t128_n221: return 0.019726762548089027;
  t128_n222: return -0.30739331245422363;
  t128_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t128_n225;
  t128_n224: return -0.31483229994773865;
  t128_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t128_n227;
  t128_n226: return 0.09750599414110184;
  t128_n227: return 0.05900188535451889;
  t128_n228: return -0.2129601091146469;
  t128_n229: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t128_n233;
  t128_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n232;
  t128_n231: return -0.10753372311592102;
  t128_n232: return -1.7491044998168945;
  t128_n233: return 0.014280424453318119;
  t128_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t128_n240;
  t128_n235: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t128_n237;
  t128_n236: return 0.08289521187543869;
  t128_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t128_n239;
  t128_n238: return -0.1667795330286026;
  t128_n239: return 0.08990631997585297;
  t128_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t128_n242;
  t128_n241: return -0.07343727350234985;
  t128_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t128_n254;
  t128_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t128_n249;
  t128_n244: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t128_n246;
  t128_n245: return 0.006598724517971277;
  t128_n246: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t128_n248;
  t128_n247: return 0.057102020829916;
  t128_n248: return 0.09699983894824982;
  t128_n249: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t128_n251;
  t128_n250: return 0.10274520516395569;
  t128_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t128_n253;
  t128_n252: return 0.10669198632240295;
  t128_n253: return -0.21558444201946259;
  t128_n254: return 0.026346761733293533;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree129(const Example& E) {
  t129_n0: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t129_n254;
  t129_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t129_n3;
  t129_n2: return -0.007691659964621067;
  t129_n3: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t129_n109;
  t129_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n94;
  t129_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t129_n45;
  t129_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t129_n44;
  t129_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t129_n11;
  t129_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n10;
  t129_n9: return 0.03797664865851402;
  t129_n10: return 0.008537189103662968;
  t129_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n19;
  t129_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t129_n14;
  t129_n13: return -0.19508744776248932;
  t129_n14: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t129_n16;
  t129_n15: return -0.03931058570742607;
  t129_n16: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t129_n18;
  t129_n17: return 0.09913968294858932;
  t129_n18: return 0.034488387405872345;
  t129_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t129_n33;
  t129_n20: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n26;
  t129_n21: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t129_n23;
  t129_n22: return 0.015164351090788841;
  t129_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n25;
  t129_n24: return -0.57021164894104;
  t129_n25: return -0.013413242995738983;
  t129_n26: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t129_n32;
  t129_n27: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t129_n31;
  t129_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t129_n30;
  t129_n29: return 0.04978952929377556;
  t129_n30: return 0.06933823972940445;
  t129_n31: return 0.09993742406368256;
  t129_n32: return -0.13248507678508759;
  t129_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n43;
  t129_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t129_n40;
  t129_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n37;
  t129_n36: return -0.0557456910610199;
  t129_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t129_n39;
  t129_n38: return 0.06242829188704491;
  t129_n39: return 0.09922176599502563;
  t129_n40: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t129_n42;
  t129_n41: return 0.501682460308075;
  t129_n42: return 0.11642182618379593;
  t129_n43: return 0.036644600331783295;
  t129_n44: return -0.004359783139079809;
  t129_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t129_n65;
  t129_n46: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t129_n58;
  t129_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t129_n57;
  t129_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t129_n50;
  t129_n49: return 0.023589113727211952;
  t129_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n56;
  t129_n51: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n55;
  t129_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n54;
  t129_n53: return -0.19565369188785553;
  t129_n54: return 0.08846700191497803;
  t129_n55: return 0.08369872719049454;
  t129_n56: return 0.02093617431819439;
  t129_n57: return 0.024689285084605217;
  t129_n58: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n60;
  t129_n59: return 0.014795291237533092;
  t129_n60: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t129_n64;
  t129_n61: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t129_n63;
  t129_n62: return -0.022713622078299522;
  t129_n63: return -0.08399244397878647;
  t129_n64: return 0.01220256369560957;
  t129_n65: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n81;
  t129_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t129_n68;
  t129_n67: return 0.021887045353651047;
  t129_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n80;
  t129_n69: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t129_n79;
  t129_n70: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n78;
  t129_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n73;
  t129_n72: return -0.07201103866100311;
  t129_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t129_n77;
  t129_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t129_n76;
  t129_n75: return -0.17525553703308105;
  t129_n76: return 0.13435927033424377;
  t129_n77: return -0.4067257046699524;
  t129_n78: return -0.12532950937747955;
  t129_n79: return -0.10391449928283691;
  t129_n80: return -0.00952683761715889;
  t129_n81: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n83;
  t129_n82: return 0.02367999404668808;
  t129_n83: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t129_n91;
  t129_n84: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t129_n86;
  t129_n85: return -0.18867696821689606;
  t129_n86: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t129_n88;
  t129_n87: return -0.05312175676226616;
  t129_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n90;
  t129_n89: return -0.1275336891412735;
  t129_n90: return 0.11044471710920334;
  t129_n91: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t129_n93;
  t129_n92: return 0.04071556776762009;
  t129_n93: return 0.11939764767885208;
  t129_n94: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t129_n98;
  t129_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n97;
  t129_n96: return -0.016267811879515648;
  t129_n97: return -0.0027695607859641314;
  t129_n98: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n102;
  t129_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t129_n101;
  t129_n100: return -0.07554813474416733;
  t129_n101: return -0.008187953382730484;
  t129_n102: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t129_n108;
  t129_n103: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t129_n107;
  t129_n104: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n106;
  t129_n105: return 0.03060128539800644;
  t129_n106: return -0.012189654633402824;
  t129_n107: return 0.011047044768929482;
  t129_n108: return 0.04454689100384712;
  t129_n109: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t129_n239;
  t129_n110: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t129_n202;
  t129_n111: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t129_n165;
  t129_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t129_n152;
  t129_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t129_n127;
  t129_n114: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t129_n116;
  t129_n115: return 0.007436295039951801;
  t129_n116: if (E.getNumReferences() >= 3284910080 /*407.5*/) goto t129_n122;
  t129_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t129_n119;
  t129_n118: return -0.05383143573999405;
  t129_n119: if (E.getNumReferences() >= 3280683008 /*278.5*/) goto t129_n121;
  t129_n120: return 0.018672190606594086;
  t129_n121: return 0.09435654431581497;
  t129_n122: if (E.getNumReferences() >= 3285647360 /*430.0*/) goto t129_n126;
  t129_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t129_n125;
  t129_n124: return 0.05368529260158539;
  t129_n125: return 0.11294212937355042;
  t129_n126: return -0.4787428379058838;
  t129_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t129_n131;
  t129_n128: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t129_n130;
  t129_n129: return -0.12939129769802094;
  t129_n130: return 0.038174472749233246;
  t129_n131: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t129_n151;
  t129_n132: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t129_n138;
  t129_n133: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t129_n135;
  t129_n134: return 0.10660149157047272;
  t129_n135: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t129_n137;
  t129_n136: return 0.014599831774830818;
  t129_n137: return 0.1159631758928299;
  t129_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t129_n142;
  t129_n139: if (E.getNumReferences() >= 3273392128 /*156.0*/) goto t129_n141;
  t129_n140: return 0.043844010680913925;
  t129_n141: return 0.11333557218313217;
  t129_n142: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n150;
  t129_n143: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t129_n145;
  t129_n144: return 0.11499449610710144;
  t129_n145: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t129_n149;
  t129_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t129_n148;
  t129_n147: return 0.06375163048505783;
  t129_n148: return 0.10614784061908722;
  t129_n149: return -0.01280986424535513;
  t129_n150: return -0.028974639251828194;
  t129_n151: return -0.0282574575394392;
  t129_n152: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t129_n154;
  t129_n153: return 0.005984603427350521;
  t129_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t129_n158;
  t129_n155: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t129_n157;
  t129_n156: return 0.10986614972352982;
  t129_n157: return 0.08775491267442703;
  t129_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t129_n160;
  t129_n159: return 0.031155792996287346;
  t129_n160: if (E.getNumReferences() >= 3279290368 /*246.0*/) goto t129_n162;
  t129_n161: return 0.07441180944442749;
  t129_n162: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t129_n164;
  t129_n163: return 0.15960188210010529;
  t129_n164: return 0.05742013081908226;
  t129_n165: if (E.getNumReferences() >= 3291652096 /*714.5*/) goto t129_n193;
  t129_n166: if (E.getNumReferences() >= 3291406336 /*699.5*/) goto t129_n190;
  t129_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t129_n189;
  t129_n168: if (E.getNumReferences() >= 3288621056 /*529.5*/) goto t129_n186;
  t129_n169: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t129_n183;
  t129_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t129_n172;
  t129_n171: return -0.20733429491519928;
  t129_n172: if (E.getNumReferences() >= 3288236032 /*509.0*/) goto t129_n182;
  t129_n173: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t129_n181;
  t129_n174: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n178;
  t129_n175: if (E.getNumReferences() >= 3287302144 /*480.5*/) goto t129_n177;
  t129_n176: return 0.09001745283603668;
  t129_n177: return 0.11221414804458618;
  t129_n178: if (E.getNumReferences() >= 3286155264 /*445.5*/) goto t129_n180;
  t129_n179: return 0.1829158216714859;
  t129_n180: return 0.030791547149419785;
  t129_n181: return 0.11794731765985489;
  t129_n182: return -0.30431389808654785;
  t129_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t129_n185;
  t129_n184: return 0.07530451565980911;
  t129_n185: return 0.1236434057354927;
  t129_n186: if (E.getNumReferences() >= 3291095040 /*680.5*/) goto t129_n188;
  t129_n187: return -0.015266263857483864;
  t129_n188: return 0.10801044851541519;
  t129_n189: return 0.03746005892753601;
  t129_n190: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t129_n192;
  t129_n191: return 0.13463523983955383;
  t129_n192: return 0.07794809341430664;
  t129_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t129_n195;
  t129_n194: return 0.0022847920190542936;
  t129_n195: if (E.getNumReferences() >= 3293192192 /*808.5*/) goto t129_n201;
  t129_n196: if (E.getNumReferences() >= 3292332032 /*756.0*/) goto t129_n198;
  t129_n197: return -0.15403933823108673;
  t129_n198: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t129_n200;
  t129_n199: return 0.11970552057027817;
  t129_n200: return 0.10228637605905533;
  t129_n201: return 0.05808211490511894;
  t129_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t129_n216;
  t129_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t129_n205;
  t129_n204: return 0.07025919109582901;
  t129_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t129_n207;
  t129_n206: return 0.06281587481498718;
  t129_n207: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t129_n215;
  t129_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t129_n214;
  t129_n209: if (E.getNumReferences() >= 3273981952 /*165.0*/) goto t129_n211;
  t129_n210: return 0.1211313009262085;
  t129_n211: if (E.getNumReferences() >= 3288653824 /*531.5*/) goto t129_n213;
  t129_n212: return -0.022730126976966858;
  t129_n213: return 0.11782926321029663;
  t129_n214: return 0.12047471106052399;
  t129_n215: return 0.03771568462252617;
  t129_n216: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n218;
  t129_n217: return 0.0613037534058094;
  t129_n218: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t129_n224;
  t129_n219: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t129_n223;
  t129_n220: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t129_n222;
  t129_n221: return 0.1030334010720253;
  t129_n222: return 0.06092708557844162;
  t129_n223: return 0.12551316618919373;
  t129_n224: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t129_n230;
  t129_n225: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t129_n229;
  t129_n226: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t129_n228;
  t129_n227: return 0.10439064353704453;
  t129_n228: return 0.08449821174144745;
  t129_n229: return -0.021648483350872993;
  t129_n230: if (E.getNumReferences() >= 3279126528 /*243.5*/) goto t129_n232;
  t129_n231: return 0.11214737594127655;
  t129_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t129_n234;
  t129_n233: return 0.06785409897565842;
  t129_n234: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t129_n236;
  t129_n235: return -0.13176950812339783;
  t129_n236: if (E.getNumReferences() >= 3288571904 /*526.5*/) goto t129_n238;
  t129_n237: return 0.1025642454624176;
  t129_n238: return 0.12511710822582245;
  t129_n239: if (E.getSymbolScopeDistance() >= 3246915584 /*17.0*/) goto t129_n241;
  t129_n240: return 0.02368789166212082;
  t129_n241: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t129_n243;
  t129_n242: return 0.004314618185162544;
  t129_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t129_n245;
  t129_n244: return -0.13367033004760742;
  t129_n245: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t129_n251;
  t129_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t129_n248;
  t129_n247: return 0.10417942702770233;
  t129_n248: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t129_n250;
  t129_n249: return 0.11251435428857803;
  t129_n250: return 0.07041535526514053;
  t129_n251: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t129_n253;
  t129_n252: return 0.17372679710388184;
  t129_n253: return -0.09710928052663803;
  t129_n254: return -0.001023133983835578;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree130(const Example& E) {
  t130_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t130_n238;
  t130_n1: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t130_n235;
  t130_n2: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t130_n212;
  t130_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t130_n145;
  t130_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n6;
  t130_n5: return -0.002948935143649578;
  t130_n6: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t130_n64;
  t130_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t130_n61;
  t130_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t130_n30;
  t130_n9: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t130_n29;
  t130_n10: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t130_n16;
  t130_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n13;
  t130_n12: return 0.00016591935127507895;
  t130_n13: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t130_n15;
  t130_n14: return -0.031554218381643295;
  t130_n15: return -0.08683695644140244;
  t130_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n18;
  t130_n17: return -0.0369434654712677;
  t130_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t130_n20;
  t130_n19: return -0.010871464386582375;
  t130_n20: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n24;
  t130_n21: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t130_n23;
  t130_n22: return 0.009204646572470665;
  t130_n23: return -0.5822681784629822;
  t130_n24: if (E.getNumReferences() >= 3262382080 /*61.0*/) goto t130_n26;
  t130_n25: return 0.06427311152219772;
  t130_n26: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t130_n28;
  t130_n27: return 0.10910850763320923;
  t130_n28: return -0.41323423385620117;
  t130_n29: return 0.006626317277550697;
  t130_n30: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t130_n54;
  t130_n31: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n47;
  t130_n32: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n40;
  t130_n33: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t130_n35;
  t130_n34: return 0.033613771200180054;
  t130_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t130_n39;
  t130_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t130_n38;
  t130_n37: return 0.043627530336380005;
  t130_n38: return 0.08494244515895844;
  t130_n39: return -0.1362394243478775;
  t130_n40: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t130_n42;
  t130_n41: return -0.004106019623577595;
  t130_n42: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t130_n44;
  t130_n43: return -0.4852466285228729;
  t130_n44: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t130_n46;
  t130_n45: return -0.31864532828330994;
  t130_n46: return 0.057939693331718445;
  t130_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t130_n49;
  t130_n48: return -0.022795360535383224;
  t130_n49: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t130_n53;
  t130_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n52;
  t130_n51: return 0.09376374632120132;
  t130_n52: return 0.05036347731947899;
  t130_n53: return -0.10311231017112732;
  t130_n54: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t130_n60;
  t130_n55: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n59;
  t130_n56: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t130_n58;
  t130_n57: return 0.11039972305297852;
  t130_n58: return -0.14481811225414276;
  t130_n59: return 0.11389802396297455;
  t130_n60: return 0.02404838241636753;
  t130_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t130_n63;
  t130_n62: return -0.11719664931297302;
  t130_n63: return 0.01594984345138073;
  t130_n64: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t130_n144;
  t130_n65: if (E.getNumReferences() >= 3290251264 /*629.0*/) goto t130_n139;
  t130_n66: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t130_n108;
  t130_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t130_n77;
  t130_n68: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t130_n72;
  t130_n69: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t130_n71;
  t130_n70: return -0.12603099644184113;
  t130_n71: return -0.6878109574317932;
  t130_n72: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t130_n74;
  t130_n73: return 0.015119596384465694;
  t130_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n76;
  t130_n75: return 0.10136393457651138;
  t130_n76: return 0.06667456775903702;
  t130_n77: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t130_n79;
  t130_n78: return -0.009225786663591862;
  t130_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t130_n85;
  t130_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n84;
  t130_n81: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n83;
  t130_n82: return -0.0875082015991211;
  t130_n83: return -0.03166820481419563;
  t130_n84: return -0.011955315247178078;
  t130_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t130_n95;
  t130_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t130_n88;
  t130_n87: return -0.024192897602915764;
  t130_n88: if (E.getNumReferences() >= 3282337792 /*329.0*/) goto t130_n94;
  t130_n89: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t130_n93;
  t130_n90: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n92;
  t130_n91: return 0.07601521909236908;
  t130_n92: return 0.11851166188716888;
  t130_n93: return 0.025585994124412537;
  t130_n94: return 0.10365032404661179;
  t130_n95: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t130_n107;
  t130_n96: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t130_n104;
  t130_n97: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n103;
  t130_n98: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t130_n100;
  t130_n99: return -0.2270313948392868;
  t130_n100: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t130_n102;
  t130_n101: return 0.06282704323530197;
  t130_n102: return -0.219752699136734;
  t130_n103: return -0.09138701111078262;
  t130_n104: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t130_n106;
  t130_n105: return 0.1261095553636551;
  t130_n106: return 0.053385891020298004;
  t130_n107: return -0.13257446885108948;
  t130_n108: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n110;
  t130_n109: return 0.01129173394292593;
  t130_n110: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t130_n138;
  t130_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t130_n135;
  t130_n112: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t130_n114;
  t130_n113: return -0.057876937091350555;
  t130_n114: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t130_n128;
  t130_n115: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n127;
  t130_n116: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n124;
  t130_n117: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t130_n121;
  t130_n118: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t130_n120;
  t130_n119: return 0.06323469430208206;
  t130_n120: return -0.2629467248916626;
  t130_n121: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t130_n123;
  t130_n122: return 0.14127756655216217;
  t130_n123: return 0.03948942944407463;
  t130_n124: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t130_n126;
  t130_n125: return 0.13805744051933289;
  t130_n126: return 0.044473662972450256;
  t130_n127: return -0.04719221591949463;
  t130_n128: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t130_n132;
  t130_n129: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t130_n131;
  t130_n130: return -0.8755866289138794;
  t130_n131: return 0.03390796482563019;
  t130_n132: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t130_n134;
  t130_n133: return 0.12129152566194534;
  t130_n134: return 0.05631513521075249;
  t130_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t130_n137;
  t130_n136: return -0.17107143998146057;
  t130_n137: return 0.13522234559059143;
  t130_n138: return -0.013871905393898487;
  t130_n139: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t130_n143;
  t130_n140: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t130_n142;
  t130_n141: return 0.10409152507781982;
  t130_n142: return 0.1292324811220169;
  t130_n143: return 0.00013861303159501404;
  t130_n144: return 0.0013663654681295156;
  t130_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t130_n207;
  t130_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n176;
  t130_n147: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n159;
  t130_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n150;
  t130_n149: return 0.0045145731419324875;
  t130_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n152;
  t130_n151: return 0.023907802999019623;
  t130_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t130_n154;
  t130_n153: return 0.010977627709507942;
  t130_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n156;
  t130_n155: return 0.04206571727991104;
  t130_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n158;
  t130_n157: return 0.0791878029704094;
  t130_n158: return 0.06751847267150879;
  t130_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n167;
  t130_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n164;
  t130_n161: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t130_n163;
  t130_n162: return -0.05879712477326393;
  t130_n163: return -0.05097723379731178;
  t130_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n166;
  t130_n165: return -0.05274703726172447;
  t130_n166: return -0.029834533110260963;
  t130_n167: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t130_n175;
  t130_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t130_n170;
  t130_n169: return -0.003338867099955678;
  t130_n170: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t130_n172;
  t130_n171: return 0.0029067222494632006;
  t130_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t130_n174;
  t130_n173: return -0.15658728778362274;
  t130_n174: return 0.02829454280436039;
  t130_n175: return 0.015800995752215385;
  t130_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n180;
  t130_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n179;
  t130_n178: return 0.001132429693825543;
  t130_n179: return 0.07831817865371704;
  t130_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n198;
  t130_n181: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t130_n183;
  t130_n182: return -0.10815229266881943;
  t130_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t130_n187;
  t130_n184: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t130_n186;
  t130_n185: return 0.010004518553614616;
  t130_n186: return 0.060571663081645966;
  t130_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n197;
  t130_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n190;
  t130_n189: return 0.12000086158514023;
  t130_n190: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n192;
  t130_n191: return 0.21851027011871338;
  t130_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n194;
  t130_n193: return 0.07631996273994446;
  t130_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n196;
  t130_n195: return 0.1442285180091858;
  t130_n196: return 0.14332698285579681;
  t130_n197: return 0.04765865579247475;
  t130_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n200;
  t130_n199: return 0.07696270197629929;
  t130_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n206;
  t130_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n205;
  t130_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t130_n204;
  t130_n203: return 0.21277908980846405;
  t130_n204: return 0.21190407872200012;
  t130_n205: return 0.23484379053115845;
  t130_n206: return 0.003019941970705986;
  t130_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n211;
  t130_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n210;
  t130_n209: return 0.11241426318883896;
  t130_n210: return -0.016642140224575996;
  t130_n211: return 0.0070789470337331295;
  t130_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t130_n216;
  t130_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t130_n215;
  t130_n214: return -0.04124343395233154;
  t130_n215: return -0.036187317222356796;
  t130_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t130_n218;
  t130_n217: return -0.001354633248411119;
  t130_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t130_n234;
  t130_n219: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t130_n221;
  t130_n220: return -0.01977895386517048;
  t130_n221: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t130_n233;
  t130_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t130_n232;
  t130_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t130_n227;
  t130_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t130_n226;
  t130_n225: return 0.03457697853446007;
  t130_n226: return 0.041850745677948;
  t130_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t130_n229;
  t130_n228: return 0.046971965581178665;
  t130_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n231;
  t130_n230: return 0.047512609511613846;
  t130_n231: return 0.08105888217687607;
  t130_n232: return -0.003076889319345355;
  t130_n233: return 0.03939313441514969;
  t130_n234: return 0.09340789914131165;
  t130_n235: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t130_n237;
  t130_n236: return -0.11572147160768509;
  t130_n237: return -0.08440274000167847;
  t130_n238: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t130_n254;
  t130_n239: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t130_n251;
  t130_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t130_n244;
  t130_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t130_n243;
  t130_n242: return -0.03744393214583397;
  t130_n243: return 0.06985469162464142;
  t130_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t130_n248;
  t130_n245: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t130_n247;
  t130_n246: return 0.07309644669294357;
  t130_n247: return 0.10619419813156128;
  t130_n248: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t130_n250;
  t130_n249: return 0.09155163913965225;
  t130_n250: return -0.11558487266302109;
  t130_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t130_n253;
  t130_n252: return -0.0069737969897687435;
  t130_n253: return 0.08267975598573685;
  t130_n254: return 0.02389529161155224;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree131(const Example& E) {
  t131_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t131_n2;
  t131_n1: return -0.0003603216027840972;
  t131_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t131_n4;
  t131_n3: return -0.005927770398557186;
  t131_n4: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t131_n146;
  t131_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t131_n125;
  t131_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t131_n14;
  t131_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t131_n9;
  t131_n8: return -0.04417499154806137;
  t131_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n11;
  t131_n10: return 0.011501467786729336;
  t131_n11: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n13;
  t131_n12: return 0.11795762926340103;
  t131_n13: return 0.06489533185958862;
  t131_n14: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t131_n16;
  t131_n15: return 0.001566210645250976;
  t131_n16: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t131_n22;
  t131_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n19;
  t131_n18: return 0.04376630857586861;
  t131_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n21;
  t131_n20: return 0.12924714386463165;
  t131_n21: return 0.09300102293491364;
  t131_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t131_n124;
  t131_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t131_n59;
  t131_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t131_n34;
  t131_n25: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t131_n27;
  t131_n26: return -0.13779930770397186;
  t131_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t131_n29;
  t131_n28: return 0.04029922932386398;
  t131_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t131_n33;
  t131_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n32;
  t131_n31: return 0.10075443238019943;
  t131_n32: return 0.08466066420078278;
  t131_n33: return 0.04164939373731613;
  t131_n34: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t131_n58;
  t131_n35: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t131_n37;
  t131_n36: return 0.04528266564011574;
  t131_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n55;
  t131_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n54;
  t131_n39: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t131_n47;
  t131_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n42;
  t131_n41: return -0.12507465481758118;
  t131_n42: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n46;
  t131_n43: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n45;
  t131_n44: return -0.10164414346218109;
  t131_n45: return 0.11607784032821655;
  t131_n46: return -0.12962056696414948;
  t131_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n49;
  t131_n48: return 0.084864042699337;
  t131_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t131_n51;
  t131_n50: return -0.011194691993296146;
  t131_n51: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t131_n53;
  t131_n52: return 0.129576176404953;
  t131_n53: return 0.086077980697155;
  t131_n54: return -0.13184835016727448;
  t131_n55: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t131_n57;
  t131_n56: return 0.11302101612091064;
  t131_n57: return 0.09585867077112198;
  t131_n58: return 0.005898073315620422;
  t131_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t131_n61;
  t131_n60: return -0.12185569852590561;
  t131_n61: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t131_n93;
  t131_n62: if (E.getNumReferences() >= 3359032704 /*187158.0*/) goto t131_n72;
  t131_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n65;
  t131_n64: return -0.009420318529009819;
  t131_n65: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t131_n71;
  t131_n66: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t131_n70;
  t131_n67: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t131_n69;
  t131_n68: return 0.11917590349912643;
  t131_n69: return 0.07925869524478912;
  t131_n70: return 0.10985764861106873;
  t131_n71: return 0.04125822335481644;
  t131_n72: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n92;
  t131_n73: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t131_n81;
  t131_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t131_n76;
  t131_n75: return 0.031143270432949066;
  t131_n76: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t131_n80;
  t131_n77: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n79;
  t131_n78: return 0.07727304100990295;
  t131_n79: return 0.11294378340244293;
  t131_n80: return -0.24834240972995758;
  t131_n81: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t131_n91;
  t131_n82: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n90;
  t131_n83: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t131_n85;
  t131_n84: return 0.035175714641809464;
  t131_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n87;
  t131_n86: return -0.27166351675987244;
  t131_n87: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t131_n89;
  t131_n88: return -0.11513693630695343;
  t131_n89: return 0.10969401150941849;
  t131_n90: return 0.05191243067383766;
  t131_n91: return 0.12951821088790894;
  t131_n92: return 0.04285501688718796;
  t131_n93: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t131_n95;
  t131_n94: return -0.050002723932266235;
  t131_n95: if (E.getNumReferences() >= 3367700464 /*383039.5*/) goto t131_n115;
  t131_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n98;
  t131_n97: return -0.17568399012088776;
  t131_n98: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n100;
  t131_n99: return 0.03869755566120148;
  t131_n100: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t131_n102;
  t131_n101: return -0.1856314092874527;
  t131_n102: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t131_n114;
  t131_n103: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t131_n109;
  t131_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t131_n108;
  t131_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n107;
  t131_n106: return 0.12017865478992462;
  t131_n107: return 0.1091117113828659;
  t131_n108: return -0.05335460230708122;
  t131_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n113;
  t131_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n112;
  t131_n111: return -0.19133485853672028;
  t131_n112: return 0.10407386720180511;
  t131_n113: return 0.0999177098274231;
  t131_n114: return -0.31616127490997314;
  t131_n115: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t131_n123;
  t131_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n122;
  t131_n117: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t131_n119;
  t131_n118: return 0.026913488283753395;
  t131_n119: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t131_n121;
  t131_n120: return 0.08861899375915527;
  t131_n121: return 0.09922938793897629;
  t131_n122: return -0.2237602323293686;
  t131_n123: return -0.006464318372309208;
  t131_n124: return -0.02886549010872841;
  t131_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t131_n145;
  t131_n126: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t131_n134;
  t131_n127: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t131_n129;
  t131_n128: return 0.08867527544498444;
  t131_n129: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n131;
  t131_n130: return 0.05749361962080002;
  t131_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t131_n133;
  t131_n132: return 0.10754286497831345;
  t131_n133: return 0.10741882771253586;
  t131_n134: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t131_n136;
  t131_n135: return 0.11484185606241226;
  t131_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n138;
  t131_n137: return -0.01610996574163437;
  t131_n138: if (E.getNumReferences() >= 3334782720 /*25183.5*/) goto t131_n140;
  t131_n139: return -0.1464831680059433;
  t131_n140: if (E.getNumReferences() >= 3335060480 /*25726.0*/) goto t131_n144;
  t131_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t131_n143;
  t131_n142: return 0.014440156519412994;
  t131_n143: return 0.10218120366334915;
  t131_n144: return 0.024396678432822227;
  t131_n145: return 0.030461158603429794;
  t131_n146: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t131_n248;
  t131_n147: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t131_n221;
  t131_n148: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t131_n196;
  t131_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n159;
  t131_n150: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t131_n158;
  t131_n151: if (E.getNumReferences() >= 3338538752 /*32519.5*/) goto t131_n153;
  t131_n152: return -0.04704482853412628;
  t131_n153: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n155;
  t131_n154: return -0.00896223820745945;
  t131_n155: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t131_n157;
  t131_n156: return 0.12483098357915878;
  t131_n157: return -0.0021671403665095568;
  t131_n158: return -0.06821350753307343;
  t131_n159: if (E.getNumReferences() >= 3336061952 /*27682.0*/) goto t131_n173;
  t131_n160: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t131_n172;
  t131_n161: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t131_n163;
  t131_n162: return -0.08106474578380585;
  t131_n163: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t131_n165;
  t131_n164: return 0.05035281553864479;
  t131_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t131_n167;
  t131_n166: return 0.059115756303071976;
  t131_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n169;
  t131_n168: return 0.16439983248710632;
  t131_n169: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t131_n171;
  t131_n170: return 0.11612065136432648;
  t131_n171: return 0.10894308984279633;
  t131_n172: return -0.19035710394382477;
  t131_n173: if (E.getNumReferences() >= 3341475968 /*43744.5*/) goto t131_n193;
  t131_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n190;
  t131_n175: if (E.getNumReferences() >= 3336492544 /*28523.0*/) goto t131_n181;
  t131_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n178;
  t131_n177: return 0.09252206981182098;
  t131_n178: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n180;
  t131_n179: return 0.13529548048973083;
  t131_n180: return 0.07451623678207397;
  t131_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t131_n185;
  t131_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n184;
  t131_n183: return -0.005304524675011635;
  t131_n184: return 0.0583963580429554;
  t131_n185: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t131_n189;
  t131_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t131_n188;
  t131_n187: return 0.03915403038263321;
  t131_n188: return 0.11361493170261383;
  t131_n189: return 0.05797029659152031;
  t131_n190: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t131_n192;
  t131_n191: return 0.04020101577043533;
  t131_n192: return 0.12158134579658508;
  t131_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t131_n195;
  t131_n194: return -0.021119985729455948;
  t131_n195: return 0.06477037817239761;
  t131_n196: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t131_n206;
  t131_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n203;
  t131_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t131_n200;
  t131_n199: return -0.053808338940143585;
  t131_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n202;
  t131_n201: return 0.03514924272894859;
  t131_n202: return 0.11422066390514374;
  t131_n203: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t131_n205;
  t131_n204: return 0.1116797924041748;
  t131_n205: return 0.1238069161772728;
  t131_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t131_n208;
  t131_n207: return 0.012073070742189884;
  t131_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t131_n210;
  t131_n209: return -0.07273460179567337;
  t131_n210: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t131_n220;
  t131_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t131_n219;
  t131_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n218;
  t131_n213: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t131_n215;
  t131_n214: return 0.1194237694144249;
  t131_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t131_n217;
  t131_n216: return 0.12102095782756805;
  t131_n217: return 0.026126712560653687;
  t131_n218: return 0.04853149503469467;
  t131_n219: return -0.1035323217511177;
  t131_n220: return 0.01858234405517578;
  t131_n221: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t131_n247;
  t131_n222: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t131_n242;
  t131_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t131_n233;
  t131_n224: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t131_n232;
  t131_n225: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t131_n231;
  t131_n226: if (E.getNumReferences() >= 3334007808 /*23670.0*/) goto t131_n230;
  t131_n227: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t131_n229;
  t131_n228: return 0.104581817984581;
  t131_n229: return 0.11011823266744614;
  t131_n230: return 0.06714744865894318;
  t131_n231: return 0.05444567650556564;
  t131_n232: return -0.004656864795833826;
  t131_n233: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t131_n239;
  t131_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t131_n236;
  t131_n235: return 0.10439599305391312;
  t131_n236: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t131_n238;
  t131_n237: return 0.07678703218698502;
  t131_n238: return 0.09560355544090271;
  t131_n239: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t131_n241;
  t131_n240: return 0.07558206468820572;
  t131_n241: return 0.11327574402093887;
  t131_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t131_n244;
  t131_n243: return -0.20026522874832153;
  t131_n244: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t131_n246;
  t131_n245: return 0.03419800475239754;
  t131_n246: return -0.23914828896522522;
  t131_n247: return 0.12865585088729858;
  t131_n248: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t131_n250;
  t131_n249: return -0.06017472967505455;
  t131_n250: if (E.getNumReferences() >= 3351127744 /*97357.5*/) goto t131_n254;
  t131_n251: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t131_n253;
  t131_n252: return 0.14087285101413727;
  t131_n253: return 0.12002420425415039;
  t131_n254: return 0.009505398571491241;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree132(const Example& E) {
  t132_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t132_n2;
  t132_n1: return -0.00023079494712874293;
  t132_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t132_n4;
  t132_n3: return -0.000370038760593161;
  t132_n4: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t132_n238;
  t132_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t132_n173;
  t132_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t132_n134;
  t132_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t132_n31;
  t132_n8: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n30;
  t132_n9: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t132_n25;
  t132_n10: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t132_n24;
  t132_n11: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t132_n13;
  t132_n12: return 0.02094973251223564;
  t132_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t132_n21;
  t132_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n16;
  t132_n15: return 0.12740810215473175;
  t132_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t132_n18;
  t132_n17: return 0.009752071462571621;
  t132_n18: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n20;
  t132_n19: return 0.1262541264295578;
  t132_n20: return 0.0863729864358902;
  t132_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n23;
  t132_n22: return 0.10526528209447861;
  t132_n23: return 0.07772671431303024;
  t132_n24: return -0.012636400759220123;
  t132_n25: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n27;
  t132_n26: return -0.12618687748908997;
  t132_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n29;
  t132_n28: return -0.2382706105709076;
  t132_n29: return 0.02957635372877121;
  t132_n30: return -0.03816269338130951;
  t132_n31: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t132_n111;
  t132_n32: if (E.getNumReferences() >= 3360198688 /*205376.5*/) goto t132_n102;
  t132_n33: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t132_n35;
  t132_n34: return 0.11150722950696945;
  t132_n35: if (E.getNumReferences() >= 3356314496 /*144686.0*/) goto t132_n101;
  t132_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n38;
  t132_n37: return -0.11951316148042679;
  t132_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n56;
  t132_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t132_n41;
  t132_n40: return -0.015636321157217026;
  t132_n41: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t132_n49;
  t132_n42: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t132_n48;
  t132_n43: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t132_n47;
  t132_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n46;
  t132_n45: return -0.13387039303779602;
  t132_n46: return 0.10677402466535568;
  t132_n47: return 0.059135209769010544;
  t132_n48: return -0.015675770118832588;
  t132_n49: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t132_n55;
  t132_n50: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t132_n52;
  t132_n51: return 0.1024903878569603;
  t132_n52: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n54;
  t132_n53: return 0.1490076780319214;
  t132_n54: return 0.09665880352258682;
  t132_n55: return 0.0015752374893054366;
  t132_n56: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t132_n100;
  t132_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t132_n59;
  t132_n58: return -0.13378240168094635;
  t132_n59: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t132_n91;
  t132_n60: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t132_n88;
  t132_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t132_n73;
  t132_n62: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t132_n68;
  t132_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n67;
  t132_n64: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t132_n66;
  t132_n65: return 0.03875603526830673;
  t132_n66: return -0.4043794572353363;
  t132_n67: return 0.06827171891927719;
  t132_n68: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t132_n72;
  t132_n69: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t132_n71;
  t132_n70: return 0.12378012388944626;
  t132_n71: return 0.07612214982509613;
  t132_n72: return -0.12261688709259033;
  t132_n73: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t132_n87;
  t132_n74: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t132_n78;
  t132_n75: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n77;
  t132_n76: return 0.10380011796951294;
  t132_n77: return 0.0666559562087059;
  t132_n78: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t132_n82;
  t132_n79: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n81;
  t132_n80: return -0.16225512325763702;
  t132_n81: return 0.11756531149148941;
  t132_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n86;
  t132_n83: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t132_n85;
  t132_n84: return 0.1069502979516983;
  t132_n85: return 0.09089995920658112;
  t132_n86: return 0.08599149435758591;
  t132_n87: return -0.0807671919465065;
  t132_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t132_n90;
  t132_n89: return -0.4660658538341522;
  t132_n90: return 0.0938781127333641;
  t132_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n93;
  t132_n92: return -0.45359006524086;
  t132_n93: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t132_n95;
  t132_n94: return 0.008756319992244244;
  t132_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t132_n97;
  t132_n96: return 0.06890810281038284;
  t132_n97: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n99;
  t132_n98: return 0.09900934249162674;
  t132_n99: return 0.09237090498209;
  t132_n100: return 0.026850711554288864;
  t132_n101: return -0.13444438576698303;
  t132_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n106;
  t132_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t132_n105;
  t132_n104: return 0.07655394077301025;
  t132_n105: return 0.06526625156402588;
  t132_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t132_n108;
  t132_n107: return -0.04312387853860855;
  t132_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t132_n110;
  t132_n109: return -0.23941729962825775;
  t132_n110: return 0.04038716480135918;
  t132_n111: if (E.getNumReferences() >= 3364277024 /*276057.0*/) goto t132_n113;
  t132_n112: return -0.12491898983716965;
  t132_n113: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t132_n115;
  t132_n114: return 0.020413119345903397;
  t132_n115: if (E.getNumReferences() >= 3364974544 /*297854.5*/) goto t132_n125;
  t132_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n118;
  t132_n117: return 0.021145647391676903;
  t132_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t132_n122;
  t132_n119: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t132_n121;
  t132_n120: return 0.009499656036496162;
  t132_n121: return 0.19517827033996582;
  t132_n122: if (E.getNumReferences() >= 3364292576 /*276543.0*/) goto t132_n124;
  t132_n123: return 0.15393130481243134;
  t132_n124: return 0.11826571822166443;
  t132_n125: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t132_n133;
  t132_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t132_n132;
  t132_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t132_n129;
  t132_n128: return -0.07975386828184128;
  t132_n129: if (E.getNumReferences() >= 3368194704 /*398484.5*/) goto t132_n131;
  t132_n130: return -0.2305002063512802;
  t132_n131: return 0.06887318938970566;
  t132_n132: return -0.010413216426968575;
  t132_n133: return 0.020718201994895935;
  t132_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t132_n172;
  t132_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t132_n141;
  t132_n136: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t132_n138;
  t132_n137: return -0.054807811975479126;
  t132_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n140;
  t132_n139: return 0.12469664216041565;
  t132_n140: return 0.03205430135130882;
  t132_n141: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t132_n159;
  t132_n142: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n144;
  t132_n143: return 0.04732026904821396;
  t132_n144: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t132_n158;
  t132_n145: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t132_n157;
  t132_n146: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t132_n156;
  t132_n147: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n155;
  t132_n148: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t132_n150;
  t132_n149: return 0.08277637511491776;
  t132_n150: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t132_n152;
  t132_n151: return 0.08481331914663315;
  t132_n152: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n154;
  t132_n153: return 0.09604128450155258;
  t132_n154: return 0.10964702069759369;
  t132_n155: return 0.11594053357839584;
  t132_n156: return -0.09088559448719025;
  t132_n157: return 0.1180669516324997;
  t132_n158: return -0.4370654225349426;
  t132_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n163;
  t132_n160: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t132_n162;
  t132_n161: return -0.026341529563069344;
  t132_n162: return 0.08491241931915283;
  t132_n163: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t132_n169;
  t132_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n168;
  t132_n165: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t132_n167;
  t132_n166: return 0.09579815715551376;
  t132_n167: return 0.09167357534170151;
  t132_n168: return 0.04617942124605179;
  t132_n169: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n171;
  t132_n170: return 0.10915204137563705;
  t132_n171: return 0.019150977954268456;
  t132_n172: return 0.10868129134178162;
  t132_n173: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t132_n207;
  t132_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t132_n188;
  t132_n175: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t132_n185;
  t132_n176: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t132_n184;
  t132_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n179;
  t132_n178: return 0.007463013753294945;
  t132_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t132_n183;
  t132_n180: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t132_n182;
  t132_n181: return 0.17742329835891724;
  t132_n182: return -0.03821028769016266;
  t132_n183: return 0.12313332408666611;
  t132_n184: return 0.176448255777359;
  t132_n185: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t132_n187;
  t132_n186: return -0.11459717154502869;
  t132_n187: return 0.024958185851573944;
  t132_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n206;
  t132_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t132_n205;
  t132_n190: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t132_n192;
  t132_n191: return -0.7604097723960876;
  t132_n192: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n202;
  t132_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n199;
  t132_n194: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t132_n198;
  t132_n195: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t132_n197;
  t132_n196: return 0.07932901382446289;
  t132_n197: return 0.10823021829128265;
  t132_n198: return -0.11763890832662582;
  t132_n199: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t132_n201;
  t132_n200: return 0.11272784322500229;
  t132_n201: return 0.0885295569896698;
  t132_n202: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t132_n204;
  t132_n203: return 0.10095072537660599;
  t132_n204: return 0.0022033816203475;
  t132_n205: return 0.05364092439413071;
  t132_n206: return 0.036674778908491135;
  t132_n207: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t132_n209;
  t132_n208: return -0.04845842346549034;
  t132_n209: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t132_n237;
  t132_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t132_n212;
  t132_n211: return -0.11431209743022919;
  t132_n212: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t132_n236;
  t132_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t132_n215;
  t132_n214: return 0.0003297704679425806;
  t132_n215: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t132_n225;
  t132_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n224;
  t132_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t132_n223;
  t132_n218: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t132_n220;
  t132_n219: return -0.020127873867750168;
  t132_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t132_n222;
  t132_n221: return 0.07981470227241516;
  t132_n222: return 0.07835733890533447;
  t132_n223: return -0.00782192125916481;
  t132_n224: return -0.34331536293029785;
  t132_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t132_n229;
  t132_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t132_n228;
  t132_n227: return 0.10033934563398361;
  t132_n228: return 0.07124831527471542;
  t132_n229: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n231;
  t132_n230: return 0.10772485285997391;
  t132_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t132_n233;
  t132_n232: return 0.14022020995616913;
  t132_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t132_n235;
  t132_n234: return 0.10327988117933273;
  t132_n235: return 0.1060648187994957;
  t132_n236: return -0.04050632193684578;
  t132_n237: return -0.08772735297679901;
  t132_n238: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t132_n254;
  t132_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t132_n249;
  t132_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t132_n242;
  t132_n241: return 0.09181050956249237;
  t132_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t132_n244;
  t132_n243: return 0.11663446575403214;
  t132_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t132_n246;
  t132_n245: return 0.0668034702539444;
  t132_n246: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t132_n248;
  t132_n247: return 0.1429954171180725;
  t132_n248: return -0.039259228855371475;
  t132_n249: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t132_n253;
  t132_n250: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t132_n252;
  t132_n251: return -0.013364232145249844;
  t132_n252: return 0.10676288604736328;
  t132_n253: return 0.13169772922992706;
  t132_n254: return 0.005715334787964821;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree133(const Example& E) {
  t133_n0: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t133_n218;
  t133_n1: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t133_n211;
  t133_n2: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t133_n100;
  t133_n3: if (E.getNumReferences() >= 3358365376 /*176731.0*/) goto t133_n99;
  t133_n4: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t133_n98;
  t133_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n7;
  t133_n6: return -0.00877845287322998;
  t133_n7: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t133_n93;
  t133_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t133_n34;
  t133_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n11;
  t133_n10: return 0.01130644790828228;
  t133_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t133_n31;
  t133_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t133_n16;
  t133_n13: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t133_n15;
  t133_n14: return 0.007402205839753151;
  t133_n15: return 0.039278965443372726;
  t133_n16: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t133_n30;
  t133_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t133_n19;
  t133_n18: return 0.036251652985811234;
  t133_n19: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t133_n29;
  t133_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n28;
  t133_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t133_n23;
  t133_n22: return 0.04599998891353607;
  t133_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n27;
  t133_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t133_n26;
  t133_n25: return -0.14591257274150848;
  t133_n26: return 0.11093499511480331;
  t133_n27: return 0.1260286420583725;
  t133_n28: return 0.008199135772883892;
  t133_n29: return -0.047670070081949234;
  t133_n30: return 0.02572455070912838;
  t133_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t133_n33;
  t133_n32: return -0.05616479367017746;
  t133_n33: return -0.005264881066977978;
  t133_n34: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t133_n76;
  t133_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t133_n37;
  t133_n36: return -0.009399202652275562;
  t133_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t133_n51;
  t133_n38: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t133_n50;
  t133_n39: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t133_n49;
  t133_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t133_n44;
  t133_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t133_n43;
  t133_n42: return -0.2155727744102478;
  t133_n43: return 0.03463761508464813;
  t133_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t133_n46;
  t133_n45: return -0.31235912442207336;
  t133_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n48;
  t133_n47: return 0.11745324730873108;
  t133_n48: return 0.050132714211940765;
  t133_n49: return -0.06991612166166306;
  t133_n50: return 0.050839539617300034;
  t133_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t133_n53;
  t133_n52: return 0.040467519313097;
  t133_n53: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t133_n75;
  t133_n54: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t133_n58;
  t133_n55: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t133_n57;
  t133_n56: return 0.09319140017032623;
  t133_n57: return 0.03778776526451111;
  t133_n58: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t133_n72;
  t133_n59: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t133_n61;
  t133_n60: return 0.12043103575706482;
  t133_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n67;
  t133_n62: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n66;
  t133_n63: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t133_n65;
  t133_n64: return 0.1269398182630539;
  t133_n65: return 0.012581050395965576;
  t133_n66: return -0.1396813988685608;
  t133_n67: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n69;
  t133_n68: return 0.08169324696063995;
  t133_n69: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t133_n71;
  t133_n70: return 0.09909620881080627;
  t133_n71: return 0.14038144052028656;
  t133_n72: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t133_n74;
  t133_n73: return 0.12771810591220856;
  t133_n74: return -0.09332259744405746;
  t133_n75: return -0.28287214040756226;
  t133_n76: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t133_n78;
  t133_n77: return 0.006310472264885902;
  t133_n78: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t133_n92;
  t133_n79: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t133_n91;
  t133_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t133_n82;
  t133_n81: return 0.03945862874388695;
  t133_n82: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n90;
  t133_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t133_n85;
  t133_n84: return 0.05746820196509361;
  t133_n85: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t133_n89;
  t133_n86: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n88;
  t133_n87: return 0.1381571739912033;
  t133_n88: return -0.04181099683046341;
  t133_n89: return 0.04945766553282738;
  t133_n90: return 0.037565141916275024;
  t133_n91: return -0.01639365404844284;
  t133_n92: return 0.10738912969827652;
  t133_n93: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t133_n95;
  t133_n94: return 0.018982725217938423;
  t133_n95: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t133_n97;
  t133_n96: return 0.10571694374084473;
  t133_n97: return 0.03637830913066864;
  t133_n98: return -0.000919215613976121;
  t133_n99: return -0.14139601588249207;
  t133_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t133_n154;
  t133_n101: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t133_n141;
  t133_n102: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t133_n126;
  t133_n103: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t133_n125;
  t133_n104: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t133_n108;
  t133_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n107;
  t133_n106: return -0.012179065495729446;
  t133_n107: return 0.059305619448423386;
  t133_n108: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t133_n120;
  t133_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n113;
  t133_n110: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t133_n112;
  t133_n111: return 0.0359310582280159;
  t133_n112: return 0.08014608919620514;
  t133_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n119;
  t133_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t133_n116;
  t133_n115: return 0.050183385610580444;
  t133_n116: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t133_n118;
  t133_n117: return 0.10777033120393753;
  t133_n118: return 0.01933145336806774;
  t133_n119: return -0.2673371136188507;
  t133_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n122;
  t133_n121: return -0.17546118795871735;
  t133_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n124;
  t133_n123: return 0.0576317124068737;
  t133_n124: return 0.14401264488697052;
  t133_n125: return -0.16914312541484833;
  t133_n126: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n132;
  t133_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t133_n129;
  t133_n128: return 0.025926623493433;
  t133_n129: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t133_n131;
  t133_n130: return 0.10505885630846024;
  t133_n131: return 0.049464281648397446;
  t133_n132: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t133_n140;
  t133_n133: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t133_n139;
  t133_n134: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t133_n136;
  t133_n135: return 0.048541031777858734;
  t133_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n138;
  t133_n137: return -0.14133009314537048;
  t133_n138: return 0.044319868087768555;
  t133_n139: return 0.04037921875715256;
  t133_n140: return 0.06859810650348663;
  t133_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t133_n143;
  t133_n142: return -0.004268605262041092;
  t133_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n145;
  t133_n144: return 0.06278946250677109;
  t133_n145: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t133_n151;
  t133_n146: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n148;
  t133_n147: return -0.008774851448833942;
  t133_n148: if (E.getNumReferences() >= 3361193824 /*220925.5*/) goto t133_n150;
  t133_n149: return 0.11016172915697098;
  t133_n150: return 0.05477721244096756;
  t133_n151: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n153;
  t133_n152: return 0.14864996075630188;
  t133_n153: return 0.11221860349178314;
  t133_n154: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t133_n204;
  t133_n155: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t133_n177;
  t133_n156: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t133_n164;
  t133_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t133_n159;
  t133_n158: return 0.0394953228533268;
  t133_n159: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n163;
  t133_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n162;
  t133_n161: return 0.1056072935461998;
  t133_n162: return 0.06995072215795517;
  t133_n163: return 0.03734789043664932;
  t133_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t133_n166;
  t133_n165: return -0.09681340306997299;
  t133_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n168;
  t133_n167: return 0.005836401600390673;
  t133_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n174;
  t133_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t133_n171;
  t133_n170: return 0.03806673735380173;
  t133_n171: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t133_n173;
  t133_n172: return 0.09493647515773773;
  t133_n173: return 0.05397256463766098;
  t133_n174: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t133_n176;
  t133_n175: return 0.0943216010928154;
  t133_n176: return 0.0027263257652521133;
  t133_n177: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t133_n203;
  t133_n178: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n202;
  t133_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t133_n181;
  t133_n180: return 0.011522280052304268;
  t133_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t133_n201;
  t133_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n184;
  t133_n183: return 0.11275701224803925;
  t133_n184: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t133_n200;
  t133_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t133_n193;
  t133_n186: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t133_n192;
  t133_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n191;
  t133_n188: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t133_n190;
  t133_n189: return -0.11408363282680511;
  t133_n190: return 0.10798834264278412;
  t133_n191: return 0.06029871106147766;
  t133_n192: return 0.07039657980203629;
  t133_n193: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t133_n195;
  t133_n194: return -0.2928747236728668;
  t133_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t133_n197;
  t133_n196: return 0.119465172290802;
  t133_n197: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t133_n199;
  t133_n198: return -0.32809239625930786;
  t133_n199: return 0.10725073516368866;
  t133_n200: return 0.0387493297457695;
  t133_n201: return 0.006100911647081375;
  t133_n202: return -0.1870645433664322;
  t133_n203: return 0.12239577621221542;
  t133_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t133_n210;
  t133_n205: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t133_n209;
  t133_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t133_n208;
  t133_n207: return 0.1075863242149353;
  t133_n208: return 0.06948912888765335;
  t133_n209: return 0.027647975832223892;
  t133_n210: return 0.11800745129585266;
  t133_n211: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t133_n213;
  t133_n212: return -0.10019996017217636;
  t133_n213: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t133_n215;
  t133_n214: return -0.05735429748892784;
  t133_n215: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t133_n217;
  t133_n216: return -0.14541539549827576;
  t133_n217: return 0.10832113027572632;
  t133_n218: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t133_n236;
  t133_n219: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t133_n221;
  t133_n220: return 0.02157176099717617;
  t133_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t133_n223;
  t133_n222: return 0.013454900123178959;
  t133_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t133_n227;
  t133_n224: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n226;
  t133_n225: return 0.07732607424259186;
  t133_n226: return 0.05403336137533188;
  t133_n227: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t133_n235;
  t133_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t133_n234;
  t133_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t133_n231;
  t133_n230: return -0.15946055948734283;
  t133_n231: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t133_n233;
  t133_n232: return -0.15938948094844818;
  t133_n233: return 0.06053916737437248;
  t133_n234: return 0.021026764065027237;
  t133_n235: return 0.09404709935188293;
  t133_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t133_n238;
  t133_n237: return -0.0065467930398881435;
  t133_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t133_n254;
  t133_n239: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t133_n245;
  t133_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t133_n242;
  t133_n241: return 0.008940257132053375;
  t133_n242: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t133_n244;
  t133_n243: return -0.23059743642807007;
  t133_n244: return 0.10125628858804703;
  t133_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t133_n247;
  t133_n246: return 0.08233146369457245;
  t133_n247: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t133_n251;
  t133_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t133_n250;
  t133_n249: return 0.06321302801370621;
  t133_n250: return 0.10176944732666016;
  t133_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t133_n253;
  t133_n252: return 0.052333783358335495;
  t133_n253: return 0.1063307672739029;
  t133_n254: return -0.8691563010215759;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree134(const Example& E) {
  t134_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t134_n90;
  t134_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t134_n3;
  t134_n2: return -0.0007464553345926106;
  t134_n3: if (E.getNumReferences() >= 3338172416 /*31804.0*/) goto t134_n57;
  t134_n4: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t134_n48;
  t134_n5: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t134_n9;
  t134_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t134_n8;
  t134_n7: return -0.005171888507902622;
  t134_n8: return 0.0059379031881690025;
  t134_n9: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t134_n31;
  t134_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t134_n24;
  t134_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n15;
  t134_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n14;
  t134_n13: return 0.06563541293144226;
  t134_n14: return 0.11302883923053741;
  t134_n15: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n19;
  t134_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n18;
  t134_n17: return 0.13165242969989777;
  t134_n18: return 0.18910378217697144;
  t134_n19: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t134_n21;
  t134_n20: return 0.0829041376709938;
  t134_n21: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n23;
  t134_n22: return 0.10028422623872757;
  t134_n23: return 0.10378947854042053;
  t134_n24: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n28;
  t134_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t134_n27;
  t134_n26: return 0.09631536155939102;
  t134_n27: return 0.05877811834216118;
  t134_n28: if (E.getNumReferences() >= 3329037312 /*15173.0*/) goto t134_n30;
  t134_n29: return 0.10350564867258072;
  t134_n30: return -0.08533814549446106;
  t134_n31: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t134_n41;
  t134_n32: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t134_n36;
  t134_n33: if (E.getNumReferences() >= 3333992192 /*23639.5*/) goto t134_n35;
  t134_n34: return 0.01965772546827793;
  t134_n35: return -0.309079647064209;
  t134_n36: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t134_n40;
  t134_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t134_n39;
  t134_n38: return 0.13551492989063263;
  t134_n39: return 0.23504088819026947;
  t134_n40: return 0.021541401743888855;
  t134_n41: if (E.getNumReferences() >= 3336049664 /*27658.0*/) goto t134_n43;
  t134_n42: return -0.30969271063804626;
  t134_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t134_n45;
  t134_n44: return -0.2111920565366745;
  t134_n45: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n47;
  t134_n46: return 0.07766643911600113;
  t134_n47: return -0.00735506322234869;
  t134_n48: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n50;
  t134_n49: return 0.03928476199507713;
  t134_n50: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t134_n54;
  t134_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t134_n53;
  t134_n52: return 0.09820032864809036;
  t134_n53: return 0.10337287932634354;
  t134_n54: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t134_n56;
  t134_n55: return 0.05594823881983757;
  t134_n56: return 0.09668688476085663;
  t134_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t134_n61;
  t134_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n60;
  t134_n59: return -0.0794244036078453;
  t134_n60: return -0.4314276874065399;
  t134_n61: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t134_n89;
  t134_n62: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t134_n76;
  t134_n63: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t134_n67;
  t134_n64: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t134_n66;
  t134_n65: return -0.1754973977804184;
  t134_n66: return 0.10951381176710129;
  t134_n67: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t134_n75;
  t134_n68: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n74;
  t134_n69: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n71;
  t134_n70: return -0.04536154493689537;
  t134_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n73;
  t134_n72: return 0.09659086167812347;
  t134_n73: return 0.07882536202669144;
  t134_n74: return -0.18539579212665558;
  t134_n75: return -0.06292502582073212;
  t134_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t134_n86;
  t134_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t134_n83;
  t134_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t134_n80;
  t134_n79: return -0.037532515823841095;
  t134_n80: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t134_n82;
  t134_n81: return 0.1266029179096222;
  t134_n82: return 0.06795568764209747;
  t134_n83: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t134_n85;
  t134_n84: return 0.1128680482506752;
  t134_n85: return 0.09510345011949539;
  t134_n86: if (E.getNumReferences() >= 3342374144 /*47253.0*/) goto t134_n88;
  t134_n87: return 0.15121124684810638;
  t134_n88: return -0.04833952710032463;
  t134_n89: return -0.06589698791503906;
  t134_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t134_n254;
  t134_n91: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t134_n93;
  t134_n92: return -0.024020085111260414;
  t134_n93: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t134_n217;
  t134_n94: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t134_n206;
  t134_n95: if (E.getNumReferences() >= 3354631552 /*124731.0*/) goto t134_n181;
  t134_n96: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t134_n172;
  t134_n97: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t134_n103;
  t134_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t134_n100;
  t134_n99: return 0.007033037021756172;
  t134_n100: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n102;
  t134_n101: return 0.06360513716936111;
  t134_n102: return -0.14270612597465515;
  t134_n103: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t134_n111;
  t134_n104: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n106;
  t134_n105: return -0.0532340370118618;
  t134_n106: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n110;
  t134_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t134_n109;
  t134_n108: return -0.25599539279937744;
  t134_n109: return 0.1325787454843521;
  t134_n110: return 0.07963566482067108;
  t134_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t134_n171;
  t134_n112: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t134_n168;
  t134_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t134_n127;
  t134_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t134_n126;
  t134_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t134_n125;
  t134_n116: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t134_n118;
  t134_n117: return -0.12780800461769104;
  t134_n118: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t134_n120;
  t134_n119: return 0.08308865875005722;
  t134_n120: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t134_n124;
  t134_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n123;
  t134_n122: return 0.10583813488483429;
  t134_n123: return 0.10725466161966324;
  t134_n124: return 0.03880598768591881;
  t134_n125: return 0.03311096504330635;
  t134_n126: return 0.009997289627790451;
  t134_n127: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n137;
  t134_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t134_n130;
  t134_n129: return -0.0864177718758583;
  t134_n130: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t134_n132;
  t134_n131: return 0.022255277261137962;
  t134_n132: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t134_n134;
  t134_n133: return -0.010309705510735512;
  t134_n134: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t134_n136;
  t134_n135: return 0.10981258749961853;
  t134_n136: return -0.05553881824016571;
  t134_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t134_n139;
  t134_n138: return -0.2221139371395111;
  t134_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n161;
  t134_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n158;
  t134_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t134_n147;
  t134_n142: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t134_n144;
  t134_n143: return 0.08959823846817017;
  t134_n144: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t134_n146;
  t134_n145: return 0.11374002695083618;
  t134_n146: return -0.23174560070037842;
  t134_n147: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t134_n155;
  t134_n148: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t134_n154;
  t134_n149: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t134_n151;
  t134_n150: return 0.01242063008248806;
  t134_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n153;
  t134_n152: return -0.10144463181495667;
  t134_n153: return 0.11279049515724182;
  t134_n154: return 0.040216896682977676;
  t134_n155: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t134_n157;
  t134_n156: return 0.14501942694187164;
  t134_n157: return 0.11724871397018433;
  t134_n158: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n160;
  t134_n159: return 0.10744389146566391;
  t134_n160: return 0.0797119289636612;
  t134_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n167;
  t134_n162: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t134_n166;
  t134_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t134_n165;
  t134_n164: return 0.07698245346546173;
  t134_n165: return 0.11059416085481644;
  t134_n166: return -0.10629978030920029;
  t134_n167: return 0.08223118633031845;
  t134_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t134_n170;
  t134_n169: return -0.1780545711517334;
  t134_n170: return 0.06615174561738968;
  t134_n171: return -0.0843518003821373;
  t134_n172: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n180;
  t134_n173: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t134_n179;
  t134_n174: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t134_n178;
  t134_n175: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n177;
  t134_n176: return 0.11126333475112915;
  t134_n177: return 0.07023420184850693;
  t134_n178: return 0.13991780579090118;
  t134_n179: return 0.041131243109703064;
  t134_n180: return 0.04149789363145828;
  t134_n181: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t134_n183;
  t134_n182: return -0.06117378547787666;
  t134_n183: if (E.getNumReferences() >= 3357836960 /*168474.5*/) goto t134_n189;
  t134_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t134_n186;
  t134_n185: return -0.16975349187850952;
  t134_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n188;
  t134_n187: return 0.2005840688943863;
  t134_n188: return 0.08761175721883774;
  t134_n189: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t134_n205;
  t134_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t134_n192;
  t134_n191: return 0.028597798198461533;
  t134_n192: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t134_n196;
  t134_n193: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t134_n195;
  t134_n194: return 0.013882085680961609;
  t134_n195: return 0.09693077951669693;
  t134_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n198;
  t134_n197: return -0.053440071642398834;
  t134_n198: if (E.getNumReferences() >= 3358763328 /*182949.0*/) goto t134_n204;
  t134_n199: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t134_n203;
  t134_n200: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t134_n202;
  t134_n201: return 0.09144182503223419;
  t134_n202: return 0.14392127096652985;
  t134_n203: return 0.012805439531803131;
  t134_n204: return -0.0035164623986929655;
  t134_n205: return -0.05655677989125252;
  t134_n206: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t134_n216;
  t134_n207: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t134_n213;
  t134_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t134_n210;
  t134_n209: return -0.09847434610128403;
  t134_n210: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t134_n212;
  t134_n211: return -0.004798772279173136;
  t134_n212: return 0.08859509974718094;
  t134_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t134_n215;
  t134_n214: return 0.009640056639909744;
  t134_n215: return 0.07753787189722061;
  t134_n216: return -0.023093337193131447;
  t134_n217: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t134_n221;
  t134_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t134_n220;
  t134_n219: return -0.045552391558885574;
  t134_n220: return -0.1372712403535843;
  t134_n221: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t134_n237;
  t134_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t134_n224;
  t134_n223: return -0.03673452138900757;
  t134_n224: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t134_n230;
  t134_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n229;
  t134_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t134_n228;
  t134_n227: return -0.13616344332695007;
  t134_n228: return 0.1619339883327484;
  t134_n229: return 0.11241341382265091;
  t134_n230: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t134_n236;
  t134_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t134_n233;
  t134_n232: return 0.08543886989355087;
  t134_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t134_n235;
  t134_n234: return 0.10209627449512482;
  t134_n235: return 0.040983039885759354;
  t134_n236: return 0.042756952345371246;
  t134_n237: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t134_n239;
  t134_n238: return -0.1486048698425293;
  t134_n239: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t134_n249;
  t134_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t134_n248;
  t134_n241: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t134_n243;
  t134_n242: return -0.062384769320487976;
  t134_n243: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t134_n245;
  t134_n244: return -0.06118899583816528;
  t134_n245: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t134_n247;
  t134_n246: return 0.0827207863330841;
  t134_n247: return 0.0858810544013977;
  t134_n248: return 0.04974903166294098;
  t134_n249: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t134_n253;
  t134_n250: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t134_n252;
  t134_n251: return -0.012264951132237911;
  t134_n252: return -0.1614484041929245;
  t134_n253: return 0.003463745815679431;
  t134_n254: return 0.013051550835371017;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree135(const Example& E) {
  t135_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t135_n54;
  t135_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n3;
  t135_n2: return -0.0021089385263621807;
  t135_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t135_n23;
  t135_n4: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n22;
  t135_n5: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t135_n21;
  t135_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t135_n20;
  t135_n7: if (E.getNumReferences() >= 3277881344 /*224.5*/) goto t135_n17;
  t135_n8: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t135_n14;
  t135_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n11;
  t135_n10: return 0.008232341147959232;
  t135_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t135_n13;
  t135_n12: return -0.04186754673719406;
  t135_n13: return -0.008332477882504463;
  t135_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t135_n16;
  t135_n15: return -0.025212887674570084;
  t135_n16: return -0.2064337432384491;
  t135_n17: if (E.getNumReferences() >= 3278962688 /*241.0*/) goto t135_n19;
  t135_n18: return 0.10995641350746155;
  t135_n19: return 0.02341580018401146;
  t135_n20: return -0.0008484895224682987;
  t135_n21: return -0.027157362550497055;
  t135_n22: return -0.020787471905350685;
  t135_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t135_n53;
  t135_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t135_n50;
  t135_n25: if (E.getNumReferences() >= 3330629120 /*17071.0*/) goto t135_n49;
  t135_n26: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n42;
  t135_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t135_n41;
  t135_n28: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n30;
  t135_n29: return -0.018389597535133362;
  t135_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t135_n34;
  t135_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t135_n33;
  t135_n32: return -0.17627766728401184;
  t135_n33: return -0.05318787321448326;
  t135_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n40;
  t135_n35: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t135_n39;
  t135_n36: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t135_n38;
  t135_n37: return 0.10126155614852905;
  t135_n38: return 0.056737978011369705;
  t135_n39: return 0.059149209409952164;
  t135_n40: return 0.006463069934397936;
  t135_n41: return -0.11120324581861496;
  t135_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t135_n44;
  t135_n43: return -0.11682059615850449;
  t135_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t135_n48;
  t135_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t135_n47;
  t135_n46: return -0.005697611253708601;
  t135_n47: return -0.1136716976761818;
  t135_n48: return 0.030773071572184563;
  t135_n49: return -0.7472226619720459;
  t135_n50: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t135_n52;
  t135_n51: return 0.013264436274766922;
  t135_n52: return 0.096340112388134;
  t135_n53: return 0.004099064040929079;
  t135_n54: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t135_n94;
  t135_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t135_n57;
  t135_n56: return -0.00044875554158352315;
  t135_n57: if (E.getNumReferences() >= 3333867264 /*23395.5*/) goto t135_n79;
  t135_n58: if (E.getNumReferences() >= 3333808640 /*23281.0*/) goto t135_n68;
  t135_n59: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t135_n61;
  t135_n60: return 0.05267957225441933;
  t135_n61: if (E.getNumReferences() >= 3332078080 /*19901.0*/) goto t135_n67;
  t135_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n64;
  t135_n63: return 0.10440721362829208;
  t135_n64: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t135_n66;
  t135_n65: return 0.048898402601480484;
  t135_n66: return 0.09944974631071091;
  t135_n67: return -0.0026261373423039913;
  t135_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n78;
  t135_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t135_n75;
  t135_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n74;
  t135_n71: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t135_n73;
  t135_n72: return 0.12438957393169403;
  t135_n73: return -0.10119323432445526;
  t135_n74: return -0.37086474895477295;
  t135_n75: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t135_n77;
  t135_n76: return -0.025653447955846786;
  t135_n77: return 0.11892315000295639;
  t135_n78: return 0.10786789655685425;
  t135_n79: if (E.getNumReferences() >= 3339934592 /*37723.5*/) goto t135_n81;
  t135_n80: return -0.007594764232635498;
  t135_n81: if (E.getNumReferences() >= 3340748416 /*40902.5*/) goto t135_n93;
  t135_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n90;
  t135_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t135_n85;
  t135_n84: return -0.11064919084310532;
  t135_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n89;
  t135_n86: if (E.getNumReferences() >= 3340364160 /*39401.5*/) goto t135_n88;
  t135_n87: return 0.09643872827291489;
  t135_n88: return 0.10850390791893005;
  t135_n89: return -0.18826353549957275;
  t135_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n92;
  t135_n91: return 0.11357448995113373;
  t135_n92: return -0.08463254570960999;
  t135_n93: return 0.012243642471730709;
  t135_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t135_n154;
  t135_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t135_n107;
  t135_n96: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t135_n98;
  t135_n97: return -0.0018047706689685583;
  t135_n98: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t135_n100;
  t135_n99: return 0.01211974024772644;
  t135_n100: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t135_n102;
  t135_n101: return 0.10285189002752304;
  t135_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t135_n104;
  t135_n103: return 0.10958916693925858;
  t135_n104: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t135_n106;
  t135_n105: return 0.09533464163541794;
  t135_n106: return 0.04801257699728012;
  t135_n107: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t135_n153;
  t135_n108: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t135_n142;
  t135_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n111;
  t135_n110: return 0.03386818990111351;
  t135_n111: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n139;
  t135_n112: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t135_n136;
  t135_n113: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t135_n121;
  t135_n114: if (E.getNumReferences() >= 3333156096 /*22006.5*/) goto t135_n120;
  t135_n115: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t135_n117;
  t135_n116: return -0.15328176319599152;
  t135_n117: if (E.getNumReferences() >= 3332416512 /*20562.0*/) goto t135_n119;
  t135_n118: return 0.13490478694438934;
  t135_n119: return 0.1432102918624878;
  t135_n120: return -0.06415287405252457;
  t135_n121: if (E.getNumReferences() >= 3341598080 /*44221.5*/) goto t135_n135;
  t135_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n134;
  t135_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n131;
  t135_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t135_n128;
  t135_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n127;
  t135_n126: return 0.03914293274283409;
  t135_n127: return 0.06583912670612335;
  t135_n128: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t135_n130;
  t135_n129: return 0.1058318167924881;
  t135_n130: return 0.04894065111875534;
  t135_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n133;
  t135_n132: return 0.1261790692806244;
  t135_n133: return 0.051879629492759705;
  t135_n134: return 0.11145196855068207;
  t135_n135: return 0.023428449407219887;
  t135_n136: if (E.getNumReferences() >= 3332303360 /*20341.0*/) goto t135_n138;
  t135_n137: return -0.30400151014328003;
  t135_n138: return 0.12246407568454742;
  t135_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t135_n141;
  t135_n140: return -0.0553986020386219;
  t135_n141: return 0.056402456015348434;
  t135_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t135_n148;
  t135_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n145;
  t135_n144: return 0.1161680519580841;
  t135_n145: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t135_n147;
  t135_n146: return 0.16083143651485443;
  t135_n147: return -0.05397263914346695;
  t135_n148: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t135_n152;
  t135_n149: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t135_n151;
  t135_n150: return 0.10046636313199997;
  t135_n151: return 0.022482572123408318;
  t135_n152: return 0.1183708980679512;
  t135_n153: return 0.0017854197649285197;
  t135_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t135_n222;
  t135_n155: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t135_n157;
  t135_n156: return 0.10213374346494675;
  t135_n157: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n181;
  t135_n158: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t135_n178;
  t135_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t135_n161;
  t135_n160: return -0.10065914690494537;
  t135_n161: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t135_n165;
  t135_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n164;
  t135_n163: return -0.18331879377365112;
  t135_n164: return 0.10296192020177841;
  t135_n165: if (E.getNumReferences() >= 3338441472 /*32329.5*/) goto t135_n171;
  t135_n166: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t135_n168;
  t135_n167: return -0.1405489146709442;
  t135_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n170;
  t135_n169: return 0.09215538203716278;
  t135_n170: return -0.13801966607570648;
  t135_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n177;
  t135_n172: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t135_n176;
  t135_n173: if (E.getNumReferences() >= 3341527296 /*43945.0*/) goto t135_n175;
  t135_n174: return 0.11032579839229584;
  t135_n175: return 0.045861583203077316;
  t135_n176: return 0.10396573692560196;
  t135_n177: return 0.002374693052843213;
  t135_n178: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n180;
  t135_n179: return 0.08826849609613419;
  t135_n180: return 0.11319912225008011;
  t135_n181: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t135_n207;
  t135_n182: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t135_n204;
  t135_n183: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t135_n197;
  t135_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n192;
  t135_n185: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t135_n187;
  t135_n186: return -0.008645984344184399;
  t135_n187: if (E.getNumReferences() >= 3343032192 /*49823.5*/) goto t135_n191;
  t135_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n190;
  t135_n189: return 0.11881081014871597;
  t135_n190: return 0.03287316486239433;
  t135_n191: return 0.07110555469989777;
  t135_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t135_n194;
  t135_n193: return -0.08744924515485764;
  t135_n194: if (E.getNumReferences() >= 3353292736 /*114271.5*/) goto t135_n196;
  t135_n195: return 0.1110357940196991;
  t135_n196: return 0.09598883986473083;
  t135_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n201;
  t135_n198: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t135_n200;
  t135_n199: return 0.11661810427904129;
  t135_n200: return 0.0956185907125473;
  t135_n201: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t135_n203;
  t135_n202: return 0.10994937270879745;
  t135_n203: return 0.046335335820913315;
  t135_n204: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t135_n206;
  t135_n205: return 0.10340097546577454;
  t135_n206: return 0.07512765377759933;
  t135_n207: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t135_n221;
  t135_n208: if (E.getNumReferences() >= 3347630656 /*70036.5*/) goto t135_n220;
  t135_n209: if (E.getNumReferences() >= 3337714176 /*30909.0*/) goto t135_n219;
  t135_n210: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t135_n212;
  t135_n211: return 0.024326352402567863;
  t135_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t135_n214;
  t135_n213: return 0.0004012669378425926;
  t135_n214: if (E.getNumReferences() >= 3334637824 /*24900.5*/) goto t135_n218;
  t135_n215: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t135_n217;
  t135_n216: return 0.19341494143009186;
  t135_n217: return 0.1153712347149849;
  t135_n218: return 0.07956889271736145;
  t135_n219: return -0.12607945501804352;
  t135_n220: return 0.08734706044197083;
  t135_n221: return -0.621349036693573;
  t135_n222: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t135_n232;
  t135_n223: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t135_n225;
  t135_n224: return 0.05712977424263954;
  t135_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n231;
  t135_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t135_n230;
  t135_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t135_n229;
  t135_n228: return 0.13455964624881744;
  t135_n229: return -0.09894262999296188;
  t135_n230: return 0.11623034626245499;
  t135_n231: return -0.02186611294746399;
  t135_n232: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t135_n252;
  t135_n233: if (E.getNumReferences() >= 3338507264 /*32458.0*/) goto t135_n235;
  t135_n234: return -0.13097307085990906;
  t135_n235: if (E.getNumReferences() >= 3339033984 /*34205.5*/) goto t135_n247;
  t135_n236: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t135_n238;
  t135_n237: return -0.0838562473654747;
  t135_n238: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t135_n242;
  t135_n239: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t135_n241;
  t135_n240: return 0.2642424404621124;
  t135_n241: return -0.13989073038101196;
  t135_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t135_n246;
  t135_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t135_n245;
  t135_n244: return 0.12830020487308502;
  t135_n245: return 0.1646413803100586;
  t135_n246: return -0.06035400927066803;
  t135_n247: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t135_n249;
  t135_n248: return -0.014833031222224236;
  t135_n249: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t135_n251;
  t135_n250: return 0.09735125303268433;
  t135_n251: return 0.016183391213417053;
  t135_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t135_n254;
  t135_n253: return -0.3679846525192261;
  t135_n254: return 0.12613099813461304;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree136(const Example& E) {
  t136_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t136_n2;
  t136_n1: return -0.0005164127796888351;
  t136_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t136_n6;
  t136_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t136_n5;
  t136_n4: return 0.008386295288801193;
  t136_n5: return 0.02391325682401657;
  t136_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t136_n8;
  t136_n7: return -0.008150143548846245;
  t136_n8: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t136_n86;
  t136_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t136_n33;
  t136_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t136_n12;
  t136_n11: return -0.02124478667974472;
  t136_n12: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t136_n16;
  t136_n13: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t136_n15;
  t136_n14: return 0.03531802445650101;
  t136_n15: return 0.0622725673019886;
  t136_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t136_n32;
  t136_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t136_n27;
  t136_n18: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t136_n26;
  t136_n19: if (E.getNumReferences() >= 3299053568 /*1308.5*/) goto t136_n25;
  t136_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t136_n22;
  t136_n21: return 0.109754279255867;
  t136_n22: if (E.getNumReferences() >= 3298709504 /*1266.5*/) goto t136_n24;
  t136_n23: return 0.10606526583433151;
  t136_n24: return 0.11783777177333832;
  t136_n25: return 0.03169209882616997;
  t136_n26: return 0.087729312479496;
  t136_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t136_n29;
  t136_n28: return -0.19503436982631683;
  t136_n29: if (E.getNumReferences() >= 3308058624 /*2767.5*/) goto t136_n31;
  t136_n30: return -0.01315764058381319;
  t136_n31: return 0.11681945621967316;
  t136_n32: return -0.027165241539478302;
  t136_n33: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t136_n67;
  t136_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t136_n36;
  t136_n35: return -0.0023707658983767033;
  t136_n36: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t136_n62;
  t136_n37: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t136_n61;
  t136_n38: if (E.getNumReferences() >= 3299151872 /*1320.5*/) goto t136_n50;
  t136_n39: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n43;
  t136_n40: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t136_n42;
  t136_n41: return -0.04394848644733429;
  t136_n42: return 0.12583348155021667;
  t136_n43: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t136_n49;
  t136_n44: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t136_n48;
  t136_n45: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t136_n47;
  t136_n46: return 0.13495425879955292;
  t136_n47: return 0.11774317920207977;
  t136_n48: return -0.1003042533993721;
  t136_n49: return -0.11459790170192719;
  t136_n50: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t136_n60;
  t136_n51: if (E.getNumReferences() >= 3303550976 /*1857.5*/) goto t136_n53;
  t136_n52: return -0.06700169295072556;
  t136_n53: if (E.getNumReferences() >= 3303952384 /*1906.5*/) goto t136_n57;
  t136_n54: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t136_n56;
  t136_n55: return 0.11033707857131958;
  t136_n56: return 0.06434668600559235;
  t136_n57: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t136_n59;
  t136_n58: return 0.04427896440029144;
  t136_n59: return 0.09406217932701111;
  t136_n60: return -0.09585505723953247;
  t136_n61: return 0.002987888641655445;
  t136_n62: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t136_n66;
  t136_n63: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t136_n65;
  t136_n64: return 0.08908488601446152;
  t136_n65: return 0.14503760635852814;
  t136_n66: return 0.08204282820224762;
  t136_n67: if (E.getNumReferences() >= 3316423680 /*5523.5*/) goto t136_n69;
  t136_n68: return -0.015185941010713577;
  t136_n69: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t136_n79;
  t136_n70: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t136_n72;
  t136_n71: return 0.10494459420442581;
  t136_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n78;
  t136_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n75;
  t136_n74: return -0.02995757758617401;
  t136_n75: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t136_n77;
  t136_n76: return 0.04824414104223251;
  t136_n77: return 0.10788051038980484;
  t136_n78: return 0.09554312378168106;
  t136_n79: if (E.getNumReferences() >= 3317987328 /*6287.0*/) goto t136_n85;
  t136_n80: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t136_n84;
  t136_n81: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n83;
  t136_n82: return 0.14045697450637817;
  t136_n83: return 0.1262287199497223;
  t136_n84: return 0.15626949071884155;
  t136_n85: return 0.028192996978759766;
  t136_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t136_n96;
  t136_n87: if (E.getNumReferences() >= 3332129024 /*20000.5*/) goto t136_n89;
  t136_n88: return -0.013971316628158092;
  t136_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t136_n91;
  t136_n90: return -0.0215836763381958;
  t136_n91: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t136_n95;
  t136_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t136_n94;
  t136_n93: return -0.21957257390022278;
  t136_n94: return 0.11422505974769592;
  t136_n95: return 0.027487918734550476;
  t136_n96: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t136_n228;
  t136_n97: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n207;
  t136_n98: if (E.getNumReferences() >= 3315700736 /*5170.5*/) goto t136_n100;
  t136_n99: return 0.006933867931365967;
  t136_n100: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t136_n108;
  t136_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n107;
  t136_n102: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t136_n106;
  t136_n103: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t136_n105;
  t136_n104: return 0.1161312460899353;
  t136_n105: return 0.07837703824043274;
  t136_n106: return 0.12948378920555115;
  t136_n107: return -0.12839336693286896;
  t136_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t136_n110;
  t136_n109: return -0.0390033982694149;
  t136_n110: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t136_n114;
  t136_n111: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t136_n113;
  t136_n112: return 0.10945384204387665;
  t136_n113: return -0.627169668674469;
  t136_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t136_n206;
  t136_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t136_n159;
  t136_n116: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t136_n152;
  t136_n117: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t136_n139;
  t136_n118: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t136_n136;
  t136_n119: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t136_n123;
  t136_n120: if (E.getNumReferences() >= 3334015488 /*23685.0*/) goto t136_n122;
  t136_n121: return 0.01497621089220047;
  t136_n122: return -0.3207433819770813;
  t136_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t136_n125;
  t136_n124: return 0.029508672654628754;
  t136_n125: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t136_n135;
  t136_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n132;
  t136_n127: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t136_n131;
  t136_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n130;
  t136_n129: return 0.18122579157352448;
  t136_n130: return 0.08862487226724625;
  t136_n131: return 0.10272087901830673;
  t136_n132: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t136_n134;
  t136_n133: return 0.1129559874534607;
  t136_n134: return 0.02317632921040058;
  t136_n135: return -0.04416244477033615;
  t136_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t136_n138;
  t136_n137: return -0.08607053756713867;
  t136_n138: return 0.0909438356757164;
  t136_n139: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t136_n151;
  t136_n140: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t136_n144;
  t136_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t136_n143;
  t136_n142: return -0.11425014585256577;
  t136_n143: return 0.04370420426130295;
  t136_n144: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n150;
  t136_n145: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n147;
  t136_n146: return 0.03640285134315491;
  t136_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n149;
  t136_n148: return 0.046863242983818054;
  t136_n149: return 0.12568870186805725;
  t136_n150: return 0.08019688725471497;
  t136_n151: return -0.10989776253700256;
  t136_n152: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t136_n158;
  t136_n153: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t136_n155;
  t136_n154: return 0.017252527177333832;
  t136_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n157;
  t136_n156: return 0.10923302918672562;
  t136_n157: return 0.11393396556377411;
  t136_n158: return 0.037438903003931046;
  t136_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n205;
  t136_n160: if (E.getNumReferences() >= 3315857408 /*5247.0*/) goto t136_n162;
  t136_n161: return 0.18166124820709229;
  t136_n162: if (E.getNumReferences() >= 3319414784 /*6984.0*/) goto t136_n164;
  t136_n163: return 0.0058874087408185005;
  t136_n164: if (E.getNumReferences() >= 3319603200 /*7076.0*/) goto t136_n166;
  t136_n165: return 0.13733001053333282;
  t136_n166: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t136_n170;
  t136_n167: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n169;
  t136_n168: return -0.10442070662975311;
  t136_n169: return 0.10722457617521286;
  t136_n170: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t136_n178;
  t136_n171: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t136_n177;
  t136_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t136_n174;
  t136_n173: return -3.027648745046463e-06;
  t136_n174: if (E.getNumReferences() >= 3319669760 /*7108.5*/) goto t136_n176;
  t136_n175: return -0.1282409131526947;
  t136_n176: return 0.11329738795757294;
  t136_n177: return 0.021026337519288063;
  t136_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t136_n194;
  t136_n179: if (E.getNumReferences() >= 3322916352 /*9195.5*/) goto t136_n193;
  t136_n180: if (E.getNumReferences() >= 3322621952 /*8908.0*/) goto t136_n188;
  t136_n181: if (E.getNumReferences() >= 3321944576 /*8246.5*/) goto t136_n183;
  t136_n182: return 0.06161767616868019;
  t136_n183: if (E.getNumReferences() >= 3322048000 /*8347.5*/) goto t136_n187;
  t136_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t136_n186;
  t136_n185: return 0.1175752803683281;
  t136_n186: return -0.16057994961738586;
  t136_n187: return 0.06223843991756439;
  t136_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n190;
  t136_n189: return 0.13586276769638062;
  t136_n190: if (E.getNumReferences() >= 3322737152 /*9020.5*/) goto t136_n192;
  t136_n191: return -0.2576340436935425;
  t136_n192: return 0.1248709037899971;
  t136_n193: return 0.03856479004025459;
  t136_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t136_n196;
  t136_n195: return -0.21391896903514862;
  t136_n196: if (E.getNumReferences() >= 3333346816 /*22379.0*/) goto t136_n200;
  t136_n197: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t136_n199;
  t136_n198: return 0.1485084593296051;
  t136_n199: return -0.2173568457365036;
  t136_n200: if (E.getNumReferences() >= 3340838912 /*41256.0*/) goto t136_n202;
  t136_n201: return 0.044647183269262314;
  t136_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n204;
  t136_n203: return 0.13147187232971191;
  t136_n204: return 0.05315902456641197;
  t136_n205: return 0.015908125787973404;
  t136_n206: return 0.07433861494064331;
  t136_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t136_n209;
  t136_n208: return 0.03849953040480614;
  t136_n209: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t136_n223;
  t136_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t136_n214;
  t136_n211: if (E.getNumReferences() >= 3340838912 /*41256.0*/) goto t136_n213;
  t136_n212: return -0.0410333126783371;
  t136_n213: return 0.10561399161815643;
  t136_n214: if (E.getNumReferences() >= 3302932480 /*1782.0*/) goto t136_n218;
  t136_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t136_n217;
  t136_n216: return 0.11482374370098114;
  t136_n217: return -0.1412556916475296;
  t136_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t136_n220;
  t136_n219: return 0.06600792706012726;
  t136_n220: if (E.getNumReferences() >= 3325197824 /*11423.5*/) goto t136_n222;
  t136_n221: return -0.10870546847581863;
  t136_n222: return 0.10351809114217758;
  t136_n223: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t136_n227;
  t136_n224: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t136_n226;
  t136_n225: return 0.11424470692873001;
  t136_n226: return 0.09265170991420746;
  t136_n227: return 0.021307360380887985;
  t136_n228: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t136_n238;
  t136_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t136_n233;
  t136_n230: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t136_n232;
  t136_n231: return -0.11613266915082932;
  t136_n232: return 0.10140012204647064;
  t136_n233: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t136_n237;
  t136_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t136_n236;
  t136_n235: return -0.1389663815498352;
  t136_n236: return 0.10642670840024948;
  t136_n237: return 0.009310307912528515;
  t136_n238: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t136_n254;
  t136_n239: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t136_n241;
  t136_n240: return -0.015718236565589905;
  t136_n241: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t136_n243;
  t136_n242: return 0.10351094603538513;
  t136_n243: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t136_n249;
  t136_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t136_n246;
  t136_n245: return 0.012480378150939941;
  t136_n246: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t136_n248;
  t136_n247: return 0.06164690479636192;
  t136_n248: return -0.6861299276351929;
  t136_n249: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t136_n253;
  t136_n250: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t136_n252;
  t136_n251: return 0.10372002422809601;
  t136_n252: return 0.05092005804181099;
  t136_n253: return 0.04066962003707886;
  t136_n254: return -0.029133232310414314;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree137(const Example& E) {
  t137_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t137_n224;
  t137_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t137_n223;
  t137_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t137_n4;
  t137_n3: return -0.006784456316381693;
  t137_n4: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t137_n204;
  t137_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t137_n87;
  t137_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t137_n8;
  t137_n7: return 0.010482413694262505;
  t137_n8: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t137_n40;
  t137_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t137_n15;
  t137_n10: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t137_n12;
  t137_n11: return 0.007585149724036455;
  t137_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n14;
  t137_n13: return -0.12676404416561127;
  t137_n14: return 0.04204960912466049;
  t137_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t137_n29;
  t137_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t137_n18;
  t137_n17: return 0.03179262951016426;
  t137_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n28;
  t137_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t137_n21;
  t137_n20: return 0.03416925296187401;
  t137_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n25;
  t137_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t137_n24;
  t137_n23: return -0.07352160662412643;
  t137_n24: return 0.09639039635658264;
  t137_n25: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t137_n27;
  t137_n26: return 0.12342202663421631;
  t137_n27: return -0.11241787672042847;
  t137_n28: return 0.07406735420227051;
  t137_n29: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t137_n31;
  t137_n30: return 0.01827516034245491;
  t137_n31: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t137_n35;
  t137_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t137_n34;
  t137_n33: return -0.12523336708545685;
  t137_n34: return 0.14315165579319;
  t137_n35: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t137_n39;
  t137_n36: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t137_n38;
  t137_n37: return 0.06841137260198593;
  t137_n38: return 0.15519477427005768;
  t137_n39: return 0.012633887119591236;
  t137_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n42;
  t137_n41: return -0.0513511560857296;
  t137_n42: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t137_n46;
  t137_n43: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t137_n45;
  t137_n44: return -0.007386655546724796;
  t137_n45: return -0.05097606033086777;
  t137_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t137_n48;
  t137_n47: return -0.02439088001847267;
  t137_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t137_n56;
  t137_n49: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t137_n53;
  t137_n50: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t137_n52;
  t137_n51: return -0.06949274241924286;
  t137_n52: return 0.09687129408121109;
  t137_n53: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n55;
  t137_n54: return 0.1480541080236435;
  t137_n55: return 0.004054448567330837;
  t137_n56: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n80;
  t137_n57: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n77;
  t137_n58: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t137_n60;
  t137_n59: return 0.08639699220657349;
  t137_n60: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t137_n62;
  t137_n61: return -0.2906073331832886;
  t137_n62: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t137_n76;
  t137_n63: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t137_n69;
  t137_n64: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t137_n68;
  t137_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n67;
  t137_n66: return -0.17285862565040588;
  t137_n67: return 0.11044507473707199;
  t137_n68: return -0.010727915912866592;
  t137_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n71;
  t137_n70: return -0.049420252442359924;
  t137_n71: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t137_n73;
  t137_n72: return 0.12426140904426575;
  t137_n73: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t137_n75;
  t137_n74: return -0.47926053404808044;
  t137_n75: return 0.2740961015224457;
  t137_n76: return -0.5330658555030823;
  t137_n77: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t137_n79;
  t137_n78: return 0.0251061599701643;
  t137_n79: return 0.09625256061553955;
  t137_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t137_n82;
  t137_n81: return 0.004501820541918278;
  t137_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n84;
  t137_n83: return 0.14016743004322052;
  t137_n84: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t137_n86;
  t137_n85: return -0.6272240281105042;
  t137_n86: return 0.14058300852775574;
  t137_n87: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t137_n143;
  t137_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t137_n90;
  t137_n89: return -0.008727162145078182;
  t137_n90: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t137_n104;
  t137_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n99;
  t137_n92: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t137_n98;
  t137_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t137_n97;
  t137_n94: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t137_n96;
  t137_n95: return -0.267622172832489;
  t137_n96: return 0.0909530520439148;
  t137_n97: return -0.027410294860601425;
  t137_n98: return 0.029282527044415474;
  t137_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n101;
  t137_n100: return 0.06785530596971512;
  t137_n101: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t137_n103;
  t137_n102: return -0.025132164359092712;
  t137_n103: return 0.08478694409132004;
  t137_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t137_n118;
  t137_n105: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n117;
  t137_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t137_n108;
  t137_n107: return 0.03839338198304176;
  t137_n108: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n110;
  t137_n109: return 0.012443636544048786;
  t137_n110: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t137_n116;
  t137_n111: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t137_n115;
  t137_n112: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n114;
  t137_n113: return 0.12891529500484467;
  t137_n114: return 0.10574504733085632;
  t137_n115: return 0.10029064118862152;
  t137_n116: return -0.1156492605805397;
  t137_n117: return 0.026810036972165108;
  t137_n118: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t137_n142;
  t137_n119: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t137_n121;
  t137_n120: return 0.04914729297161102;
  t137_n121: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t137_n139;
  t137_n122: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t137_n124;
  t137_n123: return 0.11795090138912201;
  t137_n124: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t137_n138;
  t137_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t137_n137;
  t137_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t137_n134;
  t137_n127: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t137_n133;
  t137_n128: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n132;
  t137_n129: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n131;
  t137_n130: return 0.09778846800327301;
  t137_n131: return 0.16408704221248627;
  t137_n132: return -0.14373822510242462;
  t137_n133: return -0.006489576306194067;
  t137_n134: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n136;
  t137_n135: return 0.07813960313796997;
  t137_n136: return 0.13492532074451447;
  t137_n137: return 0.1064232662320137;
  t137_n138: return 0.0015057780547067523;
  t137_n139: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t137_n141;
  t137_n140: return 0.12472505867481232;
  t137_n141: return -0.09361130744218826;
  t137_n142: return -0.2685827314853668;
  t137_n143: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t137_n165;
  t137_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t137_n162;
  t137_n145: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t137_n147;
  t137_n146: return 0.002007697941735387;
  t137_n147: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t137_n149;
  t137_n148: return 0.029523266479372978;
  t137_n149: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t137_n151;
  t137_n150: return 0.035948898643255234;
  t137_n151: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t137_n161;
  t137_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t137_n160;
  t137_n153: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t137_n155;
  t137_n154: return -0.030473969876766205;
  t137_n155: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t137_n159;
  t137_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t137_n158;
  t137_n157: return 0.057114724069833755;
  t137_n158: return 0.12529215216636658;
  t137_n159: return -0.10361336916685104;
  t137_n160: return 0.14024153351783752;
  t137_n161: return 0.024910826236009598;
  t137_n162: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t137_n164;
  t137_n163: return -0.12257131189107895;
  t137_n164: return 0.032131217420101166;
  t137_n165: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t137_n203;
  t137_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n202;
  t137_n167: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t137_n199;
  t137_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t137_n170;
  t137_n169: return -0.13371559977531433;
  t137_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t137_n188;
  t137_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t137_n173;
  t137_n172: return 0.031002353876829147;
  t137_n173: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t137_n183;
  t137_n174: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n178;
  t137_n175: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t137_n177;
  t137_n176: return 0.053144022822380066;
  t137_n177: return 0.1245851218700409;
  t137_n178: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t137_n182;
  t137_n179: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t137_n181;
  t137_n180: return -0.12663160264492035;
  t137_n181: return 0.13331051170825958;
  t137_n182: return 0.060769155621528625;
  t137_n183: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t137_n185;
  t137_n184: return -0.1651700735092163;
  t137_n185: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t137_n187;
  t137_n186: return 0.160080224275589;
  t137_n187: return 0.0935988575220108;
  t137_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t137_n190;
  t137_n189: return -0.003671912243589759;
  t137_n190: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t137_n192;
  t137_n191: return 0.5694182515144348;
  t137_n192: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t137_n194;
  t137_n193: return -0.06977544724941254;
  t137_n194: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t137_n196;
  t137_n195: return 0.0776682123541832;
  t137_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t137_n198;
  t137_n197: return 0.09258375316858292;
  t137_n198: return -0.013218323700129986;
  t137_n199: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t137_n201;
  t137_n200: return 0.08581152558326721;
  t137_n201: return -0.11089219897985458;
  t137_n202: return -0.04055776819586754;
  t137_n203: return 0.10628848522901535;
  t137_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t137_n220;
  t137_n205: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t137_n207;
  t137_n206: return 0.017400206997990608;
  t137_n207: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t137_n217;
  t137_n208: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t137_n212;
  t137_n209: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t137_n211;
  t137_n210: return 0.11717648804187775;
  t137_n211: return 0.03550538420677185;
  t137_n212: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t137_n214;
  t137_n213: return -0.1076115071773529;
  t137_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t137_n216;
  t137_n215: return -0.08720636367797852;
  t137_n216: return 0.1470232605934143;
  t137_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t137_n219;
  t137_n218: return -0.2455192357301712;
  t137_n219: return 0.03945760056376457;
  t137_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n222;
  t137_n221: return 0.061150841414928436;
  t137_n222: return 0.0261967945843935;
  t137_n223: return -0.0012098001316189766;
  t137_n224: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t137_n226;
  t137_n225: return -0.005928732454776764;
  t137_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t137_n236;
  t137_n227: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t137_n235;
  t137_n228: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t137_n234;
  t137_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t137_n231;
  t137_n230: return 0.10793446004390717;
  t137_n231: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t137_n233;
  t137_n232: return 0.09463182091712952;
  t137_n233: return -0.020754415541887283;
  t137_n234: return 0.11408918350934982;
  t137_n235: return 0.010663012973964214;
  t137_n236: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t137_n254;
  t137_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t137_n251;
  t137_n238: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t137_n244;
  t137_n239: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t137_n241;
  t137_n240: return 0.018183359876275063;
  t137_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t137_n243;
  t137_n242: return 0.11126412451267242;
  t137_n243: return 0.12046452611684799;
  t137_n244: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t137_n246;
  t137_n245: return 0.01425148919224739;
  t137_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t137_n250;
  t137_n247: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t137_n249;
  t137_n248: return 0.17009437084197998;
  t137_n249: return -0.10507209599018097;
  t137_n250: return 0.03720647469162941;
  t137_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t137_n253;
  t137_n252: return 0.09539894014596939;
  t137_n253: return 0.107129767537117;
  t137_n254: return 0.011465990915894508;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree138(const Example& E) {
  t138_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t138_n166;
  t138_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t138_n3;
  t138_n2: return -0.0007724555907770991;
  t138_n3: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t138_n165;
  t138_n4: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t138_n118;
  t138_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t138_n7;
  t138_n6: return -0.005701020359992981;
  t138_n7: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t138_n77;
  t138_n8: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t138_n10;
  t138_n9: return 0.010722859762609005;
  t138_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t138_n28;
  t138_n11: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t138_n17;
  t138_n12: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n14;
  t138_n13: return -0.12389856576919556;
  t138_n14: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t138_n16;
  t138_n15: return -0.29655706882476807;
  t138_n16: return 0.10428669303655624;
  t138_n17: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t138_n23;
  t138_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n22;
  t138_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t138_n21;
  t138_n20: return 0.03488518297672272;
  t138_n21: return 0.10447019338607788;
  t138_n22: return -0.13864538073539734;
  t138_n23: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t138_n27;
  t138_n24: if (E.getNumReferences() >= 3309611008 /*3146.5*/) goto t138_n26;
  t138_n25: return 0.05218896269798279;
  t138_n26: return 0.14711160957813263;
  t138_n27: return -0.16186389327049255;
  t138_n28: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t138_n30;
  t138_n29: return 0.005086042452603579;
  t138_n30: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t138_n34;
  t138_n31: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t138_n33;
  t138_n32: return -1.5383135080337524;
  t138_n33: return 0.02632301114499569;
  t138_n34: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t138_n76;
  t138_n35: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t138_n73;
  t138_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t138_n60;
  t138_n37: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t138_n57;
  t138_n38: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t138_n48;
  t138_n39: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t138_n41;
  t138_n40: return 0.07417742908000946;
  t138_n41: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t138_n45;
  t138_n42: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t138_n44;
  t138_n43: return 0.12119223177433014;
  t138_n44: return -0.14553698897361755;
  t138_n45: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t138_n47;
  t138_n46: return 0.2104472666978836;
  t138_n47: return 0.10361972451210022;
  t138_n48: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t138_n50;
  t138_n49: return -0.16436487436294556;
  t138_n50: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t138_n52;
  t138_n51: return 0.1394404023885727;
  t138_n52: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t138_n56;
  t138_n53: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t138_n55;
  t138_n54: return 0.11144914478063583;
  t138_n55: return -0.11836748570203781;
  t138_n56: return -0.23089967668056488;
  t138_n57: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t138_n59;
  t138_n58: return 0.11858359724283218;
  t138_n59: return 0.008985819295048714;
  t138_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t138_n62;
  t138_n61: return 0.040789514780044556;
  t138_n62: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t138_n66;
  t138_n63: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t138_n65;
  t138_n64: return -0.2644260823726654;
  t138_n65: return 0.12670621275901794;
  t138_n66: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n68;
  t138_n67: return 0.06623811274766922;
  t138_n68: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t138_n70;
  t138_n69: return -0.11708545684814453;
  t138_n70: if (E.getNumReferences() >= 3274473472 /*172.5*/) goto t138_n72;
  t138_n71: return 0.12248381972312927;
  t138_n72: return 0.08444467186927795;
  t138_n73: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t138_n75;
  t138_n74: return 0.11569450050592422;
  t138_n75: return 0.10699772834777832;
  t138_n76: return 0.018350273370742798;
  t138_n77: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t138_n89;
  t138_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n86;
  t138_n79: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n81;
  t138_n80: return -0.022036153823137283;
  t138_n81: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t138_n83;
  t138_n82: return 0.0719277411699295;
  t138_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t138_n85;
  t138_n84: return -0.3594520390033722;
  t138_n85: return 0.5295704007148743;
  t138_n86: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t138_n88;
  t138_n87: return -0.008871777914464474;
  t138_n88: return -0.04945468530058861;
  t138_n89: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t138_n117;
  t138_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t138_n108;
  t138_n91: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t138_n93;
  t138_n92: return 0.008343550376594067;
  t138_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n103;
  t138_n94: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t138_n98;
  t138_n95: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t138_n97;
  t138_n96: return -0.015479793772101402;
  t138_n97: return 0.02915956638753414;
  t138_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n102;
  t138_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t138_n101;
  t138_n100: return -0.0008285543881356716;
  t138_n101: return 0.06250505149364471;
  t138_n102: return -0.016040923073887825;
  t138_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t138_n107;
  t138_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t138_n106;
  t138_n105: return -4.06507682800293;
  t138_n106: return -0.012873885221779346;
  t138_n107: return 0.015089508146047592;
  t138_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t138_n110;
  t138_n109: return -0.0009451155783608556;
  t138_n110: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t138_n112;
  t138_n111: return 0.023914899677038193;
  t138_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n116;
  t138_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t138_n115;
  t138_n114: return 0.07546931505203247;
  t138_n115: return 0.04770367220044136;
  t138_n116: return 0.018747596070170403;
  t138_n117: return -0.2660566568374634;
  t138_n118: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t138_n138;
  t138_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t138_n133;
  t138_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n124;
  t138_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n123;
  t138_n122: return 0.05935997515916824;
  t138_n123: return 0.10147859156131744;
  t138_n124: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t138_n128;
  t138_n125: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t138_n127;
  t138_n126: return 0.13201573491096497;
  t138_n127: return 0.19513648748397827;
  t138_n128: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t138_n130;
  t138_n129: return 0.06790991872549057;
  t138_n130: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t138_n132;
  t138_n131: return 0.10057190805673599;
  t138_n132: return 0.1016656830906868;
  t138_n133: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n135;
  t138_n134: return 0.09205907583236694;
  t138_n135: if (E.getNumReferences() >= 3329037312 /*15173.0*/) goto t138_n137;
  t138_n136: return 0.1013917326927185;
  t138_n137: return -0.07842633128166199;
  t138_n138: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t138_n140;
  t138_n139: return -0.10024245083332062;
  t138_n140: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t138_n164;
  t138_n141: if (E.getNumReferences() >= 3331505664 /*18783.0*/) goto t138_n143;
  t138_n142: return -0.06278415769338608;
  t138_n143: if (E.getNumReferences() >= 3331936768 /*19625.0*/) goto t138_n147;
  t138_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n146;
  t138_n145: return 0.11401360481977463;
  t138_n146: return 0.0766739472746849;
  t138_n147: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t138_n149;
  t138_n148: return -0.008690974675118923;
  t138_n149: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t138_n153;
  t138_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t138_n152;
  t138_n151: return 0.12574049830436707;
  t138_n152: return 0.13680772483348846;
  t138_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t138_n163;
  t138_n154: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t138_n156;
  t138_n155: return -0.007531364448368549;
  t138_n156: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n160;
  t138_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t138_n159;
  t138_n158: return -0.38653722405433655;
  t138_n159: return 0.04880162328481674;
  t138_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t138_n162;
  t138_n161: return 0.08775895833969116;
  t138_n162: return 0.09895258396863937;
  t138_n163: return -0.2182459533214569;
  t138_n164: return -0.0030753971077501774;
  t138_n165: return -0.07470909506082535;
  t138_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t138_n170;
  t138_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t138_n169;
  t138_n168: return 0.010199818760156631;
  t138_n169: return -0.02873804233968258;
  t138_n170: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t138_n202;
  t138_n171: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t138_n187;
  t138_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t138_n174;
  t138_n173: return -0.07856068015098572;
  t138_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n176;
  t138_n175: return 0.20096388459205627;
  t138_n176: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t138_n184;
  t138_n177: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t138_n183;
  t138_n178: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t138_n180;
  t138_n179: return 0.08023542165756226;
  t138_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t138_n182;
  t138_n181: return 0.11956530064344406;
  t138_n182: return -0.5837963223457336;
  t138_n183: return -0.18654920160770416;
  t138_n184: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t138_n186;
  t138_n185: return 0.11830539256334305;
  t138_n186: return 0.1893777698278427;
  t138_n187: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t138_n189;
  t138_n188: return 0.11072154343128204;
  t138_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t138_n193;
  t138_n190: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t138_n192;
  t138_n191: return 0.05622564256191254;
  t138_n192: return 0.11271099746227264;
  t138_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t138_n195;
  t138_n194: return 0.08693580329418182;
  t138_n195: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n201;
  t138_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t138_n200;
  t138_n197: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t138_n199;
  t138_n198: return 0.09665334969758987;
  t138_n199: return 0.11204490065574646;
  t138_n200: return 0.10109641402959824;
  t138_n201: return 0.08439411222934723;
  t138_n202: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t138_n204;
  t138_n203: return -0.0812164917588234;
  t138_n204: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t138_n206;
  t138_n205: return -0.06541159749031067;
  t138_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t138_n244;
  t138_n207: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t138_n211;
  t138_n208: if (E.getNumReferences() >= 3342177536 /*46485.0*/) goto t138_n210;
  t138_n209: return -0.1458313763141632;
  t138_n210: return 0.00873592495918274;
  t138_n211: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t138_n243;
  t138_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t138_n234;
  t138_n213: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t138_n233;
  t138_n214: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t138_n232;
  t138_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n231;
  t138_n216: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t138_n222;
  t138_n217: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t138_n221;
  t138_n218: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t138_n220;
  t138_n219: return -0.10717799514532089;
  t138_n220: return 0.11291225254535675;
  t138_n221: return -0.1311616748571396;
  t138_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t138_n224;
  t138_n223: return -0.17661897838115692;
  t138_n224: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t138_n226;
  t138_n225: return 0.05925723910331726;
  t138_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t138_n230;
  t138_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t138_n229;
  t138_n228: return 0.040629126131534576;
  t138_n229: return 0.1037616953253746;
  t138_n230: return 0.08175888657569885;
  t138_n231: return 0.013501527719199657;
  t138_n232: return -0.07197187095880508;
  t138_n233: return -0.006951607298105955;
  t138_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t138_n240;
  t138_n235: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t138_n239;
  t138_n236: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t138_n238;
  t138_n237: return 0.08852169662714005;
  t138_n238: return 0.11152675002813339;
  t138_n239: return 0.04314926266670227;
  t138_n240: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t138_n242;
  t138_n241: return 0.22408905625343323;
  t138_n242: return -0.18479949235916138;
  t138_n243: return 0.12375987321138382;
  t138_n244: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t138_n254;
  t138_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t138_n247;
  t138_n246: return 0.09927480667829514;
  t138_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t138_n253;
  t138_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t138_n250;
  t138_n249: return 0.14196032285690308;
  t138_n250: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t138_n252;
  t138_n251: return 0.04642779007554054;
  t138_n252: return 0.10909327119588852;
  t138_n253: return 0.1016545221209526;
  t138_n254: return 0.014301563613116741;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree139(const Example& E) {
  t139_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t139_n254;
  t139_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t139_n143;
  t139_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t139_n4;
  t139_n3: return -0.018384454771876335;
  t139_n4: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t139_n124;
  t139_n5: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t139_n7;
  t139_n6: return -0.004253596533089876;
  t139_n7: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t139_n55;
  t139_n8: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t139_n14;
  t139_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t139_n13;
  t139_n10: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t139_n12;
  t139_n11: return -0.08169001340866089;
  t139_n12: return 0.09945235401391983;
  t139_n13: return 0.03370939940214157;
  t139_n14: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t139_n22;
  t139_n15: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t139_n21;
  t139_n16: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t139_n18;
  t139_n17: return 0.047203440219163895;
  t139_n18: if (E.getFilterLength() >= 3245867008 /*15.5*/) goto t139_n20;
  t139_n19: return 0.12218774855136871;
  t139_n20: return 0.11740966141223907;
  t139_n21: return -0.010177774354815483;
  t139_n22: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t139_n24;
  t139_n23: return 0.004547168966382742;
  t139_n24: if (E.getNumReferences() >= 3347692736 /*70521.5*/) goto t139_n54;
  t139_n25: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t139_n53;
  t139_n26: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t139_n46;
  t139_n27: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t139_n39;
  t139_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n36;
  t139_n29: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t139_n31;
  t139_n30: return -0.14833597838878632;
  t139_n31: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t139_n33;
  t139_n32: return 0.06671947985887527;
  t139_n33: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t139_n35;
  t139_n34: return 0.12343072146177292;
  t139_n35: return 0.05949155613780022;
  t139_n36: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t139_n38;
  t139_n37: return 0.025242434814572334;
  t139_n38: return -0.27463284134864807;
  t139_n39: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t139_n43;
  t139_n40: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t139_n42;
  t139_n41: return 0.11059103906154633;
  t139_n42: return -0.08072938024997711;
  t139_n43: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t139_n45;
  t139_n44: return 0.13635294139385223;
  t139_n45: return 0.093729667365551;
  t139_n46: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t139_n50;
  t139_n47: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t139_n49;
  t139_n48: return 0.0915154218673706;
  t139_n49: return 0.14541581273078918;
  t139_n50: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n52;
  t139_n51: return 0.057077743113040924;
  t139_n52: return 0.1098184585571289;
  t139_n53: return 0.0280531607568264;
  t139_n54: return 0.12161555141210556;
  t139_n55: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t139_n115;
  t139_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n66;
  t139_n57: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t139_n65;
  t139_n58: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t139_n64;
  t139_n59: if (E.getNumReferences() >= 3253731328 /*30.0*/) goto t139_n61;
  t139_n60: return 0.013816497288644314;
  t139_n61: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t139_n63;
  t139_n62: return 0.10013727098703384;
  t139_n63: return -0.1457962691783905;
  t139_n64: return -0.02300512231886387;
  t139_n65: return -1.863906741142273;
  t139_n66: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t139_n102;
  t139_n67: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t139_n97;
  t139_n68: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t139_n90;
  t139_n69: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n81;
  t139_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t139_n72;
  t139_n71: return 0.0855269581079483;
  t139_n72: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t139_n80;
  t139_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t139_n75;
  t139_n74: return 0.06316065788269043;
  t139_n75: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t139_n79;
  t139_n76: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t139_n78;
  t139_n77: return -0.12551608681678772;
  t139_n78: return 0.12768417596817017;
  t139_n79: return 0.059449851512908936;
  t139_n80: return 0.07312171161174774;
  t139_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t139_n83;
  t139_n82: return -0.015837883576750755;
  t139_n83: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t139_n89;
  t139_n84: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t139_n86;
  t139_n85: return -0.01689411886036396;
  t139_n86: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t139_n88;
  t139_n87: return 0.13402986526489258;
  t139_n88: return -0.17376291751861572;
  t139_n89: return 0.06420429050922394;
  t139_n90: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t139_n92;
  t139_n91: return 0.1588079333305359;
  t139_n92: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t139_n96;
  t139_n93: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t139_n95;
  t139_n94: return 0.13702543079853058;
  t139_n95: return 0.039951618760824203;
  t139_n96: return 0.10910559445619583;
  t139_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t139_n101;
  t139_n98: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t139_n100;
  t139_n99: return 0.11511901766061783;
  t139_n100: return -0.2303636521100998;
  t139_n101: return -0.01937801204621792;
  t139_n102: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t139_n114;
  t139_n103: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t139_n105;
  t139_n104: return 0.07644256204366684;
  t139_n105: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t139_n109;
  t139_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t139_n108;
  t139_n107: return -0.1439039260149002;
  t139_n108: return 0.13152876496315002;
  t139_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t139_n113;
  t139_n110: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t139_n112;
  t139_n111: return 0.6284003853797913;
  t139_n112: return 0.11207885295152664;
  t139_n113: return 0.05354832857847214;
  t139_n114: return -0.08490142971277237;
  t139_n115: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t139_n117;
  t139_n116: return -0.03713218867778778;
  t139_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n123;
  t139_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t139_n122;
  t139_n119: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t139_n121;
  t139_n120: return 0.1741107553243637;
  t139_n121: return 0.11977539211511612;
  t139_n122: return 0.05885745584964752;
  t139_n123: return 0.03174600005149841;
  t139_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t139_n126;
  t139_n125: return 0.005562969017773867;
  t139_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t139_n128;
  t139_n127: return -0.06149500980973244;
  t139_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t139_n134;
  t139_n129: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t139_n131;
  t139_n130: return 0.013821377418935299;
  t139_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n133;
  t139_n132: return 0.05288488045334816;
  t139_n133: return 0.007274182979017496;
  t139_n134: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t139_n142;
  t139_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n141;
  t139_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t139_n140;
  t139_n137: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n139;
  t139_n138: return 0.09868999570608139;
  t139_n139: return 0.10143256932497025;
  t139_n140: return 0.07287311553955078;
  t139_n141: return 0.06841184943914413;
  t139_n142: return -0.044711172580718994;
  t139_n143: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t139_n145;
  t139_n144: return -0.053343579173088074;
  t139_n145: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t139_n237;
  t139_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t139_n148;
  t139_n147: return 0.0007021354977041483;
  t139_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t139_n152;
  t139_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t139_n151;
  t139_n150: return -0.11067859828472137;
  t139_n151: return 0.003512233728542924;
  t139_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t139_n154;
  t139_n153: return 0.008088372647762299;
  t139_n154: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t139_n164;
  t139_n155: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t139_n163;
  t139_n156: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t139_n160;
  t139_n157: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t139_n159;
  t139_n158: return -0.008938190527260303;
  t139_n159: return -0.030797917395830154;
  t139_n160: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t139_n162;
  t139_n161: return -0.03257538378238678;
  t139_n162: return 0.007024771999567747;
  t139_n163: return 0.02559307962656021;
  t139_n164: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t139_n180;
  t139_n165: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t139_n179;
  t139_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t139_n178;
  t139_n167: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t139_n169;
  t139_n168: return -0.03254048526287079;
  t139_n169: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t139_n177;
  t139_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n172;
  t139_n171: return -0.13407059013843536;
  t139_n172: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t139_n174;
  t139_n173: return -0.17986012995243073;
  t139_n174: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t139_n176;
  t139_n175: return 0.09789270162582397;
  t139_n176: return -0.00011314953735563904;
  t139_n177: return -0.1762036383152008;
  t139_n178: return -0.017564935609698296;
  t139_n179: return 0.0741783082485199;
  t139_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t139_n184;
  t139_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t139_n183;
  t139_n182: return -0.03189030662178993;
  t139_n183: return 0.0396646223962307;
  t139_n184: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t139_n236;
  t139_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t139_n233;
  t139_n186: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t139_n192;
  t139_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t139_n189;
  t139_n188: return 0.06994058936834335;
  t139_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t139_n191;
  t139_n190: return -0.13025543093681335;
  t139_n191: return 0.09085720777511597;
  t139_n192: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t139_n228;
  t139_n193: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t139_n209;
  t139_n194: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t139_n204;
  t139_n195: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t139_n199;
  t139_n196: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t139_n198;
  t139_n197: return 0.07727500051259995;
  t139_n198: return -0.018773090094327927;
  t139_n199: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t139_n203;
  t139_n200: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t139_n202;
  t139_n201: return -0.1325111836194992;
  t139_n202: return 0.10144128650426865;
  t139_n203: return 0.0637061670422554;
  t139_n204: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t139_n208;
  t139_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t139_n207;
  t139_n206: return 0.12825541198253632;
  t139_n207: return 0.12288645654916763;
  t139_n208: return 0.047262173146009445;
  t139_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t139_n221;
  t139_n210: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t139_n212;
  t139_n211: return 0.07823525369167328;
  t139_n212: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t139_n220;
  t139_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t139_n215;
  t139_n214: return 0.08274500072002411;
  t139_n215: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t139_n219;
  t139_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t139_n218;
  t139_n217: return -0.11995347589254379;
  t139_n218: return 0.12059272080659866;
  t139_n219: return 0.13593368232250214;
  t139_n220: return -0.044229134917259216;
  t139_n221: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t139_n225;
  t139_n222: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t139_n224;
  t139_n223: return 0.05281137675046921;
  t139_n224: return 0.1130647361278534;
  t139_n225: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t139_n227;
  t139_n226: return -0.019327523186802864;
  t139_n227: return 0.11692661792039871;
  t139_n228: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t139_n230;
  t139_n229: return 0.05554017424583435;
  t139_n230: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t139_n232;
  t139_n231: return -0.055477458983659744;
  t139_n232: return 0.19137047231197357;
  t139_n233: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t139_n235;
  t139_n234: return 0.046292442828416824;
  t139_n235: return -0.0773678570985794;
  t139_n236: return -0.10411252826452255;
  t139_n237: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t139_n241;
  t139_n238: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t139_n240;
  t139_n239: return 0.003010950982570648;
  t139_n240: return -0.07518351823091507;
  t139_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t139_n253;
  t139_n242: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t139_n244;
  t139_n243: return -0.005300991237163544;
  t139_n244: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t139_n250;
  t139_n245: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t139_n249;
  t139_n246: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t139_n248;
  t139_n247: return 0.015173152089118958;
  t139_n248: return 0.03825343772768974;
  t139_n249: return -0.017184924334287643;
  t139_n250: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t139_n252;
  t139_n251: return 0.0249615665525198;
  t139_n252: return 0.04505009576678276;
  t139_n253: return 0.010236939415335655;
  t139_n254: return -0.04702233895659447;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree140(const Example& E) {
  t140_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t140_n2;
  t140_n1: return -0.00034147530095651746;
  t140_n2: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t140_n192;
  t140_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t140_n5;
  t140_n4: return -0.0006226508994586766;
  t140_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t140_n69;
  t140_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n64;
  t140_n7: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t140_n19;
  t140_n8: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t140_n18;
  t140_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n13;
  t140_n10: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n12;
  t140_n11: return 0.01869836263358593;
  t140_n12: return 0.2470342516899109;
  t140_n13: if (E.getNumReferences() >= 3331706880 /*19176.0*/) goto t140_n15;
  t140_n14: return 0.026692422106862068;
  t140_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t140_n17;
  t140_n16: return 0.10252829641103745;
  t140_n17: return 0.10555864125490189;
  t140_n18: return -0.022632397711277008;
  t140_n19: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t140_n31;
  t140_n20: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t140_n26;
  t140_n21: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n23;
  t140_n22: return -0.10470467060804367;
  t140_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n25;
  t140_n24: return 0.11027631163597107;
  t140_n25: return 0.10115274786949158;
  t140_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n30;
  t140_n27: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t140_n29;
  t140_n28: return 0.1885467767715454;
  t140_n29: return -0.33489421010017395;
  t140_n30: return 0.06033853441476822;
  t140_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t140_n63;
  t140_n32: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t140_n34;
  t140_n33: return -0.06327182054519653;
  t140_n34: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t140_n46;
  t140_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n45;
  t140_n36: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t140_n44;
  t140_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n41;
  t140_n38: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t140_n40;
  t140_n39: return 0.12275151163339615;
  t140_n40: return 0.09565731137990952;
  t140_n41: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t140_n43;
  t140_n42: return -1.9190890789031982;
  t140_n43: return 0.09267310798168182;
  t140_n44: return -0.6240440607070923;
  t140_n45: return 0.07645323872566223;
  t140_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n62;
  t140_n47: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t140_n51;
  t140_n48: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t140_n50;
  t140_n49: return 0.037009309977293015;
  t140_n50: return 0.09593233466148376;
  t140_n51: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t140_n53;
  t140_n52: return -0.682624101638794;
  t140_n53: if (E.getNumReferences() >= 3368810912 /*417741.0*/) goto t140_n59;
  t140_n54: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t140_n56;
  t140_n55: return 0.02889098785817623;
  t140_n56: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t140_n58;
  t140_n57: return 0.04625469818711281;
  t140_n58: return 0.12102112174034119;
  t140_n59: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t140_n61;
  t140_n60: return -0.17713116109371185;
  t140_n61: return 0.011174670420587063;
  t140_n62: return 0.013868148438632488;
  t140_n63: return -0.02772345393896103;
  t140_n64: if (E.getNumReferences() >= 3370129424 /*458944.5*/) goto t140_n68;
  t140_n65: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t140_n67;
  t140_n66: return 0.2572278678417206;
  t140_n67: return -0.07841795682907104;
  t140_n68: return -0.22497984766960144;
  t140_n69: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t140_n157;
  t140_n70: if (E.getNumReferences() >= 3350811072 /*94883.5*/) goto t140_n156;
  t140_n71: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n117;
  t140_n72: if (E.getNumReferences() >= 3348238784 /*74787.5*/) goto t140_n96;
  t140_n73: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t140_n93;
  t140_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n76;
  t140_n75: return 0.02859710343182087;
  t140_n76: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t140_n86;
  t140_n77: if (E.getNumReferences() >= 3346171136 /*62085.0*/) goto t140_n85;
  t140_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t140_n80;
  t140_n79: return 0.002952534006908536;
  t140_n80: if (E.getNumReferences() >= 3332418304 /*20565.5*/) goto t140_n82;
  t140_n81: return 0.09038684517145157;
  t140_n82: if (E.getNumReferences() >= 3334534144 /*24698.0*/) goto t140_n84;
  t140_n83: return -0.7106515765190125;
  t140_n84: return -0.16675066947937012;
  t140_n85: return -1.0669751167297363;
  t140_n86: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t140_n88;
  t140_n87: return -0.10447824001312256;
  t140_n88: if (E.getNumReferences() >= 3340538496 /*40082.5*/) goto t140_n90;
  t140_n89: return 0.10025584697723389;
  t140_n90: if (E.getNumReferences() >= 3345400960 /*59076.5*/) goto t140_n92;
  t140_n91: return 0.10922681540250778;
  t140_n92: return -0.019177230075001717;
  t140_n93: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n95;
  t140_n94: return -0.17479005455970764;
  t140_n95: return 0.057817015796899796;
  t140_n96: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t140_n112;
  t140_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t140_n103;
  t140_n98: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n102;
  t140_n99: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t140_n101;
  t140_n100: return -0.03375506401062012;
  t140_n101: return 0.13148252665996552;
  t140_n102: return -0.08243200182914734;
  t140_n103: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t140_n105;
  t140_n104: return -0.008069777861237526;
  t140_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n109;
  t140_n106: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t140_n108;
  t140_n107: return 0.07730647176504135;
  t140_n108: return 0.10559394210577011;
  t140_n109: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t140_n111;
  t140_n110: return 0.09301245957612991;
  t140_n111: return -0.014198646880686283;
  t140_n112: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t140_n114;
  t140_n113: return 0.016943499445915222;
  t140_n114: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n116;
  t140_n115: return 0.05701713263988495;
  t140_n116: return 0.06280618906021118;
  t140_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n141;
  t140_n118: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t140_n140;
  t140_n119: if (E.getNumReferences() >= 3340106752 /*38396.0*/) goto t140_n131;
  t140_n120: if (E.getNumReferences() >= 3336351232 /*28247.0*/) goto t140_n130;
  t140_n121: if (E.getNumReferences() >= 3336193792 /*27939.5*/) goto t140_n129;
  t140_n122: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t140_n128;
  t140_n123: if (E.getNumReferences() >= 3333474560 /*22628.5*/) goto t140_n125;
  t140_n124: return -0.02094852551817894;
  t140_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n127;
  t140_n126: return 0.11638307571411133;
  t140_n127: return -0.41425928473472595;
  t140_n128: return 0.04892871156334877;
  t140_n129: return 0.47732478380203247;
  t140_n130: return -0.11426212638616562;
  t140_n131: if (E.getNumReferences() >= 3341427584 /*43555.5*/) goto t140_n133;
  t140_n132: return 0.11271502077579498;
  t140_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t140_n135;
  t140_n134: return 0.2102934718132019;
  t140_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n137;
  t140_n136: return 0.13019384443759918;
  t140_n137: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t140_n139;
  t140_n138: return 0.11757270246744156;
  t140_n139: return -0.004294759593904018;
  t140_n140: return -0.04327978566288948;
  t140_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n147;
  t140_n142: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t140_n146;
  t140_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t140_n145;
  t140_n144: return 0.052496593445539474;
  t140_n145: return 0.10420368611812592;
  t140_n146: return 0.13397644460201263;
  t140_n147: if (E.getNumReferences() >= 3346358272 /*62816.0*/) goto t140_n153;
  t140_n148: if (E.getNumReferences() >= 3334260992 /*24164.5*/) goto t140_n150;
  t140_n149: return 0.021952908486127853;
  t140_n150: if (E.getNumReferences() >= 3334637824 /*24900.5*/) goto t140_n152;
  t140_n151: return 0.10813838988542557;
  t140_n152: return 0.10930529981851578;
  t140_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n155;
  t140_n154: return -1.4928148984909058;
  t140_n155: return -0.02452990412712097;
  t140_n156: return -0.03114793635904789;
  t140_n157: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t140_n167;
  t140_n158: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t140_n166;
  t140_n159: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t140_n161;
  t140_n160: return 0.016811447218060493;
  t140_n161: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n163;
  t140_n162: return 0.16472765803337097;
  t140_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n165;
  t140_n164: return 0.1301960051059723;
  t140_n165: return 0.12288934737443924;
  t140_n166: return -0.11950868368148804;
  t140_n167: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t140_n191;
  t140_n168: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t140_n178;
  t140_n169: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n177;
  t140_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t140_n172;
  t140_n171: return -0.014706188812851906;
  t140_n172: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t140_n176;
  t140_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n175;
  t140_n174: return 0.10422506183385849;
  t140_n175: return 0.04010577127337456;
  t140_n176: return -0.10906124860048294;
  t140_n177: return 0.033121999353170395;
  t140_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n186;
  t140_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n185;
  t140_n180: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t140_n184;
  t140_n181: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t140_n183;
  t140_n182: return 0.035444580018520355;
  t140_n183: return 0.07950285077095032;
  t140_n184: return 0.047200266271829605;
  t140_n185: return 0.07644045352935791;
  t140_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t140_n188;
  t140_n187: return 0.025895489379763603;
  t140_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n190;
  t140_n189: return 0.08002832531929016;
  t140_n190: return 0.03668691962957382;
  t140_n191: return -0.036835379898548126;
  t140_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t140_n196;
  t140_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t140_n195;
  t140_n194: return 0.004024907946586609;
  t140_n195: return 0.023482557386159897;
  t140_n196: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t140_n240;
  t140_n197: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t140_n199;
  t140_n198: return 0.10112787783145905;
  t140_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n219;
  t140_n200: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t140_n216;
  t140_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t140_n203;
  t140_n202: return -0.08510429412126541;
  t140_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t140_n207;
  t140_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n206;
  t140_n205: return -0.10160898417234421;
  t140_n206: return 0.11866551637649536;
  t140_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t140_n215;
  t140_n208: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t140_n214;
  t140_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n211;
  t140_n210: return 0.013823929242789745;
  t140_n211: if (E.getNumReferences() >= 3341667584 /*44493.0*/) goto t140_n213;
  t140_n212: return 0.0965941920876503;
  t140_n213: return 0.027185847982764244;
  t140_n214: return 0.10151797533035278;
  t140_n215: return -0.042628709226846695;
  t140_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n218;
  t140_n217: return 0.08383802324533463;
  t140_n218: return 0.11055430769920349;
  t140_n219: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t140_n237;
  t140_n220: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t140_n234;
  t140_n221: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t140_n227;
  t140_n222: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t140_n224;
  t140_n223: return 0.06957527250051498;
  t140_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t140_n226;
  t140_n225: return 0.08669121563434601;
  t140_n226: return 0.0954883024096489;
  t140_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n231;
  t140_n228: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t140_n230;
  t140_n229: return 0.11553587764501572;
  t140_n230: return 0.09360872209072113;
  t140_n231: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t140_n233;
  t140_n232: return 0.10938163101673126;
  t140_n233: return 0.047873739153146744;
  t140_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t140_n236;
  t140_n235: return 0.10242418944835663;
  t140_n236: return 0.07018275558948517;
  t140_n237: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t140_n239;
  t140_n238: return 0.04703441634774208;
  t140_n239: return -0.4283779561519623;
  t140_n240: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t140_n248;
  t140_n241: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t140_n243;
  t140_n242: return 0.052250489592552185;
  t140_n243: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t140_n247;
  t140_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t140_n246;
  t140_n245: return 0.11794160306453705;
  t140_n246: return -0.007347887847572565;
  t140_n247: return -0.013378801755607128;
  t140_n248: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t140_n252;
  t140_n249: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t140_n251;
  t140_n250: return -0.16596433520317078;
  t140_n251: return -0.0014557801187038422;
  t140_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t140_n254;
  t140_n253: return -0.3019437789916992;
  t140_n254: return 0.11954367160797119;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree141(const Example& E) {
  t141_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t141_n162;
  t141_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t141_n19;
  t141_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t141_n4;
  t141_n3: return 0.0010205128928646445;
  t141_n4: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n10;
  t141_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t141_n7;
  t141_n6: return 0.004833218175917864;
  t141_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t141_n9;
  t141_n8: return -0.11980519443750381;
  t141_n9: return 0.02279859222471714;
  t141_n10: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t141_n12;
  t141_n11: return 0.10515967756509781;
  t141_n12: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t141_n18;
  t141_n13: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t141_n15;
  t141_n14: return 0.019585464149713516;
  t141_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t141_n17;
  t141_n16: return 0.04292409121990204;
  t141_n17: return -0.014569812454283237;
  t141_n18: return 0.040495485067367554;
  t141_n19: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t141_n109;
  t141_n20: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t141_n22;
  t141_n21: return -0.018853923305869102;
  t141_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t141_n24;
  t141_n23: return -0.007411425467580557;
  t141_n24: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t141_n44;
  t141_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t141_n27;
  t141_n26: return -0.0069656819105148315;
  t141_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t141_n29;
  t141_n28: return -0.09804453700780869;
  t141_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n43;
  t141_n30: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t141_n32;
  t141_n31: return 0.0243188738822937;
  t141_n32: if (E.getNumReferences() >= 3335751680 /*27076.0*/) goto t141_n42;
  t141_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t141_n35;
  t141_n34: return 0.022419463843107224;
  t141_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n41;
  t141_n36: if (E.getSymbolScopeDistance() >= 3244294144 /*14.0*/) goto t141_n38;
  t141_n37: return 0.11854279041290283;
  t141_n38: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n40;
  t141_n39: return 0.10182730108499527;
  t141_n40: return 0.04966916888952255;
  t141_n41: return 0.01555416639894247;
  t141_n42: return 0.12074726819992065;
  t141_n43: return 0.0017263167537748814;
  t141_n44: if (E.getNumReferences() >= 3280912384 /*285.5*/) goto t141_n106;
  t141_n45: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t141_n105;
  t141_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t141_n48;
  t141_n47: return -0.05707995221018791;
  t141_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t141_n52;
  t141_n49: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t141_n51;
  t141_n50: return 0.03051414154469967;
  t141_n51: return 0.042999569326639175;
  t141_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t141_n58;
  t141_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t141_n55;
  t141_n54: return -0.04750862345099449;
  t141_n55: if (E.getSymbolScopeDistance() >= 3249012736 /*21.0*/) goto t141_n57;
  t141_n56: return 0.128861665725708;
  t141_n57: return 0.12039552628993988;
  t141_n58: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t141_n60;
  t141_n59: return 0.03017568215727806;
  t141_n60: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t141_n104;
  t141_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t141_n63;
  t141_n62: return 0.013486954383552074;
  t141_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n103;
  t141_n64: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t141_n80;
  t141_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n67;
  t141_n66: return 0.05812166631221771;
  t141_n67: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t141_n79;
  t141_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n70;
  t141_n69: return 0.07234231382608414;
  t141_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t141_n72;
  t141_n71: return 0.06472468376159668;
  t141_n72: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t141_n74;
  t141_n73: return 0.10668689757585526;
  t141_n74: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t141_n76;
  t141_n75: return -0.03250705450773239;
  t141_n76: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t141_n78;
  t141_n77: return 0.10864849388599396;
  t141_n78: return -0.13955895602703094;
  t141_n79: return 0.029859324917197227;
  t141_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t141_n88;
  t141_n81: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t141_n87;
  t141_n82: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t141_n86;
  t141_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t141_n85;
  t141_n84: return -0.16848501563072205;
  t141_n85: return 0.10110755264759064;
  t141_n86: return 0.019740642979741096;
  t141_n87: return 0.08141844719648361;
  t141_n88: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t141_n102;
  t141_n89: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t141_n97;
  t141_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n92;
  t141_n91: return 0.10444959998130798;
  t141_n92: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t141_n96;
  t141_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t141_n95;
  t141_n94: return -0.11573834717273712;
  t141_n95: return 0.11927691102027893;
  t141_n96: return 0.051413968205451965;
  t141_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t141_n99;
  t141_n98: return -0.15290215611457825;
  t141_n99: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t141_n101;
  t141_n100: return 0.12450128048658371;
  t141_n101: return 0.12333116680383682;
  t141_n102: return 0.1256067305803299;
  t141_n103: return 0.02682838961482048;
  t141_n104: return -0.1081579253077507;
  t141_n105: return -0.04206463322043419;
  t141_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t141_n108;
  t141_n107: return 0.04760146141052246;
  t141_n108: return 0.09680846333503723;
  t141_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t141_n145;
  t141_n110: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t141_n144;
  t141_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t141_n113;
  t141_n112: return -0.03594433143734932;
  t141_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t141_n133;
  t141_n114: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t141_n132;
  t141_n115: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t141_n117;
  t141_n116: return 0.0306314118206501;
  t141_n117: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t141_n131;
  t141_n118: if (E.getNumReferences() >= 3292512256 /*767.0*/) goto t141_n130;
  t141_n119: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t141_n125;
  t141_n120: if (E.getNumReferences() >= 3271819264 /*132.0*/) goto t141_n122;
  t141_n121: return -0.013725324533879757;
  t141_n122: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t141_n124;
  t141_n123: return -0.10681411623954773;
  t141_n124: return 0.10993590205907822;
  t141_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n129;
  t141_n126: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t141_n128;
  t141_n127: return 0.12249863892793655;
  t141_n128: return 0.3229580223560333;
  t141_n129: return 0.09624335914850235;
  t141_n130: return 0.10153920948505402;
  t141_n131: return 0.056536734104156494;
  t141_n132: return -0.08343935757875443;
  t141_n133: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t141_n135;
  t141_n134: return -0.013374140486121178;
  t141_n135: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t141_n143;
  t141_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n138;
  t141_n137: return 0.011583571322262287;
  t141_n138: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t141_n142;
  t141_n139: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t141_n141;
  t141_n140: return 0.11164886504411697;
  t141_n141: return -0.008429521694779396;
  t141_n142: return 0.011401367373764515;
  t141_n143: return 0.034791938960552216;
  t141_n144: return -0.010815444402396679;
  t141_n145: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t141_n153;
  t141_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t141_n150;
  t141_n147: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t141_n149;
  t141_n148: return 0.004901782609522343;
  t141_n149: return -0.009287248365581036;
  t141_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n152;
  t141_n151: return 0.09995558112859726;
  t141_n152: return -0.0015392544446513057;
  t141_n153: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t141_n161;
  t141_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n156;
  t141_n155: return -0.10053147375583649;
  t141_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t141_n158;
  t141_n157: return 0.10526394098997116;
  t141_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n160;
  t141_n159: return 0.0983576700091362;
  t141_n160: return -0.004502694588154554;
  t141_n161: return 0.04169416427612305;
  t141_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t141_n222;
  t141_n163: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t141_n177;
  t141_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t141_n168;
  t141_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n167;
  t141_n166: return -0.07669582217931747;
  t141_n167: return 0.19441568851470947;
  t141_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n176;
  t141_n169: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t141_n175;
  t141_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t141_n174;
  t141_n171: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n173;
  t141_n172: return 0.1100158840417862;
  t141_n173: return 0.1000387966632843;
  t141_n174: return 0.08800184726715088;
  t141_n175: return -0.027762161567807198;
  t141_n176: return -0.15232890844345093;
  t141_n177: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t141_n179;
  t141_n178: return 0.0003793254727497697;
  t141_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t141_n215;
  t141_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t141_n214;
  t141_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n213;
  t141_n182: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n184;
  t141_n183: return 0.11300131678581238;
  t141_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t141_n208;
  t141_n185: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t141_n207;
  t141_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t141_n206;
  t141_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t141_n189;
  t141_n188: return 0.030432865023612976;
  t141_n189: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t141_n201;
  t141_n190: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t141_n192;
  t141_n191: return 0.09973432868719101;
  t141_n192: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t141_n196;
  t141_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t141_n195;
  t141_n194: return 0.10055503994226456;
  t141_n195: return 0.006970573682337999;
  t141_n196: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t141_n198;
  t141_n197: return 0.10015841573476791;
  t141_n198: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t141_n200;
  t141_n199: return 0.10512777417898178;
  t141_n200: return 0.052973147481679916;
  t141_n201: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t141_n203;
  t141_n202: return -0.15089042484760284;
  t141_n203: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t141_n205;
  t141_n204: return 0.12454226613044739;
  t141_n205: return 0.08526529371738434;
  t141_n206: return 0.01184102613478899;
  t141_n207: return 0.015864327549934387;
  t141_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t141_n212;
  t141_n209: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t141_n211;
  t141_n210: return 0.08509473502635956;
  t141_n211: return 0.11372477561235428;
  t141_n212: return 0.038655612617731094;
  t141_n213: return -0.10292454808950424;
  t141_n214: return 0.10932771861553192;
  t141_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t141_n221;
  t141_n216: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t141_n220;
  t141_n217: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t141_n219;
  t141_n218: return 0.026236290112137794;
  t141_n219: return 0.13157805800437927;
  t141_n220: return -0.12488171458244324;
  t141_n221: return -0.10732851922512054;
  t141_n222: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t141_n254;
  t141_n223: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t141_n233;
  t141_n224: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t141_n226;
  t141_n225: return 0.011607903987169266;
  t141_n226: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t141_n228;
  t141_n227: return -0.004664773587137461;
  t141_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n232;
  t141_n229: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t141_n231;
  t141_n230: return 0.15890507400035858;
  t141_n231: return -0.10491856932640076;
  t141_n232: return 0.04463159665465355;
  t141_n233: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t141_n241;
  t141_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n240;
  t141_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n237;
  t141_n236: return 0.0488264299929142;
  t141_n237: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t141_n239;
  t141_n238: return 0.12927216291427612;
  t141_n239: return 0.0369529090821743;
  t141_n240: return -0.39127597212791443;
  t141_n241: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t141_n249;
  t141_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t141_n246;
  t141_n243: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t141_n245;
  t141_n244: return 0.1578780859708786;
  t141_n245: return 0.1133488193154335;
  t141_n246: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t141_n248;
  t141_n247: return 0.12989018857479095;
  t141_n248: return 0.08454027771949768;
  t141_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t141_n253;
  t141_n250: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t141_n252;
  t141_n251: return 0.09229575097560883;
  t141_n252: return 0.16822104156017303;
  t141_n253: return 0.11226730793714523;
  t141_n254: return 0.008480455726385117;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree142(const Example& E) {
  t142_n0: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t142_n208;
  t142_n1: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t142_n3;
  t142_n2: return -0.0007742340676486492;
  t142_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t142_n7;
  t142_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t142_n6;
  t142_n5: return 0.008263060823082924;
  t142_n6: return 0.023236557841300964;
  t142_n7: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t142_n9;
  t142_n8: return -0.0032550166361033916;
  t142_n9: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t142_n201;
  t142_n10: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t142_n170;
  t142_n11: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t142_n59;
  t142_n12: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t142_n58;
  t142_n13: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t142_n15;
  t142_n14: return -0.01820977032184601;
  t142_n15: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t142_n17;
  t142_n16: return 0.006414564326405525;
  t142_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t142_n47;
  t142_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t142_n20;
  t142_n19: return 0.028731055557727814;
  t142_n20: if (E.getNumReferences() >= 3307925504 /*2735.0*/) goto t142_n22;
  t142_n21: return 0.022682957351207733;
  t142_n22: if (E.getNumReferences() >= 3308326912 /*2833.0*/) goto t142_n28;
  t142_n23: if (E.getNumReferences() >= 3308234752 /*2810.5*/) goto t142_n27;
  t142_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n26;
  t142_n25: return 0.14861692488193512;
  t142_n26: return -0.356219619512558;
  t142_n27: return 0.11090154200792313;
  t142_n28: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t142_n46;
  t142_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t142_n31;
  t142_n30: return -0.007563568186014891;
  t142_n31: if (E.getNumReferences() >= 3313252352 /*4035.5*/) goto t142_n39;
  t142_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t142_n34;
  t142_n33: return -0.2074689418077469;
  t142_n34: if (E.getNumReferences() >= 3310622720 /*3393.5*/) goto t142_n38;
  t142_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t142_n37;
  t142_n36: return 0.12968353927135468;
  t142_n37: return 0.10021825134754181;
  t142_n38: return -0.1219141036272049;
  t142_n39: if (E.getNumReferences() >= 3313750016 /*4218.0*/) goto t142_n41;
  t142_n40: return 0.11803414672613144;
  t142_n41: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t142_n43;
  t142_n42: return 0.013061326928436756;
  t142_n43: if (E.getNumReferences() >= 3314864128 /*4762.0*/) goto t142_n45;
  t142_n44: return 0.10264204442501068;
  t142_n45: return 0.13529297709465027;
  t142_n46: return -0.07841387391090393;
  t142_n47: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t142_n53;
  t142_n48: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t142_n50;
  t142_n49: return 0.05651649832725525;
  t142_n50: if (E.getNumReferences() >= 3306643456 /*2422.0*/) goto t142_n52;
  t142_n51: return 0.10863620042800903;
  t142_n52: return 0.041586898267269135;
  t142_n53: if (E.getNumReferences() >= 3304992768 /*2033.5*/) goto t142_n55;
  t142_n54: return -0.1003488153219223;
  t142_n55: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t142_n57;
  t142_n56: return 0.11049307882785797;
  t142_n57: return -0.14916367828845978;
  t142_n58: return 0.061979297548532486;
  t142_n59: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t142_n69;
  t142_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t142_n66;
  t142_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n63;
  t142_n62: return 0.0013331928057596087;
  t142_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t142_n65;
  t142_n64: return 0.1163831576704979;
  t142_n65: return -0.1259361207485199;
  t142_n66: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t142_n68;
  t142_n67: return 0.09971169382333755;
  t142_n68: return 0.1279975324869156;
  t142_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t142_n71;
  t142_n70: return 0.01917993277311325;
  t142_n71: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t142_n157;
  t142_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t142_n80;
  t142_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t142_n77;
  t142_n74: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t142_n76;
  t142_n75: return -0.19359630346298218;
  t142_n76: return 0.06237225607037544;
  t142_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t142_n79;
  t142_n78: return -0.05085595324635506;
  t142_n79: return 0.03860773518681526;
  t142_n80: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t142_n84;
  t142_n81: if (E.getNumReferences() >= 3322151424 /*8448.5*/) goto t142_n83;
  t142_n82: return 0.1418684422969818;
  t142_n83: return -0.188652902841568;
  t142_n84: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t142_n156;
  t142_n85: if (E.getNumReferences() >= 3329426944 /*15553.5*/) goto t142_n143;
  t142_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n88;
  t142_n87: return -0.02707483060657978;
  t142_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t142_n98;
  t142_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n93;
  t142_n90: if (E.getNumReferences() >= 3316420608 /*5522.0*/) goto t142_n92;
  t142_n91: return 0.15248826146125793;
  t142_n92: return 0.014328856021165848;
  t142_n93: if (E.getNumReferences() >= 3322974720 /*9252.5*/) goto t142_n97;
  t142_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n96;
  t142_n95: return -0.12639206647872925;
  t142_n96: return 0.10485595464706421;
  t142_n97: return 0.12919610738754272;
  t142_n98: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t142_n112;
  t142_n99: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n101;
  t142_n100: return -0.010461743921041489;
  t142_n101: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t142_n103;
  t142_n102: return 0.04186265170574188;
  t142_n103: if (E.getNumReferences() >= 3317264384 /*5934.0*/) goto t142_n105;
  t142_n104: return 0.12537159025669098;
  t142_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n107;
  t142_n106: return 0.023482976481318474;
  t142_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t142_n111;
  t142_n108: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t142_n110;
  t142_n109: return 0.10694635659456253;
  t142_n110: return -0.16518071293830872;
  t142_n111: return 0.10279097408056259;
  t142_n112: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t142_n114;
  t142_n113: return 0.11580953747034073;
  t142_n114: if (E.getNumReferences() >= 3324665856 /*10904.0*/) goto t142_n142;
  t142_n115: if (E.getNumReferences() >= 3324570112 /*10810.5*/) goto t142_n141;
  t142_n116: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t142_n130;
  t142_n117: if (E.getNumReferences() >= 3323522048 /*9787.0*/) goto t142_n127;
  t142_n118: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t142_n120;
  t142_n119: return 0.035993095487356186;
  t142_n120: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t142_n124;
  t142_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t142_n123;
  t142_n122: return -0.10608511418104172;
  t142_n123: return 0.11199961602687836;
  t142_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t142_n126;
  t142_n125: return 0.13304394483566284;
  t142_n126: return 0.0978306233882904;
  t142_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t142_n129;
  t142_n128: return -0.013875915668904781;
  t142_n129: return -0.8290230631828308;
  t142_n130: if (E.getNumReferences() >= 3324409856 /*10654.0*/) goto t142_n140;
  t142_n131: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t142_n139;
  t142_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n138;
  t142_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t142_n137;
  t142_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t142_n136;
  t142_n135: return 0.581957221031189;
  t142_n136: return 0.10704021900892258;
  t142_n137: return 0.12452743202447891;
  t142_n138: return 0.08219154179096222;
  t142_n139: return 0.05071550980210304;
  t142_n140: return -0.2852509617805481;
  t142_n141: return 0.12257318943738937;
  t142_n142: return 0.008337553590536118;
  t142_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t142_n145;
  t142_n144: return 0.04637017846107483;
  t142_n145: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t142_n151;
  t142_n146: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t142_n148;
  t142_n147: return 0.11786479502916336;
  t142_n148: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t142_n150;
  t142_n149: return 0.007941885851323605;
  t142_n150: return 0.09777942299842834;
  t142_n151: if (E.getNumReferences() >= 3331808000 /*19373.5*/) goto t142_n153;
  t142_n152: return 0.040049389004707336;
  t142_n153: if (E.getNumReferences() >= 3332234496 /*20206.5*/) goto t142_n155;
  t142_n154: return 0.09698224812746048;
  t142_n155: return 0.046153292059898376;
  t142_n156: return 0.11277983337640762;
  t142_n157: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t142_n169;
  t142_n158: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t142_n166;
  t142_n159: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n161;
  t142_n160: return 0.10354695469141006;
  t142_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t142_n165;
  t142_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t142_n164;
  t142_n163: return -0.3180624544620514;
  t142_n164: return 0.09063656628131866;
  t142_n165: return 0.11557430028915405;
  t142_n166: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n168;
  t142_n167: return 0.10846473276615143;
  t142_n168: return 0.0731944665312767;
  t142_n169: return 0.0016502419020980597;
  t142_n170: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t142_n200;
  t142_n171: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t142_n175;
  t142_n172: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t142_n174;
  t142_n173: return -0.017681891098618507;
  t142_n174: return 0.004289797507226467;
  t142_n175: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t142_n179;
  t142_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t142_n178;
  t142_n177: return 0.06351368874311447;
  t142_n178: return 0.10569840669631958;
  t142_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n189;
  t142_n180: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t142_n188;
  t142_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t142_n185;
  t142_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t142_n184;
  t142_n183: return 0.0018393052741885185;
  t142_n184: return 0.09271302819252014;
  t142_n185: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t142_n187;
  t142_n186: return -0.02107340283691883;
  t142_n187: return -0.15778349339962006;
  t142_n188: return 0.0519767589867115;
  t142_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t142_n191;
  t142_n190: return 0.06361785531044006;
  t142_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n193;
  t142_n192: return 0.02113969437777996;
  t142_n193: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t142_n199;
  t142_n194: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t142_n196;
  t142_n195: return 0.11321821808815002;
  t142_n196: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t142_n198;
  t142_n197: return 0.025139085948467255;
  t142_n198: return 0.12164279073476791;
  t142_n199: return 0.0683988481760025;
  t142_n200: return 0.04386598616838455;
  t142_n201: if (E.getNumReferences() >= 3306448896 /*2374.5*/) goto t142_n203;
  t142_n202: return 0.0055405194871127605;
  t142_n203: if (E.getNumReferences() >= 3306622976 /*2417.0*/) goto t142_n207;
  t142_n204: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t142_n206;
  t142_n205: return 0.11280570924282074;
  t142_n206: return 0.022210512310266495;
  t142_n207: return 0.03769202157855034;
  t142_n208: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t142_n242;
  t142_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t142_n229;
  t142_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n226;
  t142_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t142_n215;
  t142_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n214;
  t142_n213: return -0.1989021599292755;
  t142_n214: return 0.09830502420663834;
  t142_n215: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t142_n221;
  t142_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t142_n220;
  t142_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n219;
  t142_n218: return -0.04378124326467514;
  t142_n219: return 0.006679334677755833;
  t142_n220: return 0.10053851455450058;
  t142_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t142_n223;
  t142_n222: return -0.007010164204984903;
  t142_n223: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t142_n225;
  t142_n224: return 0.038671620190143585;
  t142_n225: return -0.02630310319364071;
  t142_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t142_n228;
  t142_n227: return -0.008261547423899174;
  t142_n228: return 0.002949565416201949;
  t142_n229: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t142_n237;
  t142_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t142_n236;
  t142_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t142_n233;
  t142_n232: return 0.005629157647490501;
  t142_n233: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t142_n235;
  t142_n234: return 0.016665019094944;
  t142_n235: return 0.00822881143540144;
  t142_n236: return 0.06863389909267426;
  t142_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t142_n241;
  t142_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n240;
  t142_n239: return -0.7198639512062073;
  t142_n240: return -2.6612045764923096;
  t142_n241: return -0.15490002930164337;
  t142_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t142_n250;
  t142_n243: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t142_n247;
  t142_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t142_n246;
  t142_n245: return 0.03357064351439476;
  t142_n246: return -0.265762060880661;
  t142_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t142_n249;
  t142_n248: return 0.0876532569527626;
  t142_n249: return -0.0631071925163269;
  t142_n250: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t142_n252;
  t142_n251: return -2.9090194702148438;
  t142_n252: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t142_n254;
  t142_n253: return 0.09276982396841049;
  t142_n254: return 0.009132345207035542;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree143(const Example& E) {
  t143_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t143_n2;
  t143_n1: return -0.00022247483138926327;
  t143_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t143_n234;
  t143_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t143_n5;
  t143_n4: return -0.03138437867164612;
  t143_n5: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t143_n163;
  t143_n6: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t143_n126;
  t143_n7: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t143_n89;
  t143_n8: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t143_n80;
  t143_n9: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t143_n79;
  t143_n10: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t143_n62;
  t143_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t143_n31;
  t143_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t143_n14;
  t143_n13: return -0.00466281408444047;
  t143_n14: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t143_n30;
  t143_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t143_n29;
  t143_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n18;
  t143_n17: return 0.08208692073822021;
  t143_n18: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t143_n24;
  t143_n19: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n23;
  t143_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n22;
  t143_n21: return 0.09420761466026306;
  t143_n22: return 0.12053915113210678;
  t143_n23: return 0.029351484030485153;
  t143_n24: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t143_n28;
  t143_n25: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t143_n27;
  t143_n26: return 0.04663468524813652;
  t143_n27: return 0.11308499425649643;
  t143_n28: return -0.10391171276569366;
  t143_n29: return -0.5522753000259399;
  t143_n30: return 0.19600655138492584;
  t143_n31: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t143_n35;
  t143_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t143_n34;
  t143_n33: return -0.17059458792209625;
  t143_n34: return 0.03962619975209236;
  t143_n35: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t143_n45;
  t143_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n38;
  t143_n37: return -0.007212852127850056;
  t143_n38: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n42;
  t143_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n41;
  t143_n40: return 0.10276860743761063;
  t143_n41: return 0.07947981357574463;
  t143_n42: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t143_n44;
  t143_n43: return 0.05556093901395798;
  t143_n44: return -0.3318637013435364;
  t143_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n55;
  t143_n46: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n48;
  t143_n47: return 0.017967475578188896;
  t143_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n50;
  t143_n49: return -0.1272299885749817;
  t143_n50: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t143_n52;
  t143_n51: return 0.03811832144856453;
  t143_n52: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t143_n54;
  t143_n53: return 0.12457208335399628;
  t143_n54: return 0.1290520876646042;
  t143_n55: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n57;
  t143_n56: return 0.05126141384243965;
  t143_n57: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t143_n61;
  t143_n58: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n60;
  t143_n59: return 0.10452830046415329;
  t143_n60: return 0.09173852205276489;
  t143_n61: return 0.06475502252578735;
  t143_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n76;
  t143_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n75;
  t143_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n66;
  t143_n65: return -0.17278435826301575;
  t143_n66: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t143_n70;
  t143_n67: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n69;
  t143_n68: return -0.10289919376373291;
  t143_n69: return 0.10598640888929367;
  t143_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n72;
  t143_n71: return 0.049864958971738815;
  t143_n72: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t143_n74;
  t143_n73: return 0.16841985285282135;
  t143_n74: return 0.07952222228050232;
  t143_n75: return -0.19218555092811584;
  t143_n76: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n78;
  t143_n77: return 0.1102161854505539;
  t143_n78: return 0.09237099438905716;
  t143_n79: return -0.038184769451618195;
  t143_n80: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t143_n84;
  t143_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n83;
  t143_n82: return -0.12162468582391739;
  t143_n83: return 0.12936906516551971;
  t143_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n86;
  t143_n85: return -0.15791502594947815;
  t143_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n88;
  t143_n87: return 0.14086225628852844;
  t143_n88: return 0.0824810042977333;
  t143_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t143_n109;
  t143_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t143_n92;
  t143_n91: return 0.12566275894641876;
  t143_n92: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n108;
  t143_n93: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n107;
  t143_n94: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t143_n106;
  t143_n95: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t143_n97;
  t143_n96: return 0.07936488091945648;
  t143_n97: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n103;
  t143_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n102;
  t143_n99: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t143_n101;
  t143_n100: return 0.10628225654363632;
  t143_n101: return 0.10284800827503204;
  t143_n102: return 0.10134081542491913;
  t143_n103: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t143_n105;
  t143_n104: return 0.10441312938928604;
  t143_n105: return 0.03377911448478699;
  t143_n106: return -0.0032284304033964872;
  t143_n107: return 0.01636168360710144;
  t143_n108: return 0.030186673626303673;
  t143_n109: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t143_n125;
  t143_n110: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t143_n116;
  t143_n111: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t143_n113;
  t143_n112: return 0.03628518059849739;
  t143_n113: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t143_n115;
  t143_n114: return 0.12223518639802933;
  t143_n115: return 0.019432341679930687;
  t143_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n122;
  t143_n117: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n121;
  t143_n118: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n120;
  t143_n119: return 0.10997273027896881;
  t143_n120: return 0.06727943569421768;
  t143_n121: return 0.13819976150989532;
  t143_n122: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t143_n124;
  t143_n123: return -0.08506565541028976;
  t143_n124: return 0.13506391644477844;
  t143_n125: return -0.04603518173098564;
  t143_n126: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t143_n158;
  t143_n127: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t143_n155;
  t143_n128: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t143_n130;
  t143_n129: return -0.03390534967184067;
  t143_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n154;
  t143_n131: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n147;
  t143_n132: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t143_n142;
  t143_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t143_n135;
  t143_n134: return 0.12092006206512451;
  t143_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n141;
  t143_n136: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t143_n138;
  t143_n137: return -0.2733423113822937;
  t143_n138: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n140;
  t143_n139: return 0.18455851078033447;
  t143_n140: return -0.22000953555107117;
  t143_n141: return 0.4870801568031311;
  t143_n142: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n146;
  t143_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t143_n145;
  t143_n144: return 0.06881660968065262;
  t143_n145: return 0.10201101005077362;
  t143_n146: return -0.03454107046127319;
  t143_n147: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t143_n153;
  t143_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t143_n152;
  t143_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t143_n151;
  t143_n150: return 0.08295854926109314;
  t143_n151: return -0.052502695471048355;
  t143_n152: return 0.10326103121042252;
  t143_n153: return 0.1062367707490921;
  t143_n154: return -0.10480666905641556;
  t143_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n157;
  t143_n156: return -0.2965274453163147;
  t143_n157: return 0.011074583046138287;
  t143_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t143_n160;
  t143_n159: return 0.011836057528853416;
  t143_n160: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t143_n162;
  t143_n161: return 0.06343349069356918;
  t143_n162: return -0.11679304391145706;
  t143_n163: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t143_n189;
  t143_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t143_n188;
  t143_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t143_n167;
  t143_n166: return -0.08269952237606049;
  t143_n167: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t143_n187;
  t143_n168: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t143_n178;
  t143_n169: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n171;
  t143_n170: return -0.03019111417233944;
  t143_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n177;
  t143_n172: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t143_n176;
  t143_n173: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t143_n175;
  t143_n174: return 0.09698840230703354;
  t143_n175: return 0.07761142402887344;
  t143_n176: return -0.10217228531837463;
  t143_n177: return -0.26099029183387756;
  t143_n178: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n180;
  t143_n179: return -0.1807221919298172;
  t143_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t143_n186;
  t143_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n183;
  t143_n182: return 0.11781508475542068;
  t143_n183: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n185;
  t143_n184: return -0.17197012901306152;
  t143_n185: return 0.10741209983825684;
  t143_n186: return -0.21005961298942566;
  t143_n187: return -0.13084575533866882;
  t143_n188: return -0.12572525441646576;
  t143_n189: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t143_n205;
  t143_n190: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n192;
  t143_n191: return -0.03179435059428215;
  t143_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t143_n198;
  t143_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n197;
  t143_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t143_n196;
  t143_n195: return -0.11982420831918716;
  t143_n196: return 0.16138091683387756;
  t143_n197: return 0.11120646446943283;
  t143_n198: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t143_n204;
  t143_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t143_n201;
  t143_n200: return 0.08037571609020233;
  t143_n201: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n203;
  t143_n202: return 0.09623783826828003;
  t143_n203: return 0.03664757311344147;
  t143_n204: return 0.0476493239402771;
  t143_n205: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t143_n207;
  t143_n206: return -0.1424131542444229;
  t143_n207: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t143_n217;
  t143_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t143_n216;
  t143_n209: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t143_n211;
  t143_n210: return -0.05233699828386307;
  t143_n211: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n213;
  t143_n212: return -0.04389231652021408;
  t143_n213: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t143_n215;
  t143_n214: return 0.08135604113340378;
  t143_n215: return 0.08539951592683792;
  t143_n216: return 0.04736502096056938;
  t143_n217: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t143_n219;
  t143_n218: return -0.005195758771151304;
  t143_n219: if (E.getNumReferences() >= 3367337376 /*371693.0*/) goto t143_n223;
  t143_n220: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t143_n222;
  t143_n221: return -0.33777323365211487;
  t143_n222: return -0.18445390462875366;
  t143_n223: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t143_n233;
  t143_n224: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t143_n226;
  t143_n225: return 0.051098279654979706;
  t143_n226: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t143_n228;
  t143_n227: return 0.0048950244672596455;
  t143_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t143_n230;
  t143_n229: return -0.3086641728878021;
  t143_n230: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t143_n232;
  t143_n231: return 0.12003791332244873;
  t143_n232: return -0.04418885335326195;
  t143_n233: return -0.04141870513558388;
  t143_n234: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t143_n236;
  t143_n235: return 0.010455294512212276;
  t143_n236: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t143_n254;
  t143_n237: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t143_n247;
  t143_n238: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t143_n240;
  t143_n239: return -0.025301750749349594;
  t143_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t143_n244;
  t143_n241: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t143_n243;
  t143_n242: return 0.09967547655105591;
  t143_n243: return 0.016138644888997078;
  t143_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t143_n246;
  t143_n245: return 0.09272236377000809;
  t143_n246: return 0.12135990709066391;
  t143_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t143_n253;
  t143_n248: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t143_n250;
  t143_n249: return -0.10599112510681152;
  t143_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t143_n252;
  t143_n251: return -0.9023605585098267;
  t143_n252: return 0.10979258269071579;
  t143_n253: return 0.11901802569627762;
  t143_n254: return -0.0006104487692937255;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree144(const Example& E) {
  t144_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t144_n38;
  t144_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t144_n37;
  t144_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t144_n4;
  t144_n3: return -0.007177260704338551;
  t144_n4: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t144_n10;
  t144_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n9;
  t144_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n8;
  t144_n7: return 0.006674942094832659;
  t144_n8: return 0.018368560820817947;
  t144_n9: return -0.002472211606800556;
  t144_n10: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t144_n36;
  t144_n11: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t144_n13;
  t144_n12: return 0.019252624362707138;
  t144_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t144_n23;
  t144_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t144_n16;
  t144_n15: return 0.06262745708227158;
  t144_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t144_n18;
  t144_n17: return 0.05689617618918419;
  t144_n18: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t144_n22;
  t144_n19: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n21;
  t144_n20: return 0.11198407411575317;
  t144_n21: return 0.11626409739255905;
  t144_n22: return 0.0370333269238472;
  t144_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n25;
  t144_n24: return 0.05569954961538315;
  t144_n25: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t144_n31;
  t144_n26: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t144_n30;
  t144_n27: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t144_n29;
  t144_n28: return 0.09999780356884003;
  t144_n29: return 0.07204645872116089;
  t144_n30: return 0.12492299824953079;
  t144_n31: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t144_n33;
  t144_n32: return 0.04419565200805664;
  t144_n33: if (E.getNumReferences() >= 3279126528 /*243.5*/) goto t144_n35;
  t144_n34: return 0.10733070224523544;
  t144_n35: return 0.08973536640405655;
  t144_n36: return 0.015253346413373947;
  t144_n37: return -0.001292180037125945;
  t144_n38: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t144_n40;
  t144_n39: return 0.002649355912581086;
  t144_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t144_n46;
  t144_n41: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t144_n43;
  t144_n42: return -0.10448475927114487;
  t144_n43: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t144_n45;
  t144_n44: return -0.03329630196094513;
  t144_n45: return 0.10526712238788605;
  t144_n46: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t144_n246;
  t144_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t144_n163;
  t144_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t144_n132;
  t144_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t144_n63;
  t144_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t144_n52;
  t144_n51: return -0.011235314421355724;
  t144_n52: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t144_n62;
  t144_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t144_n55;
  t144_n54: return -0.009104610420763493;
  t144_n55: if (E.getNumReferences() >= 3350811072 /*94883.5*/) goto t144_n61;
  t144_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t144_n58;
  t144_n57: return 0.10080836713314056;
  t144_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n60;
  t144_n59: return 0.09838616847991943;
  t144_n60: return 0.08322466164827347;
  t144_n61: return 0.031136404722929;
  t144_n62: return 0.027715055271983147;
  t144_n63: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t144_n131;
  t144_n64: if (E.getNumReferences() >= 3360198688 /*205376.5*/) goto t144_n110;
  t144_n65: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t144_n67;
  t144_n66: return 0.10742373764514923;
  t144_n67: if (E.getNumReferences() >= 3356314496 /*144686.0*/) goto t144_n109;
  t144_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n80;
  t144_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t144_n71;
  t144_n70: return -0.02341577038168907;
  t144_n71: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t144_n73;
  t144_n72: return 0.026946403086185455;
  t144_n73: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t144_n79;
  t144_n74: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t144_n76;
  t144_n75: return 0.19153042137622833;
  t144_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t144_n78;
  t144_n77: return -0.14387303590774536;
  t144_n78: return 0.1284315139055252;
  t144_n79: return 0.04928546026349068;
  t144_n80: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t144_n90;
  t144_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t144_n83;
  t144_n82: return -0.09639541804790497;
  t144_n83: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t144_n85;
  t144_n84: return 0.05724112316966057;
  t144_n85: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t144_n87;
  t144_n86: return -0.003734510624781251;
  t144_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t144_n89;
  t144_n88: return -0.0007100976072251797;
  t144_n89: return 0.08953233808279037;
  t144_n90: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t144_n92;
  t144_n91: return -0.2419901341199875;
  t144_n92: if (E.getNumReferences() >= 3355834112 /*137180.0*/) goto t144_n104;
  t144_n93: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t144_n95;
  t144_n94: return 0.00570674566552043;
  t144_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t144_n99;
  t144_n96: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t144_n98;
  t144_n97: return -0.15086965262889862;
  t144_n98: return 0.11300969123840332;
  t144_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t144_n101;
  t144_n100: return -0.4481494128704071;
  t144_n101: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t144_n103;
  t144_n102: return -0.20690159499645233;
  t144_n103: return 0.07705467194318771;
  t144_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n106;
  t144_n105: return -0.038930103182792664;
  t144_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t144_n108;
  t144_n107: return 0.1094435378909111;
  t144_n108: return 0.0662936195731163;
  t144_n109: return -0.11201857775449753;
  t144_n110: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n130;
  t144_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t144_n113;
  t144_n112: return 0.06404571980237961;
  t144_n113: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t144_n115;
  t144_n114: return 0.043247371912002563;
  t144_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t144_n117;
  t144_n116: return 0.019374847412109375;
  t144_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n129;
  t144_n118: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t144_n124;
  t144_n119: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t144_n121;
  t144_n120: return -0.12019730359315872;
  t144_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t144_n123;
  t144_n122: return -0.11703018099069595;
  t144_n123: return 0.1019483432173729;
  t144_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t144_n128;
  t144_n125: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t144_n127;
  t144_n126: return 0.05577322468161583;
  t144_n127: return 0.11409588158130646;
  t144_n128: return 0.11498460173606873;
  t144_n129: return -0.187926784157753;
  t144_n130: return 0.024832243099808693;
  t144_n131: return 0.0049558160826563835;
  t144_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t144_n162;
  t144_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t144_n135;
  t144_n134: return -0.03128013014793396;
  t144_n135: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t144_n141;
  t144_n136: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t144_n140;
  t144_n137: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t144_n139;
  t144_n138: return -0.10218759626150131;
  t144_n139: return 0.1254744678735733;
  t144_n140: return -0.7972574830055237;
  t144_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n145;
  t144_n142: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t144_n144;
  t144_n143: return 0.06244036555290222;
  t144_n144: return 0.054909512400627136;
  t144_n145: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n161;
  t144_n146: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t144_n160;
  t144_n147: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t144_n159;
  t144_n148: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t144_n158;
  t144_n149: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t144_n153;
  t144_n150: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t144_n152;
  t144_n151: return 0.08233324438333511;
  t144_n152: return 0.09246832877397537;
  t144_n153: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t144_n157;
  t144_n154: if (E.getNumReferences() >= 3363872672 /*263421.0*/) goto t144_n156;
  t144_n155: return -0.2070544958114624;
  t144_n156: return 0.10533653944730759;
  t144_n157: return 0.02807369828224182;
  t144_n158: return 0.10068035125732422;
  t144_n159: return -0.0054720924235880375;
  t144_n160: return 0.11366824805736542;
  t144_n161: return 0.033954720944166183;
  t144_n162: return 0.10622710734605789;
  t144_n163: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t144_n207;
  t144_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t144_n188;
  t144_n165: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t144_n177;
  t144_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t144_n168;
  t144_n167: return 0.055492103099823;
  t144_n168: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t144_n170;
  t144_n169: return 0.14302153885364532;
  t144_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n176;
  t144_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n175;
  t144_n172: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t144_n174;
  t144_n173: return -0.14636772871017456;
  t144_n174: return 0.2844131886959076;
  t144_n175: return 0.1632729470729828;
  t144_n176: return 0.05444084480404854;
  t144_n177: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t144_n179;
  t144_n178: return -0.1668754369020462;
  t144_n179: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t144_n187;
  t144_n180: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t144_n184;
  t144_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n183;
  t144_n182: return -0.0032370772678405046;
  t144_n183: return 0.13430732488632202;
  t144_n184: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t144_n186;
  t144_n185: return 0.14579525589942932;
  t144_n186: return 0.14262470602989197;
  t144_n187: return -0.007096884772181511;
  t144_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n202;
  t144_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t144_n199;
  t144_n190: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t144_n196;
  t144_n191: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t144_n195;
  t144_n192: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t144_n194;
  t144_n193: return 0.06724292039871216;
  t144_n194: return 0.1040879562497139;
  t144_n195: return -0.11405796557664871;
  t144_n196: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t144_n198;
  t144_n197: return 0.10978472232818604;
  t144_n198: return 0.08189026266336441;
  t144_n199: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t144_n201;
  t144_n200: return -0.01610756292939186;
  t144_n201: return 0.0876929759979248;
  t144_n202: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t144_n206;
  t144_n203: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t144_n205;
  t144_n204: return 0.08622101694345474;
  t144_n205: return 0.029982229694724083;
  t144_n206: return -0.10113069415092468;
  t144_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t144_n209;
  t144_n208: return -0.10928681492805481;
  t144_n209: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t144_n231;
  t144_n210: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t144_n230;
  t144_n211: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t144_n219;
  t144_n212: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t144_n218;
  t144_n213: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t144_n215;
  t144_n214: return 0.07357488572597504;
  t144_n215: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t144_n217;
  t144_n216: return 0.1139201894402504;
  t144_n217: return 0.026525050401687622;
  t144_n218: return -0.14067600667476654;
  t144_n219: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t144_n225;
  t144_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n224;
  t144_n221: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t144_n223;
  t144_n222: return -0.15031376481056213;
  t144_n223: return 0.1292661428451538;
  t144_n224: return 0.07167471200227737;
  t144_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t144_n227;
  t144_n226: return 0.0335591621696949;
  t144_n227: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t144_n229;
  t144_n228: return 0.05839749425649643;
  t144_n229: return -0.014461904764175415;
  t144_n230: return -0.1554875522851944;
  t144_n231: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t144_n245;
  t144_n232: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t144_n244;
  t144_n233: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t144_n235;
  t144_n234: return 0.0634060725569725;
  t144_n235: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t144_n239;
  t144_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n238;
  t144_n237: return 0.08435211330652237;
  t144_n238: return 0.019440477713942528;
  t144_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t144_n243;
  t144_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n242;
  t144_n241: return 0.1368524134159088;
  t144_n242: return 0.08886601775884628;
  t144_n243: return -0.24404621124267578;
  t144_n244: return 0.014778465032577515;
  t144_n245: return -0.08106445521116257;
  t144_n246: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t144_n254;
  t144_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t144_n251;
  t144_n248: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t144_n250;
  t144_n249: return 0.11115584522485733;
  t144_n250: return 0.08797184377908707;
  t144_n251: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t144_n253;
  t144_n252: return 0.06090034916996956;
  t144_n253: return 0.12850725650787354;
  t144_n254: return 0.006193504203110933;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree145(const Example& E) {
  t145_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t145_n6;
  t145_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t145_n3;
  t145_n2: return -0.000675576739013195;
  t145_n3: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t145_n5;
  t145_n4: return 0.003828794928267598;
  t145_n5: return -0.044586408883333206;
  t145_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t145_n8;
  t145_n7: return 0.0014810938155278563;
  t145_n8: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t145_n212;
  t145_n9: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t145_n155;
  t145_n10: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t145_n100;
  t145_n11: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t145_n89;
  t145_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t145_n40;
  t145_n13: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t145_n39;
  t145_n14: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t145_n22;
  t145_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t145_n17;
  t145_n16: return 0.0019574412144720554;
  t145_n17: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t145_n19;
  t145_n18: return 0.0539587140083313;
  t145_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n21;
  t145_n20: return -0.18277420103549957;
  t145_n21: return 0.22949498891830444;
  t145_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n36;
  t145_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n35;
  t145_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t145_n26;
  t145_n25: return -0.12247178703546524;
  t145_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n34;
  t145_n27: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t145_n33;
  t145_n28: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n32;
  t145_n29: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t145_n31;
  t145_n30: return -0.17564435303211212;
  t145_n31: return 0.12355650216341019;
  t145_n32: return -0.019478069618344307;
  t145_n33: return 0.12971550226211548;
  t145_n34: return 0.10485226660966873;
  t145_n35: return -0.19469821453094482;
  t145_n36: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n38;
  t145_n37: return 0.09699560701847076;
  t145_n38: return 0.09557920694351196;
  t145_n39: return -0.039426352828741074;
  t145_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t145_n42;
  t145_n41: return -0.03955107554793358;
  t145_n42: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t145_n76;
  t145_n43: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n67;
  t145_n44: if (E.getNumReferences() >= 3354093056 /*120524.0*/) goto t145_n66;
  t145_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t145_n65;
  t145_n46: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t145_n58;
  t145_n47: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t145_n51;
  t145_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n50;
  t145_n49: return -0.12487131357192993;
  t145_n50: return 0.102289117872715;
  t145_n51: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n53;
  t145_n52: return 0.008819935843348503;
  t145_n53: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t145_n57;
  t145_n54: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t145_n56;
  t145_n55: return -0.024231011047959328;
  t145_n56: return 0.10710014402866364;
  t145_n57: return 0.003952501341700554;
  t145_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n60;
  t145_n59: return -0.11470875889062881;
  t145_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n64;
  t145_n61: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n63;
  t145_n62: return -0.10279306769371033;
  t145_n63: return 0.1039445698261261;
  t145_n64: return -0.1579461246728897;
  t145_n65: return 0.009137528948485851;
  t145_n66: return -0.05941716954112053;
  t145_n67: if (E.getNumReferences() >= 3356904640 /*153907.0*/) goto t145_n75;
  t145_n68: if (E.getNumReferences() >= 3352615936 /*108984.0*/) goto t145_n72;
  t145_n69: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t145_n71;
  t145_n70: return 0.07088401168584824;
  t145_n71: return -0.11666266620159149;
  t145_n72: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t145_n74;
  t145_n73: return 0.02414862811565399;
  t145_n74: return 0.08121688663959503;
  t145_n75: return -0.2075628936290741;
  t145_n76: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t145_n80;
  t145_n77: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t145_n79;
  t145_n78: return 0.015421253629028797;
  t145_n79: return 0.19972604513168335;
  t145_n80: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t145_n84;
  t145_n81: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t145_n83;
  t145_n82: return 0.1684507131576538;
  t145_n83: return 0.106744185090065;
  t145_n84: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t145_n88;
  t145_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n87;
  t145_n86: return -0.13760749995708466;
  t145_n87: return 0.11336708813905716;
  t145_n88: return 0.020543130114674568;
  t145_n89: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t145_n93;
  t145_n90: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n92;
  t145_n91: return -0.12133265286684036;
  t145_n92: return 0.12277676165103912;
  t145_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t145_n95;
  t145_n94: return -0.1419445276260376;
  t145_n95: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n97;
  t145_n96: return 0.06894233077764511;
  t145_n97: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n99;
  t145_n98: return 0.10437966883182526;
  t145_n99: return 0.04686615988612175;
  t145_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t145_n136;
  t145_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t145_n119;
  t145_n102: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t145_n118;
  t145_n103: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t145_n111;
  t145_n104: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t145_n110;
  t145_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n107;
  t145_n106: return -0.0033449972979724407;
  t145_n107: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t145_n109;
  t145_n108: return 0.11730262637138367;
  t145_n109: return 0.010279039852321148;
  t145_n110: return 0.1451217085123062;
  t145_n111: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t145_n115;
  t145_n112: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n114;
  t145_n113: return -0.054985810071229935;
  t145_n114: return 0.12988494336605072;
  t145_n115: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n117;
  t145_n116: return 0.13825589418411255;
  t145_n117: return 0.043613702058792114;
  t145_n118: return -0.10737399756908417;
  t145_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n135;
  t145_n120: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t145_n134;
  t145_n121: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t145_n133;
  t145_n122: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t145_n124;
  t145_n123: return 0.0726427212357521;
  t145_n124: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t145_n130;
  t145_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n129;
  t145_n126: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t145_n128;
  t145_n127: return 0.10263639688491821;
  t145_n128: return 0.1010546013712883;
  t145_n129: return 0.0998024269938469;
  t145_n130: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t145_n132;
  t145_n131: return 0.10442744195461273;
  t145_n132: return 0.030655520036816597;
  t145_n133: return 0.00011253944103373215;
  t145_n134: return 0.021698391065001488;
  t145_n135: return 0.018885886296629906;
  t145_n136: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t145_n138;
  t145_n137: return -0.03683772310614586;
  t145_n138: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t145_n154;
  t145_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n149;
  t145_n140: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t145_n146;
  t145_n141: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t145_n145;
  t145_n142: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n144;
  t145_n143: return 0.10197755694389343;
  t145_n144: return 0.057006314396858215;
  t145_n145: return 0.11867091804742813;
  t145_n146: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t145_n148;
  t145_n147: return -0.2539672255516052;
  t145_n148: return 0.1291910707950592;
  t145_n149: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t145_n153;
  t145_n150: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t145_n152;
  t145_n151: return -0.1066669225692749;
  t145_n152: return 0.09572631865739822;
  t145_n153: return 0.12058857083320618;
  t145_n154: return -0.05217938870191574;
  t145_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t145_n189;
  t145_n156: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t145_n176;
  t145_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n161;
  t145_n158: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t145_n160;
  t145_n159: return -0.01833438128232956;
  t145_n160: return 0.058936066925525665;
  t145_n161: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n163;
  t145_n162: return 0.032590389251708984;
  t145_n163: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t145_n175;
  t145_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n170;
  t145_n165: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t145_n167;
  t145_n166: return 0.12723635137081146;
  t145_n167: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t145_n169;
  t145_n168: return -0.05615357682108879;
  t145_n169: return 0.09583796560764313;
  t145_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t145_n172;
  t145_n171: return -0.05247432366013527;
  t145_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t145_n174;
  t145_n173: return 0.061720918864011765;
  t145_n174: return 0.1045474261045456;
  t145_n175: return -0.2868620455265045;
  t145_n176: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t145_n188;
  t145_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n179;
  t145_n178: return 0.036063358187675476;
  t145_n179: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t145_n187;
  t145_n180: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t145_n182;
  t145_n181: return -0.17688331007957458;
  t145_n182: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n184;
  t145_n183: return 0.04132293164730072;
  t145_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t145_n186;
  t145_n185: return 0.024166135117411613;
  t145_n186: return 0.08375168591737747;
  t145_n187: return 0.06843555718660355;
  t145_n188: return 0.012601910158991814;
  t145_n189: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t145_n191;
  t145_n190: return 0.0251962561160326;
  t145_n191: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t145_n211;
  t145_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n210;
  t145_n193: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t145_n209;
  t145_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t145_n204;
  t145_n195: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t145_n203;
  t145_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n202;
  t145_n197: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t145_n199;
  t145_n198: return -0.11819904297590256;
  t145_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n201;
  t145_n200: return -0.11017901450395584;
  t145_n201: return 0.09958828240633011;
  t145_n202: return 0.048835474997758865;
  t145_n203: return 0.0545014888048172;
  t145_n204: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t145_n206;
  t145_n205: return -0.11509360373020172;
  t145_n206: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t145_n208;
  t145_n207: return 0.10136791318655014;
  t145_n208: return -0.1861058473587036;
  t145_n209: return 0.009314138442277908;
  t145_n210: return -0.15962418913841248;
  t145_n211: return 0.11318431049585342;
  t145_n212: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t145_n214;
  t145_n213: return -0.15148550271987915;
  t145_n214: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t145_n228;
  t145_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n217;
  t145_n216: return -0.04789147898554802;
  t145_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t145_n219;
  t145_n218: return -0.04057147726416588;
  t145_n219: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t145_n223;
  t145_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t145_n222;
  t145_n221: return 0.1459929645061493;
  t145_n222: return 0.10956182330846786;
  t145_n223: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t145_n227;
  t145_n224: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t145_n226;
  t145_n225: return 0.07296978682279587;
  t145_n226: return 0.11401046812534332;
  t145_n227: return 0.04207754135131836;
  t145_n228: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t145_n230;
  t145_n229: return -0.08787219971418381;
  t145_n230: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t145_n254;
  t145_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t145_n233;
  t145_n232: return -0.008604584261775017;
  t145_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t145_n237;
  t145_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n236;
  t145_n235: return 0.06822729855775833;
  t145_n236: return 0.0359327532351017;
  t145_n237: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t145_n243;
  t145_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t145_n240;
  t145_n239: return -0.06830073893070221;
  t145_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t145_n242;
  t145_n241: return 0.12789775431156158;
  t145_n242: return 0.06736735254526138;
  t145_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t145_n253;
  t145_n244: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t145_n252;
  t145_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t145_n251;
  t145_n246: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t145_n248;
  t145_n247: return -0.017284035682678223;
  t145_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t145_n250;
  t145_n249: return -0.13563001155853271;
  t145_n250: return -0.029478473588824272;
  t145_n251: return 0.0394623689353466;
  t145_n252: return 0.09599869698286057;
  t145_n253: return 0.16775017976760864;
  t145_n254: return 0.00313093070872128;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree146(const Example& E) {
  t146_n0: if (E.getNumReferences() >= 3305437184 /*2127.5*/) goto t146_n2;
  t146_n1: return -0.00045815849443897605;
  t146_n2: if (E.getNumReferences() >= 3305449472 /*2130.5*/) goto t146_n8;
  t146_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t146_n7;
  t146_n4: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n6;
  t146_n5: return -0.072431780397892;
  t146_n6: return 0.10569024085998535;
  t146_n7: return 0.3553738594055176;
  t146_n8: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t146_n22;
  t146_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t146_n11;
  t146_n10: return 0.009852997958660126;
  t146_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t146_n13;
  t146_n12: return 0.022580280900001526;
  t146_n13: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t146_n15;
  t146_n14: return -0.025662612169981003;
  t146_n15: if (E.getNumReferences() >= 3318562816 /*6568.0*/) goto t146_n21;
  t146_n16: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t146_n18;
  t146_n17: return -0.21221092343330383;
  t146_n18: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t146_n20;
  t146_n19: return 0.16733849048614502;
  t146_n20: return 0.1397455334663391;
  t146_n21: return -0.03511923924088478;
  t146_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t146_n26;
  t146_n23: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t146_n25;
  t146_n24: return -0.0018592342967167497;
  t146_n25: return -0.023492993786931038;
  t146_n26: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t146_n244;
  t146_n27: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t146_n227;
  t146_n28: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t146_n46;
  t146_n29: if (E.getNumReferences() >= 3305551872 /*2155.5*/) goto t146_n39;
  t146_n30: if (E.getNumReferences() >= 3305539584 /*2152.5*/) goto t146_n32;
  t146_n31: return -0.004596408922225237;
  t146_n32: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t146_n38;
  t146_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t146_n35;
  t146_n34: return -0.03088812530040741;
  t146_n35: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t146_n37;
  t146_n36: return -0.0359032079577446;
  t146_n37: return 0.11610159277915955;
  t146_n38: return 0.12161815166473389;
  t146_n39: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t146_n41;
  t146_n40: return 3.8981830584816635e-05;
  t146_n41: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t146_n43;
  t146_n42: return 0.10599441081285477;
  t146_n43: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n45;
  t146_n44: return -0.018557395786046982;
  t146_n45: return 0.11415594816207886;
  t146_n46: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t146_n56;
  t146_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t146_n53;
  t146_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n50;
  t146_n49: return 0.005639952141791582;
  t146_n50: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n52;
  t146_n51: return 0.10737285763025284;
  t146_n52: return -0.12320470809936523;
  t146_n53: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t146_n55;
  t146_n54: return 0.09869677573442459;
  t146_n55: return 0.12660686671733856;
  t146_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t146_n128;
  t146_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t146_n89;
  t146_n58: if (E.getNumReferences() >= 3316641792 /*5630.0*/) goto t146_n62;
  t146_n59: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t146_n61;
  t146_n60: return 0.19374851882457733;
  t146_n61: return -0.3065454065799713;
  t146_n62: if (E.getNumReferences() >= 3329391104 /*15518.5*/) goto t146_n88;
  t146_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n75;
  t146_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t146_n66;
  t146_n65: return -0.09109583497047424;
  t146_n66: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t146_n74;
  t146_n67: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n69;
  t146_n68: return 0.005694903898984194;
  t146_n69: if (E.getNumReferences() >= 3328288256 /*14441.5*/) goto t146_n73;
  t146_n70: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t146_n72;
  t146_n71: return 0.067308709025383;
  t146_n72: return -0.10774162411689758;
  t146_n73: return 0.10691352188587189;
  t146_n74: return -1.5354560613632202;
  t146_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t146_n77;
  t146_n76: return 0.04228074103593826;
  t146_n77: if (E.getNumReferences() >= 3321165824 /*7839.0*/) goto t146_n79;
  t146_n78: return -0.014529695734381676;
  t146_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n83;
  t146_n80: if (E.getNumReferences() >= 3323752960 /*10012.5*/) goto t146_n82;
  t146_n81: return 0.09415304660797119;
  t146_n82: return 0.0025700365658849478;
  t146_n83: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t146_n85;
  t146_n84: return 0.07599849998950958;
  t146_n85: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t146_n87;
  t146_n86: return 0.14632359147071838;
  t146_n87: return 0.11701926589012146;
  t146_n88: return -0.09817404299974442;
  t146_n89: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t146_n91;
  t146_n90: return 0.01907159760594368;
  t146_n91: if (E.getNumReferences() >= 3332022528 /*19792.5*/) goto t146_n97;
  t146_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n96;
  t146_n93: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n95;
  t146_n94: return 0.11102046072483063;
  t146_n95: return 0.1041112169623375;
  t146_n96: return -0.10204457491636276;
  t146_n97: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t146_n123;
  t146_n98: if (E.getNumReferences() >= 3333845504 /*23353.0*/) goto t146_n122;
  t146_n99: if (E.getNumReferences() >= 3332544000 /*20811.0*/) goto t146_n107;
  t146_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t146_n102;
  t146_n101: return -0.027696285396814346;
  t146_n102: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t146_n104;
  t146_n103: return 0.0914522036910057;
  t146_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n106;
  t146_n105: return -0.7221584320068359;
  t146_n106: return 0.12460901588201523;
  t146_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t146_n109;
  t146_n108: return 0.03568730875849724;
  t146_n109: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n121;
  t146_n110: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t146_n120;
  t146_n111: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t146_n117;
  t146_n112: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t146_n114;
  t146_n113: return -0.45706605911254883;
  t146_n114: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n116;
  t146_n115: return 0.14544525742530823;
  t146_n116: return 0.10278749465942383;
  t146_n117: if (E.getNumReferences() >= 3332934144 /*21573.0*/) goto t146_n119;
  t146_n118: return 0.16873504221439362;
  t146_n119: return -0.6633085608482361;
  t146_n120: return 0.0755399689078331;
  t146_n121: return 0.03708116337656975;
  t146_n122: return -0.050247445702552795;
  t146_n123: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t146_n127;
  t146_n124: if (E.getNumReferences() >= 3332429312 /*20587.0*/) goto t146_n126;
  t146_n125: return 0.13683924078941345;
  t146_n126: return 0.054418280720710754;
  t146_n127: return 0.05272141471505165;
  t146_n128: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t146_n212;
  t146_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t146_n175;
  t146_n130: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t146_n132;
  t146_n131: return 0.05162372067570686;
  t146_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t146_n148;
  t146_n133: if (E.getNumReferences() >= 3327639040 /*13807.5*/) goto t146_n145;
  t146_n134: if (E.getNumReferences() >= 3323017216 /*9294.0*/) goto t146_n142;
  t146_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t146_n137;
  t146_n136: return -0.11379683762788773;
  t146_n137: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n139;
  t146_n138: return -0.2677822411060333;
  t146_n139: if (E.getNumReferences() >= 3319199744 /*6879.0*/) goto t146_n141;
  t146_n140: return -0.11673147976398468;
  t146_n141: return 0.11528196185827255;
  t146_n142: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n144;
  t146_n143: return -0.21260038018226624;
  t146_n144: return 0.09916316717863083;
  t146_n145: if (E.getNumReferences() >= 3327672832 /*13840.5*/) goto t146_n147;
  t146_n146: return 0.1947464495897293;
  t146_n147: return 0.002918862272053957;
  t146_n148: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t146_n156;
  t146_n149: if (E.getNumReferences() >= 3321062400 /*7788.5*/) goto t146_n155;
  t146_n150: if (E.getNumReferences() >= 3320159232 /*7347.5*/) goto t146_n154;
  t146_n151: if (E.getNumReferences() >= 3315995648 /*5314.5*/) goto t146_n153;
  t146_n152: return 0.17838045954704285;
  t146_n153: return 0.09242171794176102;
  t146_n154: return 0.11499562859535217;
  t146_n155: return -0.1302732229232788;
  t146_n156: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t146_n170;
  t146_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t146_n159;
  t146_n158: return -0.007889126427471638;
  t146_n159: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n161;
  t146_n160: return 0.07118996232748032;
  t146_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t146_n165;
  t146_n162: if (E.getNumReferences() >= 3332404480 /*20538.5*/) goto t146_n164;
  t146_n163: return 0.11765909194946289;
  t146_n164: return 0.1019158661365509;
  t146_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t146_n169;
  t146_n166: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t146_n168;
  t146_n167: return 0.09995637089014053;
  t146_n168: return 0.10100322216749191;
  t146_n169: return 0.07464684545993805;
  t146_n170: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t146_n172;
  t146_n171: return -0.035683147609233856;
  t146_n172: if (E.getNumReferences() >= 3331892480 /*19538.5*/) goto t146_n174;
  t146_n173: return 0.11559838056564331;
  t146_n174: return -0.1550024151802063;
  t146_n175: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t146_n177;
  t146_n176: return 0.14873726665973663;
  t146_n177: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t146_n211;
  t146_n178: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t146_n208;
  t146_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t146_n185;
  t146_n180: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t146_n182;
  t146_n181: return 0.0225831288844347;
  t146_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t146_n184;
  t146_n183: return -0.051980361342430115;
  t146_n184: return -0.5461257100105286;
  t146_n185: if (E.getNumReferences() >= 3320443904 /*7486.5*/) goto t146_n207;
  t146_n186: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t146_n198;
  t146_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t146_n189;
  t146_n188: return 0.03173929825425148;
  t146_n189: if (E.getNumReferences() >= 3315877888 /*5257.0*/) goto t146_n193;
  t146_n190: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t146_n192;
  t146_n191: return 0.10265905410051346;
  t146_n192: return 0.0903639942407608;
  t146_n193: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t146_n195;
  t146_n194: return 0.03138994053006172;
  t146_n195: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t146_n197;
  t146_n196: return 0.11227679252624512;
  t146_n197: return -0.33878710865974426;
  t146_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t146_n204;
  t146_n199: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t146_n203;
  t146_n200: if (E.getNumReferences() >= 3320094720 /*7316.0*/) goto t146_n202;
  t146_n201: return 0.10333114862442017;
  t146_n202: return 0.06252143532037735;
  t146_n203: return 0.04031367227435112;
  t146_n204: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t146_n206;
  t146_n205: return 0.105662040412426;
  t146_n206: return 0.09733472764492035;
  t146_n207: return -0.260355144739151;
  t146_n208: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t146_n210;
  t146_n209: return 0.11503271013498306;
  t146_n210: return 0.05124371126294136;
  t146_n211: return 0.1097242683172226;
  t146_n212: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t146_n224;
  t146_n213: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t146_n221;
  t146_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n216;
  t146_n215: return 0.09287599474191666;
  t146_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t146_n220;
  t146_n217: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t146_n219;
  t146_n218: return -0.2388419210910797;
  t146_n219: return 0.08848465234041214;
  t146_n220: return 0.11488284915685654;
  t146_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n223;
  t146_n222: return 0.10880213975906372;
  t146_n223: return 0.07375877350568771;
  t146_n224: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t146_n226;
  t146_n225: return 0.11163507401943207;
  t146_n226: return -0.24990403652191162;
  t146_n227: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t146_n243;
  t146_n228: if (E.getNumReferences() >= 3335010048 /*25627.5*/) goto t146_n230;
  t146_n229: return -0.07028772681951523;
  t146_n230: if (E.getNumReferences() >= 3335170304 /*25940.5*/) goto t146_n234;
  t146_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t146_n233;
  t146_n232: return 0.06519964337348938;
  t146_n233: return 0.10270313173532486;
  t146_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t146_n236;
  t146_n235: return -0.007614204194396734;
  t146_n236: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t146_n242;
  t146_n237: if (E.getNumReferences() >= 3346571264 /*63648.0*/) goto t146_n241;
  t146_n238: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t146_n240;
  t146_n239: return 0.06668416410684586;
  t146_n240: return 0.12243681401014328;
  t146_n241: return -0.051838286221027374;
  t146_n242: return 0.030144095420837402;
  t146_n243: return 0.04235474765300751;
  t146_n244: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t146_n254;
  t146_n245: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t146_n251;
  t146_n246: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t146_n248;
  t146_n247: return 0.014738406985998154;
  t146_n248: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t146_n250;
  t146_n249: return 0.10506380349397659;
  t146_n250: return 0.06312283873558044;
  t146_n251: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t146_n253;
  t146_n252: return 0.10232427716255188;
  t146_n253: return 0.05024126544594765;
  t146_n254: return 0.011573518626391888;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree147(const Example& E) {
  t147_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t147_n174;
  t147_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n153;
  t147_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t147_n80;
  t147_n3: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t147_n79;
  t147_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t147_n68;
  t147_n5: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t147_n7;
  t147_n6: return 0.007224816828966141;
  t147_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t147_n55;
  t147_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t147_n10;
  t147_n9: return -0.01246443297713995;
  t147_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n54;
  t147_n11: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t147_n19;
  t147_n12: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t147_n18;
  t147_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t147_n15;
  t147_n14: return 0.034670233726501465;
  t147_n15: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t147_n17;
  t147_n16: return -0.04501857981085777;
  t147_n17: return 0.04934874176979065;
  t147_n18: return -0.019126735627651215;
  t147_n19: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t147_n23;
  t147_n20: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t147_n22;
  t147_n21: return 0.04161086678504944;
  t147_n22: return 0.07863400876522064;
  t147_n23: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t147_n29;
  t147_n24: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t147_n28;
  t147_n25: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t147_n27;
  t147_n26: return -0.15371906757354736;
  t147_n27: return 0.11093053221702576;
  t147_n28: return 0.06849713623523712;
  t147_n29: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t147_n51;
  t147_n30: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t147_n50;
  t147_n31: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t147_n33;
  t147_n32: return 0.006792205385863781;
  t147_n33: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t147_n35;
  t147_n34: return 0.11178760230541229;
  t147_n35: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t147_n47;
  t147_n36: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t147_n44;
  t147_n37: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t147_n43;
  t147_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t147_n40;
  t147_n39: return -0.22795699536800385;
  t147_n40: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t147_n42;
  t147_n41: return 0.12332064658403397;
  t147_n42: return -1.2346017360687256;
  t147_n43: return 0.11236856877803802;
  t147_n44: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t147_n46;
  t147_n45: return 0.0005969775374978781;
  t147_n46: return 0.11055459082126617;
  t147_n47: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t147_n49;
  t147_n48: return 0.12035014480352402;
  t147_n49: return 0.14380256831645966;
  t147_n50: return 0.0014315573498606682;
  t147_n51: if (E.getNumReferences() >= 3253731328 /*30.0*/) goto t147_n53;
  t147_n52: return -0.13975003361701965;
  t147_n53: return 0.09393573552370071;
  t147_n54: return 0.0023917220532894135;
  t147_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n59;
  t147_n56: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t147_n58;
  t147_n57: return 0.0843241810798645;
  t147_n58: return -0.17026367783546448;
  t147_n59: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t147_n61;
  t147_n60: return 0.02637612260878086;
  t147_n61: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t147_n67;
  t147_n62: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t147_n66;
  t147_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n65;
  t147_n64: return 0.08224224299192429;
  t147_n65: return 0.06324923783540726;
  t147_n66: return 0.1139756515622139;
  t147_n67: return -0.045362688601017;
  t147_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t147_n74;
  t147_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n71;
  t147_n70: return -0.06031837686896324;
  t147_n71: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t147_n73;
  t147_n72: return 0.05171460285782814;
  t147_n73: return 0.004713577684015036;
  t147_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n78;
  t147_n75: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t147_n77;
  t147_n76: return 0.09698983281850815;
  t147_n77: return -0.023166531696915627;
  t147_n78: return 0.027925625443458557;
  t147_n79: return -0.0051334938034415245;
  t147_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t147_n102;
  t147_n81: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t147_n101;
  t147_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n84;
  t147_n83: return -0.041384007781744;
  t147_n84: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t147_n86;
  t147_n85: return -0.009143070317804813;
  t147_n86: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t147_n88;
  t147_n87: return 0.10315146297216415;
  t147_n88: if (E.getNumReferences() >= 3324753920 /*10990.0*/) goto t147_n100;
  t147_n89: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n97;
  t147_n90: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t147_n92;
  t147_n91: return -0.0314883254468441;
  t147_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t147_n94;
  t147_n93: return 0.03268376737833023;
  t147_n94: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t147_n96;
  t147_n95: return 0.11617247015237808;
  t147_n96: return 0.09265437722206116;
  t147_n97: if (E.getNumReferences() >= 3324366336 /*10611.5*/) goto t147_n99;
  t147_n98: return 0.025298085063695908;
  t147_n99: return 0.12180893123149872;
  t147_n100: return -0.4274612069129944;
  t147_n101: return 0.10567212104797363;
  t147_n102: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t147_n152;
  t147_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t147_n105;
  t147_n104: return 0.004868334159255028;
  t147_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n151;
  t147_n106: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n108;
  t147_n107: return 0.046076349914073944;
  t147_n108: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t147_n150;
  t147_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n119;
  t147_n110: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t147_n114;
  t147_n111: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t147_n113;
  t147_n112: return -0.09431491047143936;
  t147_n113: return -0.00418156199157238;
  t147_n114: if (E.getNumReferences() >= 3322876928 /*9157.0*/) goto t147_n118;
  t147_n115: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t147_n117;
  t147_n116: return 0.09230279177427292;
  t147_n117: return -0.04978897050023079;
  t147_n118: return -0.6909665465354919;
  t147_n119: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t147_n147;
  t147_n120: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t147_n124;
  t147_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n123;
  t147_n122: return 0.0744759663939476;
  t147_n123: return 0.024837730452418327;
  t147_n124: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t147_n136;
  t147_n125: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t147_n127;
  t147_n126: return 0.09479384124279022;
  t147_n127: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t147_n135;
  t147_n128: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t147_n132;
  t147_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n131;
  t147_n130: return -0.07656212151050568;
  t147_n131: return 0.12861740589141846;
  t147_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t147_n134;
  t147_n133: return 0.0807235985994339;
  t147_n134: return 0.12182985246181488;
  t147_n135: return 0.031705208122730255;
  t147_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t147_n140;
  t147_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n139;
  t147_n138: return -0.5015990138053894;
  t147_n139: return 0.12535367906093597;
  t147_n140: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t147_n142;
  t147_n141: return -0.12759608030319214;
  t147_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t147_n146;
  t147_n143: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t147_n145;
  t147_n144: return 0.10577497631311417;
  t147_n145: return 0.10955731570720673;
  t147_n146: return 0.14136949181556702;
  t147_n147: if (E.getNumReferences() >= 3319705600 /*7126.0*/) goto t147_n149;
  t147_n148: return 0.012767213396728039;
  t147_n149: return -0.16392552852630615;
  t147_n150: return 0.10688207298517227;
  t147_n151: return -0.03646790608763695;
  t147_n152: return -0.05132443085312843;
  t147_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t147_n159;
  t147_n154: if (E.getNumReferences() >= 3329839104 /*15956.0*/) goto t147_n156;
  t147_n155: return -0.004169469699263573;
  t147_n156: if (E.getNumReferences() >= 3330029056 /*16141.5*/) goto t147_n158;
  t147_n157: return 0.09946689754724503;
  t147_n158: return 0.08321340382099152;
  t147_n159: if (E.getNumReferences() >= 3330547456 /*16911.5*/) goto t147_n171;
  t147_n160: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t147_n162;
  t147_n161: return 0.002910482930019498;
  t147_n162: if (E.getNumReferences() >= 3330237440 /*16345.0*/) goto t147_n170;
  t147_n163: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t147_n167;
  t147_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t147_n166;
  t147_n165: return -0.03919889032840729;
  t147_n166: return 0.11200354993343353;
  t147_n167: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t147_n169;
  t147_n168: return 0.13116230070590973;
  t147_n169: return 0.10449494421482086;
  t147_n170: return 0.009746669791638851;
  t147_n171: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t147_n173;
  t147_n172: return -0.050192028284072876;
  t147_n173: return -0.17393121123313904;
  t147_n174: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t147_n178;
  t147_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t147_n177;
  t147_n176: return 0.0003179831837769598;
  t147_n177: return 0.012273721396923065;
  t147_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t147_n200;
  t147_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t147_n181;
  t147_n180: return 0.007290302310138941;
  t147_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t147_n197;
  t147_n182: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t147_n184;
  t147_n183: return 0.02769569680094719;
  t147_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n196;
  t147_n185: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t147_n195;
  t147_n186: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t147_n194;
  t147_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n189;
  t147_n188: return -0.12474669516086578;
  t147_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t147_n193;
  t147_n190: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t147_n192;
  t147_n191: return -0.19993895292282104;
  t147_n192: return 0.11798761039972305;
  t147_n193: return 0.12582440674304962;
  t147_n194: return 0.1193784698843956;
  t147_n195: return 0.013348007574677467;
  t147_n196: return 0.11147676408290863;
  t147_n197: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t147_n199;
  t147_n198: return 0.03841691091656685;
  t147_n199: return -0.03815574571490288;
  t147_n200: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t147_n246;
  t147_n201: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t147_n203;
  t147_n202: return 0.09950779378414154;
  t147_n203: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n225;
  t147_n204: if (E.getNumReferences() >= 3349616960 /*85554.5*/) goto t147_n222;
  t147_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t147_n207;
  t147_n206: return -0.08021234720945358;
  t147_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t147_n211;
  t147_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n210;
  t147_n209: return -0.17384028434753418;
  t147_n210: return 0.11964276432991028;
  t147_n211: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t147_n221;
  t147_n212: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t147_n220;
  t147_n213: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t147_n217;
  t147_n214: if (E.getNumReferences() >= 3337714176 /*30909.0*/) goto t147_n216;
  t147_n215: return -0.14175349473953247;
  t147_n216: return 0.05210711061954498;
  t147_n217: if (E.getNumReferences() >= 3341667584 /*44493.0*/) goto t147_n219;
  t147_n218: return 0.09028156846761703;
  t147_n219: return 0.03518333286046982;
  t147_n220: return 0.10032728314399719;
  t147_n221: return -0.04269767552614212;
  t147_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n224;
  t147_n223: return 0.08024250715970993;
  t147_n224: return 0.10665880143642426;
  t147_n225: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t147_n245;
  t147_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t147_n242;
  t147_n227: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t147_n235;
  t147_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t147_n230;
  t147_n229: return 0.0658583715558052;
  t147_n230: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t147_n232;
  t147_n231: return -0.08947884291410446;
  t147_n232: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t147_n234;
  t147_n233: return 0.07408567517995834;
  t147_n234: return 0.09721650183200836;
  t147_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t147_n239;
  t147_n236: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t147_n238;
  t147_n237: return 0.11410452425479889;
  t147_n238: return 0.0772741436958313;
  t147_n239: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t147_n241;
  t147_n240: return 0.10842452943325043;
  t147_n241: return 0.04311281442642212;
  t147_n242: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t147_n244;
  t147_n243: return 0.10071521997451782;
  t147_n244: return 0.06743597239255905;
  t147_n245: return 0.03532329946756363;
  t147_n246: if (E.getNumReferences() >= 3337423104 /*30340.5*/) goto t147_n254;
  t147_n247: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t147_n249;
  t147_n248: return 0.043191976845264435;
  t147_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t147_n253;
  t147_n250: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t147_n252;
  t147_n251: return 0.11437606066465378;
  t147_n252: return -0.013974405825138092;
  t147_n253: return -0.02463645301759243;
  t147_n254: return -0.0045295050367712975;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree148(const Example& E) {
  t148_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t148_n248;
  t148_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t148_n159;
  t148_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t148_n118;
  t148_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t148_n5;
  t148_n4: return -0.050965387374162674;
  t148_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t148_n7;
  t148_n6: return -0.06713027507066727;
  t148_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t148_n77;
  t148_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t148_n16;
  t148_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t148_n11;
  t148_n10: return -0.05475429445505142;
  t148_n11: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t148_n13;
  t148_n12: return 0.0022602397948503494;
  t148_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n15;
  t148_n14: return 0.05283045768737793;
  t148_n15: return 0.09994453191757202;
  t148_n16: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t148_n20;
  t148_n17: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n19;
  t148_n18: return 0.0030634566210210323;
  t148_n19: return -0.06577198207378387;
  t148_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n60;
  t148_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n47;
  t148_n22: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t148_n42;
  t148_n23: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t148_n41;
  t148_n24: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n40;
  t148_n25: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t148_n27;
  t148_n26: return 0.03533452749252319;
  t148_n27: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t148_n39;
  t148_n28: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n32;
  t148_n29: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t148_n31;
  t148_n30: return -0.030650872737169266;
  t148_n31: return 0.10481618344783783;
  t148_n32: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t148_n34;
  t148_n33: return 0.11643832176923752;
  t148_n34: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t148_n38;
  t148_n35: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t148_n37;
  t148_n36: return 0.13324452936649323;
  t148_n37: return 0.049498915672302246;
  t148_n38: return 0.10422489792108536;
  t148_n39: return 0.025382790714502335;
  t148_n40: return -0.08620157837867737;
  t148_n41: return 0.11361361294984818;
  t148_n42: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t148_n44;
  t148_n43: return 0.053426213562488556;
  t148_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n46;
  t148_n45: return -0.08623027056455612;
  t148_n46: return -0.007874797098338604;
  t148_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n59;
  t148_n48: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t148_n54;
  t148_n49: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t148_n51;
  t148_n50: return 0.1089111715555191;
  t148_n51: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t148_n53;
  t148_n52: return -0.010670170187950134;
  t148_n53: return -0.9007749557495117;
  t148_n54: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t148_n56;
  t148_n55: return -0.29599079489707947;
  t148_n56: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t148_n58;
  t148_n57: return 0.08208005875349045;
  t148_n58: return -0.1519237458705902;
  t148_n59: return 0.014958684332668781;
  t148_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n62;
  t148_n61: return 0.06371717154979706;
  t148_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n64;
  t148_n63: return -0.035984549671411514;
  t148_n64: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n68;
  t148_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t148_n67;
  t148_n66: return 0.03113090805709362;
  t148_n67: return 0.000634010590147227;
  t148_n68: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t148_n70;
  t148_n69: return -0.05615963414311409;
  t148_n70: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t148_n74;
  t148_n71: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t148_n73;
  t148_n72: return 0.11193366348743439;
  t148_n73: return 0.07072174549102783;
  t148_n74: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t148_n76;
  t148_n75: return 0.08602093160152435;
  t148_n76: return 0.10723141580820084;
  t148_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t148_n105;
  t148_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t148_n80;
  t148_n79: return 0.004488517064601183;
  t148_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n96;
  t148_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n83;
  t148_n82: return 0.03636199235916138;
  t148_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n87;
  t148_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n86;
  t148_n85: return -0.07739447802305222;
  t148_n86: return 0.01531211193650961;
  t148_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t148_n89;
  t148_n88: return 0.03803395852446556;
  t148_n89: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t148_n91;
  t148_n90: return 0.04623677209019661;
  t148_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n93;
  t148_n92: return 0.10901346802711487;
  t148_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n95;
  t148_n94: return 0.08151531964540482;
  t148_n95: return 0.04943395406007767;
  t148_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n98;
  t148_n97: return 0.011283899657428265;
  t148_n98: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n104;
  t148_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n101;
  t148_n100: return -0.028278788551688194;
  t148_n101: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n103;
  t148_n102: return 0.047162383794784546;
  t148_n103: return -1.612094759941101;
  t148_n104: return 0.0017139703268185258;
  t148_n105: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t148_n117;
  t148_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n116;
  t148_n107: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n111;
  t148_n108: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n110;
  t148_n109: return 0.09711949527263641;
  t148_n110: return 0.07331234961748123;
  t148_n111: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n115;
  t148_n112: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t148_n114;
  t148_n113: return 0.10012771189212799;
  t148_n114: return 0.08779837191104889;
  t148_n115: return 0.058075517416000366;
  t148_n116: return 0.06965059041976929;
  t148_n117: return -0.041346874088048935;
  t148_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n158;
  t148_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n157;
  t148_n120: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t148_n156;
  t148_n121: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t148_n147;
  t148_n122: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t148_n134;
  t148_n123: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t148_n127;
  t148_n124: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t148_n126;
  t148_n125: return -0.17325147986412048;
  t148_n126: return -0.0253861416131258;
  t148_n127: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t148_n131;
  t148_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n130;
  t148_n129: return 0.09918765723705292;
  t148_n130: return 0.10774707794189453;
  t148_n131: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n133;
  t148_n132: return -0.1427324265241623;
  t148_n133: return 0.037042856216430664;
  t148_n134: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n146;
  t148_n135: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t148_n137;
  t148_n136: return -0.006464327219873667;
  t148_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t148_n145;
  t148_n138: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n142;
  t148_n139: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n141;
  t148_n140: return -0.18812572956085205;
  t148_n141: return 0.06968636065721512;
  t148_n142: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t148_n144;
  t148_n143: return 0.03134389594197273;
  t148_n144: return 0.13529737293720245;
  t148_n145: return -0.007200266700237989;
  t148_n146: return 0.02040208876132965;
  t148_n147: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t148_n155;
  t148_n148: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n154;
  t148_n149: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n151;
  t148_n150: return 0.0387800969183445;
  t148_n151: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t148_n153;
  t148_n152: return 0.17895007133483887;
  t148_n153: return 0.11905362457036972;
  t148_n154: return -0.055809590965509415;
  t148_n155: return -0.09428589791059494;
  t148_n156: return -0.07961750775575638;
  t148_n157: return -0.012739147059619427;
  t148_n158: return 0.004228373523801565;
  t148_n159: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t148_n237;
  t148_n160: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t148_n174;
  t148_n161: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n163;
  t148_n162: return -0.03548884391784668;
  t148_n163: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t148_n165;
  t148_n164: return -0.1364622265100479;
  t148_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n167;
  t148_n166: return 0.08764481544494629;
  t148_n167: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t148_n173;
  t148_n168: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t148_n172;
  t148_n169: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t148_n171;
  t148_n170: return 0.17450515925884247;
  t148_n171: return 0.34965580701828003;
  t148_n172: return 0.0813017413020134;
  t148_n173: return 0.09253803640604019;
  t148_n174: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t148_n176;
  t148_n175: return 0.0037296998780220747;
  t148_n176: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t148_n194;
  t148_n177: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t148_n179;
  t148_n178: return 0.018440546467900276;
  t148_n179: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n191;
  t148_n180: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n184;
  t148_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t148_n183;
  t148_n182: return 0.030520964413881302;
  t148_n183: return 0.08926144987344742;
  t148_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t148_n190;
  t148_n185: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t148_n189;
  t148_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t148_n188;
  t148_n187: return -0.09374897181987762;
  t148_n188: return 0.13182547688484192;
  t148_n189: return 0.11083108931779861;
  t148_n190: return 0.019317930564284325;
  t148_n191: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n193;
  t148_n192: return 0.00013349844084586948;
  t148_n193: return 0.09233938902616501;
  t148_n194: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t148_n228;
  t148_n195: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t148_n227;
  t148_n196: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t148_n222;
  t148_n197: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t148_n201;
  t148_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t148_n200;
  t148_n199: return -0.034009672701358795;
  t148_n200: return 0.027932588011026382;
  t148_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t148_n203;
  t148_n202: return 0.07879769057035446;
  t148_n203: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t148_n221;
  t148_n204: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t148_n220;
  t148_n205: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t148_n207;
  t148_n206: return -0.06653700023889542;
  t148_n207: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t148_n209;
  t148_n208: return 0.10751330852508545;
  t148_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t148_n217;
  t148_n210: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t148_n212;
  t148_n211: return -0.10048659890890121;
  t148_n212: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t148_n214;
  t148_n213: return -0.10223215073347092;
  t148_n214: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t148_n216;
  t148_n215: return 0.12639640271663666;
  t148_n216: return 0.08304692804813385;
  t148_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t148_n219;
  t148_n218: return 2.3630285263061523;
  t148_n219: return 0.1325722187757492;
  t148_n220: return 0.11783198267221451;
  t148_n221: return 0.13517692685127258;
  t148_n222: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t148_n226;
  t148_n223: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n225;
  t148_n224: return 0.1782185286283493;
  t148_n225: return -0.25922277569770813;
  t148_n226: return 0.113111712038517;
  t148_n227: return 0.04628433659672737;
  t148_n228: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t148_n236;
  t148_n229: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t148_n231;
  t148_n230: return -0.011215032078325748;
  t148_n231: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t148_n235;
  t148_n232: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t148_n234;
  t148_n233: return 0.0870058611035347;
  t148_n234: return 0.11089789122343063;
  t148_n235: return 0.04269547015428543;
  t148_n236: return -0.020709030330181122;
  t148_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t148_n239;
  t148_n238: return -0.035571224987506866;
  t148_n239: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t148_n241;
  t148_n240: return 0.004867872688919306;
  t148_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t148_n243;
  t148_n242: return -0.050456441938877106;
  t148_n243: if (E.getNumReferences() >= 3297144832 /*1075.5*/) goto t148_n245;
  t148_n244: return 0.03497907519340515;
  t148_n245: if (E.getNumReferences() >= 3297366016 /*1102.5*/) goto t148_n247;
  t148_n246: return 0.10004538297653198;
  t148_n247: return 0.018766652792692184;
  t148_n248: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t148_n252;
  t148_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t148_n251;
  t148_n250: return 0.008016569539904594;
  t148_n251: return 0.022118939086794853;
  t148_n252: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t148_n254;
  t148_n253: return -0.0071126436814665794;
  t148_n254: return 0.0074642556719481945;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree149(const Example& E) {
  t149_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t149_n50;
  t149_n1: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t149_n33;
  t149_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t149_n4;
  t149_n3: return -0.0002643822517711669;
  t149_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t149_n6;
  t149_n5: return -0.006857994012534618;
  t149_n6: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t149_n32;
  t149_n7: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t149_n25;
  t149_n8: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t149_n24;
  t149_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t149_n23;
  t149_n10: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t149_n22;
  t149_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n13;
  t149_n12: return -0.2274857461452484;
  t149_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n21;
  t149_n14: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t149_n16;
  t149_n15: return -0.04875296354293823;
  t149_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n20;
  t149_n17: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t149_n19;
  t149_n18: return 0.8068740963935852;
  t149_n19: return -0.1509336680173874;
  t149_n20: return 0.1147775948047638;
  t149_n21: return -0.0375070758163929;
  t149_n22: return -0.18833313882350922;
  t149_n23: return 0.011243580840528011;
  t149_n24: return 0.016997335478663445;
  t149_n25: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t149_n29;
  t149_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n28;
  t149_n27: return -0.013922257348895073;
  t149_n28: return 0.02323256805539131;
  t149_n29: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t149_n31;
  t149_n30: return 0.004431792069226503;
  t149_n31: return -0.20844599604606628;
  t149_n32: return -0.09421487152576447;
  t149_n33: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t149_n39;
  t149_n34: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t149_n38;
  t149_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t149_n37;
  t149_n36: return -0.11307530105113983;
  t149_n37: return -0.21562062203884125;
  t149_n38: return -0.08248334378004074;
  t149_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t149_n49;
  t149_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t149_n46;
  t149_n41: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t149_n43;
  t149_n42: return -0.08465345203876495;
  t149_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t149_n45;
  t149_n44: return 0.0850568562746048;
  t149_n45: return -0.07374591380357742;
  t149_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n48;
  t149_n47: return 0.07963357865810394;
  t149_n48: return 0.08137170970439911;
  t149_n49: return -0.12966547906398773;
  t149_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t149_n52;
  t149_n51: return 0.0016632442129775882;
  t149_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n58;
  t149_n53: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t149_n55;
  t149_n54: return -0.09349971264600754;
  t149_n55: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n57;
  t149_n56: return -0.03351889178156853;
  t149_n57: return 0.09919758886098862;
  t149_n58: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t149_n238;
  t149_n59: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t149_n183;
  t149_n60: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t149_n150;
  t149_n61: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t149_n131;
  t149_n62: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t149_n130;
  t149_n63: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t149_n103;
  t149_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t149_n66;
  t149_n65: return 0.012819850817322731;
  t149_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t149_n68;
  t149_n67: return -0.1114858090877533;
  t149_n68: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t149_n72;
  t149_n69: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t149_n71;
  t149_n70: return -0.17387154698371887;
  t149_n71: return 0.04732527211308479;
  t149_n72: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t149_n80;
  t149_n73: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n79;
  t149_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t149_n76;
  t149_n75: return 0.06810735166072845;
  t149_n76: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n78;
  t149_n77: return 0.09701944887638092;
  t149_n78: return 0.013921594247221947;
  t149_n79: return 0.002729157917201519;
  t149_n80: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t149_n92;
  t149_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n83;
  t149_n82: return 0.0020447184797376394;
  t149_n83: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t149_n91;
  t149_n84: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t149_n86;
  t149_n85: return 0.042546022683382034;
  t149_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t149_n90;
  t149_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n89;
  t149_n88: return 0.02614416368305683;
  t149_n89: return 0.09472779184579849;
  t149_n90: return 0.055712006986141205;
  t149_n91: return -0.34893813729286194;
  t149_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n94;
  t149_n93: return 0.03715353086590767;
  t149_n94: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t149_n100;
  t149_n95: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t149_n97;
  t149_n96: return 0.06030631065368652;
  t149_n97: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t149_n99;
  t149_n98: return 0.10857461392879486;
  t149_n99: return 0.09729068726301193;
  t149_n100: if (E.getNumReferences() >= 3351432768 /*99740.5*/) goto t149_n102;
  t149_n101: return 0.1047767698764801;
  t149_n102: return 0.08707249909639359;
  t149_n103: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n129;
  t149_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t149_n106;
  t149_n105: return -0.08757995069026947;
  t149_n106: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t149_n120;
  t149_n107: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n119;
  t149_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t149_n116;
  t149_n109: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n115;
  t149_n110: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t149_n112;
  t149_n111: return -0.10253655910491943;
  t149_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n114;
  t149_n113: return 0.09537949413061142;
  t149_n114: return -0.03550711274147034;
  t149_n115: return -0.19645565748214722;
  t149_n116: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t149_n118;
  t149_n117: return -0.13614758849143982;
  t149_n118: return 0.12447983026504517;
  t149_n119: return 0.10901852697134018;
  t149_n120: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t149_n126;
  t149_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n123;
  t149_n122: return 0.027397075667977333;
  t149_n123: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t149_n125;
  t149_n124: return 0.1780054271221161;
  t149_n125: return 0.06329836696386337;
  t149_n126: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t149_n128;
  t149_n127: return 0.11157738417387009;
  t149_n128: return 0.024082116782665253;
  t149_n129: return -0.029716037213802338;
  t149_n130: return -0.019629433751106262;
  t149_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t149_n139;
  t149_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n136;
  t149_n133: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t149_n135;
  t149_n134: return 0.09280543029308319;
  t149_n135: return -0.12347834557294846;
  t149_n136: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t149_n138;
  t149_n137: return -0.18987390398979187;
  t149_n138: return 0.1187906414270401;
  t149_n139: if (E.getNumReferences() >= 3359621216 /*196353.5*/) goto t149_n149;
  t149_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n146;
  t149_n141: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t149_n145;
  t149_n142: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t149_n144;
  t149_n143: return -0.15158121287822723;
  t149_n144: return 0.044353634119033813;
  t149_n145: return 0.11878652125597;
  t149_n146: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t149_n148;
  t149_n147: return 0.02873404696583748;
  t149_n148: return 0.09449708461761475;
  t149_n149: return -0.16902178525924683;
  t149_n150: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t149_n172;
  t149_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t149_n165;
  t149_n152: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t149_n164;
  t149_n153: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t149_n159;
  t149_n154: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t149_n158;
  t149_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n157;
  t149_n156: return -0.0011367765255272388;
  t149_n157: return 0.0929136872291565;
  t149_n158: return 0.13937778770923615;
  t149_n159: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t149_n161;
  t149_n160: return 0.09496501088142395;
  t149_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n163;
  t149_n162: return 0.13563145697116852;
  t149_n163: return 0.03999195620417595;
  t149_n164: return -0.06627853959798813;
  t149_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t149_n171;
  t149_n166: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t149_n170;
  t149_n167: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t149_n169;
  t149_n168: return 0.0901634693145752;
  t149_n169: return 0.0007215062505565584;
  t149_n170: return 0.024499593302607536;
  t149_n171: return 0.016270296648144722;
  t149_n172: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t149_n174;
  t149_n173: return -0.020930949598550797;
  t149_n174: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t149_n182;
  t149_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n177;
  t149_n176: return 0.09292130172252655;
  t149_n177: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t149_n181;
  t149_n178: if (E.getNumReferences() >= 3350572224 /*93017.5*/) goto t149_n180;
  t149_n179: return -0.08174887299537659;
  t149_n180: return 0.0931299552321434;
  t149_n181: return 0.1168966293334961;
  t149_n182: return -0.03182857111096382;
  t149_n183: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t149_n195;
  t149_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n194;
  t149_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t149_n187;
  t149_n186: return -0.12810692191123962;
  t149_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n193;
  t149_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t149_n190;
  t149_n189: return 0.0028650974854826927;
  t149_n190: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t149_n192;
  t149_n191: return 0.11056247353553772;
  t149_n192: return -0.1507454663515091;
  t149_n193: return 0.0013588363071903586;
  t149_n194: return 0.05559517443180084;
  t149_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t149_n197;
  t149_n196: return -0.008980144746601582;
  t149_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t149_n203;
  t149_n198: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t149_n200;
  t149_n199: return 0.016443580389022827;
  t149_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n202;
  t149_n201: return 0.09901008754968643;
  t149_n202: return -0.32759222388267517;
  t149_n203: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t149_n237;
  t149_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t149_n236;
  t149_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t149_n215;
  t149_n206: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t149_n214;
  t149_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n213;
  t149_n208: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t149_n212;
  t149_n209: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t149_n211;
  t149_n210: return 0.1441962569952011;
  t149_n211: return 0.022702660411596298;
  t149_n212: return 0.12839458882808685;
  t149_n213: return 0.12005742639303207;
  t149_n214: return 0.028451241552829742;
  t149_n215: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t149_n221;
  t149_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t149_n218;
  t149_n217: return 0.028802866116166115;
  t149_n218: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t149_n220;
  t149_n219: return 0.09192001074552536;
  t149_n220: return 0.04430681839585304;
  t149_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t149_n223;
  t149_n222: return 0.014822795055806637;
  t149_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n235;
  t149_n224: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t149_n234;
  t149_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t149_n233;
  t149_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t149_n232;
  t149_n227: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t149_n231;
  t149_n228: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t149_n230;
  t149_n229: return -0.1154065951704979;
  t149_n230: return 0.09786130487918854;
  t149_n231: return 0.0606323778629303;
  t149_n232: return 0.11710742115974426;
  t149_n233: return 0.052104681730270386;
  t149_n234: return 0.10883364826440811;
  t149_n235: return -0.12545783817768097;
  t149_n236: return 0.022928794845938683;
  t149_n237: return -0.25795337557792664;
  t149_n238: if (E.getNumReferences() >= 3363974896 /*266615.5*/) goto t149_n240;
  t149_n239: return -0.14942023158073425;
  t149_n240: if (E.getNumReferences() >= 3364158064 /*272339.5*/) goto t149_n252;
  t149_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t149_n243;
  t149_n242: return -0.03722875192761421;
  t149_n243: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t149_n245;
  t149_n244: return -0.03091396950185299;
  t149_n245: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t149_n251;
  t149_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t149_n250;
  t149_n247: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t149_n249;
  t149_n248: return 0.07757174223661423;
  t149_n249: return 0.11043311655521393;
  t149_n250: return 0.07558739185333252;
  t149_n251: return 0.039009615778923035;
  t149_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t149_n254;
  t149_n253: return 0.00032219698186963797;
  t149_n254: return 0.016836218535900116;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree150(const Example& E) {
  t150_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t150_n78;
  t150_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t150_n53;
  t150_n2: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t150_n4;
  t150_n3: return 0.0011707284720614552;
  t150_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t150_n36;
  t150_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t150_n35;
  t150_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t150_n10;
  t150_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n9;
  t150_n8: return -0.10690581798553467;
  t150_n9: return -0.0020876643247902393;
  t150_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t150_n20;
  t150_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n13;
  t150_n12: return -0.018970167264342308;
  t150_n13: if (E.getNumReferences() >= 3311441920 /*3593.5*/) goto t150_n19;
  t150_n14: if (E.getNumReferences() >= 3309668352 /*3160.5*/) goto t150_n16;
  t150_n15: return -0.08817681670188904;
  t150_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n18;
  t150_n17: return -0.34247881174087524;
  t150_n18: return 0.11002915352582932;
  t150_n19: return -0.5183537602424622;
  t150_n20: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t150_n32;
  t150_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t150_n29;
  t150_n22: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t150_n24;
  t150_n23: return 0.007093534804880619;
  t150_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t150_n26;
  t150_n25: return 0.08743412792682648;
  t150_n26: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t150_n28;
  t150_n27: return 0.11887326836585999;
  t150_n28: return -0.5982344150543213;
  t150_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n31;
  t150_n30: return 0.09981773793697357;
  t150_n31: return -0.23650872707366943;
  t150_n32: if (E.getNumReferences() >= 3330339840 /*16506.0*/) goto t150_n34;
  t150_n33: return -0.04660456255078316;
  t150_n34: return 0.12160250544548035;
  t150_n35: return 0.024273885414004326;
  t150_n36: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t150_n50;
  t150_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t150_n39;
  t150_n38: return 0.022662553936243057;
  t150_n39: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t150_n49;
  t150_n40: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t150_n44;
  t150_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n43;
  t150_n42: return -0.6818764805793762;
  t150_n43: return 0.013818936422467232;
  t150_n44: if (E.getNumReferences() >= 3325212160 /*11437.5*/) goto t150_n46;
  t150_n45: return 0.03413369879126549;
  t150_n46: if (E.getNumReferences() >= 3326160384 /*12363.5*/) goto t150_n48;
  t150_n47: return 0.16014890372753143;
  t150_n48: return 0.06470304727554321;
  t150_n49: return -0.012741642072796822;
  t150_n50: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t150_n52;
  t150_n51: return 0.015162190422415733;
  t150_n52: return -0.0733974352478981;
  t150_n53: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t150_n55;
  t150_n54: return 2.5274759536841884e-05;
  t150_n55: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t150_n77;
  t150_n56: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t150_n58;
  t150_n57: return 0.011121781542897224;
  t150_n58: if (E.getNumReferences() >= 3327494144 /*13666.0*/) goto t150_n72;
  t150_n59: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t150_n61;
  t150_n60: return -0.0976223573088646;
  t150_n61: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t150_n63;
  t150_n62: return -0.03445763140916824;
  t150_n63: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t150_n71;
  t150_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n66;
  t150_n65: return 0.010427202098071575;
  t150_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t150_n68;
  t150_n67: return -0.0015980610623955727;
  t150_n68: if (E.getNumReferences() >= 3324599296 /*10839.0*/) goto t150_n70;
  t150_n69: return 0.0696302279829979;
  t150_n70: return -0.19121207296848297;
  t150_n71: return -0.014520417898893356;
  t150_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t150_n74;
  t150_n73: return -0.21319067478179932;
  t150_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n76;
  t150_n75: return 0.11018542945384979;
  t150_n76: return 0.15173949301242828;
  t150_n77: return -0.027248015627264977;
  t150_n78: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t150_n106;
  t150_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t150_n81;
  t150_n80: return 0.0031977184116840363;
  t150_n81: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t150_n99;
  t150_n82: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t150_n94;
  t150_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t150_n85;
  t150_n84: return 0.1101030707359314;
  t150_n85: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t150_n91;
  t150_n86: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t150_n90;
  t150_n87: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t150_n89;
  t150_n88: return 0.0864504799246788;
  t150_n89: return 0.11597326397895813;
  t150_n90: return 0.05415669456124306;
  t150_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t150_n93;
  t150_n92: return 0.12075425684452057;
  t150_n93: return 0.11468927562236786;
  t150_n94: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n96;
  t150_n95: return 0.09820887446403503;
  t150_n96: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t150_n98;
  t150_n97: return 0.04887231066823006;
  t150_n98: return 0.0931621640920639;
  t150_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n105;
  t150_n100: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t150_n102;
  t150_n101: return -0.5560339093208313;
  t150_n102: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t150_n104;
  t150_n103: return 0.13695985078811646;
  t150_n104: return 0.13416096568107605;
  t150_n105: return 0.003992708865553141;
  t150_n106: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t150_n214;
  t150_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t150_n109;
  t150_n108: return -0.01206845324486494;
  t150_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n111;
  t150_n110: return 0.00030944752506911755;
  t150_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t150_n191;
  t150_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t150_n132;
  t150_n113: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t150_n117;
  t150_n114: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t150_n116;
  t150_n115: return -0.034213900566101074;
  t150_n116: return -0.43526872992515564;
  t150_n117: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t150_n131;
  t150_n118: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t150_n128;
  t150_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t150_n127;
  t150_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t150_n122;
  t150_n121: return -0.20384475588798523;
  t150_n122: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t150_n126;
  t150_n123: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t150_n125;
  t150_n124: return 0.03306260704994202;
  t150_n125: return 0.09411657601594925;
  t150_n126: return -0.1286967396736145;
  t150_n127: return 0.12860938906669617;
  t150_n128: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t150_n130;
  t150_n129: return 0.053510881960392;
  t150_n130: return 0.11304157227277756;
  t150_n131: return 0.005185876041650772;
  t150_n132: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t150_n186;
  t150_n133: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t150_n181;
  t150_n134: if (E.getNumReferences() >= 3332416512 /*20562.0*/) goto t150_n138;
  t150_n135: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t150_n137;
  t150_n136: return -0.060468174517154694;
  t150_n137: return 0.13166160881519318;
  t150_n138: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t150_n142;
  t150_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n141;
  t150_n140: return -0.11650042235851288;
  t150_n141: return -0.388493150472641;
  t150_n142: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t150_n158;
  t150_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t150_n157;
  t150_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n146;
  t150_n145: return -0.21701936423778534;
  t150_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n154;
  t150_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t150_n151;
  t150_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t150_n150;
  t150_n149: return -1.5501021146774292;
  t150_n150: return 0.11095596104860306;
  t150_n151: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t150_n153;
  t150_n152: return 0.0645664855837822;
  t150_n153: return 0.1041783019900322;
  t150_n154: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t150_n156;
  t150_n155: return -0.001278663519769907;
  t150_n156: return 0.12792128324508667;
  t150_n157: return 0.10393139719963074;
  t150_n158: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t150_n164;
  t150_n159: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t150_n163;
  t150_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t150_n162;
  t150_n161: return -0.32930123805999756;
  t150_n162: return -0.0009310460300184786;
  t150_n163: return 0.05284285172820091;
  t150_n164: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t150_n174;
  t150_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t150_n173;
  t150_n166: if (E.getNumReferences() >= 3343484032 /*51588.5*/) goto t150_n168;
  t150_n167: return -0.0798761248588562;
  t150_n168: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t150_n170;
  t150_n169: return 0.10612176358699799;
  t150_n170: if (E.getNumReferences() >= 3357991456 /*170888.5*/) goto t150_n172;
  t150_n171: return -0.06398488581180573;
  t150_n172: return 0.10439679026603699;
  t150_n173: return 0.10920193791389465;
  t150_n174: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t150_n176;
  t150_n175: return -0.05812719836831093;
  t150_n176: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t150_n178;
  t150_n177: return -0.018046220764517784;
  t150_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t150_n180;
  t150_n179: return -0.008671884424984455;
  t150_n180: return 0.10808101296424866;
  t150_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t150_n185;
  t150_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n184;
  t150_n183: return 0.11163900792598724;
  t150_n184: return 0.025316262617707253;
  t150_n185: return 0.11550372838973999;
  t150_n186: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t150_n190;
  t150_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n189;
  t150_n188: return -0.12523376941680908;
  t150_n189: return 0.002932610223069787;
  t150_n190: return 0.07693403214216232;
  t150_n191: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t150_n199;
  t150_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t150_n194;
  t150_n193: return -0.0009887396590784192;
  t150_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t150_n198;
  t150_n195: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t150_n197;
  t150_n196: return 0.09697303175926208;
  t150_n197: return 0.07438036054372787;
  t150_n198: return 0.06862947344779968;
  t150_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t150_n201;
  t150_n200: return -0.15804216265678406;
  t150_n201: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t150_n203;
  t150_n202: return -0.014707721769809723;
  t150_n203: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t150_n207;
  t150_n204: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t150_n206;
  t150_n205: return 0.1281338632106781;
  t150_n206: return 0.10507019609212875;
  t150_n207: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t150_n209;
  t150_n208: return 0.049932919442653656;
  t150_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n213;
  t150_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t150_n212;
  t150_n211: return 0.11634672433137894;
  t150_n212: return -0.09112243354320526;
  t150_n213: return 0.021478325128555298;
  t150_n214: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t150_n216;
  t150_n215: return 0.008777842856943607;
  t150_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t150_n248;
  t150_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t150_n237;
  t150_n218: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t150_n236;
  t150_n219: if (E.getNumReferences() >= 3362085632 /*234860.0*/) goto t150_n235;
  t150_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n230;
  t150_n221: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n225;
  t150_n222: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t150_n224;
  t150_n223: return 0.06954573094844818;
  t150_n224: return 1.1355143785476685;
  t150_n225: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n229;
  t150_n226: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t150_n228;
  t150_n227: return -0.3887336552143097;
  t150_n228: return 0.1222376748919487;
  t150_n229: return 0.05816386640071869;
  t150_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t150_n234;
  t150_n231: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t150_n233;
  t150_n232: return 0.05354287102818489;
  t150_n233: return -0.1968984156847;
  t150_n234: return -0.08129319548606873;
  t150_n235: return -0.07054781168699265;
  t150_n236: return 0.11678200215101242;
  t150_n237: if (E.getNumReferences() >= 3336251648 /*28052.5*/) goto t150_n247;
  t150_n238: if (E.getNumReferences() >= 3334339584 /*24318.0*/) goto t150_n242;
  t150_n239: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t150_n241;
  t150_n240: return -0.09479056298732758;
  t150_n241: return 0.0936460867524147;
  t150_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t150_n246;
  t150_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t150_n245;
  t150_n244: return -0.13159222900867462;
  t150_n245: return 0.1069289967417717;
  t150_n246: return 0.11075947433710098;
  t150_n247: return 0.029492901638150215;
  t150_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t150_n254;
  t150_n249: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t150_n251;
  t150_n250: return -0.09056193381547928;
  t150_n251: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t150_n253;
  t150_n252: return 0.1235378310084343;
  t150_n253: return -0.12095549702644348;
  t150_n254: return -0.06885196268558502;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree151(const Example& E) {
  t151_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t151_n2;
  t151_n1: return -0.00043545279186218977;
  t151_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t151_n16;
  t151_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t151_n5;
  t151_n4: return 0.009738503023982048;
  t151_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t151_n7;
  t151_n6: return 0.0216587632894516;
  t151_n7: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t151_n15;
  t151_n8: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t151_n10;
  t151_n9: return -0.18813075125217438;
  t151_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t151_n12;
  t151_n11: return 0.10095684975385666;
  t151_n12: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n14;
  t151_n13: return 0.1442340463399887;
  t151_n14: return 0.13841280341148376;
  t151_n15: return -0.008962706662714481;
  t151_n16: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t151_n18;
  t151_n17: return -0.002806692849844694;
  t151_n18: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t151_n218;
  t151_n19: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t151_n27;
  t151_n20: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t151_n24;
  t151_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t151_n23;
  t151_n22: return 0.0392635315656662;
  t151_n23: return 0.11539028584957123;
  t151_n24: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t151_n26;
  t151_n25: return 0.004707269836217165;
  t151_n26: return 0.08556046336889267;
  t151_n27: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t151_n37;
  t151_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t151_n34;
  t151_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n31;
  t151_n30: return -0.00035908666905015707;
  t151_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n33;
  t151_n32: return 0.09908497333526611;
  t151_n33: return -0.12234605103731155;
  t151_n34: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t151_n36;
  t151_n35: return 0.09724979102611542;
  t151_n36: return 0.12582451105117798;
  t151_n37: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t151_n203;
  t151_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t151_n94;
  t151_n39: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t151_n69;
  t151_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t151_n42;
  t151_n41: return -0.028094368055462837;
  t151_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t151_n58;
  t151_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n45;
  t151_n44: return -0.02266014739871025;
  t151_n45: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t151_n47;
  t151_n46: return -0.1736333817243576;
  t151_n47: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t151_n55;
  t151_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n50;
  t151_n49: return 0.12406112253665924;
  t151_n50: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t151_n52;
  t151_n51: return -0.1138983890414238;
  t151_n52: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t151_n54;
  t151_n53: return 0.12314701080322266;
  t151_n54: return 0.12981046736240387;
  t151_n55: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t151_n57;
  t151_n56: return 0.08505978435277939;
  t151_n57: return 0.10323630273342133;
  t151_n58: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t151_n60;
  t151_n59: return -0.008383593522012234;
  t151_n60: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t151_n68;
  t151_n61: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t151_n67;
  t151_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n64;
  t151_n63: return -0.1045675128698349;
  t151_n64: if (E.getNumReferences() >= 3322096640 /*8395.0*/) goto t151_n66;
  t151_n65: return 0.03487173467874527;
  t151_n66: return 0.16220690310001373;
  t151_n67: return 0.1257304698228836;
  t151_n68: return 0.10031621903181076;
  t151_n69: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t151_n73;
  t151_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n72;
  t151_n71: return 0.003204312175512314;
  t151_n72: return 0.11287324875593185;
  t151_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t151_n75;
  t151_n74: return 0.021554457023739815;
  t151_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n93;
  t151_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n80;
  t151_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t151_n79;
  t151_n78: return 0.12217453867197037;
  t151_n79: return 0.11495719105005264;
  t151_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t151_n92;
  t151_n81: if (E.getNumReferences() >= 3317499904 /*6049.0*/) goto t151_n85;
  t151_n82: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t151_n84;
  t151_n83: return 0.11090273410081863;
  t151_n84: return 0.10590197890996933;
  t151_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n89;
  t151_n86: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t151_n88;
  t151_n87: return -0.1363116204738617;
  t151_n88: return 0.09934008121490479;
  t151_n89: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t151_n91;
  t151_n90: return 0.10390619933605194;
  t151_n91: return -0.08971324563026428;
  t151_n92: return 0.10325489193201065;
  t151_n93: return -0.13354074954986572;
  t151_n94: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t151_n188;
  t151_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t151_n159;
  t151_n96: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t151_n152;
  t151_n97: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t151_n149;
  t151_n98: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t151_n112;
  t151_n99: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t151_n101;
  t151_n100: return -0.03210652992129326;
  t151_n101: if (E.getNumReferences() >= 3319636992 /*7092.5*/) goto t151_n107;
  t151_n102: if (E.getNumReferences() >= 3317832704 /*6211.5*/) goto t151_n106;
  t151_n103: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t151_n105;
  t151_n104: return 0.15778163075447083;
  t151_n105: return 0.11472880095243454;
  t151_n106: return -0.2576814889907837;
  t151_n107: if (E.getNumReferences() >= 3320252416 /*7393.0*/) goto t151_n109;
  t151_n108: return 0.13108162581920624;
  t151_n109: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t151_n111;
  t151_n110: return 0.10325673222541809;
  t151_n111: return -0.10644271224737167;
  t151_n112: if (E.getNumReferences() >= 3319918592 /*7230.0*/) goto t151_n130;
  t151_n113: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t151_n129;
  t151_n114: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t151_n128;
  t151_n115: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t151_n117;
  t151_n116: return -0.07646097987890244;
  t151_n117: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t151_n119;
  t151_n118: return -0.2299100160598755;
  t151_n119: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t151_n121;
  t151_n120: return 0.11940469592809677;
  t151_n121: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t151_n127;
  t151_n122: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n126;
  t151_n123: if (E.getNumReferences() >= 3319047168 /*6804.5*/) goto t151_n125;
  t151_n124: return 0.11104380339384079;
  t151_n125: return -0.1519901156425476;
  t151_n126: return -0.13099172711372375;
  t151_n127: return 0.09456785768270493;
  t151_n128: return 0.0032177830580621958;
  t151_n129: return -0.05092566832900047;
  t151_n130: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n138;
  t151_n131: if (E.getNumReferences() >= 3320159232 /*7347.5*/) goto t151_n135;
  t151_n132: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t151_n134;
  t151_n133: return -0.1079171821475029;
  t151_n134: return 0.12493585050106049;
  t151_n135: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t151_n137;
  t151_n136: return 0.030855905264616013;
  t151_n137: return -0.5332649350166321;
  t151_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t151_n146;
  t151_n139: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t151_n145;
  t151_n140: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n142;
  t151_n141: return -0.1298578828573227;
  t151_n142: if (E.getNumReferences() >= 3321062400 /*7788.5*/) goto t151_n144;
  t151_n143: return 0.11092390865087509;
  t151_n144: return 0.11525065451860428;
  t151_n145: return 0.07176414877176285;
  t151_n146: if (E.getNumReferences() >= 3320749056 /*7635.5*/) goto t151_n148;
  t151_n147: return -0.10113594681024551;
  t151_n148: return 0.11716372519731522;
  t151_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t151_n151;
  t151_n150: return -0.11664937436580658;
  t151_n151: return 0.1199507862329483;
  t151_n152: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t151_n154;
  t151_n153: return -0.016833893954753876;
  t151_n154: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t151_n156;
  t151_n155: return 0.02717766910791397;
  t151_n156: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t151_n158;
  t151_n157: return 0.11538873612880707;
  t151_n158: return -0.02647900953888893;
  t151_n159: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t151_n161;
  t151_n160: return 0.151762917637825;
  t151_n161: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t151_n187;
  t151_n162: if (E.getNumReferences() >= 3321896960 /*8200.0*/) goto t151_n184;
  t151_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n165;
  t151_n164: return -0.00024124662741087377;
  t151_n165: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t151_n167;
  t151_n166: return 0.10437799245119095;
  t151_n167: if (E.getNumReferences() >= 3320443904 /*7486.5*/) goto t151_n183;
  t151_n168: if (E.getNumReferences() >= 3319744512 /*7145.0*/) goto t151_n178;
  t151_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t151_n171;
  t151_n170: return 0.027755053713917732;
  t151_n171: if (E.getNumReferences() >= 3315877888 /*5257.0*/) goto t151_n173;
  t151_n172: return 0.0996299535036087;
  t151_n173: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t151_n175;
  t151_n174: return 0.026929736137390137;
  t151_n175: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t151_n177;
  t151_n176: return 0.11499323695898056;
  t151_n177: return -0.28481945395469666;
  t151_n178: if (E.getNumReferences() >= 3319828480 /*7186.0*/) goto t151_n182;
  t151_n179: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t151_n181;
  t151_n180: return 0.10258269309997559;
  t151_n181: return 0.09472787380218506;
  t151_n182: return 0.07248102873563766;
  t151_n183: return -0.1875799596309662;
  t151_n184: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t151_n186;
  t151_n185: return 0.11319059878587723;
  t151_n186: return 0.04715369641780853;
  t151_n187: return 0.1045333594083786;
  t151_n188: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t151_n202;
  t151_n189: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t151_n199;
  t151_n190: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n192;
  t151_n191: return 0.08689802139997482;
  t151_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t151_n198;
  t151_n193: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t151_n195;
  t151_n194: return -0.1010102704167366;
  t151_n195: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t151_n197;
  t151_n196: return 0.09916798770427704;
  t151_n197: return 0.06570155918598175;
  t151_n198: return 0.11416072398424149;
  t151_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t151_n201;
  t151_n200: return 0.10945098102092743;
  t151_n201: return 0.06989581882953644;
  t151_n202: return 0.03216373175382614;
  t151_n203: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t151_n217;
  t151_n204: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t151_n206;
  t151_n205: return -0.15238215029239655;
  t151_n206: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n216;
  t151_n207: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t151_n209;
  t151_n208: return -0.10554506629705429;
  t151_n209: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t151_n215;
  t151_n210: if (E.getNumReferences() >= 3319302144 /*6929.0*/) goto t151_n214;
  t151_n211: if (E.getNumReferences() >= 3318825984 /*6696.5*/) goto t151_n213;
  t151_n212: return 0.10347791761159897;
  t151_n213: return -0.11744607985019684;
  t151_n214: return 0.09905122965574265;
  t151_n215: return 0.05031636357307434;
  t151_n216: return -0.0442984513938427;
  t151_n217: return 0.04481038078665733;
  t151_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t151_n254;
  t151_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t151_n251;
  t151_n220: if (E.getNumReferences() >= 3335010048 /*25627.5*/) goto t151_n226;
  t151_n221: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t151_n223;
  t151_n222: return -0.0730506107211113;
  t151_n223: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t151_n225;
  t151_n224: return 0.0862327367067337;
  t151_n225: return -0.34384700655937195;
  t151_n226: if (E.getNumReferences() >= 3335170304 /*25940.5*/) goto t151_n230;
  t151_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t151_n229;
  t151_n228: return -0.29280927777290344;
  t151_n229: return 0.09988941997289658;
  t151_n230: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t151_n232;
  t151_n231: return -0.013753936626017094;
  t151_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t151_n238;
  t151_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t151_n235;
  t151_n234: return 0.03028811514377594;
  t151_n235: if (E.getNumReferences() >= 3370747520 /*478260.0*/) goto t151_n237;
  t151_n236: return 0.10947556048631668;
  t151_n237: return 0.033384885638952255;
  t151_n238: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t151_n240;
  t151_n239: return -0.018235623836517334;
  t151_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t151_n242;
  t151_n241: return 0.05746462196111679;
  t151_n242: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t151_n248;
  t151_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t151_n245;
  t151_n244: return 0.05737617611885071;
  t151_n245: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t151_n247;
  t151_n246: return 0.10585806518793106;
  t151_n247: return 0.08329249918460846;
  t151_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t151_n250;
  t151_n249: return 0.07499319314956665;
  t151_n250: return -0.411899209022522;
  t151_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t151_n253;
  t151_n252: return -0.026692340150475502;
  t151_n253: return 0.018174167722463608;
  t151_n254: return 0.04018937051296234;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree152(const Example& E) {
  t152_n0: if (E.getNumReferences() >= 3324859904 /*11093.5*/) goto t152_n2;
  t152_n1: return -0.0003530648536980152;
  t152_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t152_n84;
  t152_n3: if (E.getNumReferences() >= 3327362048 /*13537.0*/) goto t152_n47;
  t152_n4: if (E.getNumReferences() >= 3327291904 /*13468.5*/) goto t152_n44;
  t152_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t152_n13;
  t152_n6: if (E.getNumReferences() >= 3327044096 /*13226.5*/) goto t152_n8;
  t152_n7: return 0.027373382821679115;
  t152_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n10;
  t152_n9: return 0.16997748613357544;
  t152_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n12;
  t152_n11: return 0.15262165665626526;
  t152_n12: return 0.10301752388477325;
  t152_n13: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t152_n17;
  t152_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n16;
  t152_n15: return -0.15825772285461426;
  t152_n16: return 0.14158053696155548;
  t152_n17: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t152_n31;
  t152_n18: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n26;
  t152_n19: if (E.getNumReferences() >= 3325212160 /*11437.5*/) goto t152_n23;
  t152_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t152_n22;
  t152_n21: return 0.03647181764245033;
  t152_n22: return -0.5331239104270935;
  t152_n23: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t152_n25;
  t152_n24: return 0.15597553551197052;
  t152_n25: return 0.06898877769708633;
  t152_n26: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t152_n30;
  t152_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n29;
  t152_n28: return 0.12941499054431915;
  t152_n29: return 0.03958865627646446;
  t152_n30: return -0.14717379212379456;
  t152_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n33;
  t152_n32: return 0.060859404504299164;
  t152_n33: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t152_n35;
  t152_n34: return -0.15022780001163483;
  t152_n35: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n39;
  t152_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n38;
  t152_n37: return 0.0557527132332325;
  t152_n38: return 0.12655223906040192;
  t152_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n41;
  t152_n40: return -0.01638045161962509;
  t152_n41: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t152_n43;
  t152_n42: return 0.11537913978099823;
  t152_n43: return 0.03253640979528427;
  t152_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n46;
  t152_n45: return 0.5940304398536682;
  t152_n46: return 0.12465257197618484;
  t152_n47: if (E.getNumReferences() >= 3327710208 /*13877.0*/) goto t152_n55;
  t152_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t152_n54;
  t152_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n53;
  t152_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n52;
  t152_n51: return -0.6281301975250244;
  t152_n52: return -3.4201126098632812;
  t152_n53: return -0.06005248799920082;
  t152_n54: return -0.0945759192109108;
  t152_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t152_n83;
  t152_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t152_n58;
  t152_n57: return 0.005003007128834724;
  t152_n58: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n60;
  t152_n59: return 0.015102673321962357;
  t152_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n76;
  t152_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t152_n69;
  t152_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n68;
  t152_n63: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t152_n67;
  t152_n64: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t152_n66;
  t152_n65: return 0.03861706703901291;
  t152_n66: return 0.13074807822704315;
  t152_n67: return 0.08017916977405548;
  t152_n68: return 0.03017689287662506;
  t152_n69: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n71;
  t152_n70: return 0.0408230721950531;
  t152_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n75;
  t152_n72: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t152_n74;
  t152_n73: return 0.1136656254529953;
  t152_n74: return 0.08505445718765259;
  t152_n75: return 0.06774649769067764;
  t152_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n82;
  t152_n77: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n79;
  t152_n78: return 0.065132737159729;
  t152_n79: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t152_n81;
  t152_n80: return -0.15635094046592712;
  t152_n81: return 0.12502464652061462;
  t152_n82: return 0.038030777126550674;
  t152_n83: return 0.008983309380710125;
  t152_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t152_n88;
  t152_n85: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t152_n87;
  t152_n86: return -0.03454064577817917;
  t152_n87: return -0.09253742545843124;
  t152_n88: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t152_n172;
  t152_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t152_n143;
  t152_n90: if (E.getNumReferences() >= 3346195456 /*62180.0*/) goto t152_n112;
  t152_n91: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t152_n107;
  t152_n92: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t152_n106;
  t152_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t152_n95;
  t152_n94: return 0.023194342851638794;
  t152_n95: if (E.getNumReferences() >= 3330989056 /*17774.0*/) goto t152_n99;
  t152_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t152_n98;
  t152_n97: return 0.07595369964838028;
  t152_n98: return 0.13957884907722473;
  t152_n99: if (E.getNumReferences() >= 3339920000 /*37666.5*/) goto t152_n103;
  t152_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t152_n102;
  t152_n101: return 0.07876088470220566;
  t152_n102: return -0.33111605048179626;
  t152_n103: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t152_n105;
  t152_n104: return -0.0009367507882416248;
  t152_n105: return 0.10865053534507751;
  t152_n106: return 0.005293200258165598;
  t152_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n109;
  t152_n108: return 0.014587384648621082;
  t152_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t152_n111;
  t152_n110: return -0.0615391731262207;
  t152_n111: return 0.11272073537111282;
  t152_n112: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t152_n128;
  t152_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n115;
  t152_n114: return -0.018988555297255516;
  t152_n115: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t152_n127;
  t152_n116: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t152_n122;
  t152_n117: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t152_n119;
  t152_n118: return -0.11452287435531616;
  t152_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t152_n121;
  t152_n120: return -0.021892046555876732;
  t152_n121: return 0.09840931743383408;
  t152_n122: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t152_n126;
  t152_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t152_n125;
  t152_n124: return -0.12937778234481812;
  t152_n125: return 0.10188450664281845;
  t152_n126: return 0.010777843184769154;
  t152_n127: return -0.02268238551914692;
  t152_n128: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t152_n142;
  t152_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n131;
  t152_n130: return -0.05618099495768547;
  t152_n131: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t152_n141;
  t152_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n140;
  t152_n133: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n139;
  t152_n134: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t152_n136;
  t152_n135: return 0.11589735746383667;
  t152_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t152_n138;
  t152_n137: return 0.11677806824445724;
  t152_n138: return 0.0048472583293914795;
  t152_n139: return 0.04653036594390869;
  t152_n140: return -0.11496122181415558;
  t152_n141: return 0.01696523278951645;
  t152_n142: return 0.11526696383953094;
  t152_n143: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t152_n159;
  t152_n144: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t152_n146;
  t152_n145: return -0.07532991468906403;
  t152_n146: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t152_n148;
  t152_n147: return 0.021743198856711388;
  t152_n148: if (E.getNumReferences() >= 3330470656 /*16761.5*/) goto t152_n150;
  t152_n149: return -0.06523853540420532;
  t152_n150: if (E.getNumReferences() >= 3334795520 /*25208.5*/) goto t152_n154;
  t152_n151: if (E.getNumReferences() >= 3333635072 /*22942.0*/) goto t152_n153;
  t152_n152: return 0.8742266297340393;
  t152_n153: return 0.11896016448736191;
  t152_n154: if (E.getNumReferences() >= 3339882752 /*37521.0*/) goto t152_n156;
  t152_n155: return -0.26804670691490173;
  t152_n156: if (E.getNumReferences() >= 3341543680 /*44009.0*/) goto t152_n158;
  t152_n157: return 0.27688321471214294;
  t152_n158: return -0.19440898299217224;
  t152_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t152_n171;
  t152_n160: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t152_n168;
  t152_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n165;
  t152_n162: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t152_n164;
  t152_n163: return 0.06668546050786972;
  t152_n164: return 0.10025845468044281;
  t152_n165: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t152_n167;
  t152_n166: return 0.10778062045574188;
  t152_n167: return 0.04585035517811775;
  t152_n168: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t152_n170;
  t152_n169: return 0.11488959193229675;
  t152_n170: return 0.006126217544078827;
  t152_n171: return 0.14568382501602173;
  t152_n172: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t152_n180;
  t152_n173: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n179;
  t152_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t152_n176;
  t152_n175: return -0.3976207375526428;
  t152_n176: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t152_n178;
  t152_n177: return 0.10254738479852676;
  t152_n178: return 0.12991948425769806;
  t152_n179: return 0.07127019762992859;
  t152_n180: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t152_n254;
  t152_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t152_n253;
  t152_n182: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t152_n242;
  t152_n183: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t152_n231;
  t152_n184: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t152_n230;
  t152_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t152_n195;
  t152_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t152_n188;
  t152_n187: return 0.02055664174258709;
  t152_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n192;
  t152_n189: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t152_n191;
  t152_n190: return 0.08075578510761261;
  t152_n191: return 0.16008365154266357;
  t152_n192: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n194;
  t152_n193: return 0.13668805360794067;
  t152_n194: return 0.04521958902478218;
  t152_n195: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t152_n215;
  t152_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t152_n198;
  t152_n197: return -0.012252209708094597;
  t152_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n212;
  t152_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n201;
  t152_n200: return 0.04608755186200142;
  t152_n201: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t152_n211;
  t152_n202: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t152_n208;
  t152_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t152_n207;
  t152_n204: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t152_n206;
  t152_n205: return 0.1092173308134079;
  t152_n206: return 0.10891794413328171;
  t152_n207: return 0.10371187329292297;
  t152_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t152_n210;
  t152_n209: return 0.04468065872788429;
  t152_n210: return 0.10597864538431168;
  t152_n211: return 0.041177522391080856;
  t152_n212: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t152_n214;
  t152_n213: return 0.07166346907615662;
  t152_n214: return 0.12355837970972061;
  t152_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t152_n227;
  t152_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t152_n218;
  t152_n217: return -0.25830554962158203;
  t152_n218: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t152_n226;
  t152_n219: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t152_n225;
  t152_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t152_n222;
  t152_n221: return 0.06942278146743774;
  t152_n222: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t152_n224;
  t152_n223: return 0.0826125293970108;
  t152_n224: return -0.10467147827148438;
  t152_n225: return 0.08676277101039886;
  t152_n226: return -0.2314951866865158;
  t152_n227: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t152_n229;
  t152_n228: return 0.09416785836219788;
  t152_n229: return 0.09581971913576126;
  t152_n230: return -0.16317741572856903;
  t152_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t152_n233;
  t152_n232: return 0.013886811211705208;
  t152_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t152_n239;
  t152_n234: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t152_n238;
  t152_n235: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t152_n237;
  t152_n236: return 0.04896402731537819;
  t152_n237: return 0.0777946338057518;
  t152_n238: return 0.10687519609928131;
  t152_n239: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t152_n241;
  t152_n240: return -0.008721845224499702;
  t152_n241: return 0.05415920913219452;
  t152_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t152_n244;
  t152_n243: return -0.14547978341579437;
  t152_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t152_n248;
  t152_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t152_n247;
  t152_n246: return 0.09321137517690659;
  t152_n247: return 0.10611261427402496;
  t152_n248: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t152_n250;
  t152_n249: return 0.0640607476234436;
  t152_n250: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t152_n252;
  t152_n251: return 0.10899679362773895;
  t152_n252: return 0.020039044320583344;
  t152_n253: return -0.04644935205578804;
  t152_n254: return 0.008097890764474869;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree153(const Example& E) {
  t153_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t153_n254;
  t153_n1: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t153_n177;
  t153_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t153_n38;
  t153_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t153_n5;
  t153_n4: return -0.0031729235779494047;
  t153_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t153_n35;
  t153_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t153_n8;
  t153_n7: return -0.006247959099709988;
  t153_n8: if (E.getNumReferences() >= 3305148416 /*2057.0*/) goto t153_n10;
  t153_n9: return 0.0032853102311491966;
  t153_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n12;
  t153_n11: return 0.0021876723039895296;
  t153_n12: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t153_n34;
  t153_n13: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t153_n33;
  t153_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t153_n32;
  t153_n15: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t153_n27;
  t153_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t153_n18;
  t153_n17: return 0.07007061690092087;
  t153_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t153_n20;
  t153_n19: return 0.06829703599214554;
  t153_n20: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t153_n22;
  t153_n21: return -0.11299063265323639;
  t153_n22: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t153_n26;
  t153_n23: if (E.getNumReferences() >= 3331793152 /*19344.5*/) goto t153_n25;
  t153_n24: return 0.114744171500206;
  t153_n25: return 0.0982092022895813;
  t153_n26: return -0.1033235415816307;
  t153_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n31;
  t153_n28: if (E.getNumReferences() >= 3320380416 /*7455.5*/) goto t153_n30;
  t153_n29: return 0.07488538324832916;
  t153_n30: return 0.11663330346345901;
  t153_n31: return 0.08261258155107498;
  t153_n32: return 0.019481852650642395;
  t153_n33: return 0.014563643373548985;
  t153_n34: return 0.03364371508359909;
  t153_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n37;
  t153_n36: return 0.08782549947500229;
  t153_n37: return 0.03203364089131355;
  t153_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t153_n40;
  t153_n39: return -0.005524586886167526;
  t153_n40: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t153_n176;
  t153_n41: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t153_n157;
  t153_n42: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t153_n44;
  t153_n43: return 0.005198133643716574;
  t153_n44: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t153_n68;
  t153_n45: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t153_n67;
  t153_n46: if (E.getNumReferences() >= 3309611008 /*3146.5*/) goto t153_n66;
  t153_n47: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t153_n53;
  t153_n48: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t153_n50;
  t153_n49: return -0.6057464480400085;
  t153_n50: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t153_n52;
  t153_n51: return -0.11540663987398148;
  t153_n52: return 0.07616231590509415;
  t153_n53: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t153_n57;
  t153_n54: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t153_n56;
  t153_n55: return 0.0697777047753334;
  t153_n56: return 0.1266922652721405;
  t153_n57: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t153_n65;
  t153_n58: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t153_n62;
  t153_n59: if (E.getNumReferences() >= 3304308736 /*1950.0*/) goto t153_n61;
  t153_n60: return 0.02808588370680809;
  t153_n61: return 0.08047593384981155;
  t153_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t153_n64;
  t153_n63: return 0.13215848803520203;
  t153_n64: return 0.03835746645927429;
  t153_n65: return 0.009635488502681255;
  t153_n66: return 0.136430561542511;
  t153_n67: return -0.12841428816318512;
  t153_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t153_n118;
  t153_n69: if (E.getNumReferences() >= 3325736448 /*11949.5*/) goto t153_n109;
  t153_n70: if (E.getNumReferences() >= 3324380672 /*10625.5*/) goto t153_n100;
  t153_n71: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t153_n73;
  t153_n72: return -0.0008195267291739583;
  t153_n73: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t153_n91;
  t153_n74: if (E.getNumReferences() >= 3322782208 /*9064.5*/) goto t153_n82;
  t153_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n79;
  t153_n76: if (E.getNumReferences() >= 3322376192 /*8668.0*/) goto t153_n78;
  t153_n77: return 0.21268320083618164;
  t153_n78: return -0.004447044339030981;
  t153_n79: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t153_n81;
  t153_n80: return -0.03420699015259743;
  t153_n81: return 0.1156013011932373;
  t153_n82: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t153_n84;
  t153_n83: return 0.05122557654976845;
  t153_n84: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t153_n90;
  t153_n85: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t153_n89;
  t153_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n88;
  t153_n87: return -0.10488434135913849;
  t153_n88: return 0.10898370295763016;
  t153_n89: return 0.11505317687988281;
  t153_n90: return -0.3665043115615845;
  t153_n91: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t153_n97;
  t153_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t153_n94;
  t153_n93: return -0.12100031226873398;
  t153_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t153_n96;
  t153_n95: return 0.10013143718242645;
  t153_n96: return -0.06880068778991699;
  t153_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n99;
  t153_n98: return 0.045531656593084335;
  t153_n99: return 0.15762723982334137;
  t153_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t153_n108;
  t153_n101: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t153_n103;
  t153_n102: return -0.0867738127708435;
  t153_n103: if (E.getNumReferences() >= 3324703232 /*10940.5*/) goto t153_n105;
  t153_n104: return 0.17834828794002533;
  t153_n105: if (E.getNumReferences() >= 3325327360 /*11550.0*/) goto t153_n107;
  t153_n106: return -0.028220558539032936;
  t153_n107: return 0.09184953570365906;
  t153_n108: return 0.10306137055158615;
  t153_n109: if (E.getNumReferences() >= 3326164992 /*12368.0*/) goto t153_n117;
  t153_n110: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t153_n116;
  t153_n111: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t153_n115;
  t153_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n114;
  t153_n113: return 0.08938179165124893;
  t153_n114: return -0.024513965472579002;
  t153_n115: return -0.19632868468761444;
  t153_n116: return 0.1148308590054512;
  t153_n117: return 0.02109580673277378;
  t153_n118: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t153_n124;
  t153_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t153_n121;
  t153_n120: return 0.04588180407881737;
  t153_n121: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t153_n123;
  t153_n122: return 0.12137364596128464;
  t153_n123: return -0.2606065571308136;
  t153_n124: if (E.getNumReferences() >= 3289612288 /*590.0*/) goto t153_n152;
  t153_n125: if (E.getNumReferences() >= 3288858624 /*544.0*/) goto t153_n147;
  t153_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t153_n140;
  t153_n127: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t153_n139;
  t153_n128: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t153_n138;
  t153_n129: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t153_n131;
  t153_n130: return 0.7316809296607971;
  t153_n131: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t153_n137;
  t153_n132: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t153_n134;
  t153_n133: return -0.23861224949359894;
  t153_n134: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t153_n136;
  t153_n135: return 0.1297009438276291;
  t153_n136: return -0.0831298977136612;
  t153_n137: return 0.04733744636178017;
  t153_n138: return 0.11763054877519608;
  t153_n139: return -0.025285862386226654;
  t153_n140: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t153_n146;
  t153_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t153_n145;
  t153_n142: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t153_n144;
  t153_n143: return 0.019812554121017456;
  t153_n144: return 0.11338625848293304;
  t153_n145: return -0.425989031791687;
  t153_n146: return 0.058073677122592926;
  t153_n147: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t153_n149;
  t153_n148: return -0.1187727078795433;
  t153_n149: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t153_n151;
  t153_n150: return 0.12708903849124908;
  t153_n151: return 0.08153201639652252;
  t153_n152: if (E.getNumReferences() >= 3315824640 /*5231.0*/) goto t153_n154;
  t153_n153: return -0.01822534017264843;
  t153_n154: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t153_n156;
  t153_n155: return 0.08638621866703033;
  t153_n156: return 0.024140872061252594;
  t153_n157: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t153_n169;
  t153_n158: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t153_n162;
  t153_n159: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t153_n161;
  t153_n160: return -0.1861540526151657;
  t153_n161: return 0.07245594263076782;
  t153_n162: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t153_n166;
  t153_n163: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n165;
  t153_n164: return 0.10460945218801498;
  t153_n165: return 0.10184139013290405;
  t153_n166: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t153_n168;
  t153_n167: return 0.0417034849524498;
  t153_n168: return 0.09525726735591888;
  t153_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n173;
  t153_n170: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t153_n172;
  t153_n171: return -0.46173715591430664;
  t153_n172: return 0.02902170456945896;
  t153_n173: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n175;
  t153_n174: return -1.4077237844467163;
  t153_n175: return 0.05515073984861374;
  t153_n176: return -0.0344228558242321;
  t153_n177: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t153_n253;
  t153_n178: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t153_n180;
  t153_n179: return 0.010814950801432133;
  t153_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t153_n200;
  t153_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n183;
  t153_n182: return 0.048270221799612045;
  t153_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t153_n185;
  t153_n184: return -0.12443739175796509;
  t153_n185: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t153_n199;
  t153_n186: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t153_n188;
  t153_n187: return -0.036580875515937805;
  t153_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n198;
  t153_n189: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t153_n193;
  t153_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t153_n192;
  t153_n191: return -0.10440681874752045;
  t153_n192: return 0.09679107367992401;
  t153_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t153_n195;
  t153_n194: return 0.05920964851975441;
  t153_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n197;
  t153_n196: return 0.09556830674409866;
  t153_n197: return 0.12153015285730362;
  t153_n198: return 0.026133818551898003;
  t153_n199: return -0.01729894056916237;
  t153_n200: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t153_n242;
  t153_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t153_n237;
  t153_n202: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t153_n214;
  t153_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t153_n205;
  t153_n204: return -0.030463313683867455;
  t153_n205: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t153_n211;
  t153_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n208;
  t153_n207: return -0.08944382518529892;
  t153_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t153_n210;
  t153_n209: return 0.04354771971702576;
  t153_n210: return -0.045583661645650864;
  t153_n211: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n213;
  t153_n212: return 0.11020254343748093;
  t153_n213: return 0.019487470388412476;
  t153_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t153_n222;
  t153_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n217;
  t153_n216: return 0.012735835276544094;
  t153_n217: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t153_n219;
  t153_n218: return 0.02375917322933674;
  t153_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n221;
  t153_n220: return 0.07225016504526138;
  t153_n221: return 0.0026674089021980762;
  t153_n222: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t153_n236;
  t153_n223: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t153_n235;
  t153_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t153_n226;
  t153_n225: return 0.03519134223461151;
  t153_n226: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t153_n234;
  t153_n227: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n231;
  t153_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t153_n230;
  t153_n229: return -0.032761987298727036;
  t153_n230: return 0.03510133922100067;
  t153_n231: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t153_n233;
  t153_n232: return 0.06268712133169174;
  t153_n233: return -0.04645251855254173;
  t153_n234: return 0.11227397620677948;
  t153_n235: return 0.03889278694987297;
  t153_n236: return -0.009243992157280445;
  t153_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t153_n239;
  t153_n238: return -0.11593499034643173;
  t153_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t153_n241;
  t153_n240: return 0.019750505685806274;
  t153_n241: return 0.10316935926675797;
  t153_n242: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t153_n250;
  t153_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t153_n247;
  t153_n244: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t153_n246;
  t153_n245: return 0.09070569276809692;
  t153_n246: return 0.003227023873478174;
  t153_n247: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t153_n249;
  t153_n248: return 0.06933560222387314;
  t153_n249: return 0.11766822636127472;
  t153_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t153_n252;
  t153_n251: return -0.5529073476791382;
  t153_n252: return 0.1113298311829567;
  t153_n253: return -0.002746619749814272;
  t153_n254: return -0.04222463443875313;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree154(const Example& E) {
  t154_n0: if (E.getNumReferences() >= 3324859904 /*11093.5*/) goto t154_n2;
  t154_n1: return -0.0003422457375563681;
  t154_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t154_n38;
  t154_n3: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t154_n37;
  t154_n4: if (E.getNumReferences() >= 3325368832 /*11590.5*/) goto t154_n26;
  t154_n5: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t154_n17;
  t154_n6: if (E.getNumReferences() >= 3325345280 /*11567.5*/) goto t154_n8;
  t154_n7: return -0.0504334457218647;
  t154_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n10;
  t154_n9: return 0.21226470172405243;
  t154_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n14;
  t154_n11: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t154_n13;
  t154_n12: return 0.5644444227218628;
  t154_n13: return -0.10049070417881012;
  t154_n14: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t154_n16;
  t154_n15: return 0.2195654958486557;
  t154_n16: return 0.22135178744792938;
  t154_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t154_n19;
  t154_n18: return 0.09848613291978836;
  t154_n19: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t154_n21;
  t154_n20: return -0.025454536080360413;
  t154_n21: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t154_n25;
  t154_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t154_n24;
  t154_n23: return 0.12529347836971283;
  t154_n24: return 0.036832522600889206;
  t154_n25: return -0.12650705873966217;
  t154_n26: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t154_n28;
  t154_n27: return 0.14005374908447266;
  t154_n28: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t154_n32;
  t154_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t154_n31;
  t154_n30: return -0.22518007457256317;
  t154_n31: return 0.11344866454601288;
  t154_n32: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t154_n36;
  t154_n33: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t154_n35;
  t154_n34: return 0.12576517462730408;
  t154_n35: return 0.17482715845108032;
  t154_n36: return -0.13254745304584503;
  t154_n37: return 0.012894229032099247;
  t154_n38: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t154_n40;
  t154_n39: return -0.035088662058115005;
  t154_n40: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t154_n190;
  t154_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t154_n167;
  t154_n42: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t154_n86;
  t154_n43: if (E.getNumReferences() >= 3345503360 /*59476.5*/) goto t154_n45;
  t154_n44: return -0.0018909018253907561;
  t154_n45: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t154_n69;
  t154_n46: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t154_n52;
  t154_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n51;
  t154_n48: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t154_n50;
  t154_n49: return -0.28015032410621643;
  t154_n50: return -1.5556249618530273;
  t154_n51: return -0.12782278656959534;
  t154_n52: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t154_n68;
  t154_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n61;
  t154_n54: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t154_n56;
  t154_n55: return -0.11156712472438812;
  t154_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t154_n60;
  t154_n57: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t154_n59;
  t154_n58: return -0.10765403509140015;
  t154_n59: return -0.8781079053878784;
  t154_n60: return -0.21484880149364471;
  t154_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t154_n63;
  t154_n62: return -0.236115962266922;
  t154_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n65;
  t154_n64: return -0.37834998965263367;
  t154_n65: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t154_n67;
  t154_n66: return 0.008656633086502552;
  t154_n67: return 0.0718991756439209;
  t154_n68: return 0.11406990885734558;
  t154_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t154_n75;
  t154_n70: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t154_n74;
  t154_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n73;
  t154_n72: return -0.3058127760887146;
  t154_n73: return 0.13526079058647156;
  t154_n74: return -0.026070652529597282;
  t154_n75: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t154_n77;
  t154_n76: return -0.09829973429441452;
  t154_n77: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t154_n85;
  t154_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n84;
  t154_n79: if (E.getNumReferences() >= 3347973248 /*72713.0*/) goto t154_n81;
  t154_n80: return 0.11383714526891708;
  t154_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t154_n83;
  t154_n82: return 0.11543654650449753;
  t154_n83: return 0.004941573832184076;
  t154_n84: return 0.039364833384752274;
  t154_n85: return 0.03454019874334335;
  t154_n86: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t154_n156;
  t154_n87: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t154_n91;
  t154_n88: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t154_n90;
  t154_n89: return 0.12975221872329712;
  t154_n90: return 0.002413001609966159;
  t154_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t154_n129;
  t154_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t154_n94;
  t154_n93: return -0.03083989769220352;
  t154_n94: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t154_n128;
  t154_n95: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t154_n103;
  t154_n96: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t154_n102;
  t154_n97: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t154_n101;
  t154_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n100;
  t154_n99: return 0.1197829470038414;
  t154_n100: return -0.28892722725868225;
  t154_n101: return 0.0005300117773003876;
  t154_n102: return -0.09219199419021606;
  t154_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n105;
  t154_n104: return 0.12632593512535095;
  t154_n105: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t154_n117;
  t154_n106: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t154_n112;
  t154_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n109;
  t154_n108: return 0.9243380427360535;
  t154_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t154_n111;
  t154_n110: return -0.07956624031066895;
  t154_n111: return 0.1325872540473938;
  t154_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n116;
  t154_n113: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t154_n115;
  t154_n114: return 0.2883203327655792;
  t154_n115: return 0.1373268961906433;
  t154_n116: return -0.15104737877845764;
  t154_n117: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t154_n125;
  t154_n118: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t154_n124;
  t154_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n121;
  t154_n120: return -0.20771870017051697;
  t154_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t154_n123;
  t154_n122: return 0.06558860838413239;
  t154_n123: return 0.11837410181760788;
  t154_n124: return 0.05110177397727966;
  t154_n125: if (E.getNumReferences() >= 3345281152 /*58608.5*/) goto t154_n127;
  t154_n126: return -0.1048726961016655;
  t154_n127: return 0.17324738204479218;
  t154_n128: return 0.027537629008293152;
  t154_n129: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t154_n149;
  t154_n130: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t154_n144;
  t154_n131: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t154_n135;
  t154_n132: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n134;
  t154_n133: return 0.09861582517623901;
  t154_n134: return 0.05960221216082573;
  t154_n135: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t154_n141;
  t154_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t154_n140;
  t154_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t154_n139;
  t154_n138: return 0.1424623727798462;
  t154_n139: return -2.308276653289795;
  t154_n140: return 0.11750476807355881;
  t154_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n143;
  t154_n142: return -0.11280437558889389;
  t154_n143: return 0.12173178791999817;
  t154_n144: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t154_n146;
  t154_n145: return -0.1825108379125595;
  t154_n146: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t154_n148;
  t154_n147: return 0.1252879798412323;
  t154_n148: return 0.030467551201581955;
  t154_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t154_n155;
  t154_n150: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t154_n154;
  t154_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t154_n153;
  t154_n152: return -0.14504830539226532;
  t154_n153: return 0.07269041985273361;
  t154_n154: return -0.02424033172428608;
  t154_n155: return 0.10769519954919815;
  t154_n156: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t154_n158;
  t154_n157: return -0.017346076667308807;
  t154_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n166;
  t154_n159: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n165;
  t154_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t154_n164;
  t154_n161: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t154_n163;
  t154_n162: return 0.13060881197452545;
  t154_n163: return 0.12430181354284286;
  t154_n164: return 0.06350294500589371;
  t154_n165: return 0.039082106202840805;
  t154_n166: return 0.057795967906713486;
  t154_n167: if (E.getNumReferences() >= 3348326400 /*75472.0*/) goto t154_n177;
  t154_n168: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t154_n170;
  t154_n169: return -0.06581731885671616;
  t154_n170: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t154_n172;
  t154_n171: return 0.020768875256180763;
  t154_n172: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t154_n174;
  t154_n173: return 0.07377095520496368;
  t154_n174: if (E.getNumReferences() >= 3335077120 /*25758.5*/) goto t154_n176;
  t154_n175: return 0.11605305224657059;
  t154_n176: return 0.04137743264436722;
  t154_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t154_n189;
  t154_n178: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t154_n186;
  t154_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n183;
  t154_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t154_n182;
  t154_n181: return 0.06339897215366364;
  t154_n182: return 0.0964057520031929;
  t154_n183: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t154_n185;
  t154_n184: return 0.10675735771656036;
  t154_n185: return 0.04445425793528557;
  t154_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t154_n188;
  t154_n187: return 0.11198437958955765;
  t154_n188: return 0.0038416674360632896;
  t154_n189: return 0.14275334775447845;
  t154_n190: if (E.getNumReferences() >= 3351094208 /*97095.5*/) goto t154_n198;
  t154_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n197;
  t154_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t154_n194;
  t154_n193: return -0.11953405290842056;
  t154_n194: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t154_n196;
  t154_n195: return 0.09782148897647858;
  t154_n196: return 0.12914535403251648;
  t154_n197: return 0.07290966063737869;
  t154_n198: if (E.getNumReferences() >= 3353301504 /*114340.0*/) goto t154_n254;
  t154_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t154_n253;
  t154_n200: if (E.getNumReferences() >= 3352895680 /*111169.5*/) goto t154_n250;
  t154_n201: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t154_n241;
  t154_n202: if (E.getNumReferences() >= 3352190592 /*105661.0*/) goto t154_n240;
  t154_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t154_n211;
  t154_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t154_n206;
  t154_n205: return 0.017162306234240532;
  t154_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n208;
  t154_n207: return 0.09361385554075241;
  t154_n208: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n210;
  t154_n209: return 0.11976298689842224;
  t154_n210: return 0.048279404640197754;
  t154_n211: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t154_n229;
  t154_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n214;
  t154_n213: return -0.043991684913635254;
  t154_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t154_n226;
  t154_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n217;
  t154_n216: return 0.04168613627552986;
  t154_n217: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t154_n223;
  t154_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n220;
  t154_n219: return 0.09218906611204147;
  t154_n220: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t154_n222;
  t154_n221: return 0.10095103830099106;
  t154_n222: return -0.3644765019416809;
  t154_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t154_n225;
  t154_n224: return 0.05464210733771324;
  t154_n225: return 0.10646592080593109;
  t154_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t154_n228;
  t154_n227: return 0.06421153247356415;
  t154_n228: return 0.1216403916478157;
  t154_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t154_n237;
  t154_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t154_n234;
  t154_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t154_n233;
  t154_n232: return 0.10884034633636475;
  t154_n233: return 0.09762097895145416;
  t154_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t154_n236;
  t154_n235: return -0.24127815663814545;
  t154_n236: return 0.0322609581053257;
  t154_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t154_n239;
  t154_n238: return 0.029218781739473343;
  t154_n239: return 0.09187452495098114;
  t154_n240: return -0.1589706838130951;
  t154_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t154_n243;
  t154_n242: return 0.008729354478418827;
  t154_n243: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t154_n249;
  t154_n244: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t154_n248;
  t154_n245: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t154_n247;
  t154_n246: return 0.04967108368873596;
  t154_n247: return 0.07695050537586212;
  t154_n248: return 0.10303653031587601;
  t154_n249: return 0.026984985917806625;
  t154_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t154_n252;
  t154_n251: return -0.139047309756279;
  t154_n252: return 0.08233904838562012;
  t154_n253: return -0.041073575615882874;
  t154_n254: return 0.007074224296957254;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree155(const Example& E) {
  t155_n0: if (E.getNumReferences() >= 3325298688 /*11522.0*/) goto t155_n6;
  t155_n1: if (E.getNumReferences() >= 3325283328 /*11507.0*/) goto t155_n3;
  t155_n2: return -0.0003330412437207997;
  t155_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t155_n5;
  t155_n4: return -0.23202653229236603;
  t155_n5: return -0.25343114137649536;
  t155_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t155_n252;
  t155_n7: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t155_n27;
  t155_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t155_n16;
  t155_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n11;
  t155_n10: return 0.11172674596309662;
  t155_n11: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t155_n13;
  t155_n12: return 0.12656909227371216;
  t155_n13: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t155_n15;
  t155_n14: return 0.22432604432106018;
  t155_n15: return 0.2184760570526123;
  t155_n16: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t155_n18;
  t155_n17: return 0.13419046998023987;
  t155_n18: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t155_n22;
  t155_n19: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t155_n21;
  t155_n20: return 0.12345612794160843;
  t155_n21: return -0.14485470950603485;
  t155_n22: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t155_n26;
  t155_n23: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t155_n25;
  t155_n24: return 0.1282983422279358;
  t155_n25: return 0.1557273268699646;
  t155_n26: return -0.09640413522720337;
  t155_n27: if (E.getNumReferences() >= 3325608960 /*11825.0*/) goto t155_n33;
  t155_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n30;
  t155_n29: return -0.24158278107643127;
  t155_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n32;
  t155_n31: return -0.19868747889995575;
  t155_n32: return -1.3018455505371094;
  t155_n33: if (E.getNumReferences() >= 3327362048 /*13537.0*/) goto t155_n43;
  t155_n34: if (E.getNumReferences() >= 3327291904 /*13468.5*/) goto t155_n42;
  t155_n35: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t155_n39;
  t155_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n38;
  t155_n37: return 0.05743874981999397;
  t155_n38: return 0.06580660492181778;
  t155_n39: if (E.getNumReferences() >= 3326233600 /*12435.0*/) goto t155_n41;
  t155_n40: return 0.08723106235265732;
  t155_n41: return 0.02345559373497963;
  t155_n42: return 0.24134628474712372;
  t155_n43: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t155_n227;
  t155_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t155_n150;
  t155_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t155_n131;
  t155_n46: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t155_n108;
  t155_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n93;
  t155_n48: if (E.getNumReferences() >= 3350379712 /*91513.5*/) goto t155_n60;
  t155_n49: if (E.getNumReferences() >= 3345303552 /*58696.0*/) goto t155_n55;
  t155_n50: if (E.getNumReferences() >= 3330356992 /*16539.5*/) goto t155_n54;
  t155_n51: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t155_n53;
  t155_n52: return -0.00014906292199157178;
  t155_n53: return 0.1325244903564453;
  t155_n54: return 0.010978915728628635;
  t155_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t155_n59;
  t155_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t155_n58;
  t155_n57: return -0.2368883639574051;
  t155_n58: return 0.06406964361667633;
  t155_n59: return -0.04995829984545708;
  t155_n60: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t155_n66;
  t155_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n65;
  t155_n62: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n64;
  t155_n63: return 0.028117720037698746;
  t155_n64: return 0.11587534099817276;
  t155_n65: return -0.0075022270902991295;
  t155_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t155_n68;
  t155_n67: return -0.5459851622581482;
  t155_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n90;
  t155_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t155_n71;
  t155_n70: return -0.06834609806537628;
  t155_n71: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t155_n89;
  t155_n72: if (E.getNumReferences() >= 3361266432 /*222060.0*/) goto t155_n80;
  t155_n73: if (E.getNumReferences() >= 3357822688 /*168251.5*/) goto t155_n79;
  t155_n74: if (E.getNumReferences() >= 3354093056 /*120524.0*/) goto t155_n78;
  t155_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n77;
  t155_n76: return -0.13183839619159698;
  t155_n77: return 0.06256169825792313;
  t155_n78: return 0.12222506105899811;
  t155_n79: return -0.06443629413843155;
  t155_n80: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t155_n88;
  t155_n81: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n87;
  t155_n82: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t155_n86;
  t155_n83: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t155_n85;
  t155_n84: return 0.08198820799589157;
  t155_n85: return 0.09744373708963394;
  t155_n86: return 0.030194517225027084;
  t155_n87: return 0.07187602669000626;
  t155_n88: return -0.11083336919546127;
  t155_n89: return 0.0129838977009058;
  t155_n90: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t155_n92;
  t155_n91: return -0.05812723934650421;
  t155_n92: return 0.02332879975438118;
  t155_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n107;
  t155_n94: if (E.getNumReferences() >= 3342114944 /*46240.5*/) goto t155_n96;
  t155_n95: return -0.7054423093795776;
  t155_n96: if (E.getNumReferences() >= 3343995264 /*53585.5*/) goto t155_n98;
  t155_n97: return 0.08547365665435791;
  t155_n98: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n104;
  t155_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n103;
  t155_n100: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t155_n102;
  t155_n101: return 0.010487895458936691;
  t155_n102: return 0.07978886365890503;
  t155_n103: return -0.24135588109493256;
  t155_n104: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t155_n106;
  t155_n105: return 0.03500404208898544;
  t155_n106: return -0.7462210059165955;
  t155_n107: return 0.024331659078598022;
  t155_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n112;
  t155_n109: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t155_n111;
  t155_n110: return 0.04415377601981163;
  t155_n111: return 0.016619164496660233;
  t155_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n130;
  t155_n113: if (E.getNumReferences() >= 3331562752 /*18894.5*/) goto t155_n117;
  t155_n114: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t155_n116;
  t155_n115: return -0.2845477759838104;
  t155_n116: return 0.11142422258853912;
  t155_n117: if (E.getNumReferences() >= 3335931904 /*27428.0*/) goto t155_n119;
  t155_n118: return -0.4745120108127594;
  t155_n119: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t155_n129;
  t155_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t155_n122;
  t155_n121: return -0.03373350575566292;
  t155_n122: if (E.getNumReferences() >= 3350379712 /*91513.5*/) goto t155_n128;
  t155_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n127;
  t155_n124: if (E.getNumReferences() >= 3344702080 /*56346.5*/) goto t155_n126;
  t155_n125: return 0.06916764378547668;
  t155_n126: return -0.5226970911026001;
  t155_n127: return 0.10477609187364578;
  t155_n128: return 0.01738252490758896;
  t155_n129: return 0.005186347756534815;
  t155_n130: return 0.029516682028770447;
  t155_n131: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t155_n139;
  t155_n132: if (E.getNumReferences() >= 3339920896 /*37670.0*/) goto t155_n136;
  t155_n133: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t155_n135;
  t155_n134: return -0.0269465409219265;
  t155_n135: return 0.11328831315040588;
  t155_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n138;
  t155_n137: return 0.12710343301296234;
  t155_n138: return 0.13660046458244324;
  t155_n139: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t155_n141;
  t155_n140: return -0.12636719644069672;
  t155_n141: if (E.getNumReferences() >= 3375095784 /*703998.5*/) goto t155_n143;
  t155_n142: return -0.014123070053756237;
  t155_n143: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t155_n147;
  t155_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t155_n146;
  t155_n145: return -0.008401167578995228;
  t155_n146: return 0.07484252005815506;
  t155_n147: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t155_n149;
  t155_n148: return -0.5246198773384094;
  t155_n149: return 0.10684089362621307;
  t155_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t155_n154;
  t155_n151: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n153;
  t155_n152: return 0.0225723497569561;
  t155_n153: return -0.10437928885221481;
  t155_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n200;
  t155_n155: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n183;
  t155_n156: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t155_n162;
  t155_n157: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t155_n159;
  t155_n158: return 0.02231159433722496;
  t155_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n161;
  t155_n160: return 0.13464674353599548;
  t155_n161: return 0.05604084953665733;
  t155_n162: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t155_n182;
  t155_n163: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t155_n175;
  t155_n164: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t155_n174;
  t155_n165: if (E.getNumReferences() >= 3333474560 /*22628.5*/) goto t155_n167;
  t155_n166: return -0.2443690150976181;
  t155_n167: if (E.getNumReferences() >= 3333914624 /*23488.0*/) goto t155_n173;
  t155_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t155_n172;
  t155_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n171;
  t155_n170: return 0.10711049288511276;
  t155_n171: return 0.09626752883195877;
  t155_n172: return -0.38257917761802673;
  t155_n173: return -0.10935736447572708;
  t155_n174: return -0.04660148173570633;
  t155_n175: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t155_n181;
  t155_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n178;
  t155_n177: return 0.1411653757095337;
  t155_n178: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t155_n180;
  t155_n179: return 0.12912549078464508;
  t155_n180: return 0.07467158883810043;
  t155_n181: return 0.21603921055793762;
  t155_n182: return -0.16406622529029846;
  t155_n183: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t155_n189;
  t155_n184: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t155_n186;
  t155_n185: return 0.05479435622692108;
  t155_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n188;
  t155_n187: return -0.2327219545841217;
  t155_n188: return 0.011266162618994713;
  t155_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t155_n191;
  t155_n190: return 0.001503068022429943;
  t155_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n195;
  t155_n192: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t155_n194;
  t155_n193: return 0.11144907772541046;
  t155_n194: return 0.08266358822584152;
  t155_n195: if (E.getNumReferences() >= 3334472192 /*24577.0*/) goto t155_n197;
  t155_n196: return 0.1021115779876709;
  t155_n197: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t155_n199;
  t155_n198: return 0.06082385033369064;
  t155_n199: return -2.127861499786377;
  t155_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n214;
  t155_n201: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t155_n209;
  t155_n202: if (E.getNumReferences() >= 3340429568 /*39657.0*/) goto t155_n204;
  t155_n203: return 0.015466378070414066;
  t155_n204: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t155_n206;
  t155_n205: return -1.5054376125335693;
  t155_n206: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t155_n208;
  t155_n207: return 0.1104530617594719;
  t155_n208: return 0.06445584446191788;
  t155_n209: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t155_n211;
  t155_n210: return -0.1427246481180191;
  t155_n211: if (E.getNumReferences() >= 3348676224 /*78205.0*/) goto t155_n213;
  t155_n212: return 0.11815992742776871;
  t155_n213: return 0.1184781864285469;
  t155_n214: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t155_n216;
  t155_n215: return -0.17375685274600983;
  t155_n216: if (E.getNumReferences() >= 3337305088 /*30110.0*/) goto t155_n226;
  t155_n217: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t155_n223;
  t155_n218: if (E.getNumReferences() >= 3332673792 /*21064.5*/) goto t155_n222;
  t155_n219: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t155_n221;
  t155_n220: return 0.07520441710948944;
  t155_n221: return 0.1754007190465927;
  t155_n222: return -0.01732534170150757;
  t155_n223: if (E.getNumReferences() >= 3334637824 /*24900.5*/) goto t155_n225;
  t155_n224: return 0.11121047288179398;
  t155_n225: return 0.11557430028915405;
  t155_n226: return 0.03785169869661331;
  t155_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t155_n247;
  t155_n228: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t155_n232;
  t155_n229: if (E.getNumReferences() >= 3352510912 /*108163.5*/) goto t155_n231;
  t155_n230: return 0.017004378139972687;
  t155_n231: return -0.11832188069820404;
  t155_n232: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t155_n238;
  t155_n233: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n237;
  t155_n234: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t155_n236;
  t155_n235: return 0.09112371504306793;
  t155_n236: return -0.10950817912817001;
  t155_n237: return -0.043492481112480164;
  t155_n238: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t155_n240;
  t155_n239: return 0.005724979564547539;
  t155_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n246;
  t155_n241: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t155_n245;
  t155_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t155_n244;
  t155_n243: return 0.008154316805303097;
  t155_n244: return 0.06893700361251831;
  t155_n245: return -0.009778168052434921;
  t155_n246: return -0.006715776864439249;
  t155_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n251;
  t155_n248: if (E.getNumReferences() >= 3340297728 /*39142.0*/) goto t155_n250;
  t155_n249: return -0.050526831299066544;
  t155_n250: return -0.17278237640857697;
  t155_n251: return 0.0065261004492640495;
  t155_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t155_n254;
  t155_n253: return -0.03167520463466644;
  t155_n254: return 0.00686180405318737;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree156(const Example& E) {
  t156_n0: if (E.getNumReferences() >= 3324859904 /*11093.5*/) goto t156_n228;
  t156_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t156_n227;
  t156_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t156_n4;
  t156_n3: return -0.005552796181291342;
  t156_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t156_n76;
  t156_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t156_n75;
  t156_n6: if (E.getNumReferences() >= 3283861504 /*375.5*/) goto t156_n60;
  t156_n7: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n51;
  t156_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n30;
  t156_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t156_n17;
  t156_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t156_n16;
  t156_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t156_n13;
  t156_n12: return 0.017789077013731003;
  t156_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t156_n15;
  t156_n14: return 0.08791683614253998;
  t156_n15: return 0.07238683849573135;
  t156_n16: return 0.0038625579327344894;
  t156_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t156_n21;
  t156_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n20;
  t156_n19: return -0.024260535836219788;
  t156_n20: return 0.0536654032766819;
  t156_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t156_n23;
  t156_n22: return 0.023978229612112045;
  t156_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t156_n29;
  t156_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t156_n26;
  t156_n25: return -0.1332639455795288;
  t156_n26: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t156_n28;
  t156_n27: return 0.1214442104101181;
  t156_n28: return -0.10988786816596985;
  t156_n29: return 0.041254691779613495;
  t156_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n34;
  t156_n31: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t156_n33;
  t156_n32: return -0.01312321051955223;
  t156_n33: return -0.06932412832975388;
  t156_n34: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t156_n38;
  t156_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t156_n37;
  t156_n36: return 0.023332640528678894;
  t156_n37: return 0.046047888696193695;
  t156_n38: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t156_n44;
  t156_n39: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t156_n43;
  t156_n40: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t156_n42;
  t156_n41: return -0.07269974052906036;
  t156_n42: return 0.06326833367347717;
  t156_n43: return 0.04305731877684593;
  t156_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t156_n48;
  t156_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t156_n47;
  t156_n46: return 0.024049928411841393;
  t156_n47: return 0.10391316562891006;
  t156_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t156_n50;
  t156_n49: return 0.0878247618675232;
  t156_n50: return 0.1269710659980774;
  t156_n51: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t156_n53;
  t156_n52: return 0.01690100133419037;
  t156_n53: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t156_n59;
  t156_n54: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t156_n58;
  t156_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n57;
  t156_n56: return -0.14970561861991882;
  t156_n57: return -0.014227651059627533;
  t156_n58: return -0.05118589848279953;
  t156_n59: return 0.008535105735063553;
  t156_n60: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t156_n74;
  t156_n61: if (E.getNumReferences() >= 3288457216 /*519.5*/) goto t156_n73;
  t156_n62: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t156_n70;
  t156_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t156_n69;
  t156_n64: if (E.getNumReferences() >= 3284058112 /*381.5*/) goto t156_n68;
  t156_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t156_n67;
  t156_n66: return 0.08631989359855652;
  t156_n67: return 0.13742434978485107;
  t156_n68: return 0.05274845287203789;
  t156_n69: return 0.08533699065446854;
  t156_n70: if (E.getNumReferences() >= 3288236032 /*509.0*/) goto t156_n72;
  t156_n71: return 0.10811144858598709;
  t156_n72: return -0.11774814128875732;
  t156_n73: return 0.12258698791265488;
  t156_n74: return 0.009981204755604267;
  t156_n75: return 0.008343472145497799;
  t156_n76: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t156_n124;
  t156_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t156_n79;
  t156_n78: return -0.0048340498469769955;
  t156_n79: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t156_n113;
  t156_n80: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t156_n90;
  t156_n81: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t156_n85;
  t156_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t156_n84;
  t156_n83: return 0.007744315080344677;
  t156_n84: return 0.06582196801900864;
  t156_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t156_n87;
  t156_n86: return 0.04999323561787605;
  t156_n87: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n89;
  t156_n88: return 0.11479201167821884;
  t156_n89: return 0.1142367497086525;
  t156_n90: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n92;
  t156_n91: return -0.05252506583929062;
  t156_n92: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n112;
  t156_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t156_n95;
  t156_n94: return 0.003417085623368621;
  t156_n95: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t156_n97;
  t156_n96: return 0.020829053595662117;
  t156_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t156_n111;
  t156_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n100;
  t156_n99: return -0.0038994878996163607;
  t156_n100: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t156_n110;
  t156_n101: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t156_n109;
  t156_n102: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t156_n108;
  t156_n103: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t156_n105;
  t156_n104: return 0.07249993830919266;
  t156_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t156_n107;
  t156_n106: return 0.12228699028491974;
  t156_n107: return 0.15423986315727234;
  t156_n108: return 0.10629996657371521;
  t156_n109: return -0.16148824989795685;
  t156_n110: return -0.4671109616756439;
  t156_n111: return 0.012438582256436348;
  t156_n112: return -0.08509902656078339;
  t156_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t156_n117;
  t156_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t156_n116;
  t156_n115: return 0.033611960709095;
  t156_n116: return 0.10320616513490677;
  t156_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t156_n123;
  t156_n118: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t156_n122;
  t156_n119: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t156_n121;
  t156_n120: return 0.10456226021051407;
  t156_n121: return 0.031099602580070496;
  t156_n122: return 0.10898584127426147;
  t156_n123: return 0.10960734635591507;
  t156_n124: if (E.getNumReferences() >= 3324251648 /*10499.5*/) goto t156_n222;
  t156_n125: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t156_n155;
  t156_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t156_n128;
  t156_n127: return -0.04557258263230324;
  t156_n128: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t156_n146;
  t156_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t156_n131;
  t156_n130: return 0.003134980332106352;
  t156_n131: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t156_n145;
  t156_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t156_n144;
  t156_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t156_n135;
  t156_n134: return 0.08929223567247391;
  t156_n135: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t156_n141;
  t156_n136: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t156_n138;
  t156_n137: return -0.1681215912103653;
  t156_n138: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n140;
  t156_n139: return 0.13766540586948395;
  t156_n140: return 0.0;
  t156_n141: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n143;
  t156_n142: return 0.11644511669874191;
  t156_n143: return 0.12222080677747726;
  t156_n144: return 0.03498181328177452;
  t156_n145: return 0.026985757052898407;
  t156_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n152;
  t156_n147: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t156_n151;
  t156_n148: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t156_n150;
  t156_n149: return -0.00386019516736269;
  t156_n150: return 0.11790043115615845;
  t156_n151: return -0.13109032809734344;
  t156_n152: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n154;
  t156_n153: return -0.019168823957443237;
  t156_n154: return 0.015078745782375336;
  t156_n155: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t156_n221;
  t156_n156: if (E.getNumReferences() >= 3273293824 /*154.5*/) goto t156_n184;
  t156_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t156_n161;
  t156_n158: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n160;
  t156_n159: return -0.005714272148907185;
  t156_n160: return 0.05096711590886116;
  t156_n161: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t156_n179;
  t156_n162: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t156_n178;
  t156_n163: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t156_n173;
  t156_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t156_n166;
  t156_n165: return -0.19220420718193054;
  t156_n166: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t156_n170;
  t156_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t156_n169;
  t156_n168: return -0.19549110531806946;
  t156_n169: return 0.13584163784980774;
  t156_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t156_n172;
  t156_n171: return 0.9363875985145569;
  t156_n172: return 0.13397227227687836;
  t156_n173: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t156_n175;
  t156_n174: return 0.06541800498962402;
  t156_n175: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t156_n177;
  t156_n176: return 0.138191357254982;
  t156_n177: return -0.5343223214149475;
  t156_n178: return 0.017307115718722343;
  t156_n179: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t156_n183;
  t156_n180: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t156_n182;
  t156_n181: return 0.10959312319755554;
  t156_n182: return 0.1259302794933319;
  t156_n183: return 0.06782951205968857;
  t156_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t156_n194;
  t156_n185: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t156_n193;
  t156_n186: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t156_n190;
  t156_n187: if (E.getNumReferences() >= 3274768384 /*177.0*/) goto t156_n189;
  t156_n188: return 0.09188767522573471;
  t156_n189: return 0.12008485198020935;
  t156_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t156_n192;
  t156_n191: return 0.13421562314033508;
  t156_n192: return 0.0995500385761261;
  t156_n193: return 0.0447038859128952;
  t156_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t156_n206;
  t156_n195: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t156_n203;
  t156_n196: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t156_n198;
  t156_n197: return 0.11889012157917023;
  t156_n198: if (E.getNumReferences() >= 3289251840 /*568.0*/) goto t156_n200;
  t156_n199: return -0.013077364303171635;
  t156_n200: if (E.getNumReferences() >= 3292078080 /*740.5*/) goto t156_n202;
  t156_n201: return 0.12673412263393402;
  t156_n202: return 0.04245030879974365;
  t156_n203: if (E.getNumReferences() >= 3317816320 /*6203.5*/) goto t156_n205;
  t156_n204: return 0.007561078295111656;
  t156_n205: return 0.18802718818187714;
  t156_n206: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t156_n210;
  t156_n207: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t156_n209;
  t156_n208: return 0.05956302583217621;
  t156_n209: return 0.1226508840918541;
  t156_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t156_n212;
  t156_n211: return -0.02531658113002777;
  t156_n212: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t156_n216;
  t156_n213: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t156_n215;
  t156_n214: return 0.11402322351932526;
  t156_n215: return 0.09803783893585205;
  t156_n216: if (E.getNumReferences() >= 3295846400 /*970.5*/) goto t156_n220;
  t156_n217: if (E.getNumReferences() >= 3289186304 /*564.0*/) goto t156_n219;
  t156_n218: return 0.08803922683000565;
  t156_n219: return 0.12427526712417603;
  t156_n220: return -0.0840868428349495;
  t156_n221: return 0.024280255660414696;
  t156_n222: if (E.getNumReferences() >= 3324598784 /*10838.5*/) goto t156_n226;
  t156_n223: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t156_n225;
  t156_n224: return 0.07901525497436523;
  t156_n225: return 0.11872357130050659;
  t156_n226: return -0.003041925374418497;
  t156_n227: return -0.001269607339054346;
  t156_n228: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t156_n254;
  t156_n229: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t156_n253;
  t156_n230: if (E.getNumReferences() >= 3325368832 /*11590.5*/) goto t156_n242;
  t156_n231: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t156_n233;
  t156_n232: return 0.0009377501555718482;
  t156_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t156_n235;
  t156_n234: return 0.07862545549869537;
  t156_n235: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t156_n237;
  t156_n236: return -0.029398512095212936;
  t156_n237: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t156_n241;
  t156_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t156_n240;
  t156_n239: return 0.12216775119304657;
  t156_n240: return 0.03418388217687607;
  t156_n241: return -0.0844343975186348;
  t156_n242: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t156_n244;
  t156_n243: return 0.13050450384616852;
  t156_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t156_n248;
  t156_n245: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t156_n247;
  t156_n246: return -0.1437915861606598;
  t156_n247: return 0.11156976968050003;
  t156_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t156_n252;
  t156_n249: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t156_n251;
  t156_n250: return 0.11470102518796921;
  t156_n251: return 0.1383165717124939;
  t156_n252: return -0.09092380106449127;
  t156_n253: return 0.013344258069992065;
  t156_n254: return 0.0024742460809648037;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree157(const Example& E) {
  t157_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t157_n2;
  t157_n1: return -0.0002466138103045523;
  t157_n2: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t157_n4;
  t157_n3: return -0.0025398179423063993;
  t157_n4: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t157_n254;
  t157_n5: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t157_n239;
  t157_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t157_n226;
  t157_n7: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t157_n23;
  t157_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n12;
  t157_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t157_n11;
  t157_n10: return -0.05168524757027626;
  t157_n11: return 0.1393503099679947;
  t157_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t157_n16;
  t157_n13: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t157_n15;
  t157_n14: return -0.40740928053855896;
  t157_n15: return 0.09606412798166275;
  t157_n16: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t157_n22;
  t157_n17: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t157_n21;
  t157_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t157_n20;
  t157_n19: return 0.0941065177321434;
  t157_n20: return 0.11023303866386414;
  t157_n21: return 0.08430939167737961;
  t157_n22: return 0.09972691535949707;
  t157_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t157_n197;
  t157_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t157_n26;
  t157_n25: return 0.005798644851893187;
  t157_n26: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t157_n196;
  t157_n27: if (E.getNumReferences() >= 3347793152 /*71306.0*/) goto t157_n53;
  t157_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n32;
  t157_n29: if (E.getNumReferences() >= 3345100032 /*57901.0*/) goto t157_n31;
  t157_n30: return 0.023216376081109047;
  t157_n31: return -0.07635632157325745;
  t157_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n40;
  t157_n33: if (E.getNumReferences() >= 3346274176 /*62487.5*/) goto t157_n39;
  t157_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t157_n36;
  t157_n35: return 0.011665822938084602;
  t157_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n38;
  t157_n37: return 0.10824767500162125;
  t157_n38: return 0.01616464927792549;
  t157_n39: return -0.4237585663795471;
  t157_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t157_n46;
  t157_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t157_n43;
  t157_n42: return -0.09177832305431366;
  t157_n43: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t157_n45;
  t157_n44: return 0.0411396287381649;
  t157_n45: return 0.10886294394731522;
  t157_n46: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t157_n50;
  t157_n47: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n49;
  t157_n48: return -0.39328038692474365;
  t157_n49: return 0.06429648399353027;
  t157_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n52;
  t157_n51: return 0.10836706310510635;
  t157_n52: return 0.1645406186580658;
  t157_n53: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t157_n181;
  t157_n54: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t157_n90;
  t157_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t157_n81;
  t157_n56: if (E.getNumReferences() >= 3347977280 /*72744.5*/) goto t157_n70;
  t157_n57: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t157_n65;
  t157_n58: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n60;
  t157_n59: return 0.04326950013637543;
  t157_n60: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n64;
  t157_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n63;
  t157_n62: return 0.07442689687013626;
  t157_n63: return 0.12703253328800201;
  t157_n64: return 0.015934649854898453;
  t157_n65: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t157_n69;
  t157_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n68;
  t157_n67: return 0.11703670024871826;
  t157_n68: return -0.07977654784917831;
  t157_n69: return -0.6243160367012024;
  t157_n70: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t157_n76;
  t157_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n75;
  t157_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t157_n74;
  t157_n73: return -0.19009266793727875;
  t157_n74: return -0.08339157700538635;
  t157_n75: return -0.011329744942486286;
  t157_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n80;
  t157_n77: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t157_n79;
  t157_n78: return 0.09299493581056595;
  t157_n79: return -0.44664159417152405;
  t157_n80: return 0.008733956143260002;
  t157_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t157_n85;
  t157_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n84;
  t157_n83: return -0.3264982998371124;
  t157_n84: return 0.057274747639894485;
  t157_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n87;
  t157_n86: return 0.08150310814380646;
  t157_n87: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t157_n89;
  t157_n88: return 0.08025246858596802;
  t157_n89: return -0.02631865069270134;
  t157_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t157_n92;
  t157_n91: return -0.014267508871853352;
  t157_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t157_n148;
  t157_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n147;
  t157_n94: if (E.getNumReferences() >= 3349201152 /*82306.0*/) goto t157_n96;
  t157_n95: return -0.08404125273227692;
  t157_n96: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t157_n112;
  t157_n97: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t157_n105;
  t157_n98: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n104;
  t157_n99: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n101;
  t157_n100: return 0.07270923256874084;
  t157_n101: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n103;
  t157_n102: return -0.38584017753601074;
  t157_n103: return 0.12801839411258698;
  t157_n104: return -0.21039976179599762;
  t157_n105: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t157_n111;
  t157_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n110;
  t157_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n109;
  t157_n108: return 0.11314805597066879;
  t157_n109: return 0.07833459228277206;
  t157_n110: return -0.05972333997488022;
  t157_n111: return -0.2661004364490509;
  t157_n112: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t157_n114;
  t157_n113: return -0.06514474749565125;
  t157_n114: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t157_n122;
  t157_n115: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n121;
  t157_n116: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n118;
  t157_n117: return 0.11337333172559738;
  t157_n118: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n120;
  t157_n119: return 0.0876610204577446;
  t157_n120: return -0.4485947787761688;
  t157_n121: return -0.4606752097606659;
  t157_n122: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t157_n126;
  t157_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t157_n125;
  t157_n124: return 0.013615940697491169;
  t157_n125: return -0.48529571294784546;
  t157_n126: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t157_n138;
  t157_n127: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n131;
  t157_n128: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n130;
  t157_n129: return 0.04575599357485771;
  t157_n130: return -0.29032522439956665;
  t157_n131: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n133;
  t157_n132: return 0.02356593869626522;
  t157_n133: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t157_n135;
  t157_n134: return 0.1206127405166626;
  t157_n135: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n137;
  t157_n136: return -0.29967087507247925;
  t157_n137: return 0.1461525708436966;
  t157_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n144;
  t157_n139: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t157_n141;
  t157_n140: return -0.43004199862480164;
  t157_n141: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n143;
  t157_n142: return -0.011030280031263828;
  t157_n143: return 0.06010096147656441;
  t157_n144: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t157_n146;
  t157_n145: return 0.08946111053228378;
  t157_n146: return -0.030094144865870476;
  t157_n147: return 0.01087587233632803;
  t157_n148: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t157_n150;
  t157_n149: return -0.0012449530186131597;
  t157_n150: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t157_n170;
  t157_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t157_n153;
  t157_n152: return 0.003769572591409087;
  t157_n153: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t157_n161;
  t157_n154: if (E.getNumReferences() >= 3354093056 /*120524.0*/) goto t157_n160;
  t157_n155: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t157_n157;
  t157_n156: return 0.0969560518860817;
  t157_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n159;
  t157_n158: return 0.09167060256004333;
  t157_n159: return -0.1597493290901184;
  t157_n160: return 0.04233735054731369;
  t157_n161: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t157_n163;
  t157_n162: return 0.0031390362419188023;
  t157_n163: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t157_n169;
  t157_n164: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n166;
  t157_n165: return 0.0710136741399765;
  t157_n166: if (E.getNumReferences() >= 3351432768 /*99740.5*/) goto t157_n168;
  t157_n167: return 0.10207060724496841;
  t157_n168: return 0.0876091942191124;
  t157_n169: return -0.0013569432776421309;
  t157_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n180;
  t157_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t157_n175;
  t157_n172: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t157_n174;
  t157_n173: return 0.07588789612054825;
  t157_n174: return 0.10406672209501266;
  t157_n175: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n179;
  t157_n176: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n178;
  t157_n177: return 0.089818574488163;
  t157_n178: return -0.18036283552646637;
  t157_n179: return -0.07902860641479492;
  t157_n180: return -0.08150537312030792;
  t157_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t157_n183;
  t157_n182: return -0.08756411820650101;
  t157_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n191;
  t157_n184: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t157_n190;
  t157_n185: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t157_n187;
  t157_n186: return 0.05532050132751465;
  t157_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n189;
  t157_n188: return 0.10757867991924286;
  t157_n189: return -0.013711209408938885;
  t157_n190: return -0.06971310824155807;
  t157_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t157_n195;
  t157_n192: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t157_n194;
  t157_n193: return 0.05907810851931572;
  t157_n194: return 0.11656423658132553;
  t157_n195: return 0.044267598539590836;
  t157_n196: return 0.004162628669291735;
  t157_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t157_n221;
  t157_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t157_n200;
  t157_n199: return -0.15974360704421997;
  t157_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t157_n202;
  t157_n201: return -0.013157675042748451;
  t157_n202: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t157_n210;
  t157_n203: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t157_n205;
  t157_n204: return 0.030245177447795868;
  t157_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t157_n209;
  t157_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n208;
  t157_n207: return 0.12613674998283386;
  t157_n208: return 0.02703837864100933;
  t157_n209: return -0.04237862676382065;
  t157_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n214;
  t157_n211: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t157_n213;
  t157_n212: return 0.17940424382686615;
  t157_n213: return 1.1408016681671143;
  t157_n214: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t157_n220;
  t157_n215: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t157_n219;
  t157_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t157_n218;
  t157_n217: return 0.1132163479924202;
  t157_n218: return 0.10794047266244888;
  t157_n219: return 0.10611958801746368;
  t157_n220: return -0.06057348847389221;
  t157_n221: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t157_n223;
  t157_n222: return -0.16978394985198975;
  t157_n223: if (E.getNumReferences() >= 3351281600 /*98559.5*/) goto t157_n225;
  t157_n224: return 0.14096508920192719;
  t157_n225: return -1.833134651184082;
  t157_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t157_n230;
  t157_n227: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t157_n229;
  t157_n228: return -0.11403415352106094;
  t157_n229: return 0.0432048961520195;
  t157_n230: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t157_n238;
  t157_n231: if (E.getNumReferences() >= 3347630656 /*70036.5*/) goto t157_n233;
  t157_n232: return -0.0016305531607940793;
  t157_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t157_n237;
  t157_n234: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n236;
  t157_n235: return 0.09844758361577988;
  t157_n236: return 0.0786212906241417;
  t157_n237: return -0.019044851884245872;
  t157_n238: return -0.04348129406571388;
  t157_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t157_n249;
  t157_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t157_n242;
  t157_n241: return 0.05863901227712631;
  t157_n242: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t157_n244;
  t157_n243: return -0.01749468222260475;
  t157_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t157_n246;
  t157_n245: return 0.23249773681163788;
  t157_n246: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t157_n248;
  t157_n247: return 0.11619853973388672;
  t157_n248: return -0.32880133390426636;
  t157_n249: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t157_n253;
  t157_n250: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t157_n252;
  t157_n251: return 0.04392160102725029;
  t157_n252: return 0.12205256521701813;
  t157_n253: return -0.07525356858968735;
  t157_n254: return -0.0020418744534254074;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree158(const Example& E) {
  t158_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t158_n208;
  t158_n1: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t158_n79;
  t158_n2: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t158_n4;
  t158_n3: return -0.00035648667835630476;
  t158_n4: if (E.getNumReferences() >= 3340908032 /*41526.0*/) goto t158_n78;
  t158_n5: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t158_n77;
  t158_n6: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t158_n8;
  t158_n7: return 0.009544510394334793;
  t158_n8: if (E.getNumReferences() >= 3289636864 /*591.5*/) goto t158_n66;
  t158_n9: if (E.getNumReferences() >= 3289464832 /*581.0*/) goto t158_n65;
  t158_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t158_n48;
  t158_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t158_n15;
  t158_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n14;
  t158_n13: return 0.04592522978782654;
  t158_n14: return -0.15205015242099762;
  t158_n15: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t158_n47;
  t158_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t158_n18;
  t158_n17: return 0.019671443849802017;
  t158_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t158_n22;
  t158_n19: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t158_n21;
  t158_n20: return -0.30163875222206116;
  t158_n21: return 0.08212631940841675;
  t158_n22: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t158_n30;
  t158_n23: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t158_n25;
  t158_n24: return 0.10540393739938736;
  t158_n25: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t158_n29;
  t158_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t158_n28;
  t158_n27: return 0.12254425883293152;
  t158_n28: return 0.12174694985151291;
  t158_n29: return -0.10167069733142853;
  t158_n30: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t158_n44;
  t158_n31: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t158_n33;
  t158_n32: return 0.06099971383810043;
  t158_n33: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t158_n43;
  t158_n34: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t158_n42;
  t158_n35: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n39;
  t158_n36: if (E.getNumReferences() >= 3278471168 /*233.5*/) goto t158_n38;
  t158_n37: return 0.13999754190444946;
  t158_n38: return 0.5642324686050415;
  t158_n39: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t158_n41;
  t158_n40: return 0.1685699224472046;
  t158_n41: return -0.08285011351108551;
  t158_n42: return 0.133170023560524;
  t158_n43: return 0.08627977967262268;
  t158_n44: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t158_n46;
  t158_n45: return 0.1500425636768341;
  t158_n46: return 0.046097803860902786;
  t158_n47: return -0.009978316724300385;
  t158_n48: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t158_n50;
  t158_n49: return 0.015061372891068459;
  t158_n50: if (E.getNumReferences() >= 3288858624 /*544.0*/) goto t158_n60;
  t158_n51: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t158_n59;
  t158_n52: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t158_n56;
  t158_n53: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t158_n55;
  t158_n54: return 0.08049249649047852;
  t158_n55: return 0.00534998020157218;
  t158_n56: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t158_n58;
  t158_n57: return 0.11289763450622559;
  t158_n58: return 0.10400954633951187;
  t158_n59: return 0.008286927826702595;
  t158_n60: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t158_n62;
  t158_n61: return -0.11500470340251923;
  t158_n62: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t158_n64;
  t158_n63: return 0.1262802928686142;
  t158_n64: return 0.08267518877983093;
  t158_n65: return 0.11537221819162369;
  t158_n66: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t158_n68;
  t158_n67: return 0.11253779381513596;
  t158_n68: if (E.getNumReferences() >= 3299790848 /*1398.5*/) goto t158_n70;
  t158_n69: return -0.03488094359636307;
  t158_n70: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n72;
  t158_n71: return 0.0013766457559540868;
  t158_n72: if (E.getNumReferences() >= 3315990528 /*5312.0*/) goto t158_n74;
  t158_n73: return 0.0175852719694376;
  t158_n74: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t158_n76;
  t158_n75: return 0.07702048122882843;
  t158_n76: return 0.034789856523275375;
  t158_n77: return -0.0002953008806798607;
  t158_n78: return -0.5362163186073303;
  t158_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t158_n91;
  t158_n80: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t158_n82;
  t158_n81: return -0.15608975291252136;
  t158_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t158_n84;
  t158_n83: return 0.019410336390137672;
  t158_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t158_n86;
  t158_n85: return -0.024419859051704407;
  t158_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t158_n90;
  t158_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n89;
  t158_n88: return 0.22639475762844086;
  t158_n89: return -0.020116442814469337;
  t158_n90: return -0.0102829085662961;
  t158_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t158_n199;
  t158_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t158_n102;
  t158_n93: if (E.getNumReferences() >= 3291856896 /*727.0*/) goto t158_n99;
  t158_n94: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t158_n96;
  t158_n95: return 0.03855625540018082;
  t158_n96: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t158_n98;
  t158_n97: return -0.059553228318691254;
  t158_n98: return -0.3675500452518463;
  t158_n99: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t158_n101;
  t158_n100: return -0.29857102036476135;
  t158_n101: return -0.17165932059288025;
  t158_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t158_n110;
  t158_n103: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t158_n109;
  t158_n104: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t158_n106;
  t158_n105: return -0.16202597320079803;
  t158_n106: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t158_n108;
  t158_n107: return 0.09935779124498367;
  t158_n108: return -0.1265937238931656;
  t158_n109: return 0.04868816211819649;
  t158_n110: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t158_n188;
  t158_n111: if (E.getNumReferences() >= 3264217088 /*72.0*/) goto t158_n181;
  t158_n112: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t158_n170;
  t158_n113: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t158_n139;
  t158_n114: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t158_n138;
  t158_n115: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t158_n131;
  t158_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t158_n118;
  t158_n117: return 0.07566077262163162;
  t158_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t158_n130;
  t158_n119: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t158_n129;
  t158_n120: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t158_n128;
  t158_n121: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t158_n125;
  t158_n122: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t158_n124;
  t158_n123: return 0.06018225476145744;
  t158_n124: return -0.034492671489715576;
  t158_n125: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n127;
  t158_n126: return 0.0293938796967268;
  t158_n127: return 0.12606583535671234;
  t158_n128: return -0.2494651824235916;
  t158_n129: return 0.10039737820625305;
  t158_n130: return -0.662981390953064;
  t158_n131: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t158_n135;
  t158_n132: if (E.getNumReferences() >= 3246915584 /*17.0*/) goto t158_n134;
  t158_n133: return 0.03832906112074852;
  t158_n134: return 0.1428592950105667;
  t158_n135: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t158_n137;
  t158_n136: return 0.12506750226020813;
  t158_n137: return 0.04588301479816437;
  t158_n138: return 0.14537672698497772;
  t158_n139: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t158_n141;
  t158_n140: return -0.006706829182803631;
  t158_n141: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t158_n143;
  t158_n142: return 0.669197142124176;
  t158_n143: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t158_n147;
  t158_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t158_n146;
  t158_n145: return -0.03434215486049652;
  t158_n146: return 0.13845902681350708;
  t158_n147: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t158_n153;
  t158_n148: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t158_n152;
  t158_n149: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t158_n151;
  t158_n150: return 0.12189557403326035;
  t158_n151: return 0.07524333149194717;
  t158_n152: return -0.23501840233802795;
  t158_n153: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t158_n169;
  t158_n154: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t158_n156;
  t158_n155: return -0.06590747833251953;
  t158_n156: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t158_n168;
  t158_n157: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t158_n167;
  t158_n158: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t158_n160;
  t158_n159: return 0.0870530977845192;
  t158_n160: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t158_n164;
  t158_n161: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t158_n163;
  t158_n162: return 0.11753223091363907;
  t158_n163: return 0.04627035930752754;
  t158_n164: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t158_n166;
  t158_n165: return 0.026731250807642937;
  t158_n166: return 0.12981484830379486;
  t158_n167: return 0.11002780497074127;
  t158_n168: return 0.027923094108700752;
  t158_n169: return 0.0034657653886824846;
  t158_n170: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t158_n172;
  t158_n171: return 0.13397173583507538;
  t158_n172: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t158_n180;
  t158_n173: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t158_n179;
  t158_n174: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t158_n176;
  t158_n175: return 0.10126297920942307;
  t158_n176: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t158_n178;
  t158_n177: return -0.2043817788362503;
  t158_n178: return 0.2255645990371704;
  t158_n179: return 0.10180168598890305;
  t158_n180: return 0.014787736348807812;
  t158_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t158_n185;
  t158_n182: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t158_n184;
  t158_n183: return 0.11420705914497375;
  t158_n184: return -0.21410049498081207;
  t158_n185: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t158_n187;
  t158_n186: return -0.005429810844361782;
  t158_n187: return -0.08292075991630554;
  t158_n188: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t158_n190;
  t158_n189: return -0.028274888172745705;
  t158_n190: if (E.getNumReferences() >= 3272802304 /*147.0*/) goto t158_n194;
  t158_n191: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t158_n193;
  t158_n192: return 0.16301122307777405;
  t158_n193: return 0.12181181460618973;
  t158_n194: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t158_n198;
  t158_n195: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t158_n197;
  t158_n196: return -0.13364830613136292;
  t158_n197: return 0.1029631569981575;
  t158_n198: return 0.06702594459056854;
  t158_n199: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t158_n201;
  t158_n200: return -0.08063758909702301;
  t158_n201: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t158_n205;
  t158_n202: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t158_n204;
  t158_n203: return 0.05667217820882797;
  t158_n204: return -0.03712747246026993;
  t158_n205: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t158_n207;
  t158_n206: return -0.022785449400544167;
  t158_n207: return 0.21868695318698883;
  t158_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t158_n210;
  t158_n209: return -0.0023497026413679123;
  t158_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t158_n234;
  t158_n211: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t158_n233;
  t158_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t158_n218;
  t158_n213: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t158_n217;
  t158_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n216;
  t158_n215: return 0.09028798341751099;
  t158_n216: return 0.10003933310508728;
  t158_n217: return 0.012191697023808956;
  t158_n218: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t158_n228;
  t158_n219: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t158_n221;
  t158_n220: return -0.03399860858917236;
  t158_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t158_n225;
  t158_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t158_n224;
  t158_n223: return 0.10590899735689163;
  t158_n224: return 0.12497060745954514;
  t158_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t158_n227;
  t158_n226: return 0.09522832185029984;
  t158_n227: return 0.01530306227505207;
  t158_n228: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t158_n232;
  t158_n229: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t158_n231;
  t158_n230: return 0.040771484375;
  t158_n231: return 0.12031954526901245;
  t158_n232: return -0.11393717676401138;
  t158_n233: return 0.00731664290651679;
  t158_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t158_n236;
  t158_n235: return -0.06113900989294052;
  t158_n236: if (E.getNumReferences() >= 3347832128 /*71610.5*/) goto t158_n250;
  t158_n237: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t158_n239;
  t158_n238: return 0.02217736281454563;
  t158_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t158_n243;
  t158_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t158_n242;
  t158_n241: return -0.18194009363651276;
  t158_n242: return 0.16518326103687286;
  t158_n243: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t158_n249;
  t158_n244: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t158_n248;
  t158_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t158_n247;
  t158_n246: return 0.10632473975419998;
  t158_n247: return 0.10335340350866318;
  t158_n248: return 0.09678038954734802;
  t158_n249: return -0.05592012777924538;
  t158_n250: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t158_n254;
  t158_n251: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t158_n253;
  t158_n252: return 0.13139721751213074;
  t158_n253: return -0.2506224811077118;
  t158_n254: return 0.13049975037574768;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree159(const Example& E) {
  t159_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t159_n162;
  t159_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t159_n3;
  t159_n2: return -0.0007213916978798807;
  t159_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t159_n5;
  t159_n4: return -0.004485865589231253;
  t159_n5: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t159_n7;
  t159_n6: return 0.0048524923622608185;
  t159_n7: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t159_n87;
  t159_n8: if (E.getNumReferences() >= 3309795328 /*3191.5*/) goto t159_n86;
  t159_n9: if (E.getNumReferences() >= 3309611008 /*3146.5*/) goto t159_n85;
  t159_n10: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t159_n18;
  t159_n11: if (E.getNumReferences() >= 3292184576 /*747.0*/) goto t159_n17;
  t159_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n16;
  t159_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t159_n15;
  t159_n14: return 0.11004521697759628;
  t159_n15: return -0.0486636608839035;
  t159_n16: return -0.12191333621740341;
  t159_n17: return 0.11908582597970963;
  t159_n18: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t159_n78;
  t159_n19: if (E.getNumReferences() >= 3280142336 /*262.0*/) goto t159_n77;
  t159_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t159_n72;
  t159_n21: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t159_n69;
  t159_n22: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t159_n26;
  t159_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t159_n25;
  t159_n24: return -0.5171283483505249;
  t159_n25: return 0.11366263031959534;
  t159_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t159_n44;
  t159_n27: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t159_n39;
  t159_n28: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t159_n30;
  t159_n29: return -0.1465958058834076;
  t159_n30: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t159_n38;
  t159_n31: if (E.getNumReferences() >= 3268345856 /*103.5*/) goto t159_n33;
  t159_n32: return 0.06717349588871002;
  t159_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n35;
  t159_n34: return 0.11340004205703735;
  t159_n35: if (E.getNumReferences() >= 3270508544 /*120.0*/) goto t159_n37;
  t159_n36: return -0.3423037528991699;
  t159_n37: return 0.10753943026065826;
  t159_n38: return -0.023576010018587112;
  t159_n39: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t159_n41;
  t159_n40: return 0.041440825909376144;
  t159_n41: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t159_n43;
  t159_n42: return -0.2255367487668991;
  t159_n43: return -9.67420482635498;
  t159_n44: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t159_n50;
  t159_n45: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t159_n47;
  t159_n46: return 0.16988669335842133;
  t159_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n49;
  t159_n48: return 0.11153396219015121;
  t159_n49: return 0.11476746201515198;
  t159_n50: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n62;
  t159_n51: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t159_n53;
  t159_n52: return 0.06388977915048599;
  t159_n53: if (E.getNumReferences() >= 3274899456 /*179.0*/) goto t159_n57;
  t159_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n56;
  t159_n55: return 0.35478803515434265;
  t159_n56: return 0.15880326926708221;
  t159_n57: if (E.getNumReferences() >= 3278438400 /*233.0*/) goto t159_n59;
  t159_n58: return -0.11897827684879303;
  t159_n59: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t159_n61;
  t159_n60: return 0.429644376039505;
  t159_n61: return -0.22701486945152283;
  t159_n62: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t159_n66;
  t159_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t159_n65;
  t159_n64: return -0.8191495537757874;
  t159_n65: return 0.04819168522953987;
  t159_n66: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t159_n68;
  t159_n67: return 0.11218487471342087;
  t159_n68: return 0.05547690391540527;
  t159_n69: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t159_n71;
  t159_n70: return 0.12376704812049866;
  t159_n71: return 0.1174682080745697;
  t159_n72: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t159_n74;
  t159_n73: return -0.01736493781208992;
  t159_n74: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t159_n76;
  t159_n75: return 0.2850021421909332;
  t159_n76: return -0.03068721666932106;
  t159_n77: return 0.12782835960388184;
  t159_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t159_n80;
  t159_n79: return 0.007894850336015224;
  t159_n80: if (E.getNumReferences() >= 3297595392 /*1130.5*/) goto t159_n82;
  t159_n81: return 0.009109788574278355;
  t159_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n84;
  t159_n83: return 0.10957051068544388;
  t159_n84: return -0.009687227196991444;
  t159_n85: return 0.13060933351516724;
  t159_n86: return -0.14273548126220703;
  t159_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t159_n147;
  t159_n88: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t159_n122;
  t159_n89: if (E.getNumReferences() >= 3324380672 /*10625.5*/) goto t159_n119;
  t159_n90: if (E.getNumReferences() >= 3322220544 /*8516.0*/) goto t159_n92;
  t159_n91: return -0.0023063188418745995;
  t159_n92: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t159_n112;
  t159_n93: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t159_n99;
  t159_n94: if (E.getNumReferences() >= 3322782208 /*9064.5*/) goto t159_n98;
  t159_n95: if (E.getNumReferences() >= 3322376192 /*8668.0*/) goto t159_n97;
  t159_n96: return 0.457334041595459;
  t159_n97: return -0.01106054987758398;
  t159_n98: return 0.1055828258395195;
  t159_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t159_n103;
  t159_n100: if (E.getNumReferences() >= 3322734080 /*9017.5*/) goto t159_n102;
  t159_n101: return 0.1065385565161705;
  t159_n102: return -0.19620737433433533;
  t159_n103: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t159_n111;
  t159_n104: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t159_n106;
  t159_n105: return 0.02687697298824787;
  t159_n106: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t159_n110;
  t159_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n109;
  t159_n108: return 0.10065958648920059;
  t159_n109: return 0.10822564363479614;
  t159_n110: return 0.1104261726140976;
  t159_n111: return -0.21953436732292175;
  t159_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t159_n114;
  t159_n113: return -0.023343805223703384;
  t159_n114: if (E.getNumReferences() >= 3323281920 /*9552.5*/) goto t159_n116;
  t159_n115: return -0.14155493676662445;
  t159_n116: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t159_n118;
  t159_n117: return 0.10570195317268372;
  t159_n118: return 0.06599582731723785;
  t159_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t159_n121;
  t159_n120: return -0.07916168123483658;
  t159_n121: return 0.10189437866210938;
  t159_n122: if (E.getNumReferences() >= 3325327360 /*11550.0*/) goto t159_n126;
  t159_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t159_n125;
  t159_n124: return -0.10132777690887451;
  t159_n125: return 0.1034049242734909;
  t159_n126: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t159_n146;
  t159_n127: if (E.getNumReferences() >= 3337633024 /*30750.5*/) goto t159_n135;
  t159_n128: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t159_n130;
  t159_n129: return 0.03673463687300682;
  t159_n130: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n132;
  t159_n131: return -0.014664932154119015;
  t159_n132: if (E.getNumReferences() >= 3325685760 /*11900.0*/) goto t159_n134;
  t159_n133: return 0.09643016010522842;
  t159_n134: return 0.047123853117227554;
  t159_n135: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t159_n145;
  t159_n136: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t159_n138;
  t159_n137: return 0.06755555421113968;
  t159_n138: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t159_n142;
  t159_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t159_n141;
  t159_n140: return 0.1020844429731369;
  t159_n141: return 0.0998983308672905;
  t159_n142: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t159_n144;
  t159_n143: return 0.0359366312623024;
  t159_n144: return 0.09235578030347824;
  t159_n145: return 0.010025760158896446;
  t159_n146: return -0.04007498547434807;
  t159_n147: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t159_n159;
  t159_n148: if (E.getNumReferences() >= 3289612288 /*590.0*/) goto t159_n156;
  t159_n149: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t159_n151;
  t159_n150: return 0.0503925085067749;
  t159_n151: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t159_n153;
  t159_n152: return 0.06649437546730042;
  t159_n153: if (E.getNumReferences() >= 3289341952 /*573.5*/) goto t159_n155;
  t159_n154: return 0.11340136080980301;
  t159_n155: return 0.11523929238319397;
  t159_n156: if (E.getNumReferences() >= 3302944768 /*1783.5*/) goto t159_n158;
  t159_n157: return -0.0357481949031353;
  t159_n158: return 0.029046611860394478;
  t159_n159: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t159_n161;
  t159_n160: return 0.11412722617387772;
  t159_n161: return 0.049172673374414444;
  t159_n162: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t159_n182;
  t159_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n171;
  t159_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n166;
  t159_n165: return -0.1249488815665245;
  t159_n166: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n170;
  t159_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t159_n169;
  t159_n168: return 0.0632675513625145;
  t159_n169: return 0.10527220368385315;
  t159_n170: return -0.24830248951911926;
  t159_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t159_n179;
  t159_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n176;
  t159_n173: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t159_n175;
  t159_n174: return 0.15957963466644287;
  t159_n175: return 0.1320899873971939;
  t159_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t159_n178;
  t159_n177: return 0.09758303314447403;
  t159_n178: return 0.06670085340738297;
  t159_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n181;
  t159_n180: return 0.13168329000473022;
  t159_n181: return 0.14092890918254852;
  t159_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t159_n240;
  t159_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t159_n227;
  t159_n184: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t159_n218;
  t159_n185: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t159_n201;
  t159_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t159_n188;
  t159_n187: return -0.07453048229217529;
  t159_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n190;
  t159_n189: return 0.07559758424758911;
  t159_n190: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n198;
  t159_n191: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t159_n197;
  t159_n192: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t159_n194;
  t159_n193: return -0.2117002159357071;
  t159_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t159_n196;
  t159_n195: return 0.10732122510671616;
  t159_n196: return 0.0949515551328659;
  t159_n197: return 0.08291737735271454;
  t159_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n200;
  t159_n199: return 0.0995340347290039;
  t159_n200: return 0.14073175191879272;
  t159_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n209;
  t159_n202: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t159_n204;
  t159_n203: return 0.00028218867373652756;
  t159_n204: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t159_n206;
  t159_n205: return -0.10352936387062073;
  t159_n206: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t159_n208;
  t159_n207: return 0.14696596562862396;
  t159_n208: return -0.13591791689395905;
  t159_n209: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t159_n213;
  t159_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t159_n212;
  t159_n211: return 0.11283876746892929;
  t159_n212: return 0.08482969552278519;
  t159_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n217;
  t159_n214: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t159_n216;
  t159_n215: return 0.06969098001718521;
  t159_n216: return 0.15936517715454102;
  t159_n217: return 0.11129435151815414;
  t159_n218: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t159_n220;
  t159_n219: return -0.10507729649543762;
  t159_n220: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t159_n226;
  t159_n221: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n225;
  t159_n222: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n224;
  t159_n223: return -0.09565455466508865;
  t159_n224: return 0.10616392642259598;
  t159_n225: return 0.39794811606407166;
  t159_n226: return 0.006803792901337147;
  t159_n227: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t159_n235;
  t159_n228: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t159_n230;
  t159_n229: return -0.026148980483412743;
  t159_n230: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t159_n234;
  t159_n231: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t159_n233;
  t159_n232: return 0.10522084683179855;
  t159_n233: return 0.1196797713637352;
  t159_n234: return 0.046050723642110825;
  t159_n235: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t159_n239;
  t159_n236: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t159_n238;
  t159_n237: return 0.03675520047545433;
  t159_n238: return 0.12022635340690613;
  t159_n239: return -0.11152750253677368;
  t159_n240: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t159_n242;
  t159_n241: return 0.0037341422867029905;
  t159_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t159_n244;
  t159_n243: return -0.014871638268232346;
  t159_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t159_n250;
  t159_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t159_n249;
  t159_n246: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t159_n248;
  t159_n247: return -0.12422781437635422;
  t159_n248: return 0.125675767660141;
  t159_n249: return -0.1565522700548172;
  t159_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t159_n254;
  t159_n251: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t159_n253;
  t159_n252: return 0.1155630424618721;
  t159_n253: return 0.07728581875562668;
  t159_n254: return 0.060640085488557816;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree160(const Example& E) {
  t160_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t160_n2;
  t160_n1: return -0.00025012739934027195;
  t160_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t160_n90;
  t160_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t160_n77;
  t160_n4: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t160_n48;
  t160_n5: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t160_n27;
  t160_n6: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t160_n12;
  t160_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n9;
  t160_n8: return -0.27594301104545593;
  t160_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n11;
  t160_n10: return 0.12702690064907074;
  t160_n11: return 0.13593502342700958;
  t160_n12: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n14;
  t160_n13: return -0.06440415233373642;
  t160_n14: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n16;
  t160_n15: return 0.06187255680561066;
  t160_n16: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t160_n24;
  t160_n17: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t160_n23;
  t160_n18: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t160_n20;
  t160_n19: return -0.20277540385723114;
  t160_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n22;
  t160_n21: return 0.10669231414794922;
  t160_n22: return 0.0932375118136406;
  t160_n23: return 0.07818008959293365;
  t160_n24: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n26;
  t160_n25: return 0.09606359153985977;
  t160_n26: return 0.1368870586156845;
  t160_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n35;
  t160_n28: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t160_n30;
  t160_n29: return -0.00013348473294172436;
  t160_n30: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t160_n32;
  t160_n31: return -0.10316653549671173;
  t160_n32: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t160_n34;
  t160_n33: return 0.13543006777763367;
  t160_n34: return -0.13364152610301971;
  t160_n35: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t160_n41;
  t160_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n40;
  t160_n37: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t160_n39;
  t160_n38: return 0.2285834699869156;
  t160_n39: return 0.10552281886339188;
  t160_n40: return 0.0846400260925293;
  t160_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t160_n45;
  t160_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n44;
  t160_n43: return 0.08068310469388962;
  t160_n44: return 0.11069901287555695;
  t160_n45: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n47;
  t160_n46: return 0.13704219460487366;
  t160_n47: return 0.10690782964229584;
  t160_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t160_n50;
  t160_n49: return 0.0030648394022136927;
  t160_n50: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n54;
  t160_n51: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n53;
  t160_n52: return 0.006587551441043615;
  t160_n53: return -0.217604398727417;
  t160_n54: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t160_n76;
  t160_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t160_n75;
  t160_n56: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n74;
  t160_n57: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n63;
  t160_n58: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t160_n62;
  t160_n59: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t160_n61;
  t160_n60: return -0.10126176476478577;
  t160_n61: return 0.6847094297409058;
  t160_n62: return 0.6839396953582764;
  t160_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n73;
  t160_n64: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t160_n72;
  t160_n65: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n71;
  t160_n66: if (E.getNumReferences() >= 3359278208 /*190994.0*/) goto t160_n70;
  t160_n67: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t160_n69;
  t160_n68: return 0.0722116082906723;
  t160_n69: return 0.09702349454164505;
  t160_n70: return -0.11108992248773575;
  t160_n71: return 0.105417400598526;
  t160_n72: return 0.07089179009199142;
  t160_n73: return 0.07936758548021317;
  t160_n74: return 0.03440320864319801;
  t160_n75: return -0.07450464367866516;
  t160_n76: return 0.03070748597383499;
  t160_n77: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t160_n85;
  t160_n78: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t160_n80;
  t160_n79: return -0.02571433037519455;
  t160_n80: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t160_n84;
  t160_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n83;
  t160_n82: return 0.10714258253574371;
  t160_n83: return 0.11829813569784164;
  t160_n84: return 0.043866127729415894;
  t160_n85: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t160_n89;
  t160_n86: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t160_n88;
  t160_n87: return 0.03326878324151039;
  t160_n88: return 0.11844085901975632;
  t160_n89: return -0.10935194045305252;
  t160_n90: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t160_n238;
  t160_n91: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t160_n93;
  t160_n92: return -0.024833472445607185;
  t160_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t160_n121;
  t160_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t160_n104;
  t160_n95: if (E.getNumReferences() >= 3344562560 /*55801.5*/) goto t160_n103;
  t160_n96: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t160_n98;
  t160_n97: return -0.10004037618637085;
  t160_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t160_n100;
  t160_n99: return -0.14045003056526184;
  t160_n100: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n102;
  t160_n101: return 1.125430941581726;
  t160_n102: return 0.1500311940908432;
  t160_n103: return -0.05448490008711815;
  t160_n104: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t160_n106;
  t160_n105: return -0.08756352216005325;
  t160_n106: if (E.getNumReferences() >= 3345303552 /*58696.0*/) goto t160_n118;
  t160_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n113;
  t160_n108: if (E.getNumReferences() >= 3343995264 /*53585.5*/) goto t160_n110;
  t160_n109: return 0.006161458790302277;
  t160_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t160_n112;
  t160_n111: return -0.2684008479118347;
  t160_n112: return 0.17019052803516388;
  t160_n113: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n117;
  t160_n114: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n116;
  t160_n115: return 0.11139226704835892;
  t160_n116: return 0.3485051095485687;
  t160_n117: return 0.09621669352054596;
  t160_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t160_n120;
  t160_n119: return -0.08408860862255096;
  t160_n120: return 0.018706249073147774;
  t160_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t160_n217;
  t160_n122: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t160_n132;
  t160_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n125;
  t160_n124: return 0.09460052847862244;
  t160_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n131;
  t160_n126: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t160_n130;
  t160_n127: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n129;
  t160_n128: return 0.10504747182130814;
  t160_n129: return 0.09505123645067215;
  t160_n130: return 0.027172677218914032;
  t160_n131: return -0.25123146176338196;
  t160_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t160_n172;
  t160_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t160_n135;
  t160_n134: return -0.010187320411205292;
  t160_n135: if (E.getNumReferences() >= 3342301952 /*46971.0*/) goto t160_n149;
  t160_n136: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n138;
  t160_n137: return -0.0008479044190607965;
  t160_n138: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t160_n140;
  t160_n139: return -0.011363357305526733;
  t160_n140: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t160_n142;
  t160_n141: return -0.13074061274528503;
  t160_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n148;
  t160_n143: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t160_n147;
  t160_n144: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t160_n146;
  t160_n145: return 0.11902197450399399;
  t160_n146: return 0.11004387587308884;
  t160_n147: return 0.1515369713306427;
  t160_n148: return 0.10128668695688248;
  t160_n149: if (E.getNumReferences() >= 3351669952 /*101593.5*/) goto t160_n153;
  t160_n150: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t160_n152;
  t160_n151: return -0.009331176057457924;
  t160_n152: return -0.1551159918308258;
  t160_n153: if (E.getNumReferences() >= 3368655888 /*412896.5*/) goto t160_n163;
  t160_n154: if (E.getNumReferences() >= 3367337376 /*371693.0*/) goto t160_n162;
  t160_n155: if (E.getNumReferences() >= 3365914464 /*327227.0*/) goto t160_n157;
  t160_n156: return 0.03412887454032898;
  t160_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n159;
  t160_n158: return -0.1770310401916504;
  t160_n159: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t160_n161;
  t160_n160: return 0.08794160187244415;
  t160_n161: return 0.08852341026067734;
  t160_n162: return 0.1027289405465126;
  t160_n163: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t160_n171;
  t160_n164: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t160_n166;
  t160_n165: return 0.01744440756738186;
  t160_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n170;
  t160_n167: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t160_n169;
  t160_n168: return 0.056283701211214066;
  t160_n169: return 0.10025563091039658;
  t160_n170: return -0.02439514547586441;
  t160_n171: return -0.023202046751976013;
  t160_n172: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n216;
  t160_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n181;
  t160_n174: if (E.getNumReferences() >= 3364539984 /*284274.5*/) goto t160_n180;
  t160_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t160_n177;
  t160_n176: return -0.02111104689538479;
  t160_n177: if (E.getNumReferences() >= 3344436864 /*55310.5*/) goto t160_n179;
  t160_n178: return -0.21182781457901;
  t160_n179: return 0.050623174756765366;
  t160_n180: return 0.04667208343744278;
  t160_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n195;
  t160_n182: if (E.getNumReferences() >= 3356993440 /*155294.5*/) goto t160_n184;
  t160_n183: return 0.07960161566734314;
  t160_n184: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t160_n186;
  t160_n185: return 0.11726737767457962;
  t160_n186: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t160_n192;
  t160_n187: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t160_n189;
  t160_n188: return 0.12753896415233612;
  t160_n189: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t160_n191;
  t160_n190: return 0.11000601947307587;
  t160_n191: return -0.12458755820989609;
  t160_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n194;
  t160_n193: return 0.04394553229212761;
  t160_n194: return 0.08084075897932053;
  t160_n195: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t160_n211;
  t160_n196: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t160_n206;
  t160_n197: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t160_n205;
  t160_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n200;
  t160_n199: return 0.48464643955230713;
  t160_n200: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t160_n202;
  t160_n201: return -0.06246822699904442;
  t160_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t160_n204;
  t160_n203: return 0.1356617957353592;
  t160_n204: return 0.11027330160140991;
  t160_n205: return 0.022077884525060654;
  t160_n206: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n210;
  t160_n207: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t160_n209;
  t160_n208: return 0.14212879538536072;
  t160_n209: return 0.13613878190517426;
  t160_n210: return -0.14539562165737152;
  t160_n211: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t160_n213;
  t160_n212: return 0.056041620671749115;
  t160_n213: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t160_n215;
  t160_n214: return 0.16130264103412628;
  t160_n215: return 0.0367644764482975;
  t160_n216: return 0.005172187928110361;
  t160_n217: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t160_n225;
  t160_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t160_n220;
  t160_n219: return 0.01775720715522766;
  t160_n220: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t160_n222;
  t160_n221: return -0.10194127261638641;
  t160_n222: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t160_n224;
  t160_n223: return -0.9287749528884888;
  t160_n224: return 0.1370803713798523;
  t160_n225: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t160_n227;
  t160_n226: return -0.2321503460407257;
  t160_n227: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t160_n237;
  t160_n228: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t160_n230;
  t160_n229: return 0.16049005091190338;
  t160_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t160_n236;
  t160_n231: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n235;
  t160_n232: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t160_n234;
  t160_n233: return 0.1058088093996048;
  t160_n234: return 0.08765970915555954;
  t160_n235: return 0.09953678399324417;
  t160_n236: return 0.09115869551897049;
  t160_n237: return 0.12660744786262512;
  t160_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t160_n244;
  t160_n239: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t160_n243;
  t160_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t160_n242;
  t160_n241: return -0.13186492025852203;
  t160_n242: return 0.10838191211223602;
  t160_n243: return -0.05877375230193138;
  t160_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t160_n250;
  t160_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t160_n249;
  t160_n246: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t160_n248;
  t160_n247: return -0.10549645870923996;
  t160_n248: return 0.12131460011005402;
  t160_n249: return -0.1303885132074356;
  t160_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t160_n254;
  t160_n251: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t160_n253;
  t160_n252: return 0.11371967941522598;
  t160_n253: return 0.07343246787786484;
  t160_n254: return 0.05605529993772507;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree161(const Example& E) {
  t161_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t161_n88;
  t161_n1: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t161_n31;
  t161_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t161_n4;
  t161_n3: return -0.0004798454756382853;
  t161_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t161_n6;
  t161_n5: return -0.01609613187611103;
  t161_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t161_n10;
  t161_n7: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t161_n9;
  t161_n8: return -0.011253266595304012;
  t161_n9: return 0.0034415507689118385;
  t161_n10: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t161_n30;
  t161_n11: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t161_n13;
  t161_n12: return 0.03472308814525604;
  t161_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n15;
  t161_n14: return 0.10553133487701416;
  t161_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n27;
  t161_n16: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t161_n22;
  t161_n17: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t161_n19;
  t161_n18: return 0.12077685445547104;
  t161_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t161_n21;
  t161_n20: return 0.09902116656303406;
  t161_n21: return 0.12657082080841064;
  t161_n22: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t161_n24;
  t161_n23: return 0.09388482570648193;
  t161_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t161_n26;
  t161_n25: return 0.1195414736866951;
  t161_n26: return 0.16232967376708984;
  t161_n27: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t161_n29;
  t161_n28: return 0.06538809090852737;
  t161_n29: return 0.09193558990955353;
  t161_n30: return -0.016798783093690872;
  t161_n31: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t161_n33;
  t161_n32: return -0.015338866040110588;
  t161_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t161_n35;
  t161_n34: return -0.04014303535223007;
  t161_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n83;
  t161_n36: if (E.getNumReferences() >= 3272671232 /*145.0*/) goto t161_n70;
  t161_n37: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t161_n69;
  t161_n38: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t161_n54;
  t161_n39: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t161_n51;
  t161_n40: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n42;
  t161_n41: return 0.06703561544418335;
  t161_n42: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t161_n46;
  t161_n43: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t161_n45;
  t161_n44: return 0.1304980218410492;
  t161_n45: return -0.045586906373500824;
  t161_n46: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t161_n50;
  t161_n47: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t161_n49;
  t161_n48: return 0.07365286350250244;
  t161_n49: return 0.09798556566238403;
  t161_n50: return 0.017948836088180542;
  t161_n51: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t161_n53;
  t161_n52: return 0.12399797141551971;
  t161_n53: return 0.08107002079486847;
  t161_n54: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t161_n60;
  t161_n55: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t161_n57;
  t161_n56: return 0.10333004593849182;
  t161_n57: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t161_n59;
  t161_n58: return 0.09960895031690598;
  t161_n59: return 0.13100561499595642;
  t161_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t161_n62;
  t161_n61: return 0.020503757521510124;
  t161_n62: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t161_n68;
  t161_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t161_n65;
  t161_n64: return 0.014991995878517628;
  t161_n65: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t161_n67;
  t161_n66: return 0.13082057237625122;
  t161_n67: return 0.09040211886167526;
  t161_n68: return -0.12795093655586243;
  t161_n69: return 0.11118925362825394;
  t161_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n76;
  t161_n71: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t161_n73;
  t161_n72: return 0.8949722647666931;
  t161_n73: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t161_n75;
  t161_n74: return 0.12365969270467758;
  t161_n75: return -0.19547727704048157;
  t161_n76: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t161_n78;
  t161_n77: return -0.017833227291703224;
  t161_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n82;
  t161_n79: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t161_n81;
  t161_n80: return 0.10477973520755768;
  t161_n81: return 0.08016026020050049;
  t161_n82: return -0.05174681171774864;
  t161_n83: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t161_n85;
  t161_n84: return 0.01186918094754219;
  t161_n85: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t161_n87;
  t161_n86: return -0.09274868667125702;
  t161_n87: return 0.9985569715499878;
  t161_n88: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t161_n114;
  t161_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n97;
  t161_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n92;
  t161_n91: return -0.11745338886976242;
  t161_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t161_n96;
  t161_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t161_n95;
  t161_n94: return -0.231393963098526;
  t161_n95: return 0.09931368380784988;
  t161_n96: return -0.2475464940071106;
  t161_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t161_n111;
  t161_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n108;
  t161_n99: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t161_n107;
  t161_n100: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t161_n106;
  t161_n101: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t161_n103;
  t161_n102: return 0.10778334736824036;
  t161_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n105;
  t161_n104: return 0.16398753225803375;
  t161_n105: return 0.11068469285964966;
  t161_n106: return -0.24026958644390106;
  t161_n107: return 0.12744611501693726;
  t161_n108: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n110;
  t161_n109: return 0.09394945949316025;
  t161_n110: return 0.06409364193677902;
  t161_n111: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n113;
  t161_n112: return 0.1256527304649353;
  t161_n113: return 0.13165569305419922;
  t161_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t161_n204;
  t161_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t161_n191;
  t161_n116: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t161_n156;
  t161_n117: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t161_n131;
  t161_n118: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t161_n120;
  t161_n119: return -0.05264212563633919;
  t161_n120: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t161_n122;
  t161_n121: return -0.1818886399269104;
  t161_n122: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t161_n124;
  t161_n123: return 0.07855578511953354;
  t161_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n128;
  t161_n125: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t161_n127;
  t161_n126: return 0.20007559657096863;
  t161_n127: return -0.3394598066806793;
  t161_n128: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t161_n130;
  t161_n129: return 0.09359004348516464;
  t161_n130: return 0.13221046328544617;
  t161_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n139;
  t161_n132: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t161_n134;
  t161_n133: return 0.0004106148553546518;
  t161_n134: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t161_n136;
  t161_n135: return -0.1028519943356514;
  t161_n136: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t161_n138;
  t161_n137: return 0.13284142315387726;
  t161_n138: return -0.13737067580223083;
  t161_n139: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t161_n145;
  t161_n140: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n144;
  t161_n141: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t161_n143;
  t161_n142: return 0.12263022363185883;
  t161_n143: return 0.09952772408723831;
  t161_n144: return 0.08082075417041779;
  t161_n145: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t161_n153;
  t161_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t161_n152;
  t161_n147: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t161_n151;
  t161_n148: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n150;
  t161_n149: return 0.11926999688148499;
  t161_n150: return 0.04315498098731041;
  t161_n151: return 0.03303990513086319;
  t161_n152: return 0.11009014397859573;
  t161_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n155;
  t161_n154: return 0.1327793151140213;
  t161_n155: return 0.10352113097906113;
  t161_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t161_n160;
  t161_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t161_n159;
  t161_n158: return -0.006185656879097223;
  t161_n159: return 0.010719179175794125;
  t161_n160: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t161_n162;
  t161_n161: return -0.00953273568302393;
  t161_n162: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t161_n190;
  t161_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n183;
  t161_n164: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t161_n180;
  t161_n165: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t161_n175;
  t161_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t161_n168;
  t161_n167: return 0.1270899772644043;
  t161_n168: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t161_n170;
  t161_n169: return -0.10393980145454407;
  t161_n170: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t161_n172;
  t161_n171: return 0.14287471771240234;
  t161_n172: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t161_n174;
  t161_n173: return 0.12342649698257446;
  t161_n174: return 0.1309620440006256;
  t161_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n177;
  t161_n176: return 0.23746903240680695;
  t161_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t161_n179;
  t161_n178: return 0.09433512389659882;
  t161_n179: return 0.0774960145354271;
  t161_n180: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t161_n182;
  t161_n181: return -0.5121796727180481;
  t161_n182: return 0.09069894999265671;
  t161_n183: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t161_n187;
  t161_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n186;
  t161_n185: return 0.07634784281253815;
  t161_n186: return 0.0334056131541729;
  t161_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n189;
  t161_n188: return -0.3286038935184479;
  t161_n189: return -0.029062995687127113;
  t161_n190: return 0.01194804534316063;
  t161_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t161_n199;
  t161_n192: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t161_n194;
  t161_n193: return -0.023778943344950676;
  t161_n194: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t161_n198;
  t161_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t161_n197;
  t161_n196: return 0.10566933453083038;
  t161_n197: return 0.12067153304815292;
  t161_n198: return 0.03668474778532982;
  t161_n199: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t161_n203;
  t161_n200: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t161_n202;
  t161_n201: return 0.03030567616224289;
  t161_n202: return 0.11719610542058945;
  t161_n203: return -0.10754139721393585;
  t161_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t161_n206;
  t161_n205: return 0.002682497026398778;
  t161_n206: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t161_n222;
  t161_n207: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t161_n213;
  t161_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t161_n210;
  t161_n209: return -0.012827778235077858;
  t161_n210: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t161_n212;
  t161_n211: return -0.16220255196094513;
  t161_n212: return 0.13115251064300537;
  t161_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n215;
  t161_n214: return -0.017816107720136642;
  t161_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n217;
  t161_n216: return 0.06263185292482376;
  t161_n217: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n221;
  t161_n218: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t161_n220;
  t161_n219: return 0.10769906640052795;
  t161_n220: return 0.08135147392749786;
  t161_n221: return 0.04400691017508507;
  t161_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t161_n248;
  t161_n223: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t161_n245;
  t161_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t161_n226;
  t161_n225: return -0.11102160066366196;
  t161_n226: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t161_n244;
  t161_n227: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t161_n233;
  t161_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n232;
  t161_n229: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t161_n231;
  t161_n230: return 2.5033936500549316;
  t161_n231: return -0.20228897035121918;
  t161_n232: return -0.11448933184146881;
  t161_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t161_n237;
  t161_n234: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t161_n236;
  t161_n235: return 0.12378638982772827;
  t161_n236: return -0.22798466682434082;
  t161_n237: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t161_n239;
  t161_n238: return -0.10998150706291199;
  t161_n239: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t161_n241;
  t161_n240: return 0.13977912068367004;
  t161_n241: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t161_n243;
  t161_n242: return -0.10043317079544067;
  t161_n243: return 0.15447892248630524;
  t161_n244: return 0.03284170851111412;
  t161_n245: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t161_n247;
  t161_n246: return -0.2142113447189331;
  t161_n247: return 0.12884235382080078;
  t161_n248: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t161_n254;
  t161_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t161_n251;
  t161_n250: return 0.2515125572681427;
  t161_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t161_n253;
  t161_n252: return 0.10208284109830856;
  t161_n253: return 0.09044199436903;
  t161_n254: return -0.1508825719356537;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree162(const Example& E) {
  t162_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t162_n134;
  t162_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t162_n3;
  t162_n2: return -0.0006945895729586482;
  t162_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t162_n19;
  t162_n4: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t162_n10;
  t162_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t162_n9;
  t162_n6: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t162_n8;
  t162_n7: return -0.1429622620344162;
  t162_n8: return -0.2219202220439911;
  t162_n9: return -0.020459463819861412;
  t162_n10: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t162_n18;
  t162_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n17;
  t162_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t162_n16;
  t162_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t162_n15;
  t162_n14: return -0.18732307851314545;
  t162_n15: return -0.007285905536264181;
  t162_n16: return 0.011974379420280457;
  t162_n17: return -0.0015944025944918394;
  t162_n18: return -0.015897653996944427;
  t162_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t162_n121;
  t162_n20: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t162_n52;
  t162_n21: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t162_n23;
  t162_n22: return 0.006776755675673485;
  t162_n23: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t162_n45;
  t162_n24: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t162_n32;
  t162_n25: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t162_n27;
  t162_n26: return -4.340443047112785e-05;
  t162_n27: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t162_n29;
  t162_n28: return -0.09465615451335907;
  t162_n29: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n31;
  t162_n30: return -0.06499207764863968;
  t162_n31: return 0.05142935737967491;
  t162_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t162_n40;
  t162_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n39;
  t162_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t162_n38;
  t162_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t162_n37;
  t162_n36: return -0.14770376682281494;
  t162_n37: return 0.28213658928871155;
  t162_n38: return -0.14040258526802063;
  t162_n39: return -0.01655616983771324;
  t162_n40: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t162_n42;
  t162_n41: return -0.12990885972976685;
  t162_n42: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t162_n44;
  t162_n43: return -0.10193604230880737;
  t162_n44: return -0.1866438090801239;
  t162_n45: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t162_n51;
  t162_n46: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t162_n48;
  t162_n47: return -0.18437212705612183;
  t162_n48: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t162_n50;
  t162_n49: return 0.0992405116558075;
  t162_n50: return -0.14455963671207428;
  t162_n51: return 0.024259373545646667;
  t162_n52: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t162_n90;
  t162_n53: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t162_n59;
  t162_n54: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t162_n56;
  t162_n55: return -0.029235245659947395;
  t162_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n58;
  t162_n57: return -0.17041528224945068;
  t162_n58: return -0.32207271456718445;
  t162_n59: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t162_n65;
  t162_n60: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t162_n62;
  t162_n61: return 0.032445866614580154;
  t162_n62: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t162_n64;
  t162_n63: return 0.10654263198375702;
  t162_n64: return -0.1237628310918808;
  t162_n65: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t162_n81;
  t162_n66: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t162_n70;
  t162_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n69;
  t162_n68: return -0.09978090971708298;
  t162_n69: return -0.25326457619667053;
  t162_n70: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n72;
  t162_n71: return -0.012812281027436256;
  t162_n72: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n80;
  t162_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n75;
  t162_n74: return 0.0;
  t162_n75: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t162_n77;
  t162_n76: return -0.12101536244153976;
  t162_n77: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n79;
  t162_n78: return 0.34839242696762085;
  t162_n79: return 0.12620045244693756;
  t162_n80: return 0.24955326318740845;
  t162_n81: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t162_n83;
  t162_n82: return 0.027580074965953827;
  t162_n83: if (E.getNumReferences() >= 3333245184 /*22180.5*/) goto t162_n89;
  t162_n84: if (E.getNumReferences() >= 3324139520 /*10390.0*/) goto t162_n86;
  t162_n85: return -0.0020370245911180973;
  t162_n86: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t162_n88;
  t162_n87: return 0.06091473251581192;
  t162_n88: return -0.24189405143260956;
  t162_n89: return -0.044921230524778366;
  t162_n90: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t162_n114;
  t162_n91: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t162_n101;
  t162_n92: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t162_n100;
  t162_n93: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t162_n95;
  t162_n94: return -0.05315345525741577;
  t162_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t162_n99;
  t162_n96: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n98;
  t162_n97: return 0.0857173278927803;
  t162_n98: return 0.14032702147960663;
  t162_n99: return -0.06745105236768723;
  t162_n100: return 0.1206170991063118;
  t162_n101: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t162_n103;
  t162_n102: return -0.066182941198349;
  t162_n103: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t162_n113;
  t162_n104: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n112;
  t162_n105: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t162_n107;
  t162_n106: return 0.09276270866394043;
  t162_n107: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t162_n111;
  t162_n108: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t162_n110;
  t162_n109: return 0.04366994649171829;
  t162_n110: return 0.13288861513137817;
  t162_n111: return 0.12805835902690887;
  t162_n112: return 0.013092193752527237;
  t162_n113: return 0.025660112500190735;
  t162_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n120;
  t162_n115: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t162_n117;
  t162_n116: return 0.12805384397506714;
  t162_n117: if (E.getNumReferences() >= 3254255616 /*31.0*/) goto t162_n119;
  t162_n118: return -2.6478335857391357;
  t162_n119: return 0.20651844143867493;
  t162_n120: return 0.03288702294230461;
  t162_n121: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t162_n133;
  t162_n122: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t162_n124;
  t162_n123: return -3.719814048963599e-05;
  t162_n124: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t162_n132;
  t162_n125: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t162_n131;
  t162_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n130;
  t162_n127: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t162_n129;
  t162_n128: return 0.05314498022198677;
  t162_n129: return 0.08794562518596649;
  t162_n130: return 0.008580495603382587;
  t162_n131: return -0.03940891847014427;
  t162_n132: return 0.005647244863212109;
  t162_n133: return -0.07974942028522491;
  t162_n134: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t162_n208;
  t162_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t162_n195;
  t162_n136: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t162_n170;
  t162_n137: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t162_n147;
  t162_n138: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t162_n144;
  t162_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n141;
  t162_n140: return -0.20463190972805023;
  t162_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n143;
  t162_n142: return 0.12433496862649918;
  t162_n143: return 0.12795376777648926;
  t162_n144: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t162_n146;
  t162_n145: return -0.046126969158649445;
  t162_n146: return 0.06015588715672493;
  t162_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n155;
  t162_n148: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n150;
  t162_n149: return -0.00040324649307876825;
  t162_n150: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t162_n152;
  t162_n151: return -0.10254976898431778;
  t162_n152: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t162_n154;
  t162_n153: return 0.12415961921215057;
  t162_n154: return -0.13883115351200104;
  t162_n155: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t162_n159;
  t162_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n158;
  t162_n157: return 0.10103418678045273;
  t162_n158: return 0.07723810523748398;
  t162_n159: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n167;
  t162_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n166;
  t162_n161: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t162_n165;
  t162_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n164;
  t162_n163: return 0.11150822043418884;
  t162_n164: return 0.040051091462373734;
  t162_n165: return 0.025314325466752052;
  t162_n166: return 0.10946178436279297;
  t162_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n169;
  t162_n168: return 0.12894058227539062;
  t162_n169: return 0.10037990659475327;
  t162_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t162_n172;
  t162_n171: return 0.0033234297297894955;
  t162_n172: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t162_n174;
  t162_n173: return -0.005128685384988785;
  t162_n174: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t162_n194;
  t162_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n193;
  t162_n176: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t162_n190;
  t162_n177: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t162_n185;
  t162_n178: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t162_n180;
  t162_n179: return 0.10135680437088013;
  t162_n180: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t162_n182;
  t162_n181: return 0.0;
  t162_n182: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t162_n184;
  t162_n183: return 0.13912397623062134;
  t162_n184: return 0.12349649518728256;
  t162_n185: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t162_n189;
  t162_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t162_n188;
  t162_n187: return 0.0;
  t162_n188: return 0.09577043354511261;
  t162_n189: return 0.07940539717674255;
  t162_n190: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t162_n192;
  t162_n191: return -0.5008249878883362;
  t162_n192: return 0.07351379841566086;
  t162_n193: return 0.033390503376722336;
  t162_n194: return 0.011314528062939644;
  t162_n195: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t162_n203;
  t162_n196: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t162_n198;
  t162_n197: return -0.018964994698762894;
  t162_n198: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t162_n202;
  t162_n199: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t162_n201;
  t162_n200: return 0.1041397824883461;
  t162_n201: return 0.1189790740609169;
  t162_n202: return 0.0332503616809845;
  t162_n203: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t162_n207;
  t162_n204: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t162_n206;
  t162_n205: return 0.035698052495718;
  t162_n206: return 0.11751198768615723;
  t162_n207: return -0.10628875344991684;
  t162_n208: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t162_n224;
  t162_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t162_n215;
  t162_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n212;
  t162_n211: return -0.09419550746679306;
  t162_n212: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t162_n214;
  t162_n213: return 0.10499145835638046;
  t162_n214: return 0.12320201098918915;
  t162_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t162_n223;
  t162_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t162_n218;
  t162_n217: return -0.17303258180618286;
  t162_n218: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t162_n222;
  t162_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n221;
  t162_n220: return 0.10732952505350113;
  t162_n221: return 0.09092066437005997;
  t162_n222: return 0.019058074802160263;
  t162_n223: return -0.20168662071228027;
  t162_n224: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t162_n226;
  t162_n225: return 0.0023343288339674473;
  t162_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t162_n228;
  t162_n227: return 0.018844373524188995;
  t162_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t162_n248;
  t162_n229: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t162_n245;
  t162_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t162_n232;
  t162_n231: return -0.10940603911876678;
  t162_n232: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t162_n244;
  t162_n233: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t162_n235;
  t162_n234: return 0.2430451214313507;
  t162_n235: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t162_n243;
  t162_n236: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t162_n240;
  t162_n237: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t162_n239;
  t162_n238: return 0.1223011389374733;
  t162_n239: return -0.1187557652592659;
  t162_n240: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t162_n242;
  t162_n241: return -0.23891080915927887;
  t162_n242: return 0.1336168497800827;
  t162_n243: return -0.49783021211624146;
  t162_n244: return 0.016164101660251617;
  t162_n245: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t162_n247;
  t162_n246: return -0.20928296446800232;
  t162_n247: return 0.1274159699678421;
  t162_n248: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t162_n254;
  t162_n249: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t162_n251;
  t162_n250: return 0.14312121272087097;
  t162_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t162_n253;
  t162_n252: return 0.10042594373226166;
  t162_n253: return 0.0881325826048851;
  t162_n254: return -0.16274045407772064;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree163(const Example& E) {
  t163_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t163_n174;
  t163_n1: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t163_n15;
  t163_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t163_n4;
  t163_n3: return 0.0004899885389022529;
  t163_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n12;
  t163_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t163_n7;
  t163_n6: return 0.0009624084923416376;
  t163_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t163_n9;
  t163_n8: return -0.1012587621808052;
  t163_n9: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t163_n11;
  t163_n10: return 0.0970035046339035;
  t163_n11: return 0.09386338293552399;
  t163_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t163_n14;
  t163_n13: return -0.1015002653002739;
  t163_n14: return 0.017189793288707733;
  t163_n15: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t163_n57;
  t163_n16: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t163_n18;
  t163_n17: return 2.6935053028864786e-05;
  t163_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t163_n34;
  t163_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t163_n21;
  t163_n20: return -0.030044658109545708;
  t163_n21: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t163_n33;
  t163_n22: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t163_n32;
  t163_n23: if (E.getNumReferences() >= 3326722048 /*12912.0*/) goto t163_n31;
  t163_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t163_n26;
  t163_n25: return -0.1342582106590271;
  t163_n26: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t163_n28;
  t163_n27: return -0.053300607949495316;
  t163_n28: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n30;
  t163_n29: return 0.03318982198834419;
  t163_n30: return 0.11080969870090485;
  t163_n31: return 0.12177389860153198;
  t163_n32: return -0.014677859842777252;
  t163_n33: return -0.06275386363267899;
  t163_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n36;
  t163_n35: return 0.04360082000494003;
  t163_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t163_n56;
  t163_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n43;
  t163_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t163_n40;
  t163_n39: return 0.03344998136162758;
  t163_n40: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n42;
  t163_n41: return 0.1146981343626976;
  t163_n42: return 0.02954774908721447;
  t163_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n51;
  t163_n44: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t163_n46;
  t163_n45: return -0.05269352346658707;
  t163_n46: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t163_n50;
  t163_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n49;
  t163_n48: return 0.14995095133781433;
  t163_n49: return 0.09173114597797394;
  t163_n50: return 0.09602970629930496;
  t163_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t163_n53;
  t163_n52: return -0.11123666912317276;
  t163_n53: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n55;
  t163_n54: return 0.10958313941955566;
  t163_n55: return 0.1112457886338234;
  t163_n56: return -0.0436239130795002;
  t163_n57: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t163_n81;
  t163_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t163_n66;
  t163_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t163_n61;
  t163_n60: return 0.004474981222301722;
  t163_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n63;
  t163_n62: return 0.11716597527265549;
  t163_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t163_n65;
  t163_n64: return 0.04224833846092224;
  t163_n65: return 0.08370360732078552;
  t163_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n70;
  t163_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t163_n69;
  t163_n68: return 0.06655792146921158;
  t163_n69: return 0.11560963839292526;
  t163_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n72;
  t163_n71: return 0.10298063606023788;
  t163_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t163_n74;
  t163_n73: return 0.030460132285952568;
  t163_n74: if (E.getNumReferences() >= 3286040576 /*442.0*/) goto t163_n80;
  t163_n75: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t163_n77;
  t163_n76: return 0.12936969101428986;
  t163_n77: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t163_n79;
  t163_n78: return -0.3013767600059509;
  t163_n79: return 0.141237273812294;
  t163_n80: return 0.10870172083377838;
  t163_n81: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t163_n173;
  t163_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t163_n130;
  t163_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t163_n85;
  t163_n84: return -0.009565899148583412;
  t163_n85: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t163_n87;
  t163_n86: return -0.0030357306823134422;
  t163_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t163_n97;
  t163_n88: if (E.getNumReferences() >= 3290931200 /*670.5*/) goto t163_n90;
  t163_n89: return -0.021221095696091652;
  t163_n90: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t163_n92;
  t163_n91: return -0.016708068549633026;
  t163_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t163_n96;
  t163_n93: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t163_n95;
  t163_n94: return 0.11560119688510895;
  t163_n95: return 0.10107562690973282;
  t163_n96: return 0.05267363041639328;
  t163_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t163_n103;
  t163_n98: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t163_n100;
  t163_n99: return 0.026075201109051704;
  t163_n100: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t163_n102;
  t163_n101: return 0.05697586387395859;
  t163_n102: return 0.10107731074094772;
  t163_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t163_n105;
  t163_n104: return -0.03326351195573807;
  t163_n105: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t163_n127;
  t163_n106: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t163_n108;
  t163_n107: return 0.04126027598977089;
  t163_n108: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t163_n126;
  t163_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n125;
  t163_n110: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t163_n118;
  t163_n111: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n113;
  t163_n112: return 0.07035236805677414;
  t163_n113: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t163_n115;
  t163_n114: return -0.00638721976429224;
  t163_n115: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t163_n117;
  t163_n116: return 0.07334938645362854;
  t163_n117: return 0.013410795480012894;
  t163_n118: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t163_n124;
  t163_n119: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t163_n123;
  t163_n120: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t163_n122;
  t163_n121: return 0.09300994873046875;
  t163_n122: return -0.05894811823964119;
  t163_n123: return 0.11719324439764023;
  t163_n124: return 0.047766342759132385;
  t163_n125: return 0.03209768235683441;
  t163_n126: return -0.10252390801906586;
  t163_n127: if (E.getNumReferences() >= 3316683776 /*5650.5*/) goto t163_n129;
  t163_n128: return -0.0006327289738692343;
  t163_n129: return 0.07026783376932144;
  t163_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t163_n138;
  t163_n131: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t163_n137;
  t163_n132: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t163_n134;
  t163_n133: return 0.006134744267910719;
  t163_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t163_n136;
  t163_n135: return 0.010488833300769329;
  t163_n136: return 0.02725367806851864;
  t163_n137: return -0.10945279896259308;
  t163_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t163_n160;
  t163_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t163_n149;
  t163_n140: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t163_n146;
  t163_n141: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t163_n143;
  t163_n142: return 0.048613373190164566;
  t163_n143: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t163_n145;
  t163_n144: return 0.15374144911766052;
  t163_n145: return 0.5809617638587952;
  t163_n146: if (E.getNumReferences() >= 3332987392 /*21677.0*/) goto t163_n148;
  t163_n147: return -0.05543459951877594;
  t163_n148: return 0.10355474054813385;
  t163_n149: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t163_n159;
  t163_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n156;
  t163_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t163_n155;
  t163_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n154;
  t163_n153: return 0.0011765464441850781;
  t163_n154: return 0.10703639686107635;
  t163_n155: return 0.0025968982372432947;
  t163_n156: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t163_n158;
  t163_n157: return 0.07586495578289032;
  t163_n158: return 0.03198496252298355;
  t163_n159: return 0.006310765631496906;
  t163_n160: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t163_n164;
  t163_n161: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t163_n163;
  t163_n162: return 0.03977745771408081;
  t163_n163: return 0.0944921225309372;
  t163_n164: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t163_n170;
  t163_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t163_n169;
  t163_n166: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n168;
  t163_n167: return 0.12206026911735535;
  t163_n168: return 0.038342319428920746;
  t163_n169: return 0.0829552710056305;
  t163_n170: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t163_n172;
  t163_n171: return 0.12249360233545303;
  t163_n172: return 0.03234643489122391;
  t163_n173: return -0.047135915607213974;
  t163_n174: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t163_n244;
  t163_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t163_n231;
  t163_n176: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t163_n208;
  t163_n177: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t163_n185;
  t163_n178: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t163_n184;
  t163_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n181;
  t163_n180: return -0.19531100988388062;
  t163_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n183;
  t163_n182: return 0.12306822836399078;
  t163_n183: return 0.12473953515291214;
  t163_n184: return 0.017159435898065567;
  t163_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n193;
  t163_n186: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n188;
  t163_n187: return -0.001663518138229847;
  t163_n188: if (E.getNumReferences() >= 3342540672 /*47903.5*/) goto t163_n190;
  t163_n189: return -0.1022966131567955;
  t163_n190: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t163_n192;
  t163_n191: return 0.1205088347196579;
  t163_n192: return -0.13113902509212494;
  t163_n193: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t163_n197;
  t163_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n196;
  t163_n195: return 0.09756768494844437;
  t163_n196: return 0.07297434657812119;
  t163_n197: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t163_n207;
  t163_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n206;
  t163_n199: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t163_n203;
  t163_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n202;
  t163_n201: return 0.10372310876846313;
  t163_n202: return 0.037279192358255386;
  t163_n203: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n205;
  t163_n204: return -0.19561852514743805;
  t163_n205: return 0.08374955505132675;
  t163_n206: return 0.108881376683712;
  t163_n207: return 0.12022096663713455;
  t163_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t163_n210;
  t163_n209: return 0.0029008383862674236;
  t163_n210: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t163_n212;
  t163_n211: return -0.005359471309930086;
  t163_n212: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t163_n230;
  t163_n213: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t163_n229;
  t163_n214: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t163_n228;
  t163_n215: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t163_n223;
  t163_n216: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t163_n218;
  t163_n217: return 0.10318757593631744;
  t163_n218: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t163_n220;
  t163_n219: return 0.125162273645401;
  t163_n220: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t163_n222;
  t163_n221: return 0.0;
  t163_n222: return 0.12170030921697617;
  t163_n223: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t163_n227;
  t163_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t163_n226;
  t163_n225: return 0.0;
  t163_n226: return 0.09342297166585922;
  t163_n227: return 0.07513988018035889;
  t163_n228: return 0.01555407140403986;
  t163_n229: return 0.03104354627430439;
  t163_n230: return 0.011289107613265514;
  t163_n231: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t163_n239;
  t163_n232: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t163_n234;
  t163_n233: return -0.01442734058946371;
  t163_n234: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t163_n238;
  t163_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t163_n237;
  t163_n236: return 0.10274885594844818;
  t163_n237: return 0.1174221932888031;
  t163_n238: return 0.033897727727890015;
  t163_n239: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t163_n243;
  t163_n240: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t163_n242;
  t163_n241: return 0.03226948529481888;
  t163_n242: return 0.1159091591835022;
  t163_n243: return -0.10531175881624222;
  t163_n244: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t163_n254;
  t163_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t163_n253;
  t163_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t163_n248;
  t163_n247: return -0.08964891731739044;
  t163_n248: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t163_n252;
  t163_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t163_n251;
  t163_n250: return -0.1883617341518402;
  t163_n251: return 0.09503157436847687;
  t163_n252: return -0.22293923795223236;
  t163_n253: return 0.09454914927482605;
  t163_n254: return 0.0031545383390039206;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree164(const Example& E) {
  t164_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t164_n78;
  t164_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t164_n3;
  t164_n2: return 0.00047555204946547747;
  t164_n3: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t164_n5;
  t164_n4: return 0.0037867631763219833;
  t164_n5: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t164_n13;
  t164_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t164_n12;
  t164_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t164_n9;
  t164_n8: return -0.0932597815990448;
  t164_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n11;
  t164_n10: return 0.10261143743991852;
  t164_n11: return -0.006226572673767805;
  t164_n12: return -0.04287434369325638;
  t164_n13: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t164_n53;
  t164_n14: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t164_n52;
  t164_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t164_n17;
  t164_n16: return -0.004953397437930107;
  t164_n17: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t164_n27;
  t164_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t164_n20;
  t164_n19: return -0.15345723927021027;
  t164_n20: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t164_n22;
  t164_n21: return -0.04227060452103615;
  t164_n22: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t164_n26;
  t164_n23: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t164_n25;
  t164_n24: return -0.03769074007868767;
  t164_n25: return 0.18540753424167633;
  t164_n26: return 0.0653560608625412;
  t164_n27: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t164_n31;
  t164_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n30;
  t164_n29: return -0.0818609818816185;
  t164_n30: return -0.0022426170762628317;
  t164_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n39;
  t164_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n34;
  t164_n33: return 0.02136388048529625;
  t164_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n36;
  t164_n35: return -0.04393041878938675;
  t164_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t164_n38;
  t164_n37: return 0.03123265691101551;
  t164_n38: return 0.12550877034664154;
  t164_n39: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t164_n51;
  t164_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t164_n50;
  t164_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t164_n43;
  t164_n42: return 0.031708624213933945;
  t164_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t164_n49;
  t164_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t164_n46;
  t164_n45: return 0.08317208290100098;
  t164_n46: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t164_n48;
  t164_n47: return 0.13380439579486847;
  t164_n48: return 0.1508534699678421;
  t164_n49: return -0.026018263772130013;
  t164_n50: return 0.02087215706706047;
  t164_n51: return 0.21365796029567719;
  t164_n52: return -0.016344716772437096;
  t164_n53: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t164_n67;
  t164_n54: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t164_n64;
  t164_n55: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t164_n61;
  t164_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t164_n58;
  t164_n57: return -0.13747380673885345;
  t164_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t164_n60;
  t164_n59: return 0.12235703319311142;
  t164_n60: return -0.09153880923986435;
  t164_n61: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t164_n63;
  t164_n62: return 0.12054448574781418;
  t164_n63: return -0.13825032114982605;
  t164_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n66;
  t164_n65: return 0.07838335633277893;
  t164_n66: return -0.08561631292104721;
  t164_n67: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t164_n73;
  t164_n68: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n72;
  t164_n69: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t164_n71;
  t164_n70: return -0.11474771797657013;
  t164_n71: return 0.11660466343164444;
  t164_n72: return 0.10136471688747406;
  t164_n73: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t164_n77;
  t164_n74: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t164_n76;
  t164_n75: return -0.26631736755371094;
  t164_n76: return 0.1339673101902008;
  t164_n77: return -0.031344082206487656;
  t164_n78: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t164_n252;
  t164_n79: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t164_n107;
  t164_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n102;
  t164_n81: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t164_n83;
  t164_n82: return -0.004487832076847553;
  t164_n83: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t164_n93;
  t164_n84: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t164_n92;
  t164_n85: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t164_n87;
  t164_n86: return 0.08798421919345856;
  t164_n87: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t164_n89;
  t164_n88: return -0.007905972190201283;
  t164_n89: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t164_n91;
  t164_n90: return 0.1151450127363205;
  t164_n91: return 0.1268569678068161;
  t164_n92: return 0.018748272210359573;
  t164_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n101;
  t164_n94: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t164_n96;
  t164_n95: return -0.005477665923535824;
  t164_n96: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t164_n100;
  t164_n97: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t164_n99;
  t164_n98: return 0.09138374030590057;
  t164_n99: return -0.11262167990207672;
  t164_n100: return 0.02389921434223652;
  t164_n101: return -0.06851910054683685;
  t164_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n106;
  t164_n103: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t164_n105;
  t164_n104: return -0.0387607105076313;
  t164_n105: return -0.17789560556411743;
  t164_n106: return 0.018694691359996796;
  t164_n107: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t164_n205;
  t164_n108: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t164_n204;
  t164_n109: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t164_n135;
  t164_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t164_n130;
  t164_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t164_n113;
  t164_n112: return 0.0008465859573334455;
  t164_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n121;
  t164_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t164_n116;
  t164_n115: return -0.10962218046188354;
  t164_n116: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t164_n120;
  t164_n117: if (E.getNumReferences() >= 3281960960 /*317.5*/) goto t164_n119;
  t164_n118: return 0.0;
  t164_n119: return 0.11111635714769363;
  t164_n120: return 0.04206680878996849;
  t164_n121: if (E.getNumReferences() >= 3292168192 /*746.0*/) goto t164_n127;
  t164_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n124;
  t164_n123: return 0.044127609580755234;
  t164_n124: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t164_n126;
  t164_n125: return 0.11584790796041489;
  t164_n126: return 0.0440109483897686;
  t164_n127: if (E.getNumReferences() >= 3293167616 /*807.0*/) goto t164_n129;
  t164_n128: return 0.14461776614189148;
  t164_n129: return 0.045937616378068924;
  t164_n130: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n132;
  t164_n131: return 0.012793325819075108;
  t164_n132: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t164_n134;
  t164_n133: return 0.11045747250318527;
  t164_n134: return -0.10914666950702667;
  t164_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t164_n151;
  t164_n136: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t164_n138;
  t164_n137: return -0.034014992415905;
  t164_n138: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t164_n142;
  t164_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t164_n141;
  t164_n140: return 0.07459478825330734;
  t164_n141: return 0.0963473841547966;
  t164_n142: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t164_n144;
  t164_n143: return -0.13663209974765778;
  t164_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n148;
  t164_n145: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t164_n147;
  t164_n146: return 0.1202511414885521;
  t164_n147: return 0.06697114557027817;
  t164_n148: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t164_n150;
  t164_n149: return -0.00693654827773571;
  t164_n150: return 0.1157338097691536;
  t164_n151: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t164_n173;
  t164_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t164_n166;
  t164_n153: if (E.getNumReferences() >= 3317816320 /*6203.5*/) goto t164_n165;
  t164_n154: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t164_n156;
  t164_n155: return -0.07398267835378647;
  t164_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t164_n162;
  t164_n157: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t164_n161;
  t164_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t164_n160;
  t164_n159: return 0.12052817642688751;
  t164_n160: return -0.10349442064762115;
  t164_n161: return 0.07510969042778015;
  t164_n162: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t164_n164;
  t164_n163: return -0.10312850028276443;
  t164_n164: return 0.18628893792629242;
  t164_n165: return 0.1824316680431366;
  t164_n166: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t164_n168;
  t164_n167: return -0.045248109847307205;
  t164_n168: if (E.getNumReferences() >= 3290480640 /*643.0*/) goto t164_n172;
  t164_n169: if (E.getNumReferences() >= 3280977920 /*287.5*/) goto t164_n171;
  t164_n170: return 0.09165851771831512;
  t164_n171: return 0.11810969561338425;
  t164_n172: return 0.08207377046346664;
  t164_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t164_n185;
  t164_n174: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t164_n176;
  t164_n175: return 0.04656168445944786;
  t164_n176: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t164_n178;
  t164_n177: return 0.12749414145946503;
  t164_n178: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t164_n180;
  t164_n179: return -0.11278913915157318;
  t164_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t164_n182;
  t164_n181: return 0.07612936943769455;
  t164_n182: if (E.getNumReferences() >= 3292618752 /*773.5*/) goto t164_n184;
  t164_n183: return 0.15669429302215576;
  t164_n184: return 0.020068015903234482;
  t164_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t164_n187;
  t164_n186: return 0.028565144166350365;
  t164_n187: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t164_n191;
  t164_n188: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t164_n190;
  t164_n189: return 0.11741072684526443;
  t164_n190: return -0.23411202430725098;
  t164_n191: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t164_n197;
  t164_n192: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t164_n196;
  t164_n193: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t164_n195;
  t164_n194: return 0.11843745410442352;
  t164_n195: return -0.007218184880912304;
  t164_n196: return 0.11959139257669449;
  t164_n197: if (E.getNumReferences() >= 3275816960 /*193.0*/) goto t164_n199;
  t164_n198: return 0.026400092989206314;
  t164_n199: if (E.getNumReferences() >= 3279323136 /*246.5*/) goto t164_n201;
  t164_n200: return 0.10432508587837219;
  t164_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t164_n203;
  t164_n202: return -0.1327662318944931;
  t164_n203: return 0.12469317018985748;
  t164_n204: return -0.005817900877445936;
  t164_n205: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t164_n211;
  t164_n206: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t164_n208;
  t164_n207: return -0.08325809985399246;
  t164_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t164_n210;
  t164_n209: return -0.15709291398525238;
  t164_n210: return 0.10964876413345337;
  t164_n211: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t164_n215;
  t164_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t164_n214;
  t164_n213: return -0.06639596074819565;
  t164_n214: return 0.037090964615345;
  t164_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t164_n217;
  t164_n216: return 0.002676212228834629;
  t164_n217: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t164_n251;
  t164_n218: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t164_n222;
  t164_n219: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t164_n221;
  t164_n220: return 0.08794429153203964;
  t164_n221: return -0.035972390323877335;
  t164_n222: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t164_n250;
  t164_n223: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t164_n245;
  t164_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t164_n226;
  t164_n225: return -0.08135027438402176;
  t164_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t164_n228;
  t164_n227: return -0.004566966090351343;
  t164_n228: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t164_n230;
  t164_n229: return 0.10942614823579788;
  t164_n230: if (E.getNumReferences() >= 3291865088 /*727.5*/) goto t164_n232;
  t164_n231: return -0.004090880509465933;
  t164_n232: if (E.getNumReferences() >= 3314309120 /*4491.0*/) goto t164_n238;
  t164_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t164_n235;
  t164_n234: return 0.1093001589179039;
  t164_n235: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t164_n237;
  t164_n236: return 0.005793809425085783;
  t164_n237: return 0.11960732936859131;
  t164_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t164_n240;
  t164_n239: return -0.08520496636629105;
  t164_n240: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t164_n242;
  t164_n241: return -0.22857792675495148;
  t164_n242: if (E.getNumReferences() >= 3327389696 /*13564.0*/) goto t164_n244;
  t164_n243: return 0.11143941432237625;
  t164_n244: return 0.045656781643629074;
  t164_n245: if (E.getNumReferences() >= 3363327264 /*254260.5*/) goto t164_n249;
  t164_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t164_n248;
  t164_n247: return -0.044647835195064545;
  t164_n248: return 0.11428780108690262;
  t164_n249: return 0.01080297864973545;
  t164_n250: return 0.01902351714670658;
  t164_n251: return 0.10972835123538971;
  t164_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t164_n254;
  t164_n253: return 0.02327170968055725;
  t164_n254: return 0.03970065712928772;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree165(const Example& E) {
  t165_n0: if (E.getNumReferences() >= 3309340672 /*3080.5*/) goto t165_n2;
  t165_n1: return -0.0004028862458653748;
  t165_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t165_n52;
  t165_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t165_n5;
  t165_n4: return 0.010801627300679684;
  t165_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t165_n43;
  t165_n6: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t165_n36;
  t165_n7: if (E.getNumReferences() >= 3344355328 /*54992.0*/) goto t165_n27;
  t165_n8: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t165_n24;
  t165_n9: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t165_n19;
  t165_n10: if (E.getNumReferences() >= 3315905536 /*5270.5*/) goto t165_n12;
  t165_n11: return 0.009025966748595238;
  t165_n12: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t165_n14;
  t165_n13: return 0.05992607772350311;
  t165_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t165_n16;
  t165_n15: return 0.029332172125577927;
  t165_n16: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t165_n18;
  t165_n17: return 0.10314308851957321;
  t165_n18: return 0.05838044360280037;
  t165_n19: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t165_n23;
  t165_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n22;
  t165_n21: return -0.11254341900348663;
  t165_n22: return -1.0256515741348267;
  t165_n23: return -0.006457197014242411;
  t165_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t165_n26;
  t165_n25: return 0.10048037022352219;
  t165_n26: return 0.024316290393471718;
  t165_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n35;
  t165_n28: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t165_n30;
  t165_n29: return 0.5705655217170715;
  t165_n30: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t165_n32;
  t165_n31: return 0.2735494077205658;
  t165_n32: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t165_n34;
  t165_n33: return 0.1425503045320511;
  t165_n34: return 0.1121358573436737;
  t165_n35: return 0.00334366993047297;
  t165_n36: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t165_n38;
  t165_n37: return -0.09486235678195953;
  t165_n38: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t165_n42;
  t165_n39: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t165_n41;
  t165_n40: return 0.1370670199394226;
  t165_n41: return 0.1359836906194687;
  t165_n42: return 0.005842081271111965;
  t165_n43: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t165_n51;
  t165_n44: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t165_n46;
  t165_n45: return -0.17279638350009918;
  t165_n46: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t165_n48;
  t165_n47: return 0.1052354946732521;
  t165_n48: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n50;
  t165_n49: return 0.14039257168769836;
  t165_n50: return 0.14039760828018188;
  t165_n51: return -0.034495119005441666;
  t165_n52: if (E.getNumReferences() >= 3309346816 /*3082.0*/) goto t165_n56;
  t165_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n55;
  t165_n54: return -0.22765815258026123;
  t165_n55: return 0.11891598999500275;
  t165_n56: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t165_n58;
  t165_n57: return -0.00041993072954937816;
  t165_n58: if (E.getNumReferences() >= 3325491712 /*11710.5*/) goto t165_n192;
  t165_n59: if (E.getNumReferences() >= 3325364224 /*11586.0*/) goto t165_n187;
  t165_n60: if (E.getNumReferences() >= 3320644608 /*7584.5*/) goto t165_n78;
  t165_n61: if (E.getNumReferences() >= 3320582144 /*7554.0*/) goto t165_n77;
  t165_n62: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t165_n76;
  t165_n63: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t165_n71;
  t165_n64: if (E.getNumReferences() >= 3309570048 /*3136.5*/) goto t165_n68;
  t165_n65: if (E.getNumReferences() >= 3309533184 /*3127.5*/) goto t165_n67;
  t165_n66: return 0.030377784743905067;
  t165_n67: return 0.10433100163936615;
  t165_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n70;
  t165_n69: return -0.11323612183332443;
  t165_n70: return 0.05722620338201523;
  t165_n71: if (E.getNumReferences() >= 3309365248 /*3086.5*/) goto t165_n75;
  t165_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n74;
  t165_n73: return -0.10212747752666473;
  t165_n74: return 0.10543319582939148;
  t165_n75: return 0.013854891993105412;
  t165_n76: return 0.11174500733613968;
  t165_n77: return -0.6866514086723328;
  t165_n78: if (E.getNumReferences() >= 3321948672 /*8250.5*/) goto t165_n110;
  t165_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t165_n103;
  t165_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t165_n94;
  t165_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n83;
  t165_n82: return -0.017806779593229294;
  t165_n83: if (E.getNumReferences() >= 3321384960 /*7946.0*/) goto t165_n89;
  t165_n84: if (E.getNumReferences() >= 3320866816 /*7693.0*/) goto t165_n88;
  t165_n85: if (E.getNumReferences() >= 3320749056 /*7635.5*/) goto t165_n87;
  t165_n86: return 0.022330328822135925;
  t165_n87: return 0.11966170370578766;
  t165_n88: return 0.001941765658557415;
  t165_n89: if (E.getNumReferences() >= 3321413632 /*7960.0*/) goto t165_n93;
  t165_n90: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n92;
  t165_n91: return 0.1311112940311432;
  t165_n92: return 0.11827903240919113;
  t165_n93: return 0.056425873190164566;
  t165_n94: if (E.getNumReferences() >= 3321060352 /*7787.5*/) goto t165_n100;
  t165_n95: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t165_n99;
  t165_n96: if (E.getNumReferences() >= 3320947712 /*7732.5*/) goto t165_n98;
  t165_n97: return 0.04716522619128227;
  t165_n98: return 0.09963924437761307;
  t165_n99: return 0.11496860533952713;
  t165_n100: if (E.getNumReferences() >= 3321886720 /*8191.0*/) goto t165_n102;
  t165_n101: return 0.06379008293151855;
  t165_n102: return 0.10546834766864777;
  t165_n103: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n105;
  t165_n104: return 0.11506211012601852;
  t165_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n107;
  t165_n106: return -0.10444121062755585;
  t165_n107: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t165_n109;
  t165_n108: return 0.11426880210638046;
  t165_n109: return 0.11981803178787231;
  t165_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n134;
  t165_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t165_n113;
  t165_n112: return -0.14319537580013275;
  t165_n113: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t165_n115;
  t165_n114: return -0.0609855093061924;
  t165_n115: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n127;
  t165_n116: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t165_n126;
  t165_n117: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t165_n119;
  t165_n118: return -0.071821428835392;
  t165_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t165_n121;
  t165_n120: return -0.3284303843975067;
  t165_n121: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n123;
  t165_n122: return -0.8354986310005188;
  t165_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n125;
  t165_n124: return 0.11360827088356018;
  t165_n125: return -0.10886365920305252;
  t165_n126: return -0.14196394383907318;
  t165_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t165_n131;
  t165_n128: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t165_n130;
  t165_n129: return 0.06565193831920624;
  t165_n130: return 0.09551139920949936;
  t165_n131: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t165_n133;
  t165_n132: return 0.10098154097795486;
  t165_n133: return -1.4897332191467285;
  t165_n134: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t165_n182;
  t165_n135: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t165_n177;
  t165_n136: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t165_n156;
  t165_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t165_n149;
  t165_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n140;
  t165_n139: return -0.12606512010097504;
  t165_n140: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t165_n142;
  t165_n141: return -0.10182911157608032;
  t165_n142: if (E.getNumReferences() >= 3323492352 /*9758.0*/) goto t165_n144;
  t165_n143: return 0.09903501719236374;
  t165_n144: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n148;
  t165_n145: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t165_n147;
  t165_n146: return 0.12062319368124008;
  t165_n147: return -0.10855866223573685;
  t165_n148: return -0.08861561864614487;
  t165_n149: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n151;
  t165_n150: return -0.005525455344468355;
  t165_n151: if (E.getNumReferences() >= 3323013120 /*9290.0*/) goto t165_n155;
  t165_n152: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t165_n154;
  t165_n153: return 0.11509793251752853;
  t165_n154: return 0.11199122667312622;
  t165_n155: return -0.037801165133714676;
  t165_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t165_n168;
  t165_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t165_n159;
  t165_n158: return 0.12357891350984573;
  t165_n159: if (E.getNumReferences() >= 3322167808 /*8464.5*/) goto t165_n163;
  t165_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n162;
  t165_n161: return -0.07569428533315659;
  t165_n162: return 0.12121927738189697;
  t165_n163: if (E.getNumReferences() >= 3324302336 /*10549.0*/) goto t165_n165;
  t165_n164: return -0.060341715812683105;
  t165_n165: if (E.getNumReferences() >= 3324882944 /*11116.0*/) goto t165_n167;
  t165_n166: return 0.10120561718940735;
  t165_n167: return -0.12831668555736542;
  t165_n168: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n170;
  t165_n169: return 0.028363768011331558;
  t165_n170: if (E.getNumReferences() >= 3324087808 /*10339.5*/) goto t165_n176;
  t165_n171: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t165_n175;
  t165_n172: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t165_n174;
  t165_n173: return 0.09079837054014206;
  t165_n174: return 0.23696346580982208;
  t165_n175: return -0.02252291329205036;
  t165_n176: return 0.10603144764900208;
  t165_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n179;
  t165_n178: return -0.2985196113586426;
  t165_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t165_n181;
  t165_n180: return 0.09908277541399002;
  t165_n181: return 0.10266083478927612;
  t165_n182: if (E.getNumReferences() >= 3323669504 /*9931.0*/) goto t165_n186;
  t165_n183: if (E.getNumReferences() >= 3322761216 /*9044.0*/) goto t165_n185;
  t165_n184: return 0.025299636647105217;
  t165_n185: return 0.10756243020296097;
  t165_n186: return 0.0036094726528972387;
  t165_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t165_n191;
  t165_n188: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t165_n190;
  t165_n189: return 0.10840442776679993;
  t165_n190: return 0.08436774462461472;
  t165_n191: return 0.11814957857131958;
  t165_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t165_n210;
  t165_n193: if (E.getNumReferences() >= 3325559808 /*11777.0*/) goto t165_n195;
  t165_n194: return -0.25367799401283264;
  t165_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t165_n201;
  t165_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n200;
  t165_n197: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t165_n199;
  t165_n198: return -0.3082372844219208;
  t165_n199: return -0.22847041487693787;
  t165_n200: return -0.04509396106004715;
  t165_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t165_n203;
  t165_n202: return -0.010238808579742908;
  t165_n203: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t165_n209;
  t165_n204: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t165_n206;
  t165_n205: return 0.4666461646556854;
  t165_n206: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t165_n208;
  t165_n207: return 0.18352870643138885;
  t165_n208: return -0.09341245144605637;
  t165_n209: return 0.018004335463047028;
  t165_n210: if (E.getNumReferences() >= 3367651744 /*381517.0*/) goto t165_n244;
  t165_n211: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t165_n231;
  t165_n212: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t165_n216;
  t165_n213: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n215;
  t165_n214: return -0.06497051566839218;
  t165_n215: return 0.03238943591713905;
  t165_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t165_n218;
  t165_n217: return 0.023860769346356392;
  t165_n218: if (E.getNumReferences() >= 3344570752 /*55833.5*/) goto t165_n230;
  t165_n219: if (E.getNumReferences() >= 3335207936 /*26014.0*/) goto t165_n225;
  t165_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t165_n222;
  t165_n221: return 0.011700427159667015;
  t165_n222: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n224;
  t165_n223: return 0.11387111991643906;
  t165_n224: return -0.11144348233938217;
  t165_n225: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n229;
  t165_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t165_n228;
  t165_n227: return 0.06858273595571518;
  t165_n228: return 0.11570139974355698;
  t165_n229: return 0.11966991424560547;
  t165_n230: return 0.02067425660789013;
  t165_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t165_n241;
  t165_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t165_n236;
  t165_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t165_n235;
  t165_n234: return -0.31321507692337036;
  t165_n235: return -0.11088378727436066;
  t165_n236: if (E.getNumReferences() >= 3338822144 /*33378.0*/) goto t165_n238;
  t165_n237: return -0.13375689089298248;
  t165_n238: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t165_n240;
  t165_n239: return 0.062263067811727524;
  t165_n240: return 0.10258661955595016;
  t165_n241: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n243;
  t165_n242: return 0.09664493799209595;
  t165_n243: return 0.026620112359523773;
  t165_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t165_n246;
  t165_n245: return 0.05532413348555565;
  t165_n246: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t165_n248;
  t165_n247: return 0.02750077284872532;
  t165_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t165_n250;
  t165_n249: return 0.11028121411800385;
  t165_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t165_n254;
  t165_n251: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t165_n253;
  t165_n252: return 0.10360893607139587;
  t165_n253: return 0.09512107074260712;
  t165_n254: return 0.06934218853712082;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree166(const Example& E) {
  t166_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t166_n2;
  t166_n1: return -0.0013024130603298545;
  t166_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t166_n84;
  t166_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t166_n81;
  t166_n4: if (E.getNumReferences() >= 3329800192 /*15918.0*/) goto t166_n64;
  t166_n5: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t166_n61;
  t166_n6: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t166_n44;
  t166_n7: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t166_n41;
  t166_n8: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t166_n14;
  t166_n9: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n13;
  t166_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t166_n12;
  t166_n11: return -0.1203548014163971;
  t166_n12: return -0.0047096204943954945;
  t166_n13: return 0.004620173014700413;
  t166_n14: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t166_n40;
  t166_n15: if (E.getNumReferences() >= 3266969600 /*93.0*/) goto t166_n39;
  t166_n16: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t166_n38;
  t166_n17: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t166_n31;
  t166_n18: if (E.getNumReferences() >= 3263561728 /*67.0*/) goto t166_n28;
  t166_n19: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t166_n27;
  t166_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t166_n24;
  t166_n21: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t166_n23;
  t166_n22: return 0.017433451488614082;
  t166_n23: return 0.09231309592723846;
  t166_n24: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t166_n26;
  t166_n25: return 0.11225274205207825;
  t166_n26: return 0.09744738042354584;
  t166_n27: return -0.24266070127487183;
  t166_n28: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t166_n30;
  t166_n29: return 0.1316603124141693;
  t166_n30: return 0.07556340098381042;
  t166_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t166_n35;
  t166_n32: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t166_n34;
  t166_n33: return -0.03228405863046646;
  t166_n34: return 0.10245022177696228;
  t166_n35: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t166_n37;
  t166_n36: return 0.0973496064543724;
  t166_n37: return 0.12241137772798538;
  t166_n38: return -0.0662304237484932;
  t166_n39: return 0.10160166770219803;
  t166_n40: return -0.07822781056165695;
  t166_n41: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t166_n43;
  t166_n42: return 0.102906234562397;
  t166_n43: return -0.03826082870364189;
  t166_n44: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t166_n56;
  t166_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n47;
  t166_n46: return -0.09193561971187592;
  t166_n47: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t166_n51;
  t166_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t166_n50;
  t166_n49: return -0.09826099127531052;
  t166_n50: return -0.012689637020230293;
  t166_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t166_n53;
  t166_n52: return -0.05631566420197487;
  t166_n53: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n55;
  t166_n54: return 0.10512089729309082;
  t166_n55: return -0.16302412748336792;
  t166_n56: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t166_n60;
  t166_n57: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t166_n59;
  t166_n58: return -0.1423855870962143;
  t166_n59: return 0.0868086889386177;
  t166_n60: return 0.12792527675628662;
  t166_n61: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t166_n63;
  t166_n62: return -0.004984728526324034;
  t166_n63: return 0.0023051206953823566;
  t166_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t166_n78;
  t166_n65: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t166_n77;
  t166_n66: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t166_n70;
  t166_n67: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n69;
  t166_n68: return 0.11061973869800568;
  t166_n69: return 0.12728118896484375;
  t166_n70: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t166_n76;
  t166_n71: if (E.getNumReferences() >= 3336411136 /*28364.0*/) goto t166_n73;
  t166_n72: return 0.11994786560535431;
  t166_n73: if (E.getNumReferences() >= 3343861504 /*53063.0*/) goto t166_n75;
  t166_n74: return -0.3567308485507965;
  t166_n75: return 0.10179830342531204;
  t166_n76: return 0.038064323365688324;
  t166_n77: return 0.009553967043757439;
  t166_n78: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t166_n80;
  t166_n79: return -0.036171600222587585;
  t166_n80: return 0.10576992481946945;
  t166_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t166_n83;
  t166_n82: return -9.390151535626501e-05;
  t166_n83: return 0.0451197475194931;
  t166_n84: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t166_n250;
  t166_n85: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t166_n209;
  t166_n86: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t166_n188;
  t166_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t166_n133;
  t166_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t166_n90;
  t166_n89: return 0.0020941407419741154;
  t166_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t166_n116;
  t166_n91: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t166_n111;
  t166_n92: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t166_n102;
  t166_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t166_n95;
  t166_n94: return 0.009713796898722649;
  t166_n95: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t166_n97;
  t166_n96: return 0.00614231638610363;
  t166_n97: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t166_n101;
  t166_n98: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t166_n100;
  t166_n99: return 0.07721754908561707;
  t166_n100: return 0.131268709897995;
  t166_n101: return 0.019251078367233276;
  t166_n102: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t166_n104;
  t166_n103: return 0.06289055943489075;
  t166_n104: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t166_n106;
  t166_n105: return 0.10657040774822235;
  t166_n106: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t166_n108;
  t166_n107: return 0.02226862497627735;
  t166_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n110;
  t166_n109: return -0.254813015460968;
  t166_n110: return 0.1828266680240631;
  t166_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t166_n113;
  t166_n112: return -0.02251775749027729;
  t166_n113: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t166_n115;
  t166_n114: return 0.01433639321476221;
  t166_n115: return 0.125406414270401;
  t166_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t166_n122;
  t166_n117: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t166_n119;
  t166_n118: return -0.1570449322462082;
  t166_n119: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t166_n121;
  t166_n120: return 0.022328443825244904;
  t166_n121: return 0.13047382235527039;
  t166_n122: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t166_n130;
  t166_n123: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t166_n129;
  t166_n124: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t166_n126;
  t166_n125: return 0.0706963911652565;
  t166_n126: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t166_n128;
  t166_n127: return 0.11085617542266846;
  t166_n128: return 0.06085053086280823;
  t166_n129: return -0.0813262015581131;
  t166_n130: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t166_n132;
  t166_n131: return 0.10631050914525986;
  t166_n132: return -0.02597920410335064;
  t166_n133: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t166_n183;
  t166_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n142;
  t166_n135: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t166_n141;
  t166_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t166_n138;
  t166_n137: return -0.06358297169208527;
  t166_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t166_n140;
  t166_n139: return -0.21512427926063538;
  t166_n140: return 0.03930584713816643;
  t166_n141: return -0.020858002826571465;
  t166_n142: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t166_n164;
  t166_n143: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t166_n145;
  t166_n144: return -0.021289797499775887;
  t166_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t166_n153;
  t166_n146: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t166_n148;
  t166_n147: return -0.008002053014934063;
  t166_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t166_n150;
  t166_n149: return 0.04679303616285324;
  t166_n150: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t166_n152;
  t166_n151: return 0.09751445800065994;
  t166_n152: return 0.10637523978948593;
  t166_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t166_n157;
  t166_n154: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t166_n156;
  t166_n155: return -0.08107952028512955;
  t166_n156: return 0.18743331730365753;
  t166_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n161;
  t166_n158: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t166_n160;
  t166_n159: return 0.2148398756980896;
  t166_n160: return -0.21557702124118805;
  t166_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t166_n163;
  t166_n162: return 0.37430113554000854;
  t166_n163: return 0.1210348904132843;
  t166_n164: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t166_n182;
  t166_n165: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t166_n169;
  t166_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t166_n168;
  t166_n167: return 0.005261542741209269;
  t166_n168: return 0.04157360643148422;
  t166_n169: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t166_n171;
  t166_n170: return 0.022649414837360382;
  t166_n171: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t166_n179;
  t166_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n174;
  t166_n173: return 0.10754420608282089;
  t166_n174: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t166_n176;
  t166_n175: return 0.05319057032465935;
  t166_n176: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t166_n178;
  t166_n177: return 0.11412031203508377;
  t166_n178: return 0.10717040300369263;
  t166_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t166_n181;
  t166_n180: return -0.055511459708213806;
  t166_n181: return 0.1371784508228302;
  t166_n182: return -0.021754663437604904;
  t166_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t166_n185;
  t166_n184: return -0.0588979534804821;
  t166_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t166_n187;
  t166_n186: return -0.032113172113895416;
  t166_n187: return 0.01437383983284235;
  t166_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t166_n204;
  t166_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t166_n191;
  t166_n190: return -0.09906313568353653;
  t166_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t166_n197;
  t166_n192: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t166_n194;
  t166_n193: return 0.07459750026464462;
  t166_n194: if (E.getNumReferences() >= 3279159296 /*244.0*/) goto t166_n196;
  t166_n195: return 0.4332926273345947;
  t166_n196: return 0.11216230690479279;
  t166_n197: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t166_n199;
  t166_n198: return 0.008094200864434242;
  t166_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t166_n203;
  t166_n200: if (E.getNumReferences() >= 3275423744 /*187.0*/) goto t166_n202;
  t166_n201: return 0.10119996964931488;
  t166_n202: return 0.030258744955062866;
  t166_n203: return 0.10822523385286331;
  t166_n204: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n208;
  t166_n205: if (E.getNumReferences() >= 3279519744 /*249.5*/) goto t166_n207;
  t166_n206: return 0.08520627021789551;
  t166_n207: return -0.355392187833786;
  t166_n208: return 0.11209701746702194;
  t166_n209: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t166_n249;
  t166_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t166_n214;
  t166_n211: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t166_n213;
  t166_n212: return -0.06858737021684647;
  t166_n213: return -0.021851185709238052;
  t166_n214: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t166_n220;
  t166_n215: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t166_n217;
  t166_n216: return -0.026937320828437805;
  t166_n217: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t166_n219;
  t166_n218: return -0.01580287143588066;
  t166_n219: return 0.0278032124042511;
  t166_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t166_n242;
  t166_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t166_n241;
  t166_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t166_n226;
  t166_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t166_n225;
  t166_n224: return -0.09521282464265823;
  t166_n225: return -0.24198418855667114;
  t166_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t166_n236;
  t166_n227: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t166_n235;
  t166_n228: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t166_n230;
  t166_n229: return -0.028844423592090607;
  t166_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t166_n234;
  t166_n231: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t166_n233;
  t166_n232: return 0.12220916897058487;
  t166_n233: return 0.09175761044025421;
  t166_n234: return -0.2142580896615982;
  t166_n235: return -0.17651353776454926;
  t166_n236: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t166_n238;
  t166_n237: return -0.00044208765029907227;
  t166_n238: if (E.getNumReferences() >= 3265658880 /*83.0*/) goto t166_n240;
  t166_n239: return 0.10696009546518326;
  t166_n240: return -0.037118688225746155;
  t166_n241: return -0.019200734794139862;
  t166_n242: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t166_n244;
  t166_n243: return -0.19925455749034882;
  t166_n244: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t166_n248;
  t166_n245: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t166_n247;
  t166_n246: return 0.05786784365773201;
  t166_n247: return 0.09871626645326614;
  t166_n248: return -0.19606713950634003;
  t166_n249: return 0.01232688594609499;
  t166_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t166_n252;
  t166_n251: return 0.007620596326887608;
  t166_n252: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t166_n254;
  t166_n253: return 0.0005229103844612837;
  t166_n254: return 0.01492831390351057;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree167(const Example& E) {
  t167_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t167_n140;
  t167_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t167_n3;
  t167_n2: return -0.01731361821293831;
  t167_n3: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t167_n139;
  t167_n4: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t167_n6;
  t167_n5: return -0.004017665516585112;
  t167_n6: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t167_n72;
  t167_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t167_n23;
  t167_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t167_n22;
  t167_n9: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t167_n21;
  t167_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n12;
  t167_n11: return -0.11495233327150345;
  t167_n12: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t167_n14;
  t167_n13: return -0.03477218374609947;
  t167_n14: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t167_n20;
  t167_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t167_n17;
  t167_n16: return 0.03045211173593998;
  t167_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t167_n19;
  t167_n18: return 0.15161176025867462;
  t167_n19: return -0.16400612890720367;
  t167_n20: return -0.11571458727121353;
  t167_n21: return 0.09827826917171478;
  t167_n22: return 0.03179502859711647;
  t167_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t167_n25;
  t167_n24: return 0.009754561819136143;
  t167_n25: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t167_n43;
  t167_n26: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t167_n36;
  t167_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n35;
  t167_n28: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t167_n30;
  t167_n29: return 0.024232368916273117;
  t167_n30: if (E.getNumReferences() >= 3271753728 /*131.0*/) goto t167_n32;
  t167_n31: return 0.08316969126462936;
  t167_n32: if (E.getNumReferences() >= 3278766080 /*238.0*/) goto t167_n34;
  t167_n33: return 0.12243986129760742;
  t167_n34: return 0.11380459368228912;
  t167_n35: return -0.015327430330216885;
  t167_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t167_n42;
  t167_n37: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t167_n39;
  t167_n38: return 0.14212682843208313;
  t167_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t167_n41;
  t167_n40: return 0.036518123000860214;
  t167_n41: return 0.10510057955980301;
  t167_n42: return -0.1449078619480133;
  t167_n43: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t167_n45;
  t167_n44: return 0.0006411854410544038;
  t167_n45: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t167_n59;
  t167_n46: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t167_n56;
  t167_n47: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t167_n55;
  t167_n48: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t167_n54;
  t167_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n51;
  t167_n50: return 0.07861961424350739;
  t167_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n53;
  t167_n52: return 0.1107986643910408;
  t167_n53: return 0.11630908399820328;
  t167_n54: return -0.20949016511440277;
  t167_n55: return 0.12156553566455841;
  t167_n56: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t167_n58;
  t167_n57: return -0.13156843185424805;
  t167_n58: return 0.14542941749095917;
  t167_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n65;
  t167_n60: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t167_n62;
  t167_n61: return 0.12719812989234924;
  t167_n62: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t167_n64;
  t167_n63: return -0.0017786158714443445;
  t167_n64: return 0.09535789489746094;
  t167_n65: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t167_n69;
  t167_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n68;
  t167_n67: return 0.16434264183044434;
  t167_n68: return -0.08763578534126282;
  t167_n69: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t167_n71;
  t167_n70: return 0.10250526666641235;
  t167_n71: return 0.044459372758865356;
  t167_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t167_n136;
  t167_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n75;
  t167_n74: return 0.011665952391922474;
  t167_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t167_n123;
  t167_n76: if (E.getNumReferences() >= 3263758336 /*68.5*/) goto t167_n118;
  t167_n77: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t167_n111;
  t167_n78: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t167_n102;
  t167_n79: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t167_n101;
  t167_n80: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n94;
  t167_n81: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t167_n87;
  t167_n82: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t167_n86;
  t167_n83: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t167_n85;
  t167_n84: return 0.06519754976034164;
  t167_n85: return 0.056503135710954666;
  t167_n86: return -0.0775432363152504;
  t167_n87: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t167_n93;
  t167_n88: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t167_n92;
  t167_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t167_n91;
  t167_n90: return 0.0014120611594989896;
  t167_n91: return 0.12104490399360657;
  t167_n92: return 0.11413145810365677;
  t167_n93: return 0.26475438475608826;
  t167_n94: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t167_n100;
  t167_n95: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t167_n99;
  t167_n96: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t167_n98;
  t167_n97: return -0.12278396636247635;
  t167_n98: return 0.1135520190000534;
  t167_n99: return 0.05093660578131676;
  t167_n100: return -0.2167055755853653;
  t167_n101: return 0.12269947677850723;
  t167_n102: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n104;
  t167_n103: return -0.005643406882882118;
  t167_n104: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t167_n110;
  t167_n105: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t167_n107;
  t167_n106: return -0.07795283943414688;
  t167_n107: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t167_n109;
  t167_n108: return 0.07377547770738602;
  t167_n109: return 0.13399021327495575;
  t167_n110: return 0.05953291431069374;
  t167_n111: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t167_n113;
  t167_n112: return 0.1241844892501831;
  t167_n113: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t167_n117;
  t167_n114: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t167_n116;
  t167_n115: return 0.14473801851272583;
  t167_n116: return 0.04182086139917374;
  t167_n117: return 0.10393523424863815;
  t167_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t167_n122;
  t167_n119: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t167_n121;
  t167_n120: return -0.452038437128067;
  t167_n121: return 0.10636299848556519;
  t167_n122: return -0.01606440544128418;
  t167_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t167_n135;
  t167_n124: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t167_n126;
  t167_n125: return 0.04912089928984642;
  t167_n126: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t167_n130;
  t167_n127: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n129;
  t167_n128: return -0.2038867324590683;
  t167_n129: return 0.1228419616818428;
  t167_n130: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t167_n134;
  t167_n131: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t167_n133;
  t167_n132: return 0.360183447599411;
  t167_n133: return 0.10765651613473892;
  t167_n134: return 0.062453627586364746;
  t167_n135: return -0.06439634412527084;
  t167_n136: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t167_n138;
  t167_n137: return -0.030147533863782883;
  t167_n138: return 0.08036525547504425;
  t167_n139: return 0.010343162342905998;
  t167_n140: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t167_n254;
  t167_n141: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t167_n241;
  t167_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t167_n144;
  t167_n143: return 0.0012373740319162607;
  t167_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t167_n164;
  t167_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t167_n147;
  t167_n146: return -0.10968296229839325;
  t167_n147: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n149;
  t167_n148: return 0.0034278465900570154;
  t167_n149: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t167_n155;
  t167_n150: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t167_n154;
  t167_n151: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t167_n153;
  t167_n152: return 0.05393138900399208;
  t167_n153: return -0.0015300634549930692;
  t167_n154: return 0.0329853892326355;
  t167_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t167_n161;
  t167_n156: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t167_n160;
  t167_n157: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t167_n159;
  t167_n158: return -0.0559052973985672;
  t167_n159: return 0.03819743171334267;
  t167_n160: return 0.03884974867105484;
  t167_n161: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t167_n163;
  t167_n162: return -0.029203834012150764;
  t167_n163: return 0.04010125249624252;
  t167_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t167_n166;
  t167_n165: return 0.007744935341179371;
  t167_n166: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t167_n168;
  t167_n167: return 0.008352930657565594;
  t167_n168: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t167_n190;
  t167_n169: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t167_n189;
  t167_n170: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t167_n186;
  t167_n171: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t167_n173;
  t167_n172: return -0.062421850860118866;
  t167_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t167_n175;
  t167_n174: return -0.04491104185581207;
  t167_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t167_n185;
  t167_n176: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t167_n182;
  t167_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t167_n179;
  t167_n178: return -0.05111731216311455;
  t167_n179: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t167_n181;
  t167_n180: return -0.3596497178077698;
  t167_n181: return 0.10588054358959198;
  t167_n182: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t167_n184;
  t167_n183: return 0.07548337429761887;
  t167_n184: return 0.09466294944286346;
  t167_n185: return -0.013570165261626244;
  t167_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t167_n188;
  t167_n187: return -0.0336991585791111;
  t167_n188: return 0.0291027519851923;
  t167_n189: return 0.06961935758590698;
  t167_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t167_n192;
  t167_n191: return -0.002079297322779894;
  t167_n192: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t167_n240;
  t167_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t167_n239;
  t167_n194: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t167_n200;
  t167_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t167_n197;
  t167_n196: return 0.06449299305677414;
  t167_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t167_n199;
  t167_n198: return -0.12669797241687775;
  t167_n199: return 0.0848488062620163;
  t167_n200: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t167_n210;
  t167_n201: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t167_n209;
  t167_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t167_n204;
  t167_n203: return 0.05188394710421562;
  t167_n204: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n206;
  t167_n205: return 0.08466019481420517;
  t167_n206: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t167_n208;
  t167_n207: return 0.09834721684455872;
  t167_n208: return -0.1497783213853836;
  t167_n209: return 0.0204024501144886;
  t167_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t167_n222;
  t167_n211: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t167_n221;
  t167_n212: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t167_n216;
  t167_n213: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t167_n215;
  t167_n214: return 0.08385146409273148;
  t167_n215: return -0.06416063010692596;
  t167_n216: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t167_n220;
  t167_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t167_n219;
  t167_n218: return 0.1022339016199112;
  t167_n219: return 0.10575056076049805;
  t167_n220: return -0.05549641326069832;
  t167_n221: return 0.07160607725381851;
  t167_n222: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t167_n238;
  t167_n223: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t167_n233;
  t167_n224: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n226;
  t167_n225: return 0.030912624672055244;
  t167_n226: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t167_n232;
  t167_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t167_n229;
  t167_n228: return -0.11171264946460724;
  t167_n229: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t167_n231;
  t167_n230: return 0.11457303911447525;
  t167_n231: return -0.10007558763027191;
  t167_n232: return 0.08946966379880905;
  t167_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t167_n235;
  t167_n234: return -0.13837338984012604;
  t167_n235: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t167_n237;
  t167_n236: return 0.11439261585474014;
  t167_n237: return 0.12005655467510223;
  t167_n238: return 0.1513637751340866;
  t167_n239: return 0.021947365254163742;
  t167_n240: return -0.10341797769069672;
  t167_n241: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t167_n243;
  t167_n242: return -0.0315253846347332;
  t167_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t167_n253;
  t167_n244: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t167_n246;
  t167_n245: return -0.0037527878303080797;
  t167_n246: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t167_n252;
  t167_n247: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t167_n251;
  t167_n248: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t167_n250;
  t167_n249: return 0.04515055939555168;
  t167_n250: return -0.019066888839006424;
  t167_n251: return 0.009526156820356846;
  t167_n252: return 0.04132305085659027;
  t167_n253: return 0.009333179332315922;
  t167_n254: return -0.0595644935965538;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree168(const Example& E) {
  t168_n0: if (E.getNumReferences() >= 3301019648 /*1548.5*/) goto t168_n2;
  t168_n1: return -0.00042821592069230974;
  t168_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t168_n76;
  t168_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n75;
  t168_n4: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t168_n6;
  t168_n5: return -0.008900318294763565;
  t168_n6: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t168_n62;
  t168_n7: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t168_n15;
  t168_n8: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t168_n10;
  t168_n9: return 0.07511236518621445;
  t168_n10: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t168_n12;
  t168_n11: return -0.018852047622203827;
  t168_n12: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t168_n14;
  t168_n13: return 0.11205390095710754;
  t168_n14: return 0.12224394083023071;
  t168_n15: if (E.getNumReferences() >= 3362860128 /*246961.5*/) goto t168_n53;
  t168_n16: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t168_n50;
  t168_n17: if (E.getNumReferences() >= 3339244032 /*35026.0*/) goto t168_n21;
  t168_n18: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t168_n20;
  t168_n19: return 0.047662053257226944;
  t168_n20: return -0.009794823825359344;
  t168_n21: if (E.getNumReferences() >= 3342848512 /*49106.0*/) goto t168_n41;
  t168_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n32;
  t168_n23: if (E.getNumReferences() >= 3339443456 /*35805.0*/) goto t168_n29;
  t168_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t168_n28;
  t168_n25: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t168_n27;
  t168_n26: return -0.1744695007801056;
  t168_n27: return 0.10941547155380249;
  t168_n28: return -0.4619182050228119;
  t168_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t168_n31;
  t168_n30: return -0.015808967873454094;
  t168_n31: return 0.05410582199692726;
  t168_n32: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t168_n36;
  t168_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t168_n35;
  t168_n34: return 0.04558630287647247;
  t168_n35: return 0.09394057840108871;
  t168_n36: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t168_n40;
  t168_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t168_n39;
  t168_n38: return -0.13745594024658203;
  t168_n39: return 0.1036667451262474;
  t168_n40: return 0.060195621103048325;
  t168_n41: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t168_n49;
  t168_n42: if (E.getNumReferences() >= 3362126976 /*235506.0*/) goto t168_n46;
  t168_n43: if (E.getNumReferences() >= 3347375936 /*68046.5*/) goto t168_n45;
  t168_n44: return 0.03089272603392601;
  t168_n45: return -0.054993342608213425;
  t168_n46: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n48;
  t168_n47: return 0.047086089849472046;
  t168_n48: return -0.12144618481397629;
  t168_n49: return 0.025004493072628975;
  t168_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t168_n52;
  t168_n51: return 0.01515953429043293;
  t168_n52: return 0.08853618055582047;
  t168_n53: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t168_n59;
  t168_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n58;
  t168_n55: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t168_n57;
  t168_n56: return 0.0;
  t168_n57: return 0.0888710767030716;
  t168_n58: return -0.11313435435295105;
  t168_n59: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t168_n61;
  t168_n60: return -0.13022339344024658;
  t168_n61: return -0.0015927581116557121;
  t168_n62: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t168_n64;
  t168_n63: return 0.004319565370678902;
  t168_n64: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t168_n66;
  t168_n65: return -0.03697730600833893;
  t168_n66: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t168_n74;
  t168_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n69;
  t168_n68: return -0.24613913893699646;
  t168_n69: if (E.getNumReferences() >= 3338529536 /*32501.5*/) goto t168_n71;
  t168_n70: return -0.11830008774995804;
  t168_n71: if (E.getNumReferences() >= 3345410816 /*59115.0*/) goto t168_n73;
  t168_n72: return 0.419765442609787;
  t168_n73: return 0.054706476628780365;
  t168_n74: return -0.5868790149688721;
  t168_n75: return 0.021171920001506805;
  t168_n76: if (E.getNumReferences() >= 3301031936 /*1550.0*/) goto t168_n82;
  t168_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t168_n79;
  t168_n78: return 0.05979115515947342;
  t168_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t168_n81;
  t168_n80: return -0.10025670379400253;
  t168_n81: return 0.16526784002780914;
  t168_n82: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t168_n84;
  t168_n83: return -0.0008764003869146109;
  t168_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t168_n144;
  t168_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t168_n101;
  t168_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n98;
  t168_n87: if (E.getNumReferences() >= 3331894528 /*19542.5*/) goto t168_n89;
  t168_n88: return -0.03630350902676582;
  t168_n89: if (E.getNumReferences() >= 3333234688 /*22160.0*/) goto t168_n97;
  t168_n90: if (E.getNumReferences() >= 3333127936 /*21951.5*/) goto t168_n96;
  t168_n91: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t168_n95;
  t168_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t168_n94;
  t168_n93: return 0.13274185359477997;
  t168_n94: return 0.1263469159603119;
  t168_n95: return 0.08095669001340866;
  t168_n96: return 0.11058309674263;
  t168_n97: return 0.02631274238228798;
  t168_n98: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n100;
  t168_n99: return -0.1018514633178711;
  t168_n100: return 0.01694960705935955;
  t168_n101: if (E.getNumReferences() >= 3319645184 /*7096.5*/) goto t168_n143;
  t168_n102: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t168_n124;
  t168_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t168_n117;
  t168_n104: if (E.getNumReferences() >= 3318055936 /*6320.5*/) goto t168_n116;
  t168_n105: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t168_n109;
  t168_n106: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t168_n108;
  t168_n107: return -0.011604161001741886;
  t168_n108: return 0.05872621387243271;
  t168_n109: if (E.getNumReferences() >= 3317976064 /*6281.5*/) goto t168_n113;
  t168_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t168_n112;
  t168_n111: return 0.11928705126047134;
  t168_n112: return 0.14443339407444;
  t168_n113: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n115;
  t168_n114: return -0.2586263120174408;
  t168_n115: return 0.12248887866735458;
  t168_n116: return -0.17485187947750092;
  t168_n117: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n119;
  t168_n118: return -0.010136459954082966;
  t168_n119: if (E.getNumReferences() >= 3303985152 /*1910.5*/) goto t168_n121;
  t168_n120: return 0.09178287535905838;
  t168_n121: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t168_n123;
  t168_n122: return -0.07947573065757751;
  t168_n123: return 0.09768825769424438;
  t168_n124: if (E.getNumReferences() >= 3318811648 /*6689.5*/) goto t168_n132;
  t168_n125: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t168_n131;
  t168_n126: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t168_n128;
  t168_n127: return 0.0992313027381897;
  t168_n128: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n130;
  t168_n129: return 0.11417999863624573;
  t168_n130: return 0.08836069703102112;
  t168_n131: return -0.2537690997123718;
  t168_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t168_n142;
  t168_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n135;
  t168_n134: return -0.22629715502262115;
  t168_n135: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t168_n137;
  t168_n136: return -0.11177241802215576;
  t168_n137: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t168_n141;
  t168_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n140;
  t168_n139: return 0.156267449259758;
  t168_n140: return 0.08189953118562698;
  t168_n141: return 0.12381886690855026;
  t168_n142: return -0.04141784831881523;
  t168_n143: return 0.0075153508223593235;
  t168_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t168_n178;
  t168_n145: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t168_n173;
  t168_n146: if (E.getNumReferences() >= 3310270464 /*3307.5*/) goto t168_n156;
  t168_n147: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t168_n153;
  t168_n148: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t168_n150;
  t168_n149: return -0.28760671615600586;
  t168_n150: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t168_n152;
  t168_n151: return 0.09872609376907349;
  t168_n152: return 0.02224471978843212;
  t168_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t168_n155;
  t168_n154: return 0.11206661909818649;
  t168_n155: return 0.10072321444749832;
  t168_n156: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t168_n158;
  t168_n157: return -0.36273595690727234;
  t168_n158: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t168_n172;
  t168_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t168_n161;
  t168_n160: return -0.03129902482032776;
  t168_n161: if (E.getNumReferences() >= 3322163200 /*8460.0*/) goto t168_n163;
  t168_n162: return -0.12418938428163528;
  t168_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t168_n167;
  t168_n164: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t168_n166;
  t168_n165: return 0.10093948245048523;
  t168_n166: return -0.1377376914024353;
  t168_n167: if (E.getNumReferences() >= 3328941056 /*15079.0*/) goto t168_n169;
  t168_n168: return 0.10744485259056091;
  t168_n169: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t168_n171;
  t168_n170: return 0.10599585622549057;
  t168_n171: return -0.08583353459835052;
  t168_n172: return -0.22123268246650696;
  t168_n173: if (E.getNumReferences() >= 3364974544 /*297854.5*/) goto t168_n177;
  t168_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t168_n176;
  t168_n175: return -0.003990662284195423;
  t168_n176: return 0.11291659623384476;
  t168_n177: return 0.009944423101842403;
  t168_n178: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t168_n254;
  t168_n179: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t168_n241;
  t168_n180: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t168_n182;
  t168_n181: return -0.023433450609445572;
  t168_n182: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t168_n240;
  t168_n183: if (E.getNumReferences() >= 3309326336 /*3077.0*/) goto t168_n189;
  t168_n184: if (E.getNumReferences() >= 3304095744 /*1924.0*/) goto t168_n186;
  t168_n185: return -0.0020619460847228765;
  t168_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t168_n188;
  t168_n187: return -0.4578133225440979;
  t168_n188: return -0.08519161492586136;
  t168_n189: if (E.getNumReferences() >= 3310000128 /*3241.5*/) goto t168_n193;
  t168_n190: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t168_n192;
  t168_n191: return 0.110181525349617;
  t168_n192: return -0.0005644728662446141;
  t168_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n195;
  t168_n194: return -0.12173125147819519;
  t168_n195: if (E.getNumReferences() >= 3320567808 /*7547.0*/) goto t168_n207;
  t168_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t168_n204;
  t168_n197: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t168_n201;
  t168_n198: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t168_n200;
  t168_n199: return -0.32799896597862244;
  t168_n200: return 0.0878758355975151;
  t168_n201: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t168_n203;
  t168_n202: return -0.0396004393696785;
  t168_n203: return 0.10608009248971939;
  t168_n204: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t168_n206;
  t168_n205: return 0.08858934789896011;
  t168_n206: return -0.49200573563575745;
  t168_n207: if (E.getNumReferences() >= 3322433024 /*8723.5*/) goto t168_n213;
  t168_n208: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t168_n212;
  t168_n209: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t168_n211;
  t168_n210: return 0.024583935737609863;
  t168_n211: return 0.10238771885633469;
  t168_n212: return 0.12676191329956055;
  t168_n213: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t168_n227;
  t168_n214: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t168_n218;
  t168_n215: if (E.getNumReferences() >= 3323767808 /*10027.0*/) goto t168_n217;
  t168_n216: return 0.12608960270881653;
  t168_n217: return -0.013140657916665077;
  t168_n218: if (E.getNumReferences() >= 3323137024 /*9411.0*/) goto t168_n220;
  t168_n219: return 0.21156983077526093;
  t168_n220: if (E.getNumReferences() >= 3324100096 /*10351.5*/) goto t168_n222;
  t168_n221: return -0.21692651510238647;
  t168_n222: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t168_n224;
  t168_n223: return 0.12419524043798447;
  t168_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t168_n226;
  t168_n225: return 0.0365569181740284;
  t168_n226: return 0.12315937131643295;
  t168_n227: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t168_n237;
  t168_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t168_n230;
  t168_n229: return -0.456790030002594;
  t168_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t168_n232;
  t168_n231: return 0.00909400638192892;
  t168_n232: if (E.getNumReferences() >= 3326458880 /*12655.0*/) goto t168_n234;
  t168_n233: return 0.0725005716085434;
  t168_n234: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t168_n236;
  t168_n235: return 0.11772077530622482;
  t168_n236: return 0.09536238759756088;
  t168_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t168_n239;
  t168_n238: return 0.09837590903043747;
  t168_n239: return 0.06744208186864853;
  t168_n240: return 0.015186401084065437;
  t168_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t168_n253;
  t168_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t168_n244;
  t168_n243: return -0.11275064200162888;
  t168_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t168_n250;
  t168_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t168_n249;
  t168_n246: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t168_n248;
  t168_n247: return -0.13504257798194885;
  t168_n248: return 0.10021056979894638;
  t168_n249: return 0.08625992387533188;
  t168_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t168_n252;
  t168_n251: return 0.08278429508209229;
  t168_n252: return 0.11248033493757248;
  t168_n253: return 0.013491182588040829;
  t168_n254: return -0.011744585819542408;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree169(const Example& E) {
  t169_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t169_n102;
  t169_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t169_n3;
  t169_n2: return -0.10826964676380157;
  t169_n3: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t169_n83;
  t169_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t169_n6;
  t169_n5: return 0.0016324652824550867;
  t169_n6: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t169_n50;
  t169_n7: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t169_n15;
  t169_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t169_n14;
  t169_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t169_n11;
  t169_n10: return 0.012342794798314571;
  t169_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t169_n13;
  t169_n12: return -0.05109015852212906;
  t169_n13: return -0.020928962156176567;
  t169_n14: return 0.004695481155067682;
  t169_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t169_n17;
  t169_n16: return -0.03353520855307579;
  t169_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n19;
  t169_n18: return 0.028499925509095192;
  t169_n19: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t169_n29;
  t169_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t169_n26;
  t169_n21: if (E.getNumReferences() >= 3288825856 /*542.0*/) goto t169_n23;
  t169_n22: return -0.02724814973771572;
  t169_n23: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t169_n25;
  t169_n24: return 0.036706626415252686;
  t169_n25: return 0.09602746367454529;
  t169_n26: if (E.getNumReferences() >= 3281731584 /*310.5*/) goto t169_n28;
  t169_n27: return 0.09848051518201828;
  t169_n28: return -0.353045254945755;
  t169_n29: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t169_n49;
  t169_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n36;
  t169_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t169_n33;
  t169_n32: return 0.03850877657532692;
  t169_n33: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n35;
  t169_n34: return 0.11596714705228806;
  t169_n35: return -0.0388321653008461;
  t169_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t169_n44;
  t169_n37: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n39;
  t169_n38: return -0.051740024238824844;
  t169_n39: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t169_n43;
  t169_n40: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t169_n42;
  t169_n41: return 0.1412803828716278;
  t169_n42: return -0.28366467356681824;
  t169_n43: return -0.5043507218360901;
  t169_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t169_n46;
  t169_n45: return -0.11412868648767471;
  t169_n46: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n48;
  t169_n47: return 0.10858672857284546;
  t169_n48: return 0.11061164736747742;
  t169_n49: return -0.03216706961393356;
  t169_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t169_n58;
  t169_n51: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n53;
  t169_n52: return -0.007189216557890177;
  t169_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n55;
  t169_n54: return -0.006059628911316395;
  t169_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t169_n57;
  t169_n56: return 0.01648963987827301;
  t169_n57: return 0.036748722195625305;
  t169_n58: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t169_n66;
  t169_n59: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t169_n65;
  t169_n60: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t169_n62;
  t169_n61: return 0.0393209308385849;
  t169_n62: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n64;
  t169_n63: return -0.10210158675909042;
  t169_n64: return 0.10687302052974701;
  t169_n65: return 0.010637683793902397;
  t169_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t169_n72;
  t169_n67: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t169_n69;
  t169_n68: return 0.029916971921920776;
  t169_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n71;
  t169_n70: return 0.0669500082731247;
  t169_n71: return 0.005395282059907913;
  t169_n72: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t169_n76;
  t169_n73: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t169_n75;
  t169_n74: return 0.05354776233434677;
  t169_n75: return 0.09245216101408005;
  t169_n76: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t169_n82;
  t169_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n79;
  t169_n78: return 0.11729738116264343;
  t169_n79: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t169_n81;
  t169_n80: return 0.07112911343574524;
  t169_n81: return 0.11679252237081528;
  t169_n82: return 0.06758453696966171;
  t169_n83: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t169_n89;
  t169_n84: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t169_n88;
  t169_n85: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t169_n87;
  t169_n86: return -0.11149334907531738;
  t169_n87: return -0.20288318395614624;
  t169_n88: return -0.08435622602701187;
  t169_n89: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t169_n101;
  t169_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n98;
  t169_n91: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t169_n95;
  t169_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n94;
  t169_n93: return 0.015731364488601685;
  t169_n94: return -1.6316407918930054;
  t169_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n97;
  t169_n96: return 0.0865081176161766;
  t169_n97: return 0.011937323957681656;
  t169_n98: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t169_n100;
  t169_n99: return 0.08924318850040436;
  t169_n100: return 0.07870595902204514;
  t169_n101: return -0.1044497862458229;
  t169_n102: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t169_n240;
  t169_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t169_n227;
  t169_n104: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t169_n142;
  t169_n105: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t169_n115;
  t169_n106: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t169_n112;
  t169_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n109;
  t169_n108: return -0.18622277677059174;
  t169_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n111;
  t169_n110: return 0.11985214054584503;
  t169_n111: return 0.12249067425727844;
  t169_n112: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t169_n114;
  t169_n113: return -0.04419560357928276;
  t169_n114: return 0.05206736922264099;
  t169_n115: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n129;
  t169_n116: if (E.getNumReferences() >= 3342417536 /*47422.5*/) goto t169_n118;
  t169_n117: return -0.08017653971910477;
  t169_n118: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t169_n126;
  t169_n119: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n125;
  t169_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n124;
  t169_n121: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t169_n123;
  t169_n122: return 0.037374939769506454;
  t169_n123: return 0.11850730329751968;
  t169_n124: return 0.09878960996866226;
  t169_n125: return -0.1290939301252365;
  t169_n126: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t169_n128;
  t169_n127: return 0.10345248132944107;
  t169_n128: return -0.12724235653877258;
  t169_n129: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t169_n141;
  t169_n130: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t169_n134;
  t169_n131: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n133;
  t169_n132: return 0.08833277225494385;
  t169_n133: return 0.07041828334331512;
  t169_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t169_n140;
  t169_n135: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t169_n139;
  t169_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n138;
  t169_n137: return 0.09311568737030029;
  t169_n138: return 0.04234400764107704;
  t169_n139: return 0.030671533197164536;
  t169_n140: return 0.10824736952781677;
  t169_n141: return 0.11703091859817505;
  t169_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t169_n206;
  t169_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t169_n145;
  t169_n144: return 0.0011298932367935777;
  t169_n145: if (E.getNumReferences() >= 3346697088 /*64139.5*/) goto t169_n177;
  t169_n146: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t169_n162;
  t169_n147: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t169_n149;
  t169_n148: return 0.10256428271532059;
  t169_n149: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t169_n151;
  t169_n150: return -0.14248675107955933;
  t169_n151: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t169_n155;
  t169_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n154;
  t169_n153: return 0.1108631044626236;
  t169_n154: return 0.09085296839475632;
  t169_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t169_n157;
  t169_n156: return 0.0726114958524704;
  t169_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n159;
  t169_n158: return -0.4123569130897522;
  t169_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n161;
  t169_n160: return 0.07214666903018951;
  t169_n161: return -0.5373157858848572;
  t169_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t169_n170;
  t169_n163: if (E.getNumReferences() >= 3344562560 /*55801.5*/) goto t169_n167;
  t169_n164: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t169_n166;
  t169_n165: return 0.0;
  t169_n166: return 0.1161576509475708;
  t169_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t169_n169;
  t169_n168: return -1.0026590824127197;
  t169_n169: return -0.03007247857749462;
  t169_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n176;
  t169_n171: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t169_n175;
  t169_n172: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n174;
  t169_n173: return 0.09354698657989502;
  t169_n174: return 0.12917102873325348;
  t169_n175: return 0.10793226957321167;
  t169_n176: return 0.13961675763130188;
  t169_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t169_n199;
  t169_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n198;
  t169_n179: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t169_n191;
  t169_n180: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t169_n190;
  t169_n181: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t169_n183;
  t169_n182: return 0.08706644177436829;
  t169_n183: if (E.getNumReferences() >= 3350349056 /*91274.0*/) goto t169_n189;
  t169_n184: if (E.getNumReferences() >= 3350097472 /*89308.5*/) goto t169_n186;
  t169_n185: return -0.15928514301776886;
  t169_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n188;
  t169_n187: return -1.339017629623413;
  t169_n188: return -0.19773127138614655;
  t169_n189: return -0.06207078695297241;
  t169_n190: return 0.0994798019528389;
  t169_n191: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t169_n197;
  t169_n192: if (E.getNumReferences() >= 3349481088 /*84493.0*/) goto t169_n194;
  t169_n193: return -0.33176189661026;
  t169_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t169_n196;
  t169_n195: return 0.10573632270097733;
  t169_n196: return 0.09958138316869736;
  t169_n197: return -0.0025724219158291817;
  t169_n198: return 0.021760890260338783;
  t169_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n201;
  t169_n200: return -0.5708135366439819;
  t169_n201: if (E.getNumReferences() >= 3366869888 /*357084.0*/) goto t169_n203;
  t169_n202: return 0.05674722418189049;
  t169_n203: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n205;
  t169_n204: return 0.12890005111694336;
  t169_n205: return -0.026201358065009117;
  t169_n206: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t169_n208;
  t169_n207: return -0.005846128799021244;
  t169_n208: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t169_n226;
  t169_n209: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t169_n225;
  t169_n210: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t169_n224;
  t169_n211: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t169_n221;
  t169_n212: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t169_n214;
  t169_n213: return 0.10252529382705688;
  t169_n214: if (E.getNumReferences() >= 3352190016 /*105656.5*/) goto t169_n216;
  t169_n215: return 0.0;
  t169_n216: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t169_n218;
  t169_n217: return 0.12185724079608917;
  t169_n218: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t169_n220;
  t169_n219: return 0.11813091486692429;
  t169_n220: return 0.11586550623178482;
  t169_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n223;
  t169_n222: return 0.0882735624909401;
  t169_n223: return 0.07635706663131714;
  t169_n224: return 0.012672771699726582;
  t169_n225: return 0.02870822139084339;
  t169_n226: return 0.006998536642640829;
  t169_n227: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t169_n235;
  t169_n228: if (E.getNumReferences() >= 3364188640 /*273295.0*/) goto t169_n230;
  t169_n229: return -0.011194456368684769;
  t169_n230: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t169_n234;
  t169_n231: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t169_n233;
  t169_n232: return 0.10153960436582565;
  t169_n233: return 0.11582732945680618;
  t169_n234: return 0.029148252680897713;
  t169_n235: if (E.getNumReferences() >= 3365564864 /*316302.0*/) goto t169_n239;
  t169_n236: if (E.getNumReferences() >= 3350436544 /*91957.5*/) goto t169_n238;
  t169_n237: return 0.03660909831523895;
  t169_n238: return 0.11172571778297424;
  t169_n239: return -0.10430265963077545;
  t169_n240: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t169_n254;
  t169_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t169_n243;
  t169_n242: return -0.0031387328635901213;
  t169_n243: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t169_n253;
  t169_n244: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t169_n252;
  t169_n245: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t169_n251;
  t169_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t169_n248;
  t169_n247: return 0.07927939295768738;
  t169_n248: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t169_n250;
  t169_n249: return 0.09105941653251648;
  t169_n250: return 0.06189655140042305;
  t169_n251: return 0.11682170629501343;
  t169_n252: return -0.23750607669353485;
  t169_n253: return 0.11576737463474274;
  t169_n254: return 0.0031968236435204744;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree170(const Example& E) {
  t170_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t170_n2;
  t170_n1: return -0.00042195606511086226;
  t170_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t170_n48;
  t170_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t170_n7;
  t170_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t170_n6;
  t170_n5: return -0.03851437568664551;
  t170_n6: return -0.27344807982444763;
  t170_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t170_n47;
  t170_n8: if (E.getNumReferences() >= 3298402304 /*1229.0*/) goto t170_n14;
  t170_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n11;
  t170_n10: return -0.006162066012620926;
  t170_n11: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t170_n13;
  t170_n12: return 0.11860248446464539;
  t170_n13: return 0.2691657841205597;
  t170_n14: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t170_n18;
  t170_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t170_n17;
  t170_n16: return -0.007081388961523771;
  t170_n17: return 0.0640927329659462;
  t170_n18: if (E.getNumReferences() >= 3325406720 /*11627.5*/) goto t170_n36;
  t170_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t170_n21;
  t170_n20: return 0.059664372354745865;
  t170_n21: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t170_n27;
  t170_n22: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t170_n26;
  t170_n23: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t170_n25;
  t170_n24: return -0.10242967307567596;
  t170_n25: return 0.125668004155159;
  t170_n26: return 0.054407548159360886;
  t170_n27: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t170_n35;
  t170_n28: if (E.getNumReferences() >= 3325212160 /*11437.5*/) goto t170_n32;
  t170_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n31;
  t170_n30: return 0.11942022293806076;
  t170_n31: return 0.07201504707336426;
  t170_n32: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t170_n34;
  t170_n33: return 0.11547777056694031;
  t170_n34: return -0.14027822017669678;
  t170_n35: return -0.1428690403699875;
  t170_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t170_n38;
  t170_n37: return 0.014748482033610344;
  t170_n38: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t170_n40;
  t170_n39: return -0.008167708292603493;
  t170_n40: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t170_n46;
  t170_n41: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t170_n43;
  t170_n42: return 0.08766001462936401;
  t170_n43: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t170_n45;
  t170_n44: return 0.017192553728818893;
  t170_n45: return 0.0629882737994194;
  t170_n46: return -0.03218185901641846;
  t170_n47: return 0.020519327372312546;
  t170_n48: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t170_n50;
  t170_n49: return -0.0008257136796601117;
  t170_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t170_n130;
  t170_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t170_n59;
  t170_n52: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t170_n54;
  t170_n53: return 0.0055969152599573135;
  t170_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n58;
  t170_n55: if (E.getNumReferences() >= 3300810752 /*1523.0*/) goto t170_n57;
  t170_n56: return 0.4993419945240021;
  t170_n57: return -0.08928769081830978;
  t170_n58: return 0.015766194090247154;
  t170_n59: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t170_n125;
  t170_n60: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t170_n122;
  t170_n61: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t170_n69;
  t170_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t170_n64;
  t170_n63: return 0.004004596266895533;
  t170_n64: if (E.getNumReferences() >= 3308197888 /*2801.5*/) goto t170_n68;
  t170_n65: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n67;
  t170_n66: return 0.08242220431566238;
  t170_n67: return 0.027173152193427086;
  t170_n68: return -0.10161072760820389;
  t170_n69: if (E.getNumReferences() >= 3319526400 /*7038.5*/) goto t170_n99;
  t170_n70: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t170_n88;
  t170_n71: if (E.getNumReferences() >= 3318019072 /*6302.5*/) goto t170_n87;
  t170_n72: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t170_n82;
  t170_n73: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t170_n75;
  t170_n74: return -0.3841574788093567;
  t170_n75: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t170_n81;
  t170_n76: if (E.getNumReferences() >= 3316544512 /*5582.5*/) goto t170_n78;
  t170_n77: return 0.12342137843370438;
  t170_n78: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t170_n80;
  t170_n79: return 0.09860433638095856;
  t170_n80: return -0.02970573492348194;
  t170_n81: return 0.027932848781347275;
  t170_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t170_n86;
  t170_n83: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t170_n85;
  t170_n84: return 0.1278751939535141;
  t170_n85: return 0.1379217803478241;
  t170_n86: return 0.09374995529651642;
  t170_n87: return -0.09849909693002701;
  t170_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t170_n96;
  t170_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t170_n91;
  t170_n90: return 0.0926036536693573;
  t170_n91: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t170_n93;
  t170_n92: return 0.11108825355768204;
  t170_n93: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t170_n95;
  t170_n94: return 0.12863479554653168;
  t170_n95: return -0.3721252679824829;
  t170_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t170_n98;
  t170_n97: return 0.01408098079264164;
  t170_n98: return 0.1207791268825531;
  t170_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t170_n109;
  t170_n100: if (E.getNumReferences() >= 3324609024 /*10848.5*/) goto t170_n102;
  t170_n101: return -0.10813019424676895;
  t170_n102: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t170_n108;
  t170_n103: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t170_n107;
  t170_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t170_n106;
  t170_n105: return 0.0534478984773159;
  t170_n106: return 0.11661145091056824;
  t170_n107: return 0.02796105109155178;
  t170_n108: return -0.06191421300172806;
  t170_n109: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t170_n111;
  t170_n110: return 0.1343103051185608;
  t170_n111: if (E.getNumReferences() >= 3323105792 /*9380.5*/) goto t170_n119;
  t170_n112: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t170_n114;
  t170_n113: return 0.008043241687119007;
  t170_n114: if (E.getNumReferences() >= 3322166272 /*8463.0*/) goto t170_n116;
  t170_n115: return 0.12284234166145325;
  t170_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n118;
  t170_n117: return 0.04608540236949921;
  t170_n118: return 0.11061551421880722;
  t170_n119: if (E.getNumReferences() >= 3328340480 /*14492.5*/) goto t170_n121;
  t170_n120: return -0.0109843909740448;
  t170_n121: return 0.2626827359199524;
  t170_n122: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t170_n124;
  t170_n123: return -0.47266438603401184;
  t170_n124: return 0.10875902324914932;
  t170_n125: if (E.getNumReferences() >= 3330075136 /*16186.5*/) goto t170_n129;
  t170_n126: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t170_n128;
  t170_n127: return -0.17053577303886414;
  t170_n128: return 0.11422690749168396;
  t170_n129: return 0.007990623824298382;
  t170_n130: if (E.getNumReferences() >= 3298828288 /*1281.0*/) goto t170_n134;
  t170_n131: if (E.getNumReferences() >= 3298672640 /*1262.0*/) goto t170_n133;
  t170_n132: return -0.007321703247725964;
  t170_n133: return 0.11337955296039581;
  t170_n134: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t170_n254;
  t170_n135: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t170_n237;
  t170_n136: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t170_n148;
  t170_n137: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t170_n145;
  t170_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n144;
  t170_n139: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t170_n141;
  t170_n140: return -0.10918290913105011;
  t170_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n143;
  t170_n142: return 0.06978033483028412;
  t170_n143: return -0.1828291118144989;
  t170_n144: return -0.5915963053703308;
  t170_n145: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n147;
  t170_n146: return -0.006122308317571878;
  t170_n147: return 0.09775163233280182;
  t170_n148: if (E.getNumReferences() >= 3310143488 /*3276.5*/) goto t170_n170;
  t170_n149: if (E.getNumReferences() >= 3309791232 /*3190.5*/) goto t170_n169;
  t170_n150: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t170_n166;
  t170_n151: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t170_n155;
  t170_n152: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t170_n154;
  t170_n153: return 0.13165409862995148;
  t170_n154: return 0.013968360610306263;
  t170_n155: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t170_n157;
  t170_n156: return -0.14003242552280426;
  t170_n157: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t170_n165;
  t170_n158: if (E.getNumReferences() >= 3307579392 /*2650.5*/) goto t170_n164;
  t170_n159: if (E.getNumReferences() >= 3301048320 /*1552.0*/) goto t170_n161;
  t170_n160: return 0.08948439359664917;
  t170_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t170_n163;
  t170_n162: return -0.4852878749370575;
  t170_n163: return 0.09222908318042755;
  t170_n164: return 0.09080558270215988;
  t170_n165: return -0.10070933401584625;
  t170_n166: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t170_n168;
  t170_n167: return 0.10734126716852188;
  t170_n168: return 0.054252319037914276;
  t170_n169: return 0.11573760211467743;
  t170_n170: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t170_n182;
  t170_n171: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t170_n175;
  t170_n172: if (E.getNumReferences() >= 3318062080 /*6323.5*/) goto t170_n174;
  t170_n173: return 0.11701828241348267;
  t170_n174: return -0.045857418328523636;
  t170_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n177;
  t170_n176: return 0.016751401126384735;
  t170_n177: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t170_n179;
  t170_n178: return 0.10423695296049118;
  t170_n179: if (E.getNumReferences() >= 3353810176 /*118314.0*/) goto t170_n181;
  t170_n180: return 0.09298044443130493;
  t170_n181: return -0.3870544731616974;
  t170_n182: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t170_n236;
  t170_n183: if (E.getNumReferences() >= 3320567808 /*7547.0*/) goto t170_n199;
  t170_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t170_n192;
  t170_n185: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t170_n191;
  t170_n186: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t170_n190;
  t170_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t170_n189;
  t170_n188: return -0.2293570637702942;
  t170_n189: return 0.13132257759571075;
  t170_n190: return 0.07646144926548004;
  t170_n191: return 0.08768144994974136;
  t170_n192: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t170_n196;
  t170_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t170_n195;
  t170_n194: return -0.34772634506225586;
  t170_n195: return 0.07057030498981476;
  t170_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t170_n198;
  t170_n197: return -0.33211246132850647;
  t170_n198: return 0.11690125614404678;
  t170_n199: if (E.getNumReferences() >= 3322577408 /*8864.5*/) goto t170_n209;
  t170_n200: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t170_n208;
  t170_n201: if (E.getNumReferences() >= 3322246144 /*8541.0*/) goto t170_n205;
  t170_n202: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t170_n204;
  t170_n203: return -0.10463829338550568;
  t170_n204: return 0.10545933246612549;
  t170_n205: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t170_n207;
  t170_n206: return 0.11930481344461441;
  t170_n207: return 0.19068880379199982;
  t170_n208: return 0.04892431199550629;
  t170_n209: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t170_n231;
  t170_n210: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t170_n222;
  t170_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t170_n219;
  t170_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n214;
  t170_n213: return -0.1986933946609497;
  t170_n214: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t170_n216;
  t170_n215: return -0.13755103945732117;
  t170_n216: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t170_n218;
  t170_n217: return 0.11455902457237244;
  t170_n218: return 0.07960418611764908;
  t170_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n221;
  t170_n220: return 0.11762493848800659;
  t170_n221: return 0.06665255129337311;
  t170_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t170_n224;
  t170_n223: return -0.32626086473464966;
  t170_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t170_n226;
  t170_n225: return 0.017655562609434128;
  t170_n226: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n228;
  t170_n227: return 0.10972487926483154;
  t170_n228: if (E.getNumReferences() >= 3328272384 /*14426.0*/) goto t170_n230;
  t170_n229: return -0.09741710871458054;
  t170_n230: return 0.10967276990413666;
  t170_n231: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t170_n233;
  t170_n232: return 0.1492459923028946;
  t170_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t170_n235;
  t170_n234: return -0.04582453891634941;
  t170_n235: return 0.09323175996541977;
  t170_n236: return 0.016122203320264816;
  t170_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t170_n241;
  t170_n238: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t170_n240;
  t170_n239: return -0.4644733667373657;
  t170_n240: return 0.10989998281002045;
  t170_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t170_n253;
  t170_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t170_n244;
  t170_n243: return -0.11168895661830902;
  t170_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t170_n250;
  t170_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t170_n249;
  t170_n246: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t170_n248;
  t170_n247: return -0.10935313999652863;
  t170_n248: return 0.08857351541519165;
  t170_n249: return 0.01177476067095995;
  t170_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t170_n252;
  t170_n251: return 0.07602708786725998;
  t170_n252: return 0.11028194427490234;
  t170_n253: return 0.011301929131150246;
  t170_n254: return -0.008704951964318752;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree171(const Example& E) {
  t171_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t171_n2;
  t171_n1: return -0.0004324068140704185;
  t171_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t171_n44;
  t171_n3: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t171_n7;
  t171_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t171_n6;
  t171_n5: return 0.010432755574584007;
  t171_n6: return 0.13788878917694092;
  t171_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t171_n15;
  t171_n8: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t171_n12;
  t171_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t171_n11;
  t171_n10: return -0.044229377061128616;
  t171_n11: return -0.15687480568885803;
  t171_n12: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t171_n14;
  t171_n13: return 0.10977301001548767;
  t171_n14: return -0.28740614652633667;
  t171_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t171_n17;
  t171_n16: return 0.00865729060024023;
  t171_n17: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t171_n43;
  t171_n18: if (E.getNumReferences() >= 3318441984 /*6509.0*/) goto t171_n20;
  t171_n19: return 0.0155702019110322;
  t171_n20: if (E.getNumReferences() >= 3323142656 /*9416.5*/) goto t171_n42;
  t171_n21: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t171_n27;
  t171_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t171_n26;
  t171_n23: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t171_n25;
  t171_n24: return 0.10661926865577698;
  t171_n25: return 0.21894051134586334;
  t171_n26: return 0.06546502560377121;
  t171_n27: if (E.getNumReferences() >= 3319041024 /*6801.5*/) goto t171_n29;
  t171_n28: return -0.07669851928949356;
  t171_n29: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t171_n31;
  t171_n30: return 0.10202479362487793;
  t171_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n37;
  t171_n32: if (E.getNumReferences() >= 3319356416 /*6955.5*/) goto t171_n34;
  t171_n33: return -0.13919131457805634;
  t171_n34: if (E.getNumReferences() >= 3320364032 /*7447.5*/) goto t171_n36;
  t171_n35: return 0.14488574862480164;
  t171_n36: return 0.12353023141622543;
  t171_n37: if (E.getNumReferences() >= 3322502656 /*8791.5*/) goto t171_n41;
  t171_n38: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t171_n40;
  t171_n39: return 0.053836554288864136;
  t171_n40: return 0.11348212510347366;
  t171_n41: return 0.1142587810754776;
  t171_n42: return 0.030808184295892715;
  t171_n43: return 0.0182010717689991;
  t171_n44: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t171_n46;
  t171_n45: return -0.0004321168817114085;
  t171_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t171_n152;
  t171_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t171_n57;
  t171_n48: if (E.getNumReferences() >= 3331681536 /*19126.5*/) goto t171_n50;
  t171_n49: return -0.03098749928176403;
  t171_n50: if (E.getNumReferences() >= 3332416512 /*20562.0*/) goto t171_n56;
  t171_n51: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n55;
  t171_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t171_n54;
  t171_n53: return 0.22298505902290344;
  t171_n54: return 0.12623336911201477;
  t171_n55: return 0.05572693794965744;
  t171_n56: return 0.01754256710410118;
  t171_n57: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t171_n143;
  t171_n58: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t171_n134;
  t171_n59: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t171_n69;
  t171_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t171_n62;
  t171_n61: return 0.0035999994724988937;
  t171_n62: if (E.getNumReferences() >= 3308197888 /*2801.5*/) goto t171_n68;
  t171_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t171_n67;
  t171_n64: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t171_n66;
  t171_n65: return -0.15359866619110107;
  t171_n66: return 0.06437664479017258;
  t171_n67: return 0.10431721806526184;
  t171_n68: return -0.06340841948986053;
  t171_n69: if (E.getNumReferences() >= 3319526400 /*7038.5*/) goto t171_n97;
  t171_n70: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t171_n86;
  t171_n71: if (E.getNumReferences() >= 3318019072 /*6302.5*/) goto t171_n85;
  t171_n72: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t171_n80;
  t171_n73: if (E.getNumReferences() >= 3317071872 /*5840.0*/) goto t171_n79;
  t171_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t171_n78;
  t171_n75: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t171_n77;
  t171_n76: return -0.017926031723618507;
  t171_n77: return 0.11415122449398041;
  t171_n78: return 0.07736137509346008;
  t171_n79: return -0.12434811145067215;
  t171_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n84;
  t171_n81: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t171_n83;
  t171_n82: return 0.1212383508682251;
  t171_n83: return 0.13722360134124756;
  t171_n84: return 0.09033427387475967;
  t171_n85: return -0.07761339098215103;
  t171_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t171_n94;
  t171_n87: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t171_n89;
  t171_n88: return 0.08991661667823792;
  t171_n89: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t171_n91;
  t171_n90: return 0.11044429987668991;
  t171_n91: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n93;
  t171_n92: return 0.12789957225322723;
  t171_n93: return -0.23517397046089172;
  t171_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t171_n96;
  t171_n95: return 0.012713182717561722;
  t171_n96: return 0.11828591674566269;
  t171_n97: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n111;
  t171_n98: if (E.getNumReferences() >= 3324609024 /*10848.5*/) goto t171_n100;
  t171_n99: return -0.08801257610321045;
  t171_n100: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t171_n106;
  t171_n101: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t171_n105;
  t171_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t171_n104;
  t171_n103: return 0.07089252024888992;
  t171_n104: return 0.11591194570064545;
  t171_n105: return 0.028243685141205788;
  t171_n106: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t171_n108;
  t171_n107: return -0.1275799721479416;
  t171_n108: if (E.getNumReferences() >= 3326428672 /*12625.5*/) goto t171_n110;
  t171_n109: return 0.1317007690668106;
  t171_n110: return -0.15186850726604462;
  t171_n111: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t171_n113;
  t171_n112: return -0.051854945719242096;
  t171_n113: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t171_n119;
  t171_n114: if (E.getNumReferences() >= 3326753280 /*12942.5*/) goto t171_n116;
  t171_n115: return -0.0849306508898735;
  t171_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n118;
  t171_n117: return 0.15868628025054932;
  t171_n118: return 0.09332545846700668;
  t171_n119: if (E.getNumReferences() >= 3323087360 /*9362.5*/) goto t171_n127;
  t171_n120: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t171_n122;
  t171_n121: return 0.036398403346538544;
  t171_n122: if (E.getNumReferences() >= 3322166272 /*8463.0*/) goto t171_n124;
  t171_n123: return 0.12007655948400497;
  t171_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t171_n126;
  t171_n125: return 0.1130535900592804;
  t171_n126: return 0.10750889778137207;
  t171_n127: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t171_n133;
  t171_n128: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t171_n130;
  t171_n129: return -0.2381414771080017;
  t171_n130: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t171_n132;
  t171_n131: return 0.11420410871505737;
  t171_n132: return -0.13663876056671143;
  t171_n133: return 0.0805388018488884;
  t171_n134: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n136;
  t171_n135: return -0.42250627279281616;
  t171_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t171_n142;
  t171_n137: if (E.getNumReferences() >= 3329118720 /*15252.5*/) goto t171_n139;
  t171_n138: return 0.0552336685359478;
  t171_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n141;
  t171_n140: return 0.10243038088083267;
  t171_n141: return 0.13531288504600525;
  t171_n142: return 0.11995341628789902;
  t171_n143: if (E.getNumReferences() >= 3329553408 /*15677.0*/) goto t171_n145;
  t171_n144: return -0.12980377674102783;
  t171_n145: if (E.getNumReferences() >= 3329933824 /*16048.5*/) goto t171_n149;
  t171_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t171_n148;
  t171_n147: return 0.10530756413936615;
  t171_n148: return 0.14526315033435822;
  t171_n149: if (E.getNumReferences() >= 3330075136 /*16186.5*/) goto t171_n151;
  t171_n150: return -0.5501658320426941;
  t171_n151: return 0.0067606340162456036;
  t171_n152: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t171_n162;
  t171_n153: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t171_n161;
  t171_n154: if (E.getNumReferences() >= 3298500608 /*1241.0*/) goto t171_n156;
  t171_n155: return -0.5676220655441284;
  t171_n156: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n160;
  t171_n157: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t171_n159;
  t171_n158: return 0.05986804515123367;
  t171_n159: return 0.13199765980243683;
  t171_n160: return 0.04386083409190178;
  t171_n161: return 0.10087142884731293;
  t171_n162: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t171_n188;
  t171_n163: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t171_n183;
  t171_n164: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t171_n166;
  t171_n165: return -0.09845943003892899;
  t171_n166: if (E.getNumReferences() >= 3310399488 /*3339.0*/) goto t171_n170;
  t171_n167: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t171_n169;
  t171_n168: return -0.051036734133958817;
  t171_n169: return 0.11164921522140503;
  t171_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n172;
  t171_n171: return -0.044675879180431366;
  t171_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t171_n176;
  t171_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t171_n175;
  t171_n174: return -0.3764229118824005;
  t171_n175: return 0.03489059954881668;
  t171_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t171_n182;
  t171_n177: if (E.getNumReferences() >= 3336411136 /*28364.0*/) goto t171_n181;
  t171_n178: if (E.getNumReferences() >= 3327422976 /*13596.5*/) goto t171_n180;
  t171_n179: return 0.0924210399389267;
  t171_n180: return -0.08245706558227539;
  t171_n181: return 0.11385613679885864;
  t171_n182: return 0.04006079211831093;
  t171_n183: if (E.getNumReferences() >= 3364974544 /*297854.5*/) goto t171_n187;
  t171_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t171_n186;
  t171_n185: return 0.015091688372194767;
  t171_n186: return 0.10966179519891739;
  t171_n187: return 0.009290046989917755;
  t171_n188: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t171_n254;
  t171_n189: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t171_n245;
  t171_n190: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t171_n192;
  t171_n191: return -0.0178214143961668;
  t171_n192: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t171_n244;
  t171_n193: if (E.getNumReferences() >= 3309326336 /*3077.0*/) goto t171_n195;
  t171_n194: return -0.05693595111370087;
  t171_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t171_n217;
  t171_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n198;
  t171_n197: return -0.26939353346824646;
  t171_n198: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t171_n202;
  t171_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t171_n201;
  t171_n200: return -0.5527371764183044;
  t171_n201: return 0.09038937091827393;
  t171_n202: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t171_n208;
  t171_n203: if (E.getNumReferences() >= 3314667520 /*4666.0*/) goto t171_n207;
  t171_n204: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t171_n206;
  t171_n205: return 0.10225287824869156;
  t171_n206: return -0.2758767902851105;
  t171_n207: return -0.18155404925346375;
  t171_n208: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t171_n214;
  t171_n209: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t171_n213;
  t171_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t171_n212;
  t171_n211: return 0.11084918677806854;
  t171_n212: return 0.11368335038423538;
  t171_n213: return 0.07388412952423096;
  t171_n214: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t171_n216;
  t171_n215: return 0.03660636022686958;
  t171_n216: return 0.09016694128513336;
  t171_n217: if (E.getNumReferences() >= 3310016512 /*3245.5*/) goto t171_n219;
  t171_n218: return 0.10839946568012238;
  t171_n219: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t171_n223;
  t171_n220: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t171_n222;
  t171_n221: return -0.023540180176496506;
  t171_n222: return 0.08747586607933044;
  t171_n223: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t171_n225;
  t171_n224: return 0.12076948583126068;
  t171_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t171_n241;
  t171_n226: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t171_n240;
  t171_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t171_n229;
  t171_n228: return 0.003369174199178815;
  t171_n229: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t171_n231;
  t171_n230: return 0.15832959115505219;
  t171_n231: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t171_n233;
  t171_n232: return 0.03591826558113098;
  t171_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t171_n235;
  t171_n234: return -0.015171959064900875;
  t171_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n237;
  t171_n236: return 0.1667923629283905;
  t171_n237: if (E.getNumReferences() >= 3327807488 /*13972.0*/) goto t171_n239;
  t171_n238: return 0.11273717880249023;
  t171_n239: return 0.09913081675767899;
  t171_n240: return 0.018619831651449203;
  t171_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t171_n243;
  t171_n242: return -0.6365578174591064;
  t171_n243: return 0.067222461104393;
  t171_n244: return 0.014122436754405499;
  t171_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t171_n253;
  t171_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t171_n248;
  t171_n247: return -0.10998524725437164;
  t171_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t171_n250;
  t171_n249: return 0.07081490755081177;
  t171_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t171_n252;
  t171_n251: return 0.06999590247869492;
  t171_n252: return 0.10320820659399033;
  t171_n253: return 0.010368632152676582;
  t171_n254: return -0.010568870231509209;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree172(const Example& E) {
  t172_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t172_n218;
  t172_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t172_n163;
  t172_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n16;
  t172_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n5;
  t172_n4: return -0.004192250315099955;
  t172_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t172_n9;
  t172_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n8;
  t172_n7: return -0.04370567202568054;
  t172_n8: return -0.020790396258234978;
  t172_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t172_n11;
  t172_n10: return 0.008942605927586555;
  t172_n11: if (E.getNumReferences() >= 3282354176 /*329.5*/) goto t172_n13;
  t172_n12: return -0.03760452941060066;
  t172_n13: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t172_n15;
  t172_n14: return 0.12190929055213928;
  t172_n15: return 0.03895523026585579;
  t172_n16: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t172_n162;
  t172_n17: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t172_n113;
  t172_n18: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n76;
  t172_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n21;
  t172_n20: return 0.0023666981142014265;
  t172_n21: if (E.getNumReferences() >= 3283779584 /*373.0*/) goto t172_n73;
  t172_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t172_n56;
  t172_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t172_n51;
  t172_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t172_n50;
  t172_n25: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t172_n31;
  t172_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t172_n28;
  t172_n27: return 0.0023724378552287817;
  t172_n28: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t172_n30;
  t172_n29: return 0.00424455339089036;
  t172_n30: return 0.06122894212603569;
  t172_n31: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t172_n35;
  t172_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n34;
  t172_n33: return -0.058670736849308014;
  t172_n34: return 0.06370863318443298;
  t172_n35: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t172_n45;
  t172_n36: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t172_n38;
  t172_n37: return 0.0950574204325676;
  t172_n38: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t172_n44;
  t172_n39: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t172_n43;
  t172_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t172_n42;
  t172_n41: return 0.06587189435958862;
  t172_n42: return 0.14498865604400635;
  t172_n43: return -0.1414703130722046;
  t172_n44: return 0.12522980570793152;
  t172_n45: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t172_n47;
  t172_n46: return 0.0245357658714056;
  t172_n47: if (E.getNumReferences() >= 3266052096 /*86.0*/) goto t172_n49;
  t172_n48: return 0.15628010034561157;
  t172_n49: return 0.4962131083011627;
  t172_n50: return -0.011133690364658833;
  t172_n51: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t172_n53;
  t172_n52: return 0.0494859404861927;
  t172_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n55;
  t172_n54: return -0.1055285707116127;
  t172_n55: return 0.11465109139680862;
  t172_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t172_n58;
  t172_n57: return -0.0047311075031757355;
  t172_n58: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t172_n70;
  t172_n59: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t172_n65;
  t172_n60: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t172_n62;
  t172_n61: return 0.06431355327367783;
  t172_n62: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t172_n64;
  t172_n63: return 0.10121805965900421;
  t172_n64: return 0.059216830879449844;
  t172_n65: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t172_n67;
  t172_n66: return -0.31735458970069885;
  t172_n67: if (E.getNumReferences() >= 3253731328 /*30.0*/) goto t172_n69;
  t172_n68: return 0.11389646679162979;
  t172_n69: return -0.10974128544330597;
  t172_n70: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t172_n72;
  t172_n71: return 0.1060086190700531;
  t172_n72: return -0.0010545147815719247;
  t172_n73: if (E.getNumReferences() >= 3289022464 /*554.0*/) goto t172_n75;
  t172_n74: return 0.11316639930009842;
  t172_n75: return -0.005828175228089094;
  t172_n76: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t172_n96;
  t172_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n83;
  t172_n78: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t172_n82;
  t172_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n81;
  t172_n80: return -0.11567794531583786;
  t172_n81: return -0.030759651213884354;
  t172_n82: return -0.02060595713555813;
  t172_n83: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t172_n85;
  t172_n84: return -0.014969026669859886;
  t172_n85: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t172_n87;
  t172_n86: return 0.004156079608947039;
  t172_n87: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t172_n89;
  t172_n88: return 0.03505042940378189;
  t172_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t172_n95;
  t172_n90: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t172_n92;
  t172_n91: return -0.1256183534860611;
  t172_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t172_n94;
  t172_n93: return -0.4140154719352722;
  t172_n94: return 0.12735214829444885;
  t172_n95: return 0.07779430598020554;
  t172_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n100;
  t172_n97: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t172_n99;
  t172_n98: return -0.14270538091659546;
  t172_n99: return 0.08027110248804092;
  t172_n100: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t172_n112;
  t172_n101: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t172_n107;
  t172_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t172_n106;
  t172_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n105;
  t172_n104: return -0.06359204649925232;
  t172_n105: return 0.03767605498433113;
  t172_n106: return -0.02554154023528099;
  t172_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n109;
  t172_n108: return -0.021741805598139763;
  t172_n109: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t172_n111;
  t172_n110: return 0.05481754243373871;
  t172_n111: return -0.28097325563430786;
  t172_n112: return -0.009726238436996937;
  t172_n113: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t172_n123;
  t172_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n118;
  t172_n115: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t172_n117;
  t172_n116: return -0.0961180031299591;
  t172_n117: return 0.061624880880117416;
  t172_n118: if (E.getNumReferences() >= 3296002048 /*980.0*/) goto t172_n120;
  t172_n119: return -0.016303544864058495;
  t172_n120: if (E.getNumReferences() >= 3296616448 /*1017.5*/) goto t172_n122;
  t172_n121: return 0.09202103316783905;
  t172_n122: return -0.02060674875974655;
  t172_n123: if (E.getNumReferences() >= 3290136576 /*622.0*/) goto t172_n159;
  t172_n124: if (E.getNumReferences() >= 3271163904 /*125.0*/) goto t172_n158;
  t172_n125: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t172_n155;
  t172_n126: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n154;
  t172_n127: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t172_n139;
  t172_n128: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t172_n130;
  t172_n129: return -0.04328471049666405;
  t172_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t172_n132;
  t172_n131: return -0.03252769261598587;
  t172_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t172_n136;
  t172_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t172_n135;
  t172_n134: return -0.03308602049946785;
  t172_n135: return 0.08086498826742172;
  t172_n136: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t172_n138;
  t172_n137: return 0.10486283153295517;
  t172_n138: return 0.13079454004764557;
  t172_n139: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t172_n143;
  t172_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n142;
  t172_n141: return -0.16289936006069183;
  t172_n142: return 0.04496808350086212;
  t172_n143: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t172_n147;
  t172_n144: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t172_n146;
  t172_n145: return -0.031767942011356354;
  t172_n146: return 0.09481877833604813;
  t172_n147: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t172_n153;
  t172_n148: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t172_n152;
  t172_n149: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n151;
  t172_n150: return 0.3180559277534485;
  t172_n151: return 0.11639788001775742;
  t172_n152: return -0.05306583270430565;
  t172_n153: return -0.154471293091774;
  t172_n154: return -0.02062896639108658;
  t172_n155: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t172_n157;
  t172_n156: return 0.11305049806833267;
  t172_n157: return 0.02650938555598259;
  t172_n158: return -0.29995301365852356;
  t172_n159: if (E.getNumReferences() >= 3292766208 /*782.5*/) goto t172_n161;
  t172_n160: return 0.12241753935813904;
  t172_n161: return -0.06373970955610275;
  t172_n162: return 0.004229987505823374;
  t172_n163: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n183;
  t172_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t172_n166;
  t172_n165: return 0.003925848752260208;
  t172_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t172_n180;
  t172_n167: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t172_n179;
  t172_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n172;
  t172_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t172_n171;
  t172_n170: return 0.004017225932329893;
  t172_n171: return 0.03558293730020523;
  t172_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t172_n174;
  t172_n173: return 0.012754312716424465;
  t172_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n176;
  t172_n175: return 0.037394240498542786;
  t172_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n178;
  t172_n177: return 0.06801344454288483;
  t172_n178: return 0.05527101457118988;
  t172_n179: return -0.09170985221862793;
  t172_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n182;
  t172_n181: return 0.038582365959882736;
  t172_n182: return 0.09695927798748016;
  t172_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t172_n189;
  t172_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n186;
  t172_n185: return -0.048281989991664886;
  t172_n186: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n188;
  t172_n187: return -0.05106306076049805;
  t172_n188: return -0.02430972270667553;
  t172_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t172_n193;
  t172_n190: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n192;
  t172_n191: return -0.5430564880371094;
  t172_n192: return 0.013839613646268845;
  t172_n193: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t172_n201;
  t172_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t172_n196;
  t172_n195: return -0.0053535206243395805;
  t172_n196: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t172_n198;
  t172_n197: return -0.1045341044664383;
  t172_n198: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t172_n200;
  t172_n199: return -0.042126815766096115;
  t172_n200: return 0.021712908521294594;
  t172_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n203;
  t172_n202: return 0.04550231248140335;
  t172_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t172_n205;
  t172_n204: return -0.06240458786487579;
  t172_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n215;
  t172_n206: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n210;
  t172_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n209;
  t172_n208: return -0.10650908946990967;
  t172_n209: return 0.09780614078044891;
  t172_n210: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n212;
  t172_n211: return -0.02269809879362583;
  t172_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t172_n214;
  t172_n213: return 0.14193764328956604;
  t172_n214: return 0.14170248806476593;
  t172_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t172_n217;
  t172_n216: return -0.007449039723724127;
  t172_n217: return 0.12274346500635147;
  t172_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t172_n232;
  t172_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t172_n221;
  t172_n220: return -0.03770482540130615;
  t172_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n223;
  t172_n222: return -0.0037373239174485207;
  t172_n223: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t172_n225;
  t172_n224: return -0.02659694291651249;
  t172_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n231;
  t172_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t172_n228;
  t172_n227: return 0.03253020718693733;
  t172_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t172_n230;
  t172_n229: return 0.03967678174376488;
  t172_n230: return 0.0580025352537632;
  t172_n231: return -0.0013483952498063445;
  t172_n232: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t172_n234;
  t172_n233: return 0.033103097230196;
  t172_n234: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t172_n246;
  t172_n235: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t172_n237;
  t172_n236: return 0.05192564055323601;
  t172_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n239;
  t172_n238: return -0.1524353176355362;
  t172_n239: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t172_n245;
  t172_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n244;
  t172_n241: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t172_n243;
  t172_n242: return -0.10709366202354431;
  t172_n243: return 0.10429204255342484;
  t172_n244: return -0.13818764686584473;
  t172_n245: return -0.17711803317070007;
  t172_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t172_n248;
  t172_n247: return -0.03131107985973358;
  t172_n248: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t172_n254;
  t172_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t172_n253;
  t172_n250: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t172_n252;
  t172_n251: return 0.06210935115814209;
  t172_n252: return 0.10187771916389465;
  t172_n253: return 0.06199165806174278;
  t172_n254: return -0.02714647725224495;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree173(const Example& E) {
  t173_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t173_n2;
  t173_n1: return -0.0004284012538846582;
  t173_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t173_n16;
  t173_n3: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t173_n7;
  t173_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t173_n6;
  t173_n5: return 0.009931406937539577;
  t173_n6: return 0.13437886536121368;
  t173_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t173_n13;
  t173_n8: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t173_n10;
  t173_n9: return -0.06901135295629501;
  t173_n10: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t173_n12;
  t173_n11: return 0.10723116248846054;
  t173_n12: return -0.27793610095977783;
  t173_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t173_n15;
  t173_n14: return 0.008435063064098358;
  t173_n15: return 0.01957901194691658;
  t173_n16: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t173_n56;
  t173_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n19;
  t173_n18: return -0.009994464926421642;
  t173_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t173_n35;
  t173_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t173_n24;
  t173_n21: if (E.getNumReferences() >= 3298660352 /*1260.5*/) goto t173_n23;
  t173_n22: return 0.14553865790367126;
  t173_n23: return 0.004527705255895853;
  t173_n24: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t173_n28;
  t173_n25: if (E.getNumReferences() >= 3309955072 /*3230.5*/) goto t173_n27;
  t173_n26: return 0.154270201921463;
  t173_n27: return 0.08509714156389236;
  t173_n28: if (E.getNumReferences() >= 3318054912 /*6320.0*/) goto t173_n30;
  t173_n29: return -0.009103828109800816;
  t173_n30: if (E.getNumReferences() >= 3320302592 /*7417.5*/) goto t173_n34;
  t173_n31: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n33;
  t173_n32: return 0.229728564620018;
  t173_n33: return 0.09808985888957977;
  t173_n34: return 0.0688985213637352;
  t173_n35: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t173_n55;
  t173_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t173_n38;
  t173_n37: return -0.027019822970032692;
  t173_n38: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t173_n48;
  t173_n39: if (E.getNumReferences() >= 3298607104 /*1254.0*/) goto t173_n47;
  t173_n40: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t173_n42;
  t173_n41: return -0.04872008040547371;
  t173_n42: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t173_n46;
  t173_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t173_n45;
  t173_n44: return 0.13513655960559845;
  t173_n45: return -0.10016674548387527;
  t173_n46: return 0.06929069757461548;
  t173_n47: return 0.12059363722801208;
  t173_n48: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t173_n52;
  t173_n49: if (E.getNumReferences() >= 3355834112 /*137180.0*/) goto t173_n51;
  t173_n50: return 0.011047939769923687;
  t173_n51: return 0.04715603590011597;
  t173_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t173_n54;
  t173_n53: return -0.12207383662462234;
  t173_n54: return 0.09801582992076874;
  t173_n55: return 0.009542862884700298;
  t173_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t173_n158;
  t173_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t173_n63;
  t173_n58: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t173_n60;
  t173_n59: return 0.005071137100458145;
  t173_n60: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t173_n62;
  t173_n61: return -0.07136791199445724;
  t173_n62: return 0.015340548008680344;
  t173_n63: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t173_n147;
  t173_n64: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t173_n138;
  t173_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t173_n125;
  t173_n66: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t173_n68;
  t173_n67: return 0.0035280198790133;
  t173_n68: if (E.getNumReferences() >= 3319526400 /*7038.5*/) goto t173_n98;
  t173_n69: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t173_n87;
  t173_n70: if (E.getNumReferences() >= 3318019072 /*6302.5*/) goto t173_n86;
  t173_n71: if (E.getNumReferences() >= 3317762048 /*6177.0*/) goto t173_n83;
  t173_n72: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t173_n74;
  t173_n73: return -0.33357948064804077;
  t173_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t173_n82;
  t173_n75: if (E.getNumReferences() >= 3316544512 /*5582.5*/) goto t173_n77;
  t173_n76: return 0.11960204690694809;
  t173_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t173_n79;
  t173_n78: return -0.04869219660758972;
  t173_n79: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n81;
  t173_n80: return 0.1046830341219902;
  t173_n81: return 0.02817070297896862;
  t173_n82: return 0.016552340239286423;
  t173_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n85;
  t173_n84: return 0.13193760812282562;
  t173_n85: return 0.08348888903856277;
  t173_n86: return -0.08466551452875137;
  t173_n87: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t173_n95;
  t173_n88: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n90;
  t173_n89: return 0.05212504789233208;
  t173_n90: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t173_n92;
  t173_n91: return 0.10941614210605621;
  t173_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n94;
  t173_n93: return 0.12671752274036407;
  t173_n94: return -0.22443923354148865;
  t173_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t173_n97;
  t173_n96: return 0.007233570329844952;
  t173_n97: return 0.11222612857818604;
  t173_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n108;
  t173_n99: if (E.getNumReferences() >= 3324609024 /*10848.5*/) goto t173_n101;
  t173_n100: return -0.08047475665807724;
  t173_n101: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t173_n107;
  t173_n102: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t173_n106;
  t173_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t173_n105;
  t173_n104: return 0.07100917398929596;
  t173_n105: return 0.1136445552110672;
  t173_n106: return 0.02014463022351265;
  t173_n107: return -0.055442873388528824;
  t173_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n110;
  t173_n109: return -0.07194482535123825;
  t173_n110: if (E.getNumReferences() >= 3323109888 /*9384.5*/) goto t173_n118;
  t173_n111: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t173_n113;
  t173_n112: return 0.020895708352327347;
  t173_n113: if (E.getNumReferences() >= 3322166272 /*8463.0*/) goto t173_n115;
  t173_n114: return 0.11733847111463547;
  t173_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t173_n117;
  t173_n116: return 0.035338789224624634;
  t173_n117: return 0.10961298644542694;
  t173_n118: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t173_n124;
  t173_n119: if (E.getNumReferences() >= 3326753280 /*12942.5*/) goto t173_n121;
  t173_n120: return -0.2058699131011963;
  t173_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n123;
  t173_n122: return 0.1479395180940628;
  t173_n123: return 0.08960411697626114;
  t173_n124: return -0.021813731640577316;
  t173_n125: if (E.getNumReferences() >= 3321170944 /*7841.5*/) goto t173_n137;
  t173_n126: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t173_n130;
  t173_n127: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t173_n129;
  t173_n128: return 0.0766717866063118;
  t173_n129: return -0.14186608791351318;
  t173_n130: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t173_n134;
  t173_n131: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t173_n133;
  t173_n132: return 0.10229643434286118;
  t173_n133: return -0.09206704795360565;
  t173_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t173_n136;
  t173_n135: return -0.18802794814109802;
  t173_n136: return 0.08089829236268997;
  t173_n137: return -0.5244418978691101;
  t173_n138: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t173_n144;
  t173_n139: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t173_n141;
  t173_n140: return -0.22561956942081451;
  t173_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n143;
  t173_n142: return 0.09789305925369263;
  t173_n143: return -0.1716519296169281;
  t173_n144: if (E.getNumReferences() >= 3329118720 /*15252.5*/) goto t173_n146;
  t173_n145: return 0.112594373524189;
  t173_n146: return 0.12072135508060455;
  t173_n147: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t173_n157;
  t173_n148: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t173_n150;
  t173_n149: return 0.10260389000177383;
  t173_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t173_n154;
  t173_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t173_n153;
  t173_n152: return -0.021110879257321358;
  t173_n153: return -0.1339297741651535;
  t173_n154: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t173_n156;
  t173_n155: return -0.033537041395902634;
  t173_n156: return 0.10032157599925995;
  t173_n157: return 0.007722513750195503;
  t173_n158: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t173_n168;
  t173_n159: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t173_n167;
  t173_n160: if (E.getNumReferences() >= 3298500608 /*1241.0*/) goto t173_n162;
  t173_n161: return -0.3819788992404938;
  t173_n162: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t173_n166;
  t173_n163: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n165;
  t173_n164: return -0.005565082188695669;
  t173_n165: return 0.1260046809911728;
  t173_n166: return 0.030823878943920135;
  t173_n167: return 0.09807323664426804;
  t173_n168: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t173_n254;
  t173_n169: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t173_n241;
  t173_n170: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t173_n174;
  t173_n171: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t173_n173;
  t173_n172: return -0.305184930562973;
  t173_n173: return -0.02147933468222618;
  t173_n174: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t173_n178;
  t173_n175: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t173_n177;
  t173_n176: return 0.11201635003089905;
  t173_n177: return -0.06201834976673126;
  t173_n178: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t173_n180;
  t173_n179: return -0.0017814846942201257;
  t173_n180: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t173_n240;
  t173_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t173_n211;
  t173_n182: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t173_n208;
  t173_n183: if (E.getNumReferences() >= 3309393920 /*3093.5*/) goto t173_n185;
  t173_n184: return -0.08379437029361725;
  t173_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n187;
  t173_n186: return -0.17893622815608978;
  t173_n187: if (E.getNumReferences() >= 3315718144 /*5179.0*/) goto t173_n193;
  t173_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t173_n190;
  t173_n189: return -0.09748886525630951;
  t173_n190: if (E.getNumReferences() >= 3314856960 /*4758.5*/) goto t173_n192;
  t173_n191: return 0.10155452787876129;
  t173_n192: return -0.6781949400901794;
  t173_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t173_n203;
  t173_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t173_n196;
  t173_n195: return 0.04976513609290123;
  t173_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n198;
  t173_n197: return 0.020240984857082367;
  t173_n198: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t173_n202;
  t173_n199: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t173_n201;
  t173_n200: return 0.1070595532655716;
  t173_n201: return 0.11266250908374786;
  t173_n202: return 0.08309243619441986;
  t173_n203: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t173_n205;
  t173_n204: return -0.04919910430908203;
  t173_n205: if (E.getNumReferences() >= 3323238400 /*9510.0*/) goto t173_n207;
  t173_n206: return 0.09773404151201248;
  t173_n207: return 0.04041055589914322;
  t173_n208: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t173_n210;
  t173_n209: return 0.08982706069946289;
  t173_n210: return -0.009838038124144077;
  t173_n211: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n215;
  t173_n212: if (E.getNumReferences() >= 3308220416 /*2807.0*/) goto t173_n214;
  t173_n213: return -0.38486552238464355;
  t173_n214: return 0.1095999926328659;
  t173_n215: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t173_n227;
  t173_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t173_n224;
  t173_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t173_n221;
  t173_n218: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n220;
  t173_n219: return -0.5198633670806885;
  t173_n220: return 0.01829935796558857;
  t173_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t173_n223;
  t173_n222: return 0.1310722529888153;
  t173_n223: return 0.07768522202968597;
  t173_n224: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t173_n226;
  t173_n225: return -0.028418220579624176;
  t173_n226: return 0.0945972353219986;
  t173_n227: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t173_n229;
  t173_n228: return 0.11876238137483597;
  t173_n229: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t173_n239;
  t173_n230: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t173_n232;
  t173_n231: return 0.1517568677663803;
  t173_n232: if (E.getNumReferences() >= 3325920768 /*12129.5*/) goto t173_n234;
  t173_n233: return 0.05524455010890961;
  t173_n234: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t173_n236;
  t173_n235: return -0.0027218740433454514;
  t173_n236: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t173_n238;
  t173_n237: return 0.1281440705060959;
  t173_n238: return 0.04592811316251755;
  t173_n239: return -0.07387468218803406;
  t173_n240: return 0.012018291279673576;
  t173_n241: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t173_n245;
  t173_n242: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t173_n244;
  t173_n243: return -0.3479765057563782;
  t173_n244: return 0.10557828843593597;
  t173_n245: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t173_n247;
  t173_n246: return 0.0529196672141552;
  t173_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t173_n251;
  t173_n248: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t173_n250;
  t173_n249: return -0.14250092208385468;
  t173_n250: return 0.08725111931562424;
  t173_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t173_n253;
  t173_n252: return 0.10702486336231232;
  t173_n253: return -0.25610747933387756;
  t173_n254: return -0.006528749596327543;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree174(const Example& E) {
  t174_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t174_n232;
  t174_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t174_n139;
  t174_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n34;
  t174_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t174_n5;
  t174_n4: return -0.00421095872297883;
  t174_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t174_n9;
  t174_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n8;
  t174_n7: return -0.037307288497686386;
  t174_n8: return -0.018890736624598503;
  t174_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t174_n29;
  t174_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t174_n12;
  t174_n11: return -0.04477576166391373;
  t174_n12: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t174_n16;
  t174_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n15;
  t174_n14: return -0.03079165890812874;
  t174_n15: return 0.004629898350685835;
  t174_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n28;
  t174_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t174_n21;
  t174_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n20;
  t174_n19: return -0.04832429811358452;
  t174_n20: return 0.031813330948352814;
  t174_n21: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t174_n27;
  t174_n22: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n24;
  t174_n23: return 0.08640828728675842;
  t174_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n26;
  t174_n25: return 0.054307710379362106;
  t174_n26: return 0.01885141059756279;
  t174_n27: return 0.0028163925744593143;
  t174_n28: return 0.0024684264790266752;
  t174_n29: if (E.getNumReferences() >= 3282354176 /*329.5*/) goto t174_n31;
  t174_n30: return -0.03419913351535797;
  t174_n31: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t174_n33;
  t174_n32: return 0.11973924189805984;
  t174_n33: return 0.04391603171825409;
  t174_n34: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t174_n138;
  t174_n35: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t174_n97;
  t174_n36: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t174_n94;
  t174_n37: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t174_n59;
  t174_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n56;
  t174_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n41;
  t174_n40: return 0.008544860407710075;
  t174_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t174_n51;
  t174_n42: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t174_n44;
  t174_n43: return 0.031046289950609207;
  t174_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t174_n46;
  t174_n45: return 0.05957324057817459;
  t174_n46: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t174_n50;
  t174_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t174_n49;
  t174_n48: return 0.10980275273323059;
  t174_n49: return -0.3075336217880249;
  t174_n50: return 0.12393631786108017;
  t174_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n53;
  t174_n52: return 0.018521863967180252;
  t174_n53: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t174_n55;
  t174_n54: return 0.06602504849433899;
  t174_n55: return 0.09872197359800339;
  t174_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n58;
  t174_n57: return -0.04775255545973778;
  t174_n58: return -0.006021272391080856;
  t174_n59: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t174_n63;
  t174_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n62;
  t174_n61: return -0.04801463708281517;
  t174_n62: return -0.01714707724750042;
  t174_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t174_n77;
  t174_n64: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t174_n66;
  t174_n65: return -0.015104933641850948;
  t174_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t174_n68;
  t174_n67: return 0.010263306088745594;
  t174_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n70;
  t174_n69: return 0.09238564223051071;
  t174_n70: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t174_n72;
  t174_n71: return -0.1653822362422943;
  t174_n72: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t174_n76;
  t174_n73: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t174_n75;
  t174_n74: return 0.04924427345395088;
  t174_n75: return 0.12594284117221832;
  t174_n76: return -0.14417725801467896;
  t174_n77: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t174_n81;
  t174_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n80;
  t174_n79: return 0.12383829802274704;
  t174_n80: return 0.05721529573202133;
  t174_n81: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t174_n85;
  t174_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n84;
  t174_n83: return -0.3884260952472687;
  t174_n84: return 0.042391013354063034;
  t174_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n93;
  t174_n86: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t174_n92;
  t174_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t174_n89;
  t174_n88: return 0.031456876546144485;
  t174_n89: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t174_n91;
  t174_n90: return 0.09396517276763916;
  t174_n91: return 0.07777409255504608;
  t174_n92: return -1.0379657745361328;
  t174_n93: return 0.018942512571811676;
  t174_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n96;
  t174_n95: return -0.10101044923067093;
  t174_n96: return -0.017583953216671944;
  t174_n97: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t174_n99;
  t174_n98: return 0.10720726102590561;
  t174_n99: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t174_n135;
  t174_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n102;
  t174_n101: return -0.13706214725971222;
  t174_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t174_n108;
  t174_n103: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t174_n105;
  t174_n104: return -0.026180844753980637;
  t174_n105: if (E.getNumReferences() >= 3275522048 /*188.5*/) goto t174_n107;
  t174_n106: return 0.10250142961740494;
  t174_n107: return 0.058130908757448196;
  t174_n108: if (E.getNumReferences() >= 3287351296 /*482.0*/) goto t174_n128;
  t174_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n111;
  t174_n110: return -0.03774216026067734;
  t174_n111: if (E.getNumReferences() >= 3278798848 /*238.5*/) goto t174_n121;
  t174_n112: if (E.getNumReferences() >= 3275849728 /*193.5*/) goto t174_n120;
  t174_n113: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t174_n117;
  t174_n114: if (E.getNumReferences() >= 3274244096 /*169.0*/) goto t174_n116;
  t174_n115: return 0.08933373540639877;
  t174_n116: return -0.38010719418525696;
  t174_n117: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t174_n119;
  t174_n118: return 0.11177628487348557;
  t174_n119: return 0.0626181960105896;
  t174_n120: return -0.08890291303396225;
  t174_n121: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t174_n123;
  t174_n122: return 0.11525218188762665;
  t174_n123: if (E.getNumReferences() >= 3283812352 /*374.0*/) goto t174_n125;
  t174_n124: return 0.03265971317887306;
  t174_n125: if (E.getNumReferences() >= 3284123648 /*383.5*/) goto t174_n127;
  t174_n126: return 0.11416599154472351;
  t174_n127: return 0.02814631722867489;
  t174_n128: if (E.getNumReferences() >= 3288137728 /*506.0*/) goto t174_n130;
  t174_n129: return 0.10271558165550232;
  t174_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t174_n132;
  t174_n131: return 0.02181173674762249;
  t174_n132: if (E.getNumReferences() >= 3292528640 /*768.0*/) goto t174_n134;
  t174_n133: return 0.1101708859205246;
  t174_n134: return -0.24395059049129486;
  t174_n135: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t174_n137;
  t174_n136: return -0.02595614828169346;
  t174_n137: return 0.0948435366153717;
  t174_n138: return 0.004092436749488115;
  t174_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t174_n183;
  t174_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t174_n158;
  t174_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n143;
  t174_n142: return 0.009870425797998905;
  t174_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n155;
  t174_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t174_n146;
  t174_n145: return -0.00663197273388505;
  t174_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t174_n148;
  t174_n147: return -0.02278924360871315;
  t174_n148: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n150;
  t174_n149: return 0.011318779550492764;
  t174_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n154;
  t174_n151: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t174_n153;
  t174_n152: return 0.041024889796972275;
  t174_n153: return -0.17413829267024994;
  t174_n154: return 0.04402310773730278;
  t174_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Expression))) goto t174_n157;
  t174_n156: return -0.0009023207239806652;
  t174_n157: return 0.01272203866392374;
  t174_n158: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t174_n182;
  t174_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n161;
  t174_n160: return 0.018827568739652634;
  t174_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t174_n171;
  t174_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t174_n168;
  t174_n163: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n167;
  t174_n164: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n166;
  t174_n165: return 0.02590988390147686;
  t174_n166: return -0.03148886561393738;
  t174_n167: return 0.03112015873193741;
  t174_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n170;
  t174_n169: return 0.03406454250216484;
  t174_n170: return 0.05639800429344177;
  t174_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t174_n175;
  t174_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n174;
  t174_n173: return 0.04766146466135979;
  t174_n174: return 0.0950751006603241;
  t174_n175: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n181;
  t174_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n180;
  t174_n177: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t174_n179;
  t174_n178: return 0.23535653948783875;
  t174_n179: return 0.18054044246673584;
  t174_n180: return 0.2167663425207138;
  t174_n181: return -0.2801021635532379;
  t174_n182: return -0.09190960228443146;
  t174_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n191;
  t174_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n188;
  t174_n185: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t174_n187;
  t174_n186: return -0.04774585738778114;
  t174_n187: return -0.047294218093156815;
  t174_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n190;
  t174_n189: return -0.04375883564352989;
  t174_n190: return -0.02450203150510788;
  t174_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t174_n207;
  t174_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t174_n194;
  t174_n193: return -0.008450713939964771;
  t174_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t174_n196;
  t174_n195: return -0.1042218953371048;
  t174_n196: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n198;
  t174_n197: return -0.044373657554388046;
  t174_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n202;
  t174_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n201;
  t174_n200: return 0.05321327596902847;
  t174_n201: return -0.0008748568361625075;
  t174_n202: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n204;
  t174_n203: return -0.015231399796903133;
  t174_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n206;
  t174_n205: return -0.0013940136414021254;
  t174_n206: return 0.039726730436086655;
  t174_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n215;
  t174_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t174_n214;
  t174_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n213;
  t174_n210: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n212;
  t174_n211: return -1.2744790315628052;
  t174_n212: return -0.12342067807912827;
  t174_n213: return 0.016191918402910233;
  t174_n214: return -0.07013558596372604;
  t174_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t174_n231;
  t174_n216: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n230;
  t174_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t174_n219;
  t174_n218: return 0.07554734498262405;
  t174_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n223;
  t174_n220: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n222;
  t174_n221: return -0.25926846265792847;
  t174_n222: return 0.10083439201116562;
  t174_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t174_n225;
  t174_n224: return 0.0926205962896347;
  t174_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n227;
  t174_n226: return -0.057509586215019226;
  t174_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t174_n229;
  t174_n228: return 0.13713344931602478;
  t174_n229: return 0.12757360935211182;
  t174_n230: return 1.7750731706619263;
  t174_n231: return 0.17864735424518585;
  t174_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t174_n234;
  t174_n233: return -0.03579888865351677;
  t174_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t174_n236;
  t174_n235: return 0.00044729726505465806;
  t174_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t174_n252;
  t174_n237: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t174_n241;
  t174_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t174_n240;
  t174_n239: return -0.026930220425128937;
  t174_n240: return 0.04902089387178421;
  t174_n241: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t174_n249;
  t174_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t174_n246;
  t174_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t174_n245;
  t174_n244: return 0.03092808648943901;
  t174_n245: return 0.03701213374733925;
  t174_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t174_n248;
  t174_n247: return 0.03834790736436844;
  t174_n248: return 0.067581407725811;
  t174_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t174_n251;
  t174_n250: return -0.005377460271120071;
  t174_n251: return 0.05261502042412758;
  t174_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t174_n254;
  t174_n253: return 0.11400895565748215;
  t174_n254: return 0.06676482409238815;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree175(const Example& E) {
  t175_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t175_n250;
  t175_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t175_n81;
  t175_n2: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t175_n6;
  t175_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t175_n5;
  t175_n4: return -0.06578267365694046;
  t175_n5: return -0.020321380347013474;
  t175_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t175_n8;
  t175_n7: return -0.09694590419530869;
  t175_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t175_n36;
  t175_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n13;
  t175_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n12;
  t175_n11: return -0.024450181052088737;
  t175_n12: return 0.035437434911727905;
  t175_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t175_n21;
  t175_n14: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t175_n18;
  t175_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n17;
  t175_n16: return -0.041089240461587906;
  t175_n17: return -0.004529738798737526;
  t175_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n20;
  t175_n19: return 0.04383694380521774;
  t175_n20: return 0.005093058105558157;
  t175_n21: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n35;
  t175_n22: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n30;
  t175_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n29;
  t175_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n28;
  t175_n25: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t175_n27;
  t175_n26: return 0.038002338260412216;
  t175_n27: return -0.7032470107078552;
  t175_n28: return 0.057635802775621414;
  t175_n29: return 0.058778636157512665;
  t175_n30: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t175_n32;
  t175_n31: return -0.04975855350494385;
  t175_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n34;
  t175_n33: return 0.025386113673448563;
  t175_n34: return 0.08193009346723557;
  t175_n35: return 0.036701951175928116;
  t175_n36: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t175_n56;
  t175_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n45;
  t175_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n40;
  t175_n39: return 0.04153118655085564;
  t175_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n42;
  t175_n41: return 0.047527652233839035;
  t175_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n44;
  t175_n43: return 0.0033310274593532085;
  t175_n44: return -0.47281041741371155;
  t175_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n53;
  t175_n46: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n52;
  t175_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n49;
  t175_n48: return -0.14808255434036255;
  t175_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n51;
  t175_n50: return -0.018689608201384544;
  t175_n51: return 0.0093385623767972;
  t175_n52: return 0.045209772884845734;
  t175_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n55;
  t175_n54: return -0.025657465681433678;
  t175_n55: return 0.031207239255309105;
  t175_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t175_n66;
  t175_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n61;
  t175_n58: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n60;
  t175_n59: return 0.018593937158584595;
  t175_n60: return 0.04959861934185028;
  t175_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n63;
  t175_n62: return -0.0672571137547493;
  t175_n63: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t175_n65;
  t175_n64: return -0.15333999693393707;
  t175_n65: return -0.010270551778376102;
  t175_n66: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t175_n70;
  t175_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n69;
  t175_n68: return -0.05097483471035957;
  t175_n69: return 0.07848037779331207;
  t175_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t175_n72;
  t175_n71: return -0.035121552646160126;
  t175_n72: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n76;
  t175_n73: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n75;
  t175_n74: return 0.10681959986686707;
  t175_n75: return 0.07760409265756607;
  t175_n76: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n78;
  t175_n77: return -0.11355426907539368;
  t175_n78: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t175_n80;
  t175_n79: return 0.09119097143411636;
  t175_n80: return -0.11630687862634659;
  t175_n81: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t175_n249;
  t175_n82: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t175_n84;
  t175_n83: return -0.0038831315468996763;
  t175_n84: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t175_n100;
  t175_n85: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t175_n99;
  t175_n86: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t175_n98;
  t175_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n91;
  t175_n88: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t175_n90;
  t175_n89: return -0.05889086797833443;
  t175_n90: return -0.13340355455875397;
  t175_n91: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t175_n93;
  t175_n92: return -0.027732787653803825;
  t175_n93: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t175_n97;
  t175_n94: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t175_n96;
  t175_n95: return 0.13901783525943756;
  t175_n96: return -0.12647703289985657;
  t175_n97: return -0.06805355101823807;
  t175_n98: return 0.09727713465690613;
  t175_n99: return 0.02831890434026718;
  t175_n100: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t175_n166;
  t175_n101: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t175_n127;
  t175_n102: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t175_n110;
  t175_n103: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t175_n105;
  t175_n104: return 0.03921220451593399;
  t175_n105: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t175_n107;
  t175_n106: return 0.10188861936330795;
  t175_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n109;
  t175_n108: return 0.11872754991054535;
  t175_n109: return -0.10052713751792908;
  t175_n110: if (E.getNumReferences() >= 3341265408 /*42922.0*/) goto t175_n112;
  t175_n111: return -0.017303353175520897;
  t175_n112: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t175_n114;
  t175_n113: return 0.0012922517489641905;
  t175_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n118;
  t175_n115: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t175_n117;
  t175_n116: return 0.11284949630498886;
  t175_n117: return 0.12595131993293762;
  t175_n118: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t175_n126;
  t175_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n121;
  t175_n120: return 0.08791298419237137;
  t175_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t175_n125;
  t175_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n124;
  t175_n123: return 0.10884398967027664;
  t175_n124: return 0.10145341604948044;
  t175_n125: return 0.08821801096200943;
  t175_n126: return -0.18932202458381653;
  t175_n127: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t175_n131;
  t175_n128: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t175_n130;
  t175_n129: return 0.005340032745152712;
  t175_n130: return -0.6019424200057983;
  t175_n131: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t175_n155;
  t175_n132: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t175_n148;
  t175_n133: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t175_n141;
  t175_n134: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t175_n140;
  t175_n135: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t175_n137;
  t175_n136: return 0.03156457841396332;
  t175_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n139;
  t175_n138: return 0.11412452906370163;
  t175_n139: return -5.476819038391113;
  t175_n140: return -0.13658881187438965;
  t175_n141: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t175_n145;
  t175_n142: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t175_n144;
  t175_n143: return 0.11146789789199829;
  t175_n144: return -0.03138618916273117;
  t175_n145: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t175_n147;
  t175_n146: return 0.1255498081445694;
  t175_n147: return 0.08119107782840729;
  t175_n148: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t175_n152;
  t175_n149: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t175_n151;
  t175_n150: return 0.08209671080112457;
  t175_n151: return 0.13789300620555878;
  t175_n152: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n154;
  t175_n153: return 0.05657481402158737;
  t175_n154: return 0.10277747362852097;
  t175_n155: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t175_n165;
  t175_n156: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t175_n164;
  t175_n157: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n161;
  t175_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n160;
  t175_n159: return 0.024394726380705833;
  t175_n160: return 0.11732762306928635;
  t175_n161: if (E.getNumReferences() >= 3304701952 /*1998.0*/) goto t175_n163;
  t175_n162: return 0.015663666650652885;
  t175_n163: return 0.10908263921737671;
  t175_n164: return 0.023908937349915504;
  t175_n165: return -0.07761967182159424;
  t175_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t175_n246;
  t175_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t175_n169;
  t175_n168: return -0.023003194481134415;
  t175_n169: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t175_n233;
  t175_n170: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t175_n214;
  t175_n171: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t175_n209;
  t175_n172: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t175_n202;
  t175_n173: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t175_n199;
  t175_n174: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t175_n196;
  t175_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n177;
  t175_n176: return 0.039020851254463196;
  t175_n177: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n183;
  t175_n178: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t175_n182;
  t175_n179: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t175_n181;
  t175_n180: return 0.11123771965503693;
  t175_n181: return -0.9190685153007507;
  t175_n182: return 0.050565607845783234;
  t175_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t175_n185;
  t175_n184: return -0.02177560329437256;
  t175_n185: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t175_n193;
  t175_n186: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t175_n192;
  t175_n187: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t175_n191;
  t175_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t175_n190;
  t175_n189: return -0.10079415887594223;
  t175_n190: return 0.13827726244926453;
  t175_n191: return 0.10900766402482986;
  t175_n192: return -0.1118987575173378;
  t175_n193: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t175_n195;
  t175_n194: return 0.06280030310153961;
  t175_n195: return 0.01118916179984808;
  t175_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t175_n198;
  t175_n197: return 0.13431096076965332;
  t175_n198: return 0.04754271358251572;
  t175_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t175_n201;
  t175_n200: return 0.03708985075354576;
  t175_n201: return -0.1909184753894806;
  t175_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t175_n204;
  t175_n203: return 0.1319207400083542;
  t175_n204: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t175_n206;
  t175_n205: return -0.10265633463859558;
  t175_n206: if (E.getNumReferences() >= 3246391296 /*16.0*/) goto t175_n208;
  t175_n207: return 0.0008461074903607368;
  t175_n208: return 0.12961634993553162;
  t175_n209: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t175_n213;
  t175_n210: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t175_n212;
  t175_n211: return 0.1378301978111267;
  t175_n212: return 0.12648224830627441;
  t175_n213: return 0.007313184905797243;
  t175_n214: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t175_n218;
  t175_n215: if (E.getNumReferences() >= 3324914176 /*11146.5*/) goto t175_n217;
  t175_n216: return -0.23640279471874237;
  t175_n217: return 0.09022556990385056;
  t175_n218: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t175_n224;
  t175_n219: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t175_n221;
  t175_n220: return 0.03735090792179108;
  t175_n221: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t175_n223;
  t175_n222: return 0.18528850376605988;
  t175_n223: return 0.07770758867263794;
  t175_n224: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t175_n230;
  t175_n225: if (E.getNumReferences() >= 3289579520 /*588.0*/) goto t175_n227;
  t175_n226: return -0.08763673156499863;
  t175_n227: if (E.getNumReferences() >= 3291111424 /*681.5*/) goto t175_n229;
  t175_n228: return 0.10109417885541916;
  t175_n229: return -0.036379918456077576;
  t175_n230: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t175_n232;
  t175_n231: return -0.1305377036333084;
  t175_n232: return 0.07888396084308624;
  t175_n233: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t175_n245;
  t175_n234: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t175_n236;
  t175_n235: return 0.035212427377700806;
  t175_n236: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t175_n240;
  t175_n237: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t175_n239;
  t175_n238: return -0.20034876465797424;
  t175_n239: return 0.12012509256601334;
  t175_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t175_n244;
  t175_n241: if (E.getNumReferences() >= 3285483520 /*425.0*/) goto t175_n243;
  t175_n242: return 0.2618654668331146;
  t175_n243: return 0.10629928857088089;
  t175_n244: return 0.05909845232963562;
  t175_n245: return -0.0606222003698349;
  t175_n246: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t175_n248;
  t175_n247: return -0.022991620004177094;
  t175_n248: return 0.07231548428535461;
  t175_n249: return 0.009947014041244984;
  t175_n250: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t175_n254;
  t175_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t175_n253;
  t175_n252: return -0.06162610277533531;
  t175_n253: return 0.05350995808839798;
  t175_n254: return 0.0012686201371252537;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree176(const Example& E) {
  t176_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t176_n2;
  t176_n1: return -0.0004264278686605394;
  t176_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t176_n24;
  t176_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t176_n23;
  t176_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n6;
  t176_n5: return -0.11174436658620834;
  t176_n6: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t176_n16;
  t176_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n11;
  t176_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n10;
  t176_n9: return -0.39417341351509094;
  t176_n10: return 0.02475498616695404;
  t176_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n15;
  t176_n12: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n14;
  t176_n13: return 0.08919243514537811;
  t176_n14: return -0.11129515618085861;
  t176_n15: return -2.25527286529541;
  t176_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n18;
  t176_n17: return 0.0062956134788692;
  t176_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n22;
  t176_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t176_n21;
  t176_n20: return 0.0921962633728981;
  t176_n21: return 0.051324497908353806;
  t176_n22: return 0.07733341306447983;
  t176_n23: return -0.01951495371758938;
  t176_n24: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t176_n236;
  t176_n25: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t176_n39;
  t176_n26: if (E.getNumReferences() >= 3283320832 /*359.0*/) goto t176_n32;
  t176_n27: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t176_n31;
  t176_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t176_n30;
  t176_n29: return -0.1764257252216339;
  t176_n30: return -0.025263819843530655;
  t176_n31: return -0.17712457478046417;
  t176_n32: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t176_n38;
  t176_n33: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n35;
  t176_n34: return -0.03177884221076965;
  t176_n35: if (E.getNumReferences() >= 3293888512 /*851.0*/) goto t176_n37;
  t176_n36: return 0.0714932307600975;
  t176_n37: return 0.04426773637533188;
  t176_n38: return 0.09918895363807678;
  t176_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t176_n81;
  t176_n40: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t176_n42;
  t176_n41: return 0.011549800634384155;
  t176_n42: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t176_n80;
  t176_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t176_n55;
  t176_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n48;
  t176_n45: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t176_n47;
  t176_n46: return -0.09019868820905685;
  t176_n47: return 0.029462816193699837;
  t176_n48: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t176_n50;
  t176_n49: return 0.03983277082443237;
  t176_n50: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t176_n52;
  t176_n51: return -0.05149456858634949;
  t176_n52: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t176_n54;
  t176_n53: return 0.13816651701927185;
  t176_n54: return -0.035262394696474075;
  t176_n55: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t176_n65;
  t176_n56: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t176_n58;
  t176_n57: return -0.19641530513763428;
  t176_n58: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t176_n64;
  t176_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n63;
  t176_n60: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t176_n62;
  t176_n61: return 0.12909498810768127;
  t176_n62: return 0.09047278016805649;
  t176_n63: return -0.1561691164970398;
  t176_n64: return 0.14759968221187592;
  t176_n65: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t176_n77;
  t176_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n68;
  t176_n67: return -0.023763328790664673;
  t176_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t176_n70;
  t176_n69: return 0.033195942640304565;
  t176_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n72;
  t176_n71: return 0.10088367015123367;
  t176_n72: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t176_n74;
  t176_n73: return -0.08969245105981827;
  t176_n74: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t176_n76;
  t176_n75: return 0.13116107881069183;
  t176_n76: return 0.047506291419267654;
  t176_n77: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t176_n79;
  t176_n78: return -0.14709466695785522;
  t176_n79: return 0.10412479192018509;
  t176_n80: return 0.013668385334312916;
  t176_n81: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t176_n161;
  t176_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n100;
  t176_n83: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t176_n99;
  t176_n84: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t176_n98;
  t176_n85: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t176_n91;
  t176_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n88;
  t176_n87: return -0.10924886912107468;
  t176_n88: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t176_n90;
  t176_n89: return 0.1096864640712738;
  t176_n90: return -0.008549611084163189;
  t176_n91: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t176_n93;
  t176_n92: return 0.10895030945539474;
  t176_n93: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t176_n97;
  t176_n94: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n96;
  t176_n95: return -0.15364687144756317;
  t176_n96: return 0.1705411672592163;
  t176_n97: return 0.11187689751386642;
  t176_n98: return 0.02276303619146347;
  t176_n99: return -0.08234378695487976;
  t176_n100: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t176_n118;
  t176_n101: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t176_n103;
  t176_n102: return 0.00896972231566906;
  t176_n103: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t176_n105;
  t176_n104: return 0.06319660693407059;
  t176_n105: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t176_n117;
  t176_n106: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t176_n108;
  t176_n107: return 0.15848729014396667;
  t176_n108: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t176_n114;
  t176_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n113;
  t176_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n112;
  t176_n111: return 0.8624885082244873;
  t176_n112: return 0.11060649156570435;
  t176_n113: return 0.03834899142384529;
  t176_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n116;
  t176_n115: return 0.11250381171703339;
  t176_n116: return 0.12692837417125702;
  t176_n117: return -0.1339406669139862;
  t176_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n120;
  t176_n119: return 0.0009153832797892392;
  t176_n120: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t176_n148;
  t176_n121: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t176_n123;
  t176_n122: return 0.0021150424145162106;
  t176_n123: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t176_n125;
  t176_n124: return -0.010180666111409664;
  t176_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t176_n127;
  t176_n126: return 0.030076628550887108;
  t176_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n143;
  t176_n128: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t176_n142;
  t176_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t176_n131;
  t176_n130: return 0.08295987546443939;
  t176_n131: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t176_n133;
  t176_n132: return 0.03238701820373535;
  t176_n133: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t176_n135;
  t176_n134: return 0.0814627856016159;
  t176_n135: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t176_n137;
  t176_n136: return 0.0294413510710001;
  t176_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t176_n139;
  t176_n138: return 0.014656325802206993;
  t176_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t176_n141;
  t176_n140: return 0.09154242277145386;
  t176_n141: return -0.13474580645561218;
  t176_n142: return 0.02033083513379097;
  t176_n143: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t176_n147;
  t176_n144: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t176_n146;
  t176_n145: return -0.017653517425060272;
  t176_n146: return 0.06114513799548149;
  t176_n147: return 0.11822322010993958;
  t176_n148: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t176_n150;
  t176_n149: return -0.06873512268066406;
  t176_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t176_n160;
  t176_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t176_n159;
  t176_n152: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t176_n158;
  t176_n153: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t176_n155;
  t176_n154: return 0.13330884277820587;
  t176_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n157;
  t176_n156: return -0.11203644424676895;
  t176_n157: return 0.10776790976524353;
  t176_n158: return 0.02282494306564331;
  t176_n159: return -0.02200036309659481;
  t176_n160: return 0.05121050029993057;
  t176_n161: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t176_n219;
  t176_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t176_n166;
  t176_n163: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t176_n165;
  t176_n164: return -0.05594972148537636;
  t176_n165: return 0.19143299758434296;
  t176_n166: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t176_n172;
  t176_n167: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t176_n169;
  t176_n168: return 0.024157943204045296;
  t176_n169: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n171;
  t176_n170: return -0.1710437536239624;
  t176_n171: return -0.03474530950188637;
  t176_n172: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t176_n192;
  t176_n173: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t176_n187;
  t176_n174: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t176_n176;
  t176_n175: return -0.07007706165313721;
  t176_n176: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t176_n184;
  t176_n177: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t176_n179;
  t176_n178: return -0.0812382772564888;
  t176_n179: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t176_n183;
  t176_n180: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t176_n182;
  t176_n181: return 0.10722175985574722;
  t176_n182: return -0.03881087154150009;
  t176_n183: return 0.10776451230049133;
  t176_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t176_n186;
  t176_n185: return 0.1293865144252777;
  t176_n186: return -0.14699813723564148;
  t176_n187: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t176_n189;
  t176_n188: return 0.11760580539703369;
  t176_n189: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t176_n191;
  t176_n190: return -0.11810611933469772;
  t176_n191: return 0.11571376770734787;
  t176_n192: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t176_n194;
  t176_n193: return -0.09014682471752167;
  t176_n194: if (E.getNumReferences() >= 3279814656 /*254.0*/) goto t176_n208;
  t176_n195: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t176_n205;
  t176_n196: if (E.getNumReferences() >= 3278962688 /*241.0*/) goto t176_n204;
  t176_n197: if (E.getNumReferences() >= 3272310784 /*139.5*/) goto t176_n201;
  t176_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n200;
  t176_n199: return 0.08830820024013519;
  t176_n200: return 0.005206044297665358;
  t176_n201: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t176_n203;
  t176_n202: return 0.11969684809446335;
  t176_n203: return 0.06653214246034622;
  t176_n204: return 0.15008200705051422;
  t176_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n207;
  t176_n206: return 0.09195809066295624;
  t176_n207: return 0.1393737494945526;
  t176_n208: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n216;
  t176_n209: if (E.getNumReferences() >= 3296608256 /*1017.0*/) goto t176_n213;
  t176_n210: if (E.getNumReferences() >= 3291398144 /*699.0*/) goto t176_n212;
  t176_n211: return -0.04336072877049446;
  t176_n212: return -0.3797342777252197;
  t176_n213: if (E.getNumReferences() >= 3297202176 /*1082.5*/) goto t176_n215;
  t176_n214: return 0.1266629546880722;
  t176_n215: return -0.07761402428150177;
  t176_n216: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t176_n218;
  t176_n217: return -0.06630448251962662;
  t176_n218: return 0.11551117897033691;
  t176_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t176_n233;
  t176_n220: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t176_n228;
  t176_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t176_n223;
  t176_n222: return 0.045424070209264755;
  t176_n223: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t176_n225;
  t176_n224: return 0.6037192940711975;
  t176_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n227;
  t176_n226: return 0.13685989379882812;
  t176_n227: return 0.051933448761701584;
  t176_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n232;
  t176_n229: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t176_n231;
  t176_n230: return -0.020969880744814873;
  t176_n231: return 0.08756247907876968;
  t176_n232: return 0.10586483031511307;
  t176_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n235;
  t176_n234: return -0.06419984251260757;
  t176_n235: return 0.05875939875841141;
  t176_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t176_n240;
  t176_n237: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t176_n239;
  t176_n238: return -0.006439375691115856;
  t176_n239: return 0.0037990580312907696;
  t176_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t176_n252;
  t176_n241: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t176_n243;
  t176_n242: return 0.02264370210468769;
  t176_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t176_n245;
  t176_n244: return 0.0800895020365715;
  t176_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t176_n251;
  t176_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t176_n248;
  t176_n247: return 0.013807513751089573;
  t176_n248: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t176_n250;
  t176_n249: return 0.10974359512329102;
  t176_n250: return 0.13233643770217896;
  t176_n251: return -0.08885827660560608;
  t176_n252: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t176_n254;
  t176_n253: return 0.007429932709783316;
  t176_n254: return -0.07878474146127701;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree177(const Example& E) {
  t177_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t177_n2;
  t177_n1: return -0.000390149507438764;
  t177_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t177_n10;
  t177_n3: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t177_n9;
  t177_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t177_n8;
  t177_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n7;
  t177_n6: return -0.14077432453632355;
  t177_n7: return -0.21501679718494415;
  t177_n8: return -0.019651515409350395;
  t177_n9: return 0.00017687772924546152;
  t177_n10: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t177_n188;
  t177_n11: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t177_n27;
  t177_n12: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t177_n14;
  t177_n13: return 0.006539792753756046;
  t177_n14: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t177_n22;
  t177_n15: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t177_n17;
  t177_n16: return -0.00989763718098402;
  t177_n17: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t177_n19;
  t177_n18: return -0.0700974240899086;
  t177_n19: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t177_n21;
  t177_n20: return -0.15801195800304413;
  t177_n21: return -0.15861250460147858;
  t177_n22: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t177_n26;
  t177_n23: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t177_n25;
  t177_n24: return -0.1639707088470459;
  t177_n25: return 0.029470127075910568;
  t177_n26: return 0.11708724498748779;
  t177_n27: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t177_n109;
  t177_n28: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t177_n50;
  t177_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n37;
  t177_n30: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t177_n36;
  t177_n31: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t177_n35;
  t177_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t177_n34;
  t177_n33: return 0.18690137565135956;
  t177_n34: return 0.11692226678133011;
  t177_n35: return 0.05051310360431671;
  t177_n36: return -0.07452430576086044;
  t177_n37: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n49;
  t177_n38: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t177_n40;
  t177_n39: return -0.1365058273077011;
  t177_n40: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t177_n48;
  t177_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t177_n43;
  t177_n42: return 0.06289684772491455;
  t177_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n47;
  t177_n44: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n46;
  t177_n45: return -0.12275335937738419;
  t177_n46: return 0.0812181755900383;
  t177_n47: return 0.08612003922462463;
  t177_n48: return -0.07802195101976395;
  t177_n49: return -0.24325628578662872;
  t177_n50: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t177_n64;
  t177_n51: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t177_n63;
  t177_n52: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t177_n60;
  t177_n53: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t177_n57;
  t177_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t177_n56;
  t177_n55: return 0.09995579719543457;
  t177_n56: return -0.03133971989154816;
  t177_n57: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t177_n59;
  t177_n58: return -0.14541399478912354;
  t177_n59: return 0.1305980086326599;
  t177_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n62;
  t177_n61: return -0.045735254883766174;
  t177_n62: return 0.12231747061014175;
  t177_n63: return -0.09389390796422958;
  t177_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t177_n100;
  t177_n65: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t177_n87;
  t177_n66: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t177_n68;
  t177_n67: return -0.00902304146438837;
  t177_n68: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t177_n86;
  t177_n69: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t177_n85;
  t177_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n72;
  t177_n71: return -0.15808500349521637;
  t177_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n76;
  t177_n73: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t177_n75;
  t177_n74: return 0.11249828338623047;
  t177_n75: return -0.13762669265270233;
  t177_n76: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t177_n84;
  t177_n77: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t177_n83;
  t177_n78: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t177_n80;
  t177_n79: return -0.1524084061384201;
  t177_n80: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t177_n82;
  t177_n81: return 0.10685862600803375;
  t177_n82: return 0.01476842351257801;
  t177_n83: return 0.16761745512485504;
  t177_n84: return -0.4336182177066803;
  t177_n85: return 0.09253909438848495;
  t177_n86: return 0.10606599599123001;
  t177_n87: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n95;
  t177_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t177_n90;
  t177_n89: return -0.38739094138145447;
  t177_n90: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t177_n94;
  t177_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n93;
  t177_n92: return -0.10733252018690109;
  t177_n93: return 0.11192444711923599;
  t177_n94: return 0.12160857766866684;
  t177_n95: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t177_n97;
  t177_n96: return 0.04012085869908333;
  t177_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n99;
  t177_n98: return 0.008728859946131706;
  t177_n99: return 0.11178336292505264;
  t177_n100: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t177_n102;
  t177_n101: return -0.004364111460745335;
  t177_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n104;
  t177_n103: return -0.10436521470546722;
  t177_n104: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t177_n108;
  t177_n105: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t177_n107;
  t177_n106: return 0.1312233805656433;
  t177_n107: return 0.011721893213689327;
  t177_n108: return 0.04396749287843704;
  t177_n109: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t177_n147;
  t177_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n116;
  t177_n111: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t177_n113;
  t177_n112: return -0.030824050307273865;
  t177_n113: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t177_n115;
  t177_n114: return 0.11378654837608337;
  t177_n115: return 0.0376536063849926;
  t177_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n122;
  t177_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t177_n119;
  t177_n118: return -0.23374895751476288;
  t177_n119: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t177_n121;
  t177_n120: return -0.137730211019516;
  t177_n121: return 0.09471195936203003;
  t177_n122: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t177_n124;
  t177_n123: return -0.14751887321472168;
  t177_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n130;
  t177_n125: if (E.getNumReferences() >= 3273129984 /*152.0*/) goto t177_n127;
  t177_n126: return -0.11126815527677536;
  t177_n127: if (E.getNumReferences() >= 3277127680 /*213.0*/) goto t177_n129;
  t177_n128: return 0.12106175720691681;
  t177_n129: return 0.004712610971182585;
  t177_n130: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t177_n136;
  t177_n131: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t177_n133;
  t177_n132: return 0.09109578281641006;
  t177_n133: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t177_n135;
  t177_n134: return 0.10168681293725967;
  t177_n135: return -0.18267704546451569;
  t177_n136: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t177_n140;
  t177_n137: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t177_n139;
  t177_n138: return -0.25942549109458923;
  t177_n139: return 0.06281420588493347;
  t177_n140: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t177_n142;
  t177_n141: return 0.10020679980516434;
  t177_n142: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t177_n144;
  t177_n143: return -0.24271777272224426;
  t177_n144: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t177_n146;
  t177_n145: return 0.11707417666912079;
  t177_n146: return 0.0744423121213913;
  t177_n147: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t177_n187;
  t177_n148: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t177_n174;
  t177_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t177_n161;
  t177_n150: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t177_n152;
  t177_n151: return -0.09687678515911102;
  t177_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n154;
  t177_n153: return 0.03401947021484375;
  t177_n154: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t177_n156;
  t177_n155: return -0.22381173074245453;
  t177_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n158;
  t177_n157: return 0.09793730080127716;
  t177_n158: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t177_n160;
  t177_n159: return 0.119362473487854;
  t177_n160: return 0.10084366053342819;
  t177_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t177_n173;
  t177_n162: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t177_n168;
  t177_n163: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t177_n167;
  t177_n164: if (E.getNumReferences() >= 3250061312 /*23.0*/) goto t177_n166;
  t177_n165: return 0.090629942715168;
  t177_n166: return -0.06629298627376556;
  t177_n167: return 0.11528375744819641;
  t177_n168: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t177_n170;
  t177_n169: return -0.2501525282859802;
  t177_n170: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t177_n172;
  t177_n171: return 0.10646555572748184;
  t177_n172: return -0.0559065006673336;
  t177_n173: return 0.031517427414655685;
  t177_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t177_n184;
  t177_n175: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t177_n177;
  t177_n176: return -0.06926585733890533;
  t177_n177: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t177_n181;
  t177_n178: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t177_n180;
  t177_n179: return 0.1133953407406807;
  t177_n180: return 0.039298128336668015;
  t177_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n183;
  t177_n182: return 0.1147204115986824;
  t177_n183: return -0.05735696479678154;
  t177_n184: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t177_n186;
  t177_n185: return 0.1147015169262886;
  t177_n186: return 0.03304498642683029;
  t177_n187: return 0.013656419701874256;
  t177_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t177_n212;
  t177_n189: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t177_n191;
  t177_n190: return -0.04378262162208557;
  t177_n191: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t177_n193;
  t177_n192: return -0.04374217614531517;
  t177_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n195;
  t177_n194: return -0.022285766899585724;
  t177_n195: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t177_n201;
  t177_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t177_n200;
  t177_n197: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t177_n199;
  t177_n198: return 0.1570809930562973;
  t177_n199: return 0.10877250880002975;
  t177_n200: return 0.05333009734749794;
  t177_n201: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t177_n211;
  t177_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t177_n204;
  t177_n203: return 0.023562509566545486;
  t177_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n210;
  t177_n205: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t177_n209;
  t177_n206: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t177_n208;
  t177_n207: return 0.024177711457014084;
  t177_n208: return 0.0594371072947979;
  t177_n209: return -0.029574759304523468;
  t177_n210: return 0.009104850701987743;
  t177_n211: return -0.003025685204192996;
  t177_n212: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t177_n254;
  t177_n213: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t177_n237;
  t177_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t177_n222;
  t177_n215: if (E.getNumReferences() >= 3322721280 /*9005.0*/) goto t177_n219;
  t177_n216: if (E.getFileProximityDistance() >= 3251109888 /*25.0*/) goto t177_n218;
  t177_n217: return 0.03170266002416611;
  t177_n218: return 1.007369875907898;
  t177_n219: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t177_n221;
  t177_n220: return 0.09120277315378189;
  t177_n221: return -0.04685872048139572;
  t177_n222: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t177_n236;
  t177_n223: if (E.getNumReferences() >= 3334587392 /*24802.0*/) goto t177_n235;
  t177_n224: if (E.getNumReferences() >= 3290071040 /*618.0*/) goto t177_n234;
  t177_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t177_n231;
  t177_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t177_n228;
  t177_n227: return 0.04099518060684204;
  t177_n228: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t177_n230;
  t177_n229: return 0.10634998977184296;
  t177_n230: return 0.08317594975233078;
  t177_n231: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t177_n233;
  t177_n232: return 0.04653552547097206;
  t177_n233: return -0.15003082156181335;
  t177_n234: return 0.09326910972595215;
  t177_n235: return -0.6865056753158569;
  t177_n236: return 0.13838237524032593;
  t177_n237: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t177_n239;
  t177_n238: return 0.0027840412221848965;
  t177_n239: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t177_n253;
  t177_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t177_n242;
  t177_n241: return -0.03804606571793556;
  t177_n242: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t177_n248;
  t177_n243: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t177_n247;
  t177_n244: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t177_n246;
  t177_n245: return 0.11219148337841034;
  t177_n246: return -0.1117468997836113;
  t177_n247: return 0.10669496655464172;
  t177_n248: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t177_n252;
  t177_n249: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t177_n251;
  t177_n250: return 0.06165629252791405;
  t177_n251: return 0.1110730841755867;
  t177_n252: return -0.13619622588157654;
  t177_n253: return 0.006763484328985214;
  t177_n254: return 0.002987643238157034;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree178(const Example& E) {
  t178_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t178_n230;
  t178_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t178_n3;
  t178_n2: return -0.00020145418238826096;
  t178_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t178_n165;
  t178_n4: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t178_n164;
  t178_n5: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t178_n25;
  t178_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t178_n10;
  t178_n7: if (E.getNumReferences() >= 3280207872 /*264.0*/) goto t178_n9;
  t178_n8: return 0.02225569635629654;
  t178_n9: return -0.4386032521724701;
  t178_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t178_n12;
  t178_n11: return -0.026421571150422096;
  t178_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n14;
  t178_n13: return 0.00583090353757143;
  t178_n14: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t178_n16;
  t178_n15: return 0.01864231377840042;
  t178_n16: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t178_n18;
  t178_n17: return -0.03270494565367699;
  t178_n18: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t178_n20;
  t178_n19: return 0.023247646167874336;
  t178_n20: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t178_n22;
  t178_n21: return -0.012974857352674007;
  t178_n22: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t178_n24;
  t178_n23: return -0.1157151609659195;
  t178_n24: return 0.11162222921848297;
  t178_n25: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t178_n129;
  t178_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n28;
  t178_n27: return 0.02660672925412655;
  t178_n28: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t178_n62;
  t178_n29: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t178_n61;
  t178_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t178_n34;
  t178_n31: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t178_n33;
  t178_n32: return -0.037410952150821686;
  t178_n33: return -0.22737224400043488;
  t178_n34: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t178_n60;
  t178_n35: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t178_n39;
  t178_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t178_n38;
  t178_n37: return 0.028122689574956894;
  t178_n38: return 0.1001436784863472;
  t178_n39: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t178_n55;
  t178_n40: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t178_n42;
  t178_n41: return -0.07286402583122253;
  t178_n42: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t178_n50;
  t178_n43: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t178_n49;
  t178_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t178_n46;
  t178_n45: return -0.1349981725215912;
  t178_n46: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t178_n48;
  t178_n47: return 0.09154918789863586;
  t178_n48: return 0.13500787317752838;
  t178_n49: return -0.027534935623407364;
  t178_n50: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t178_n52;
  t178_n51: return -0.09464459121227264;
  t178_n52: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t178_n54;
  t178_n53: return 0.02532198466360569;
  t178_n54: return 0.13900305330753326;
  t178_n55: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t178_n57;
  t178_n56: return 0.020892083644866943;
  t178_n57: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t178_n59;
  t178_n58: return 0.12279364466667175;
  t178_n59: return -0.11412575095891953;
  t178_n60: return 0.10405834019184113;
  t178_n61: return -0.0009496358688920736;
  t178_n62: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n64;
  t178_n63: return -0.049769822508096695;
  t178_n64: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t178_n74;
  t178_n65: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n69;
  t178_n66: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t178_n68;
  t178_n67: return -0.4498443007469177;
  t178_n68: return 0.08675692975521088;
  t178_n69: if (E.getNumReferences() >= 3269459968 /*112.0*/) goto t178_n71;
  t178_n70: return -0.03050893358886242;
  t178_n71: if (E.getNumReferences() >= 3274899456 /*179.0*/) goto t178_n73;
  t178_n72: return 0.12125296145677567;
  t178_n73: return 0.0410318523645401;
  t178_n74: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t178_n96;
  t178_n75: if (E.getNumReferences() >= 3278503936 /*234.0*/) goto t178_n95;
  t178_n76: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t178_n94;
  t178_n77: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t178_n91;
  t178_n78: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t178_n90;
  t178_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n81;
  t178_n80: return -0.6921550631523132;
  t178_n81: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t178_n83;
  t178_n82: return -0.07243554294109344;
  t178_n83: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t178_n85;
  t178_n84: return 0.09583292156457901;
  t178_n85: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t178_n89;
  t178_n86: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t178_n88;
  t178_n87: return -0.0015079390723258257;
  t178_n88: return 0.11832374334335327;
  t178_n89: return -0.33082446455955505;
  t178_n90: return 0.10098050534725189;
  t178_n91: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t178_n93;
  t178_n92: return 0.10483294725418091;
  t178_n93: return 0.02193715237081051;
  t178_n94: return -0.10469905287027359;
  t178_n95: return 0.07874462008476257;
  t178_n96: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t178_n114;
  t178_n97: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n101;
  t178_n98: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t178_n100;
  t178_n99: return 0.11487466841936111;
  t178_n100: return 0.056790150701999664;
  t178_n101: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t178_n109;
  t178_n102: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t178_n108;
  t178_n103: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t178_n105;
  t178_n104: return -0.07018359750509262;
  t178_n105: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t178_n107;
  t178_n106: return 0.11969397962093353;
  t178_n107: return 0.04435697942972183;
  t178_n108: return 0.09233160316944122;
  t178_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t178_n111;
  t178_n110: return 0.11442156136035919;
  t178_n111: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t178_n113;
  t178_n112: return -0.14979925751686096;
  t178_n113: return 0.1118730753660202;
  t178_n114: if (E.getNumReferences() >= 3269066752 /*109.0*/) goto t178_n120;
  t178_n115: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t178_n119;
  t178_n116: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t178_n118;
  t178_n117: return 0.12633544206619263;
  t178_n118: return 0.06396222114562988;
  t178_n119: return -0.014791748486459255;
  t178_n120: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t178_n128;
  t178_n121: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t178_n125;
  t178_n122: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t178_n124;
  t178_n123: return -0.14140069484710693;
  t178_n124: return 0.12176613509654999;
  t178_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n127;
  t178_n126: return -0.23153725266456604;
  t178_n127: return 0.11796277016401291;
  t178_n128: return 0.021743157878518105;
  t178_n129: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n159;
  t178_n130: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t178_n152;
  t178_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n149;
  t178_n132: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t178_n134;
  t178_n133: return 0.10427269339561462;
  t178_n134: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n142;
  t178_n135: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t178_n137;
  t178_n136: return 0.06543313711881638;
  t178_n137: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t178_n139;
  t178_n138: return 0.21429535746574402;
  t178_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t178_n141;
  t178_n140: return 0.13480810821056366;
  t178_n141: return 0.04959540814161301;
  t178_n142: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t178_n148;
  t178_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t178_n145;
  t178_n144: return -0.19346283376216888;
  t178_n145: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t178_n147;
  t178_n146: return 0.08898285031318665;
  t178_n147: return 0.10962776839733124;
  t178_n148: return -0.012936791405081749;
  t178_n149: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t178_n151;
  t178_n150: return 0.017175450921058655;
  t178_n151: return -0.6122277975082397;
  t178_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n154;
  t178_n153: return -0.01205557119101286;
  t178_n154: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t178_n156;
  t178_n155: return -0.002586424583569169;
  t178_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n158;
  t178_n157: return 0.10199514776468277;
  t178_n158: return 0.1137448102235794;
  t178_n159: if (E.getNumReferences() >= 3303403520 /*1839.5*/) goto t178_n163;
  t178_n160: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t178_n162;
  t178_n161: return 0.006636401172727346;
  t178_n162: return -0.22753921151161194;
  t178_n163: return 0.09561043977737427;
  t178_n164: return -0.0019318696577101946;
  t178_n165: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t178_n167;
  t178_n166: return 0.0064772069454193115;
  t178_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t178_n181;
  t178_n168: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t178_n180;
  t178_n169: if (E.getNumReferences() >= 3305879552 /*2235.5*/) goto t178_n179;
  t178_n170: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t178_n178;
  t178_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n175;
  t178_n172: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t178_n174;
  t178_n173: return 0.10374537110328674;
  t178_n174: return 0.11584331095218658;
  t178_n175: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t178_n177;
  t178_n176: return 0.09150953590869904;
  t178_n177: return -0.34021905064582825;
  t178_n178: return 0.053244698792696;
  t178_n179: return 0.10874247550964355;
  t178_n180: return 0.008969453163444996;
  t178_n181: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t178_n223;
  t178_n182: if (E.getNumReferences() >= 3324623872 /*10863.0*/) goto t178_n220;
  t178_n183: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t178_n209;
  t178_n184: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t178_n204;
  t178_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n195;
  t178_n186: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t178_n194;
  t178_n187: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n189;
  t178_n188: return 0.08025682717561722;
  t178_n189: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t178_n193;
  t178_n190: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t178_n192;
  t178_n191: return -0.15171626210212708;
  t178_n192: return 0.13465553522109985;
  t178_n193: return 0.10371610522270203;
  t178_n194: return -0.023629801347851753;
  t178_n195: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t178_n203;
  t178_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t178_n198;
  t178_n197: return -0.012766093946993351;
  t178_n198: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t178_n202;
  t178_n199: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t178_n201;
  t178_n200: return 0.09511766582727432;
  t178_n201: return 0.09000690281391144;
  t178_n202: return -0.4988269507884979;
  t178_n203: return -0.039677694439888;
  t178_n204: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n208;
  t178_n205: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t178_n207;
  t178_n206: return 0.10456015169620514;
  t178_n207: return 0.11504139006137848;
  t178_n208: return 0.004218322690576315;
  t178_n209: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t178_n211;
  t178_n210: return 0.02802639827132225;
  t178_n211: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n213;
  t178_n212: return 0.03291323035955429;
  t178_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t178_n215;
  t178_n214: return 0.12438186258077621;
  t178_n215: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t178_n217;
  t178_n216: return 0.11971411854028702;
  t178_n217: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t178_n219;
  t178_n218: return 0.1301061064004898;
  t178_n219: return -0.0279241930693388;
  t178_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t178_n222;
  t178_n221: return 0.1009020060300827;
  t178_n222: return 0.006687514949589968;
  t178_n223: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t178_n227;
  t178_n224: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t178_n226;
  t178_n225: return -0.19174383580684662;
  t178_n226: return 0.10750926285982132;
  t178_n227: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t178_n229;
  t178_n228: return -0.6217468976974487;
  t178_n229: return -0.30951523780822754;
  t178_n230: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t178_n246;
  t178_n231: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t178_n233;
  t178_n232: return -0.038484279066324234;
  t178_n233: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t178_n245;
  t178_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n244;
  t178_n235: if (E.getNumReferences() >= 3298754560 /*1272.0*/) goto t178_n241;
  t178_n236: if (E.getNumReferences() >= 3294642176 /*897.0*/) goto t178_n240;
  t178_n237: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t178_n239;
  t178_n238: return -0.13799281418323517;
  t178_n239: return 0.883996307849884;
  t178_n240: return 0.19915200769901276;
  t178_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t178_n243;
  t178_n242: return -0.11338190734386444;
  t178_n243: return 0.3873768448829651;
  t178_n244: return 0.07181569188833237;
  t178_n245: return -0.10227082669734955;
  t178_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t178_n254;
  t178_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t178_n249;
  t178_n248: return -0.07719717174768448;
  t178_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t178_n253;
  t178_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t178_n252;
  t178_n251: return -0.14223049581050873;
  t178_n252: return -0.2879208028316498;
  t178_n253: return -0.12408822029829025;
  t178_n254: return -0.01726151444017887;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree179(const Example& E) {
  t179_n0: if (E.getNumReferences() >= 3298316288 /*1218.5*/) goto t179_n2;
  t179_n1: return -0.00039998465217649937;
  t179_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t179_n168;
  t179_n3: if (E.getNumReferences() >= 3298328576 /*1220.0*/) goto t179_n7;
  t179_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n6;
  t179_n5: return -0.0028190561570227146;
  t179_n6: return 0.13108253479003906;
  t179_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t179_n167;
  t179_n8: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t179_n12;
  t179_n9: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t179_n11;
  t179_n10: return -0.008237339556217194;
  t179_n11: return 0.0616728700697422;
  t179_n12: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t179_n156;
  t179_n13: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t179_n21;
  t179_n14: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t179_n16;
  t179_n15: return 0.05982687696814537;
  t179_n16: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t179_n18;
  t179_n17: return -0.010620025917887688;
  t179_n18: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t179_n20;
  t179_n19: return 0.10692249983549118;
  t179_n20: return 0.11250372976064682;
  t179_n21: if (E.getNumReferences() >= 3361098688 /*219439.0*/) goto t179_n155;
  t179_n22: if (E.getNumReferences() >= 3339244032 /*35026.0*/) goto t179_n80;
  t179_n23: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t179_n77;
  t179_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n66;
  t179_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n49;
  t179_n26: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t179_n48;
  t179_n27: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t179_n37;
  t179_n28: if (E.getNumReferences() >= 3330330368 /*16487.5*/) goto t179_n36;
  t179_n29: if (E.getNumReferences() >= 3330192896 /*16301.5*/) goto t179_n35;
  t179_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t179_n34;
  t179_n31: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t179_n33;
  t179_n32: return 0.1212223470211029;
  t179_n33: return 0.03221386298537254;
  t179_n34: return -0.07725005596876144;
  t179_n35: return 0.1320531964302063;
  t179_n36: return -0.017849059775471687;
  t179_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n43;
  t179_n38: if (E.getNumReferences() >= 3337965568 /*31400.0*/) goto t179_n40;
  t179_n39: return 0.009879023768007755;
  t179_n40: if (E.getNumReferences() >= 3338812928 /*33342.0*/) goto t179_n42;
  t179_n41: return 0.15554344654083252;
  t179_n42: return -0.10554318875074387;
  t179_n43: if (E.getNumReferences() >= 3332038144 /*19823.0*/) goto t179_n47;
  t179_n44: if (E.getNumReferences() >= 3331079424 /*17950.5*/) goto t179_n46;
  t179_n45: return 0.5013631582260132;
  t179_n46: return 0.12705029547214508;
  t179_n47: return -0.2357441931962967;
  t179_n48: return 0.004418500699102879;
  t179_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n55;
  t179_n50: if (E.getNumReferences() >= 3331347712 /*18474.5*/) goto t179_n54;
  t179_n51: if (E.getNumReferences() >= 3331214848 /*18215.0*/) goto t179_n53;
  t179_n52: return 0.021192342042922974;
  t179_n53: return 0.11307284235954285;
  t179_n54: return -0.15522004663944244;
  t179_n55: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t179_n59;
  t179_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type))) goto t179_n58;
  t179_n57: return -0.1429699808359146;
  t179_n58: return 0.09141042828559875;
  t179_n59: if (E.getNumReferences() >= 3335568384 /*26718.0*/) goto t179_n65;
  t179_n60: if (E.getNumReferences() >= 3334574080 /*24776.0*/) goto t179_n64;
  t179_n61: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n63;
  t179_n62: return 0.012183521874248981;
  t179_n63: return 0.13219834864139557;
  t179_n64: return 0.10008124262094498;
  t179_n65: return -0.059245895594358444;
  t179_n66: if (E.getNumReferences() >= 3330499328 /*16817.5*/) goto t179_n70;
  t179_n67: if (E.getNumReferences() >= 3325739520 /*11952.5*/) goto t179_n69;
  t179_n68: return 0.025176016613841057;
  t179_n69: return -0.32512107491493225;
  t179_n70: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t179_n76;
  t179_n71: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t179_n75;
  t179_n72: if (E.getNumReferences() >= 3331408640 /*18593.5*/) goto t179_n74;
  t179_n73: return 0.10072766244411469;
  t179_n74: return 0.10414355993270874;
  t179_n75: return -0.02561655268073082;
  t179_n76: return -0.040144845843315125;
  t179_n77: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n79;
  t179_n78: return -0.23080971837043762;
  t179_n79: return 0.10454107075929642;
  t179_n80: if (E.getNumReferences() >= 3342848512 /*49106.0*/) goto t179_n100;
  t179_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n91;
  t179_n82: if (E.getNumReferences() >= 3339443456 /*35805.0*/) goto t179_n88;
  t179_n83: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n87;
  t179_n84: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t179_n86;
  t179_n85: return -0.1857873946428299;
  t179_n86: return 0.10567515343427658;
  t179_n87: return -0.3736220598220825;
  t179_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t179_n90;
  t179_n89: return -0.01702474057674408;
  t179_n90: return 0.05043250694870949;
  t179_n91: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t179_n95;
  t179_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t179_n94;
  t179_n93: return 0.034261107444763184;
  t179_n94: return 0.08730768412351608;
  t179_n95: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t179_n99;
  t179_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t179_n98;
  t179_n97: return -0.13243485987186432;
  t179_n98: return 0.08891291171312332;
  t179_n99: return 0.0560181550681591;
  t179_n100: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t179_n102;
  t179_n101: return -0.020639510825276375;
  t179_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n146;
  t179_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t179_n105;
  t179_n104: return -0.0003562315250746906;
  t179_n105: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t179_n123;
  t179_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n116;
  t179_n107: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t179_n115;
  t179_n108: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t179_n110;
  t179_n109: return 0.0323173888027668;
  t179_n110: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t179_n114;
  t179_n111: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n113;
  t179_n112: return 0.102862149477005;
  t179_n113: return 0.06170634552836418;
  t179_n114: return -0.2331061065196991;
  t179_n115: return -0.10174140334129333;
  t179_n116: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n118;
  t179_n117: return -0.013782525435090065;
  t179_n118: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t179_n120;
  t179_n119: return 0.09841644018888474;
  t179_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n122;
  t179_n121: return -0.5529049038887024;
  t179_n122: return 0.1053927093744278;
  t179_n123: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t179_n133;
  t179_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n130;
  t179_n125: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t179_n127;
  t179_n126: return 0.10909270495176315;
  t179_n127: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n129;
  t179_n128: return 0.09218146651983261;
  t179_n129: return -0.19299833476543427;
  t179_n130: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n132;
  t179_n131: return 0.053278449922800064;
  t179_n132: return -0.455231249332428;
  t179_n133: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t179_n135;
  t179_n134: return -0.019955020397901535;
  t179_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n145;
  t179_n136: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t179_n138;
  t179_n137: return 0.03960325941443443;
  t179_n138: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n140;
  t179_n139: return 0.02078094333410263;
  t179_n140: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t179_n142;
  t179_n141: return 0.12079114466905594;
  t179_n142: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t179_n144;
  t179_n143: return -0.2784310281276703;
  t179_n144: return 0.153601735830307;
  t179_n145: return -0.10640688985586166;
  t179_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t179_n148;
  t179_n147: return -0.09700322896242142;
  t179_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t179_n152;
  t179_n149: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t179_n151;
  t179_n150: return 0.047057077288627625;
  t179_n151: return 0.09797867387533188;
  t179_n152: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t179_n154;
  t179_n153: return 0.08389124274253845;
  t179_n154: return 0.11027498543262482;
  t179_n155: return -0.00776694668456912;
  t179_n156: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t179_n158;
  t179_n157: return -0.0057794805616140366;
  t179_n158: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t179_n166;
  t179_n159: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t179_n161;
  t179_n160: return 0.08495788276195526;
  t179_n161: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t179_n165;
  t179_n162: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t179_n164;
  t179_n163: return -0.028445135802030563;
  t179_n164: return 0.029858944937586784;
  t179_n165: return 0.06024080887436867;
  t179_n166: return -0.02447957918047905;
  t179_n167: return 0.018547028303146362;
  t179_n168: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t179_n170;
  t179_n169: return -0.0004777481372002512;
  t179_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t179_n172;
  t179_n171: return 0.005694905761629343;
  t179_n172: if (E.getNumReferences() >= 3299901440 /*1412.0*/) goto t179_n180;
  t179_n173: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t179_n179;
  t179_n174: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t179_n178;
  t179_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t179_n177;
  t179_n176: return -0.026724830269813538;
  t179_n177: return 0.08762840181589127;
  t179_n178: return 0.11988922208547592;
  t179_n179: return 0.02347046323120594;
  t179_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t179_n206;
  t179_n181: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t179_n205;
  t179_n182: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n190;
  t179_n183: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t179_n185;
  t179_n184: return -0.039432596415281296;
  t179_n185: if (E.getNumReferences() >= 3310399488 /*3339.0*/) goto t179_n189;
  t179_n186: if (E.getNumReferences() >= 3309062144 /*3012.5*/) goto t179_n188;
  t179_n187: return -0.13639555871486664;
  t179_n188: return 0.10995916277170181;
  t179_n189: return 0.0296745877712965;
  t179_n190: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t179_n200;
  t179_n191: if (E.getNumReferences() >= 3338323200 /*32098.5*/) goto t179_n195;
  t179_n192: if (E.getNumReferences() >= 3316014080 /*5323.5*/) goto t179_n194;
  t179_n193: return 0.10443536937236786;
  t179_n194: return -0.12158460170030594;
  t179_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t179_n197;
  t179_n196: return -0.14795707166194916;
  t179_n197: if (E.getNumReferences() >= 3339744256 /*36980.0*/) goto t179_n199;
  t179_n198: return 0.1292692869901657;
  t179_n199: return 0.1221500113606453;
  t179_n200: if (E.getNumReferences() >= 3363327264 /*254260.5*/) goto t179_n204;
  t179_n201: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t179_n203;
  t179_n202: return 0.10688687115907669;
  t179_n203: return 0.10759350657463074;
  t179_n204: return -0.052828311920166016;
  t179_n205: return -0.06512115895748138;
  t179_n206: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t179_n254;
  t179_n207: if (E.getNumReferences() >= 3359807328 /*199261.5*/) goto t179_n245;
  t179_n208: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t179_n210;
  t179_n209: return -0.018409358337521553;
  t179_n210: if (E.getNumReferences() >= 3330095104 /*16206.0*/) goto t179_n244;
  t179_n211: if (E.getNumReferences() >= 3309326336 /*3077.0*/) goto t179_n213;
  t179_n212: return -0.04012124612927437;
  t179_n213: if (E.getNumReferences() >= 3310000128 /*3241.5*/) goto t179_n217;
  t179_n214: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t179_n216;
  t179_n215: return 0.1044839397072792;
  t179_n216: return 0.011139802634716034;
  t179_n217: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t179_n219;
  t179_n218: return -0.03212020918726921;
  t179_n219: if (E.getNumReferences() >= 3320567808 /*7547.0*/) goto t179_n221;
  t179_n220: return 0.035415634512901306;
  t179_n221: if (E.getNumReferences() >= 3322433024 /*8723.5*/) goto t179_n227;
  t179_n222: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t179_n226;
  t179_n223: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t179_n225;
  t179_n224: return 0.008431429974734783;
  t179_n225: return 0.09738503396511078;
  t179_n226: return 0.11776309460401535;
  t179_n227: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t179_n241;
  t179_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t179_n238;
  t179_n229: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t179_n231;
  t179_n230: return -0.14199551939964294;
  t179_n231: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t179_n233;
  t179_n232: return -0.417422354221344;
  t179_n233: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t179_n235;
  t179_n234: return 0.10542873293161392;
  t179_n235: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t179_n237;
  t179_n236: return 0.050343070179224014;
  t179_n237: return 0.0803866758942604;
  t179_n238: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t179_n240;
  t179_n239: return 0.1467849314212799;
  t179_n240: return 0.08054427057504654;
  t179_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t179_n243;
  t179_n242: return -0.5370262265205383;
  t179_n243: return 0.07232190668582916;
  t179_n244: return 0.010128199122846127;
  t179_n245: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t179_n247;
  t179_n246: return 0.045570265501737595;
  t179_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t179_n251;
  t179_n248: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n250;
  t179_n249: return -0.09828488528728485;
  t179_n250: return 0.08403901010751724;
  t179_n251: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t179_n253;
  t179_n252: return 0.1050480306148529;
  t179_n253: return -0.18777012825012207;
  t179_n254: return -0.008209028281271458;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree180(const Example& E) {
  t180_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t180_n236;
  t180_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t180_n127;
  t180_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t180_n100;
  t180_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t180_n5;
  t180_n4: return -0.04628494381904602;
  t180_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t180_n7;
  t180_n6: return -0.06266451627016068;
  t180_n7: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t180_n73;
  t180_n8: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t180_n30;
  t180_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t180_n11;
  t180_n10: return -0.10859336704015732;
  t180_n11: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t180_n29;
  t180_n12: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n22;
  t180_n13: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t180_n21;
  t180_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n20;
  t180_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n19;
  t180_n16: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n18;
  t180_n17: return 0.0028684765566140413;
  t180_n18: return -0.01504200417548418;
  t180_n19: return -0.008707613684237003;
  t180_n20: return 0.004041273146867752;
  t180_n21: return 0.007334784604609013;
  t180_n22: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t180_n24;
  t180_n23: return -0.0016596510540693998;
  t180_n24: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t180_n26;
  t180_n25: return 0.014299564994871616;
  t180_n26: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t180_n28;
  t180_n27: return 0.08836674690246582;
  t180_n28: return -0.020458223298192024;
  t180_n29: return -0.051813311874866486;
  t180_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n38;
  t180_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t180_n33;
  t180_n32: return 0.0009673252352513373;
  t180_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n37;
  t180_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n36;
  t180_n35: return 0.08369125425815582;
  t180_n36: return 0.09777361154556274;
  t180_n37: return 0.017545174807310104;
  t180_n38: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t180_n68;
  t180_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n45;
  t180_n40: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t180_n44;
  t180_n41: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t180_n43;
  t180_n42: return -0.24257464706897736;
  t180_n43: return -0.07501308619976044;
  t180_n44: return -0.18927811086177826;
  t180_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n47;
  t180_n46: return 0.042406268417835236;
  t180_n47: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t180_n63;
  t180_n48: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t180_n52;
  t180_n49: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n51;
  t180_n50: return -0.0665026530623436;
  t180_n51: return -0.0005112877697683871;
  t180_n52: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t180_n54;
  t180_n53: return -0.030497577041387558;
  t180_n54: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t180_n58;
  t180_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n57;
  t180_n56: return 0.10465893894433975;
  t180_n57: return 0.10476826876401901;
  t180_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n62;
  t180_n59: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t180_n61;
  t180_n60: return 0.10131648182868958;
  t180_n61: return 0.10639595240354538;
  t180_n62: return 0.00627591647207737;
  t180_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n67;
  t180_n64: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t180_n66;
  t180_n65: return 0.20060837268829346;
  t180_n66: return 0.020408527925610542;
  t180_n67: return 0.08133211731910706;
  t180_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n72;
  t180_n69: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t180_n71;
  t180_n70: return 0.1763128936290741;
  t180_n71: return -0.03034706600010395;
  t180_n72: return -0.028944911435246468;
  t180_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t180_n91;
  t180_n74: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t180_n80;
  t180_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t180_n77;
  t180_n76: return 0.005347174126654863;
  t180_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t180_n79;
  t180_n78: return 0.024953462183475494;
  t180_n79: return 0.02280914969742298;
  t180_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n86;
  t180_n81: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t180_n85;
  t180_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t180_n84;
  t180_n83: return 0.014004012569785118;
  t180_n84: return 0.0609004870057106;
  t180_n85: return -0.011491521261632442;
  t180_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n90;
  t180_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t180_n89;
  t180_n88: return -0.02493251860141754;
  t180_n89: return 0.041232138872146606;
  t180_n90: return -0.0010058965999633074;
  t180_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t180_n99;
  t180_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n98;
  t180_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t180_n97;
  t180_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n96;
  t180_n95: return 0.09799212217330933;
  t180_n96: return 0.09633806347846985;
  t180_n97: return 0.059776827692985535;
  t180_n98: return 0.06533707678318024;
  t180_n99: return -0.043587297201156616;
  t180_n100: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t180_n126;
  t180_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t180_n103;
  t180_n102: return 0.0011095565278083086;
  t180_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t180_n105;
  t180_n104: return -0.0008377032936550677;
  t180_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n107;
  t180_n106: return 0.005925206001847982;
  t180_n107: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t180_n109;
  t180_n108: return 0.007452378980815411;
  t180_n109: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t180_n113;
  t180_n110: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t180_n112;
  t180_n111: return -0.015247092582285404;
  t180_n112: return 0.06039436534047127;
  t180_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t180_n115;
  t180_n114: return -0.0009428478660993278;
  t180_n115: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t180_n125;
  t180_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n124;
  t180_n117: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n119;
  t180_n118: return 0.06565598398447037;
  t180_n119: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t180_n123;
  t180_n120: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t180_n122;
  t180_n121: return 0.06581185013055801;
  t180_n122: return 0.08878441154956818;
  t180_n123: return 0.019449152052402496;
  t180_n124: return 0.024144019931554794;
  t180_n125: return -0.10264390707015991;
  t180_n126: return -0.05783015489578247;
  t180_n127: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t180_n129;
  t180_n128: return 0.0044548227451741695;
  t180_n129: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t180_n131;
  t180_n130: return -0.050505734980106354;
  t180_n131: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t180_n235;
  t180_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t180_n134;
  t180_n133: return -0.004130261018872261;
  t180_n134: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t180_n186;
  t180_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n137;
  t180_n136: return -0.04380081221461296;
  t180_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n173;
  t180_n138: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t180_n140;
  t180_n139: return 0.014409860596060753;
  t180_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t180_n168;
  t180_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t180_n143;
  t180_n142: return 0.03318597003817558;
  t180_n143: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t180_n167;
  t180_n144: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n166;
  t180_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t180_n161;
  t180_n146: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t180_n160;
  t180_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n157;
  t180_n148: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t180_n150;
  t180_n149: return 0.11178689450025558;
  t180_n150: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t180_n156;
  t180_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n153;
  t180_n152: return 0.1177116259932518;
  t180_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n155;
  t180_n154: return -0.2485622763633728;
  t180_n155: return 0.10443127900362015;
  t180_n156: return -0.2500877380371094;
  t180_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t180_n159;
  t180_n158: return -0.2342892587184906;
  t180_n159: return 0.15031364560127258;
  t180_n160: return 0.06375293433666229;
  t180_n161: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n165;
  t180_n162: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t180_n164;
  t180_n163: return 0.12458450347185135;
  t180_n164: return -0.17558403313159943;
  t180_n165: return 0.16345159709453583;
  t180_n166: return 0.10328947752714157;
  t180_n167: return -0.00032025668770074844;
  t180_n168: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t180_n172;
  t180_n169: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n171;
  t180_n170: return -0.11110451072454453;
  t180_n171: return 0.1272381991147995;
  t180_n172: return -0.12043686211109161;
  t180_n173: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t180_n175;
  t180_n174: return 0.022002335637807846;
  t180_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t180_n179;
  t180_n176: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t180_n178;
  t180_n177: return 0.05861881375312805;
  t180_n178: return 0.21046972274780273;
  t180_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t180_n181;
  t180_n180: return -0.10102355480194092;
  t180_n181: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t180_n183;
  t180_n182: return -0.13621680438518524;
  t180_n183: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t180_n185;
  t180_n184: return 0.12235208600759506;
  t180_n185: return 0.5679478049278259;
  t180_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n208;
  t180_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t180_n191;
  t180_n188: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t180_n190;
  t180_n189: return -0.07362175732851028;
  t180_n190: return 0.055941883474588394;
  t180_n191: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t180_n205;
  t180_n192: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t180_n194;
  t180_n193: return -0.14833028614521027;
  t180_n194: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t180_n204;
  t180_n195: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t180_n197;
  t180_n196: return -0.004078893922269344;
  t180_n197: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t180_n203;
  t180_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n200;
  t180_n199: return 0.11060479283332825;
  t180_n200: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t180_n202;
  t180_n201: return -0.20037873089313507;
  t180_n202: return 0.10849402844905853;
  t180_n203: return 0.11371657252311707;
  t180_n204: return -0.0529976412653923;
  t180_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n207;
  t180_n206: return 0.1349056363105774;
  t180_n207: return 0.048008110374212265;
  t180_n208: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t180_n234;
  t180_n209: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t180_n223;
  t180_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t180_n216;
  t180_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t180_n213;
  t180_n212: return 0.00940269511193037;
  t180_n213: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t180_n215;
  t180_n214: return 0.04624434933066368;
  t180_n215: return 0.10308396071195602;
  t180_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t180_n222;
  t180_n217: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n219;
  t180_n218: return -0.5428057909011841;
  t180_n219: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t180_n221;
  t180_n220: return 0.0342194028198719;
  t180_n221: return -1.0538171529769897;
  t180_n222: return -0.012540485709905624;
  t180_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t180_n229;
  t180_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n228;
  t180_n225: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t180_n227;
  t180_n226: return 0.020914411172270775;
  t180_n227: return -0.2714061439037323;
  t180_n228: return 0.045181840658187866;
  t180_n229: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t180_n233;
  t180_n230: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t180_n232;
  t180_n231: return 0.053795382380485535;
  t180_n232: return 0.1475246548652649;
  t180_n233: return 0.07672049105167389;
  t180_n234: return -0.10397972911596298;
  t180_n235: return -0.01755037158727646;
  t180_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t180_n252;
  t180_n237: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t180_n251;
  t180_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t180_n246;
  t180_n239: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t180_n241;
  t180_n240: return -0.0044383700005710125;
  t180_n241: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t180_n245;
  t180_n242: if (E.getNumReferences() >= 3358908544 /*185218.0*/) goto t180_n244;
  t180_n243: return 0.028660131618380547;
  t180_n244: return -0.005997000727802515;
  t180_n245: return 0.00042260007467120886;
  t180_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t180_n250;
  t180_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t180_n249;
  t180_n248: return -0.018887480720877647;
  t180_n249: return -0.1127694621682167;
  t180_n250: return 0.01758459024131298;
  t180_n251: return -0.0016231245826929808;
  t180_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t180_n254;
  t180_n253: return 0.021323716267943382;
  t180_n254: return 0.03588753566145897;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree181(const Example& E) {
  t181_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t181_n254;
  t181_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t181_n3;
  t181_n2: return -0.005014815367758274;
  t181_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t181_n65;
  t181_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t181_n64;
  t181_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t181_n57;
  t181_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n54;
  t181_n7: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n23;
  t181_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Symbol))) goto t181_n14;
  t181_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t181_n11;
  t181_n10: return 0.01824582740664482;
  t181_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n13;
  t181_n12: return 0.08091114461421967;
  t181_n13: return 0.06706328690052032;
  t181_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n16;
  t181_n15: return 0.0029984943103045225;
  t181_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t181_n18;
  t181_n17: return 0.019338048994541168;
  t181_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t181_n22;
  t181_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t181_n21;
  t181_n20: return -0.1441810429096222;
  t181_n21: return 0.11825219541788101;
  t181_n22: return -0.09603410214185715;
  t181_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t181_n45;
  t181_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t181_n26;
  t181_n25: return 0.020336216315627098;
  t181_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t181_n28;
  t181_n27: return -0.03628062829375267;
  t181_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n42;
  t181_n29: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t181_n31;
  t181_n30: return 0.025435779243707657;
  t181_n31: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t181_n41;
  t181_n32: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t181_n40;
  t181_n33: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t181_n35;
  t181_n34: return 0.13369332253932953;
  t181_n35: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t181_n39;
  t181_n36: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t181_n38;
  t181_n37: return 0.09395311027765274;
  t181_n38: return 0.0019443468190729618;
  t181_n39: return 0.10967651754617691;
  t181_n40: return 0.17824716866016388;
  t181_n41: return -0.05946781486272812;
  t181_n42: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t181_n44;
  t181_n43: return 0.07265793532133102;
  t181_n44: return -0.03676087409257889;
  t181_n45: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t181_n49;
  t181_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t181_n48;
  t181_n47: return -0.13142244517803192;
  t181_n48: return -0.004774325992912054;
  t181_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Namespace))) goto t181_n51;
  t181_n50: return -0.05111478269100189;
  t181_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n53;
  t181_n52: return -0.05995502322912216;
  t181_n53: return 0.12792706489562988;
  t181_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t181_n56;
  t181_n55: return 0.014970039017498493;
  t181_n56: return 0.10949261486530304;
  t181_n57: if (E.getNumReferences() >= 3287318528 /*481.0*/) goto t181_n59;
  t181_n58: return 0.002046664012596011;
  t181_n59: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t181_n63;
  t181_n60: if (E.getNumReferences() >= 3288072192 /*504.0*/) goto t181_n62;
  t181_n61: return 0.09825824946165085;
  t181_n62: return 0.11528678238391876;
  t181_n63: return -0.06324490159749985;
  t181_n64: return 0.007984789088368416;
  t181_n65: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t181_n157;
  t181_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t181_n68;
  t181_n67: return -0.004529192578047514;
  t181_n68: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t181_n122;
  t181_n69: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t181_n111;
  t181_n70: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t181_n106;
  t181_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t181_n93;
  t181_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t181_n90;
  t181_n73: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t181_n83;
  t181_n74: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t181_n76;
  t181_n75: return -0.10086347907781601;
  t181_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t181_n78;
  t181_n77: return 0.010873881168663502;
  t181_n78: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t181_n82;
  t181_n79: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n81;
  t181_n80: return 0.09851019829511642;
  t181_n81: return -0.04367154464125633;
  t181_n82: return 0.1110948771238327;
  t181_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t181_n85;
  t181_n84: return 0.017524270340800285;
  t181_n85: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n87;
  t181_n86: return -0.395682692527771;
  t181_n87: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n89;
  t181_n88: return 0.11166781187057495;
  t181_n89: return -0.1351151466369629;
  t181_n90: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t181_n92;
  t181_n91: return 0.07223940640687943;
  t181_n92: return 0.02896467037498951;
  t181_n93: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t181_n105;
  t181_n94: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t181_n104;
  t181_n95: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t181_n97;
  t181_n96: return 0.04696177691221237;
  t181_n97: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n103;
  t181_n98: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t181_n102;
  t181_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n101;
  t181_n100: return 0.10248609632253647;
  t181_n101: return 0.07947064191102982;
  t181_n102: return 0.10111589729785919;
  t181_n103: return -0.3169642686843872;
  t181_n104: return 0.1071612536907196;
  t181_n105: return -0.34004315733909607;
  t181_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t181_n108;
  t181_n107: return 0.05068778991699219;
  t181_n108: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n110;
  t181_n109: return 0.11447665840387344;
  t181_n110: return 0.11374961584806442;
  t181_n111: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t181_n113;
  t181_n112: return -0.050461702048778534;
  t181_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t181_n115;
  t181_n114: return 0.00903636496514082;
  t181_n115: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t181_n117;
  t181_n116: return 0.09747406095266342;
  t181_n117: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t181_n119;
  t181_n118: return -0.1421816200017929;
  t181_n119: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n121;
  t181_n120: return 0.11708196997642517;
  t181_n121: return -0.10557655245065689;
  t181_n122: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t181_n138;
  t181_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t181_n137;
  t181_n124: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t181_n136;
  t181_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t181_n127;
  t181_n126: return 0.031950101256370544;
  t181_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n129;
  t181_n128: return 0.03383219614624977;
  t181_n129: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n131;
  t181_n130: return -0.2285328060388565;
  t181_n131: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n135;
  t181_n132: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t181_n134;
  t181_n133: return 0.143879234790802;
  t181_n134: return 0.35313645005226135;
  t181_n135: return 0.39475440979003906;
  t181_n136: return 0.020744547247886658;
  t181_n137: return 0.08884534239768982;
  t181_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t181_n156;
  t181_n139: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t181_n155;
  t181_n140: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t181_n154;
  t181_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t181_n151;
  t181_n142: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t181_n150;
  t181_n143: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t181_n149;
  t181_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n146;
  t181_n145: return 0.09650279581546783;
  t181_n146: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t181_n148;
  t181_n147: return 0.4997074007987976;
  t181_n148: return 0.10952669382095337;
  t181_n149: return 0.08602803945541382;
  t181_n150: return -0.7188640832901001;
  t181_n151: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t181_n153;
  t181_n152: return -0.3063431680202484;
  t181_n153: return 0.12432903051376343;
  t181_n154: return 0.04672197625041008;
  t181_n155: return 0.10911185294389725;
  t181_n156: return 0.1090698167681694;
  t181_n157: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t181_n179;
  t181_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t181_n166;
  t181_n159: if (E.getNumReferences() >= 3266772992 /*91.5*/) goto t181_n163;
  t181_n160: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t181_n162;
  t181_n161: return -0.0580422468483448;
  t181_n162: return -0.016505656763911247;
  t181_n163: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t181_n165;
  t181_n164: return -0.12848542630672455;
  t181_n165: return -0.013868873938918114;
  t181_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t181_n178;
  t181_n167: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t181_n175;
  t181_n168: if (E.getNumReferences() >= 3301953536 /*1662.5*/) goto t181_n174;
  t181_n169: if (E.getNumReferences() >= 3300220928 /*1451.0*/) goto t181_n171;
  t181_n170: return -0.001935973996296525;
  t181_n171: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t181_n173;
  t181_n172: return 0.15329720079898834;
  t181_n173: return 0.009708196856081486;
  t181_n174: return -0.097439706325531;
  t181_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t181_n177;
  t181_n176: return -0.2585180401802063;
  t181_n177: return 0.022289326414465904;
  t181_n178: return 0.023608556017279625;
  t181_n179: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t181_n253;
  t181_n180: if (E.getNumReferences() >= 3273293824 /*154.5*/) goto t181_n218;
  t181_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t181_n183;
  t181_n182: return 0.02726280875504017;
  t181_n183: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t181_n213;
  t181_n184: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t181_n212;
  t181_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t181_n187;
  t181_n186: return -0.04101613909006119;
  t181_n187: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t181_n199;
  t181_n188: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t181_n198;
  t181_n189: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t181_n197;
  t181_n190: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t181_n194;
  t181_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t181_n193;
  t181_n192: return -0.1885397881269455;
  t181_n193: return 0.1317158043384552;
  t181_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t181_n196;
  t181_n195: return 0.4137127697467804;
  t181_n196: return 0.13215123116970062;
  t181_n197: return 0.21195253729820251;
  t181_n198: return 0.017420154064893723;
  t181_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n201;
  t181_n200: return -0.17531222105026245;
  t181_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t181_n203;
  t181_n202: return -0.10847223550081253;
  t181_n203: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t181_n209;
  t181_n204: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n208;
  t181_n205: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t181_n207;
  t181_n206: return 0.12902504205703735;
  t181_n207: return 0.14189521968364716;
  t181_n208: return -0.3053768277168274;
  t181_n209: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t181_n211;
  t181_n210: return -0.1428411900997162;
  t181_n211: return 0.1260836273431778;
  t181_n212: return -0.003934008534997702;
  t181_n213: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t181_n217;
  t181_n214: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t181_n216;
  t181_n215: return 0.0975392684340477;
  t181_n216: return 0.11944660544395447;
  t181_n217: return 0.06533866375684738;
  t181_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t181_n232;
  t181_n219: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t181_n231;
  t181_n220: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t181_n226;
  t181_n221: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t181_n223;
  t181_n222: return 0.07817649841308594;
  t181_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t181_n225;
  t181_n224: return 0.10140737891197205;
  t181_n225: return 0.1150192841887474;
  t181_n226: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t181_n228;
  t181_n227: return 0.10843773931264877;
  t181_n228: if (E.getNumReferences() >= 3274539008 /*173.5*/) goto t181_n230;
  t181_n229: return 0.06247392296791077;
  t181_n230: return 0.13906234502792358;
  t181_n231: return 0.03992035612463951;
  t181_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t181_n246;
  t181_n233: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t181_n241;
  t181_n234: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t181_n236;
  t181_n235: return 0.11215230077505112;
  t181_n236: if (E.getNumReferences() >= 3289128960 /*560.5*/) goto t181_n238;
  t181_n237: return -0.0023483445402234793;
  t181_n238: if (E.getNumReferences() >= 3292078080 /*740.5*/) goto t181_n240;
  t181_n239: return 0.11792157590389252;
  t181_n240: return 0.05616992712020874;
  t181_n241: if (E.getNumReferences() >= 3317816320 /*6203.5*/) goto t181_n243;
  t181_n242: return 0.008025907911360264;
  t181_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t181_n245;
  t181_n244: return 0.19635146856307983;
  t181_n245: return 1.8206694221589714e-05;
  t181_n246: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t181_n250;
  t181_n247: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t181_n249;
  t181_n248: return 0.060268569737672806;
  t181_n249: return 0.11857152730226517;
  t181_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t181_n252;
  t181_n251: return -0.02737201377749443;
  t181_n252: return 0.09093685448169708;
  t181_n253: return 0.02012431062757969;
  t181_n254: return -0.0006794330547563732;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree182(const Example& E) {
  t182_n0: if (E.getNumReferences() >= 3300909056 /*1535.0*/) goto t182_n228;
  t182_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t182_n3;
  t182_n2: return 0.0031944899819791317;
  t182_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t182_n5;
  t182_n4: return -0.00010490298882359639;
  t182_n5: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t182_n179;
  t182_n6: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t182_n8;
  t182_n7: return -0.04050224646925926;
  t182_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t182_n10;
  t182_n9: return -0.004086284898221493;
  t182_n10: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t182_n70;
  t182_n11: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t182_n13;
  t182_n12: return 0.02703881449997425;
  t182_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t182_n43;
  t182_n14: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t182_n18;
  t182_n15: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t182_n17;
  t182_n16: return -0.10627700388431549;
  t182_n17: return -0.41894280910491943;
  t182_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n42;
  t182_n19: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t182_n21;
  t182_n20: return -0.10647132247686386;
  t182_n21: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t182_n23;
  t182_n22: return -0.04931119084358215;
  t182_n23: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t182_n41;
  t182_n24: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t182_n28;
  t182_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n27;
  t182_n26: return -0.2231960892677307;
  t182_n27: return 0.11721235513687134;
  t182_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t182_n40;
  t182_n29: if (E.getNumReferences() >= 3283369984 /*360.5*/) goto t182_n39;
  t182_n30: if (E.getNumReferences() >= 3281698816 /*309.5*/) goto t182_n36;
  t182_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t182_n33;
  t182_n32: return 0.02743026614189148;
  t182_n33: if (E.getNumReferences() >= 3270901760 /*123.0*/) goto t182_n35;
  t182_n34: return 0.11398747563362122;
  t182_n35: return 0.07660534232854843;
  t182_n36: if (E.getNumReferences() >= 3282681856 /*339.5*/) goto t182_n38;
  t182_n37: return 0.12579579651355743;
  t182_n38: return 0.10617270320653915;
  t182_n39: return -0.13304877281188965;
  t182_n40: return 0.1073240414261818;
  t182_n41: return -0.03855415806174278;
  t182_n42: return 0.019997214898467064;
  t182_n43: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t182_n69;
  t182_n44: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t182_n52;
  t182_n45: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t182_n47;
  t182_n46: return -0.030086059123277664;
  t182_n47: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t182_n49;
  t182_n48: return -0.09701814502477646;
  t182_n49: if (E.getNumReferences() >= 3246915584 /*17.0*/) goto t182_n51;
  t182_n50: return 0.16744780540466309;
  t182_n51: return 0.038889214396476746;
  t182_n52: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t182_n54;
  t182_n53: return 0.03050844371318817;
  t182_n54: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t182_n58;
  t182_n55: if (E.getNumReferences() >= 3257008128 /*40.5*/) goto t182_n57;
  t182_n56: return 0.06250199675559998;
  t182_n57: return 0.12080085277557373;
  t182_n58: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t182_n60;
  t182_n59: return 0.007534489035606384;
  t182_n60: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t182_n68;
  t182_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n63;
  t182_n62: return -0.012850450351834297;
  t182_n63: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t182_n67;
  t182_n64: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t182_n66;
  t182_n65: return 0.05615997686982155;
  t182_n66: return 0.134567990899086;
  t182_n67: return 0.10754141211509705;
  t182_n68: return 0.006179125979542732;
  t182_n69: return -0.07371591031551361;
  t182_n70: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t182_n114;
  t182_n71: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t182_n113;
  t182_n72: if (E.getNumReferences() >= 3299135488 /*1318.5*/) goto t182_n100;
  t182_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t182_n75;
  t182_n74: return 0.03923127055168152;
  t182_n75: if (E.getNumReferences() >= 3288391680 /*515.5*/) goto t182_n95;
  t182_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n78;
  t182_n77: return 0.07254110276699066;
  t182_n78: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t182_n82;
  t182_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t182_n81;
  t182_n80: return 0.13175716996192932;
  t182_n81: return -0.13511952757835388;
  t182_n82: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t182_n92;
  t182_n83: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t182_n85;
  t182_n84: return 0.0693102702498436;
  t182_n85: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t182_n91;
  t182_n86: if (E.getNumReferences() >= 3268673536 /*106.0*/) goto t182_n90;
  t182_n87: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t182_n89;
  t182_n88: return 0.1423364132642746;
  t182_n89: return 0.5394939184188843;
  t182_n90: return 0.12584084272384644;
  t182_n91: return 0.008575604297220707;
  t182_n92: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t182_n94;
  t182_n93: return 0.06491739302873611;
  t182_n94: return 0.13696950674057007;
  t182_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t182_n99;
  t182_n96: if (E.getNumReferences() >= 3288924160 /*548.0*/) goto t182_n98;
  t182_n97: return 0.12676286697387695;
  t182_n98: return 0.11441385000944138;
  t182_n99: return 0.1245310828089714;
  t182_n100: if (E.getNumReferences() >= 3299160064 /*1321.5*/) goto t182_n104;
  t182_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n103;
  t182_n102: return -0.1008075475692749;
  t182_n103: return 0.12455190718173981;
  t182_n104: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t182_n108;
  t182_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t182_n107;
  t182_n106: return -0.4544238746166229;
  t182_n107: return 0.12347500026226044;
  t182_n108: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t182_n110;
  t182_n109: return -0.06653737276792526;
  t182_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t182_n112;
  t182_n111: return 0.03308621421456337;
  t182_n112: return 0.11546028405427933;
  t182_n113: return -0.025287173688411713;
  t182_n114: if (E.getNumReferences() >= 3291545600 /*708.0*/) goto t182_n174;
  t182_n115: if (E.getNumReferences() >= 3282927616 /*347.0*/) goto t182_n173;
  t182_n116: if (E.getNumReferences() >= 3282518016 /*334.5*/) goto t182_n170;
  t182_n117: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t182_n155;
  t182_n118: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t182_n134;
  t182_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t182_n121;
  t182_n120: return -0.44628235697746277;
  t182_n121: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t182_n123;
  t182_n122: return -0.0381096713244915;
  t182_n123: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t182_n133;
  t182_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t182_n132;
  t182_n125: if (E.getNumReferences() >= 3271557120 /*128.0*/) goto t182_n131;
  t182_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n128;
  t182_n127: return -0.46585893630981445;
  t182_n128: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t182_n130;
  t182_n129: return 0.16153451800346375;
  t182_n130: return 0.10067593306303024;
  t182_n131: return -0.1760074645280838;
  t182_n132: return 0.12796247005462646;
  t182_n133: return -0.2521098554134369;
  t182_n134: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t182_n142;
  t182_n135: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t182_n137;
  t182_n136: return -0.008798763155937195;
  t182_n137: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t182_n141;
  t182_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n140;
  t182_n139: return 0.03943028673529625;
  t182_n140: return 0.10792442411184311;
  t182_n141: return 0.053572241216897964;
  t182_n142: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t182_n150;
  t182_n143: if (E.getNumReferences() >= 3274964992 /*180.0*/) goto t182_n149;
  t182_n144: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t182_n148;
  t182_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t182_n147;
  t182_n146: return -0.07855000346899033;
  t182_n147: return 0.1177186518907547;
  t182_n148: return 0.1030270904302597;
  t182_n149: return -0.00044780559255741537;
  t182_n150: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t182_n154;
  t182_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t182_n153;
  t182_n152: return -0.24956922233104706;
  t182_n153: return 0.11513686180114746;
  t182_n154: return 0.04054916277527809;
  t182_n155: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t182_n159;
  t182_n156: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t182_n158;
  t182_n157: return -0.1117861196398735;
  t182_n158: return 0.13502250611782074;
  t182_n159: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t182_n167;
  t182_n160: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t182_n164;
  t182_n161: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t182_n163;
  t182_n162: return -0.02469170093536377;
  t182_n163: return 0.11490143835544586;
  t182_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t182_n166;
  t182_n165: return 0.04611942917108536;
  t182_n166: return 0.11583967506885529;
  t182_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t182_n169;
  t182_n168: return -0.02846226841211319;
  t182_n169: return 0.11328056454658508;
  t182_n170: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t182_n172;
  t182_n171: return -0.05326344445347786;
  t182_n172: return 0.19001387059688568;
  t182_n173: return -0.08526018261909485;
  t182_n174: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t182_n178;
  t182_n175: if (E.getNumReferences() >= 3292413952 /*761.0*/) goto t182_n177;
  t182_n176: return 0.07833552360534668;
  t182_n177: return 0.1033463329076767;
  t182_n178: return 0.00430723512545228;
  t182_n179: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t182_n207;
  t182_n180: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t182_n182;
  t182_n181: return -0.041745152324438095;
  t182_n182: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t182_n206;
  t182_n183: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t182_n203;
  t182_n184: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t182_n186;
  t182_n185: return 0.033778201788663864;
  t182_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t182_n192;
  t182_n187: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t182_n191;
  t182_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n190;
  t182_n189: return 11.944103240966797;
  t182_n190: return 0.11474881321191788;
  t182_n191: return 0.08901528269052505;
  t182_n192: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t182_n198;
  t182_n193: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t182_n195;
  t182_n194: return 0.03734009712934494;
  t182_n195: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t182_n197;
  t182_n196: return 0.13123618066310883;
  t182_n197: return -0.10222800076007843;
  t182_n198: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t182_n200;
  t182_n199: return 0.14175692200660706;
  t182_n200: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t182_n202;
  t182_n201: return -0.10081258416175842;
  t182_n202: return 0.1138281300663948;
  t182_n203: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t182_n205;
  t182_n204: return 0.1114489808678627;
  t182_n205: return -0.10159128159284592;
  t182_n206: return 0.026133034378290176;
  t182_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t182_n215;
  t182_n208: if (E.getNumReferences() >= 3274211328 /*168.5*/) goto t182_n214;
  t182_n209: if (E.getNumReferences() >= 3274145792 /*167.5*/) goto t182_n213;
  t182_n210: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t182_n212;
  t182_n211: return 0.04397662729024887;
  t182_n212: return -0.0011606179177761078;
  t182_n213: return 0.11485189199447632;
  t182_n214: return -0.005784195382148027;
  t182_n215: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t182_n217;
  t182_n216: return 0.10536504536867142;
  t182_n217: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t182_n225;
  t182_n218: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t182_n224;
  t182_n219: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t182_n223;
  t182_n220: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t182_n222;
  t182_n221: return 0.09052539616823196;
  t182_n222: return -0.03186918795108795;
  t182_n223: return -0.2716638445854187;
  t182_n224: return 0.16276830434799194;
  t182_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t182_n227;
  t182_n226: return 0.06524316221475601;
  t182_n227: return -0.024809710681438446;
  t182_n228: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t182_n254;
  t182_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t182_n249;
  t182_n230: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t182_n232;
  t182_n231: return -0.008296347223222256;
  t182_n232: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t182_n248;
  t182_n233: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t182_n241;
  t182_n234: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t182_n236;
  t182_n235: return 0.048261817544698715;
  t182_n236: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t182_n238;
  t182_n237: return -0.01263643242418766;
  t182_n238: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t182_n240;
  t182_n239: return 0.10373962670564651;
  t182_n240: return 0.10750532895326614;
  t182_n241: if (E.getNumReferences() >= 3368810912 /*417741.0*/) goto t182_n243;
  t182_n242: return 0.018479226157069206;
  t182_n243: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t182_n245;
  t182_n244: return -0.023665713146328926;
  t182_n245: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t182_n247;
  t182_n246: return -0.01213014591485262;
  t182_n247: return 0.07144788652658463;
  t182_n248: return 0.0012551081599667668;
  t182_n249: if (E.getNumReferences() >= 3300937728 /*1538.5*/) goto t182_n253;
  t182_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t182_n252;
  t182_n251: return -0.10916101932525635;
  t182_n252: return 0.1259223073720932;
  t182_n253: return 0.01856742799282074;
  t182_n254: return 0.001451138756237924;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree183(const Example& E) {
  t183_n0: if (E.getNumReferences() >= 3325298688 /*11522.0*/) goto t183_n64;
  t183_n1: if (E.getNumReferences() >= 3325283328 /*11507.0*/) goto t183_n55;
  t183_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t183_n4;
  t183_n3: return -0.10718642175197601;
  t183_n4: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t183_n36;
  t183_n5: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t183_n7;
  t183_n6: return 0.0010464375372976065;
  t183_n7: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t183_n9;
  t183_n8: return -0.04779021814465523;
  t183_n9: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t183_n11;
  t183_n10: return 0.00462611997500062;
  t183_n11: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t183_n13;
  t183_n12: return 0.018350915983319283;
  t183_n13: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t183_n15;
  t183_n14: return -0.0233839713037014;
  t183_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t183_n17;
  t183_n16: return 0.01189308613538742;
  t183_n17: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t183_n33;
  t183_n18: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t183_n28;
  t183_n19: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n27;
  t183_n20: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t183_n22;
  t183_n21: return 0.032910484820604324;
  t183_n22: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t183_n26;
  t183_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n25;
  t183_n24: return 0.10393980145454407;
  t183_n25: return 0.06873802840709686;
  t183_n26: return 0.18206118047237396;
  t183_n27: return 0.020134465768933296;
  t183_n28: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t183_n30;
  t183_n29: return -0.13518324494361877;
  t183_n30: if (E.getNumReferences() >= 3265789952 /*84.0*/) goto t183_n32;
  t183_n31: return -0.2922656536102295;
  t183_n32: return 0.050147153437137604;
  t183_n33: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t183_n35;
  t183_n34: return 0.11481203883886337;
  t183_n35: return 0.10061737895011902;
  t183_n36: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t183_n40;
  t183_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t183_n39;
  t183_n38: return -0.11716097593307495;
  t183_n39: return -0.07686857879161835;
  t183_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t183_n48;
  t183_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n47;
  t183_n42: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t183_n44;
  t183_n43: return -0.011257611215114594;
  t183_n44: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n46;
  t183_n45: return 0.07794879376888275;
  t183_n46: return -0.28687432408332825;
  t183_n47: return -0.2445629984140396;
  t183_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n54;
  t183_n49: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n53;
  t183_n50: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t183_n52;
  t183_n51: return -0.10008649528026581;
  t183_n52: return 0.07146132737398148;
  t183_n53: return -0.130430668592453;
  t183_n54: return 0.10539832711219788;
  t183_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n57;
  t183_n56: return -0.17097115516662598;
  t183_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t183_n63;
  t183_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t183_n60;
  t183_n59: return -0.11529000103473663;
  t183_n60: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t183_n62;
  t183_n61: return -1.4612258672714233;
  t183_n62: return -0.18624594807624817;
  t183_n63: return -0.15559250116348267;
  t183_n64: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t183_n86;
  t183_n65: if (E.getNumReferences() >= 3325406720 /*11627.5*/) goto t183_n85;
  t183_n66: if (E.getNumReferences() >= 3325368832 /*11590.5*/) goto t183_n74;
  t183_n67: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n69;
  t183_n68: return 0.06397614628076553;
  t183_n69: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n73;
  t183_n70: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t183_n72;
  t183_n71: return 0.5477854013442993;
  t183_n72: return -0.093460813164711;
  t183_n73: return 0.22587457299232483;
  t183_n74: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t183_n76;
  t183_n75: return 0.12013522535562515;
  t183_n76: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t183_n80;
  t183_n77: if (E.getNumReferences() >= 3325383680 /*11605.0*/) goto t183_n79;
  t183_n78: return 0.10023244470357895;
  t183_n79: return -0.1287040412425995;
  t183_n80: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n84;
  t183_n81: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t183_n83;
  t183_n82: return 0.11006079614162445;
  t183_n83: return 0.12372563779354095;
  t183_n84: return -0.06331092119216919;
  t183_n85: return 0.011268979869782925;
  t183_n86: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t183_n88;
  t183_n87: return -0.026330361142754555;
  t183_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t183_n90;
  t183_n89: return 0.003878544317558408;
  t183_n90: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t183_n92;
  t183_n91: return -0.04053103178739548;
  t183_n92: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t183_n254;
  t183_n93: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t183_n243;
  t183_n94: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t183_n184;
  t183_n95: if (E.getNumReferences() >= 3342114944 /*46240.5*/) goto t183_n183;
  t183_n96: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t183_n176;
  t183_n97: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t183_n163;
  t183_n98: if (E.getNumReferences() >= 3338855552 /*33508.5*/) goto t183_n154;
  t183_n99: if (E.getNumReferences() >= 3336705792 /*28939.5*/) goto t183_n153;
  t183_n100: if (E.getNumReferences() >= 3336160512 /*27874.5*/) goto t183_n152;
  t183_n101: if (E.getNumReferences() >= 3335010048 /*25627.5*/) goto t183_n151;
  t183_n102: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t183_n104;
  t183_n103: return 0.01931658573448658;
  t183_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n146;
  t183_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n107;
  t183_n106: return 0.09987791627645493;
  t183_n107: if (E.getNumReferences() >= 3334461184 /*24555.5*/) goto t183_n141;
  t183_n108: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t183_n140;
  t183_n109: if (E.getNumReferences() >= 3333667072 /*23004.5*/) goto t183_n139;
  t183_n110: if (E.getNumReferences() >= 3333190144 /*22073.0*/) goto t183_n138;
  t183_n111: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t183_n113;
  t183_n112: return 0.025874659419059753;
  t183_n113: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t183_n115;
  t183_n114: return -0.07449270784854889;
  t183_n115: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t183_n117;
  t183_n116: return 0.1203155517578125;
  t183_n117: if (E.getNumReferences() >= 3327795200 /*13960.0*/) goto t183_n119;
  t183_n118: return -0.16762232780456543;
  t183_n119: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t183_n135;
  t183_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n132;
  t183_n121: if (E.getNumReferences() >= 3330296064 /*16420.5*/) goto t183_n127;
  t183_n122: if (E.getNumReferences() >= 3329126400 /*15260.0*/) goto t183_n126;
  t183_n123: if (E.getNumReferences() >= 3328901632 /*15040.5*/) goto t183_n125;
  t183_n124: return 0.3076615631580353;
  t183_n125: return -0.11574903875589371;
  t183_n126: return 0.22394679486751556;
  t183_n127: if (E.getNumReferences() >= 3331473408 /*18720.0*/) goto t183_n129;
  t183_n128: return -0.11240619421005249;
  t183_n129: if (E.getNumReferences() >= 3332023808 /*19795.0*/) goto t183_n131;
  t183_n130: return 0.1227954775094986;
  t183_n131: return -0.1467662751674652;
  t183_n132: if (E.getNumReferences() >= 3331949568 /*19650.0*/) goto t183_n134;
  t183_n133: return -0.08170758932828903;
  t183_n134: return -0.5698365569114685;
  t183_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t183_n137;
  t183_n136: return -0.03975128382444382;
  t183_n137: return 0.10275254398584366;
  t183_n138: return 0.1108826994895935;
  t183_n139: return -0.09641029685735703;
  t183_n140: return 0.11500298231840134;
  t183_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n145;
  t183_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t183_n144;
  t183_n143: return -0.1729172021150589;
  t183_n144: return 0.26558858156204224;
  t183_n145: return -0.5210919380187988;
  t183_n146: if (E.getNumReferences() >= 3334778368 /*25175.0*/) goto t183_n150;
  t183_n147: if (E.getNumReferences() >= 3326497792 /*12693.0*/) goto t183_n149;
  t183_n148: return 0.22319211065769196;
  t183_n149: return -0.01524352841079235;
  t183_n150: return 0.09905315190553665;
  t183_n151: return -0.11317810416221619;
  t183_n152: return 0.2478528618812561;
  t183_n153: return -0.05341102555394173;
  t183_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n162;
  t183_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t183_n161;
  t183_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n160;
  t183_n157: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t183_n159;
  t183_n158: return 0.5625491142272949;
  t183_n159: return 0.6075589656829834;
  t183_n160: return -0.10970498621463776;
  t183_n161: return 0.11351188272237778;
  t183_n162: return 0.11902667582035065;
  t183_n163: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t183_n171;
  t183_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t183_n170;
  t183_n165: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n169;
  t183_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n168;
  t183_n167: return -0.1202315017580986;
  t183_n168: return -0.6585590839385986;
  t183_n169: return 0.013414968736469746;
  t183_n170: return -0.05309849604964256;
  t183_n171: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t183_n173;
  t183_n172: return -0.04095492511987686;
  t183_n173: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t183_n175;
  t183_n174: return 0.10989005118608475;
  t183_n175: return 0.10282562673091888;
  t183_n176: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t183_n180;
  t183_n177: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n179;
  t183_n178: return -0.22565187513828278;
  t183_n179: return 0.11067222058773041;
  t183_n180: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n182;
  t183_n181: return 0.14975258708000183;
  t183_n182: return -0.21664725244045258;
  t183_n183: return -0.19975335896015167;
  t183_n184: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t183_n190;
  t183_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n189;
  t183_n186: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n188;
  t183_n187: return 0.15047436952590942;
  t183_n188: return -0.11384521424770355;
  t183_n189: return 0.10956577956676483;
  t183_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t183_n232;
  t183_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n231;
  t183_n192: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t183_n214;
  t183_n193: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t183_n213;
  t183_n194: if (E.getNumReferences() >= 3350105536 /*89371.5*/) goto t183_n208;
  t183_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t183_n197;
  t183_n196: return -0.06489657610654831;
  t183_n197: if (E.getNumReferences() >= 3348219712 /*74638.5*/) goto t183_n203;
  t183_n198: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t183_n202;
  t183_n199: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t183_n201;
  t183_n200: return 0.05136241018772125;
  t183_n201: return 0.12654830515384674;
  t183_n202: return -0.14319808781147003;
  t183_n203: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t183_n207;
  t183_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t183_n206;
  t183_n205: return 0.044186972081661224;
  t183_n206: return 0.08288905024528503;
  t183_n207: return 0.1119823157787323;
  t183_n208: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t183_n212;
  t183_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t183_n211;
  t183_n210: return -0.10213882476091385;
  t183_n211: return 0.09224534034729004;
  t183_n212: return 0.054563503712415695;
  t183_n213: return 0.010304376482963562;
  t183_n214: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t183_n220;
  t183_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t183_n217;
  t183_n216: return 0.10438898205757141;
  t183_n217: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t183_n219;
  t183_n218: return 0.015657221898436546;
  t183_n219: return 0.06999775767326355;
  t183_n220: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t183_n226;
  t183_n221: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t183_n223;
  t183_n222: return -0.16514979302883148;
  t183_n223: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t183_n225;
  t183_n224: return -0.11807815730571747;
  t183_n225: return 0.10409494489431381;
  t183_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t183_n228;
  t183_n227: return -0.10178247094154358;
  t183_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n230;
  t183_n229: return 0.08582144230604172;
  t183_n230: return 0.034804925322532654;
  t183_n231: return -0.010647900402545929;
  t183_n232: if (E.getNumReferences() >= 3348514112 /*76938.5*/) goto t183_n236;
  t183_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t183_n235;
  t183_n234: return -0.029228227213025093;
  t183_n235: return 0.10120672732591629;
  t183_n236: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t183_n242;
  t183_n237: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t183_n239;
  t183_n238: return 0.0839545801281929;
  t183_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t183_n241;
  t183_n240: return -0.05222005769610405;
  t183_n241: return 0.0735643282532692;
  t183_n242: return 0.12887944281101227;
  t183_n243: if (E.getNumReferences() >= 3334795520 /*25208.5*/) goto t183_n251;
  t183_n244: if (E.getNumReferences() >= 3333635072 /*22942.0*/) goto t183_n250;
  t183_n245: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t183_n249;
  t183_n246: if (E.getNumReferences() >= 3330470656 /*16761.5*/) goto t183_n248;
  t183_n247: return -0.10312832146883011;
  t183_n248: return 1.2999589443206787;
  t183_n249: return -0.12630848586559296;
  t183_n250: return 0.12072981148958206;
  t183_n251: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t183_n253;
  t183_n252: return -0.16097374260425568;
  t183_n253: return 0.25018569827079773;
  t183_n254: return -0.09842358529567719;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree184(const Example& E) {
  t184_n0: if (E.getNumReferences() >= 3308861440 /*2963.5*/) goto t184_n8;
  t184_n1: if (E.getNumReferences() >= 3308840960 /*2958.5*/) goto t184_n3;
  t184_n2: return -0.00035733680124394596;
  t184_n3: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n5;
  t184_n4: return -0.14209286868572235;
  t184_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t184_n7;
  t184_n6: return -0.6634206175804138;
  t184_n7: return -0.5386044383049011;
  t184_n8: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t184_n66;
  t184_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t184_n51;
  t184_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t184_n50;
  t184_n11: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t184_n43;
  t184_n12: if (E.getNumReferences() >= 3339317120 /*35311.5*/) goto t184_n36;
  t184_n13: if (E.getNumReferences() >= 3313035264 /*3982.5*/) goto t184_n23;
  t184_n14: if (E.getNumReferences() >= 3313004544 /*3975.0*/) goto t184_n22;
  t184_n15: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n17;
  t184_n16: return -0.21708306670188904;
  t184_n17: if (E.getNumReferences() >= 3311329280 /*3566.0*/) goto t184_n19;
  t184_n18: return -0.44697993993759155;
  t184_n19: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t184_n21;
  t184_n20: return 0.12766851484775543;
  t184_n21: return 0.037015728652477264;
  t184_n22: return 0.1200091689825058;
  t184_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n35;
  t184_n24: if (E.getNumReferences() >= 3323488768 /*9754.5*/) goto t184_n30;
  t184_n25: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n27;
  t184_n26: return -0.15369239449501038;
  t184_n27: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t184_n29;
  t184_n28: return -0.33862340450286865;
  t184_n29: return -1.6902390718460083;
  t184_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n32;
  t184_n31: return -0.041336990892887115;
  t184_n32: if (E.getNumReferences() >= 3331854592 /*19464.5*/) goto t184_n34;
  t184_n33: return 0.07964643836021423;
  t184_n34: return -0.4437645375728607;
  t184_n35: return 0.04505482688546181;
  t184_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t184_n38;
  t184_n37: return -0.3739854693412781;
  t184_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n40;
  t184_n39: return 0.05490680783987045;
  t184_n40: if (E.getNumReferences() >= 3344898560 /*57114.0*/) goto t184_n42;
  t184_n41: return 0.10785537213087082;
  t184_n42: return 0.047585126012563705;
  t184_n43: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t184_n45;
  t184_n44: return -0.17148029804229736;
  t184_n45: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t184_n49;
  t184_n46: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n48;
  t184_n47: return 0.04762778431177139;
  t184_n48: return -0.34687182307243347;
  t184_n49: return -0.19983072578907013;
  t184_n50: return 0.011243102140724659;
  t184_n51: if (E.getNumReferences() >= 3308972032 /*2990.5*/) goto t184_n57;
  t184_n52: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t184_n56;
  t184_n53: if (E.getNumReferences() >= 3308906496 /*2974.5*/) goto t184_n55;
  t184_n54: return 0.13686998188495636;
  t184_n55: return 0.031132705509662628;
  t184_n56: return 0.11149261146783829;
  t184_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t184_n59;
  t184_n58: return 0.017102396115660667;
  t184_n59: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t184_n65;
  t184_n60: if (E.getNumReferences() >= 3317001216 /*5805.5*/) goto t184_n64;
  t184_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t184_n63;
  t184_n62: return -0.13404347002506256;
  t184_n63: return 0.16423480212688446;
  t184_n64: return 0.1175604984164238;
  t184_n65: return -0.03587713837623596;
  t184_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t184_n68;
  t184_n67: return -0.0015003113076090813;
  t184_n68: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t184_n234;
  t184_n69: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t184_n165;
  t184_n70: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t184_n120;
  t184_n71: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t184_n81;
  t184_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t184_n80;
  t184_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t184_n75;
  t184_n74: return 0.009781773202121258;
  t184_n75: if (E.getNumReferences() >= 3320302592 /*7417.5*/) goto t184_n79;
  t184_n76: if (E.getNumReferences() >= 3319290880 /*6923.5*/) goto t184_n78;
  t184_n77: return 0.10721231251955032;
  t184_n78: return 0.1074562668800354;
  t184_n79: return 0.04416098818182945;
  t184_n80: return -0.0937422662973404;
  t184_n81: if (E.getNumReferences() >= 3318226944 /*6404.0*/) goto t184_n89;
  t184_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t184_n88;
  t184_n83: if (E.getNumReferences() >= 3309780992 /*3188.0*/) goto t184_n87;
  t184_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t184_n86;
  t184_n85: return 0.06300542503595352;
  t184_n86: return 0.11774332821369171;
  t184_n87: return 0.028402650728821754;
  t184_n88: return 0.0024592955596745014;
  t184_n89: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t184_n119;
  t184_n90: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n96;
  t184_n91: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t184_n95;
  t184_n92: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t184_n94;
  t184_n93: return 0.10940928757190704;
  t184_n94: return -0.04119542986154556;
  t184_n95: return 0.01350487396121025;
  t184_n96: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t184_n106;
  t184_n97: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t184_n99;
  t184_n98: return 0.27667200565338135;
  t184_n99: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t184_n105;
  t184_n100: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t184_n102;
  t184_n101: return -0.11945128440856934;
  t184_n102: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t184_n104;
  t184_n103: return 0.12514232099056244;
  t184_n104: return 0.08991323411464691;
  t184_n105: return 0.08378748595714569;
  t184_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t184_n112;
  t184_n107: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t184_n109;
  t184_n108: return 0.08279432356357574;
  t184_n109: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n111;
  t184_n110: return 0.11387267708778381;
  t184_n111: return 0.06559960544109344;
  t184_n112: if (E.getNumReferences() >= 3318714368 /*6642.0*/) goto t184_n118;
  t184_n113: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n115;
  t184_n114: return -0.11348031461238861;
  t184_n115: if (E.getNumReferences() >= 3318256640 /*6418.5*/) goto t184_n117;
  t184_n116: return 0.1324397176504135;
  t184_n117: return 0.11333335936069489;
  t184_n118: return 0.13806840777397156;
  t184_n119: return 0.017334921285510063;
  t184_n120: if (E.getNumReferences() >= 3309760512 /*3183.0*/) goto t184_n122;
  t184_n121: return -0.10116156935691833;
  t184_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t184_n160;
  t184_n123: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t184_n157;
  t184_n124: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t184_n132;
  t184_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t184_n129;
  t184_n126: if (E.getNumReferences() >= 3311990784 /*3727.5*/) goto t184_n128;
  t184_n127: return 0.0795750692486763;
  t184_n128: return -0.05654770880937576;
  t184_n129: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t184_n131;
  t184_n130: return 0.10840052366256714;
  t184_n131: return -0.14450420439243317;
  t184_n132: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t184_n138;
  t184_n133: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t184_n135;
  t184_n134: return 0.04652930051088333;
  t184_n135: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n137;
  t184_n136: return 0.1049511656165123;
  t184_n137: return 0.11525100469589233;
  t184_n138: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t184_n140;
  t184_n139: return -0.027642134577035904;
  t184_n140: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t184_n146;
  t184_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n143;
  t184_n142: return 0.10460109263658524;
  t184_n143: if (E.getNumReferences() >= 3322208768 /*8504.5*/) goto t184_n145;
  t184_n144: return 0.11253786087036133;
  t184_n145: return 0.09855704009532928;
  t184_n146: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t184_n154;
  t184_n147: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t184_n153;
  t184_n148: if (E.getNumReferences() >= 3324703232 /*10940.5*/) goto t184_n152;
  t184_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n151;
  t184_n150: return 0.13788558542728424;
  t184_n151: return 0.11153776198625565;
  t184_n152: return 0.06134341284632683;
  t184_n153: return 0.014302845112979412;
  t184_n154: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t184_n156;
  t184_n155: return -0.046510327607393265;
  t184_n156: return 0.08708252012729645;
  t184_n157: if (E.getNumReferences() >= 3314504704 /*4586.5*/) goto t184_n159;
  t184_n158: return 0.10108499228954315;
  t184_n159: return 0.03521665185689926;
  t184_n160: if (E.getNumReferences() >= 3315111936 /*4883.0*/) goto t184_n164;
  t184_n161: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n163;
  t184_n162: return 0.12324710190296173;
  t184_n163: return -0.3767958879470825;
  t184_n164: return 0.06965842097997665;
  t184_n165: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t184_n175;
  t184_n166: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t184_n174;
  t184_n167: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t184_n173;
  t184_n168: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t184_n172;
  t184_n169: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t184_n171;
  t184_n170: return 0.15003293752670288;
  t184_n171: return 0.11796627193689346;
  t184_n172: return 0.00013063081132713705;
  t184_n173: return 0.027439303696155548;
  t184_n174: return 0.12649011611938477;
  t184_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t184_n225;
  t184_n176: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t184_n214;
  t184_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t184_n179;
  t184_n178: return -0.08294659107923508;
  t184_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t184_n183;
  t184_n180: if (E.getNumReferences() >= 3333062144 /*21823.0*/) goto t184_n182;
  t184_n181: return 0.0034780350979417562;
  t184_n182: return -0.7859443426132202;
  t184_n183: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t184_n197;
  t184_n184: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t184_n186;
  t184_n185: return -0.07194910943508148;
  t184_n186: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n194;
  t184_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t184_n189;
  t184_n188: return 0.038890253752470016;
  t184_n189: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n191;
  t184_n190: return -0.23271845281124115;
  t184_n191: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t184_n193;
  t184_n192: return 0.1254224330186844;
  t184_n193: return -0.5227401852607727;
  t184_n194: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n196;
  t184_n195: return -0.014535917900502682;
  t184_n196: return 0.12458661198616028;
  t184_n197: if (E.getNumReferences() >= 3332022528 /*19792.5*/) goto t184_n203;
  t184_n198: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n202;
  t184_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n201;
  t184_n200: return 0.11025134474039078;
  t184_n201: return 0.10182156413793564;
  t184_n202: return -0.10175175964832306;
  t184_n203: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t184_n205;
  t184_n204: return 0.03057844564318657;
  t184_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t184_n213;
  t184_n206: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t184_n212;
  t184_n207: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t184_n211;
  t184_n208: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t184_n210;
  t184_n209: return -0.12753723561763763;
  t184_n210: return 0.14823468029499054;
  t184_n211: return 0.10585367679595947;
  t184_n212: return -0.5997214317321777;
  t184_n213: return -0.11409372836351395;
  t184_n214: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t184_n218;
  t184_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t184_n217;
  t184_n216: return 0.20092681050300598;
  t184_n217: return 0.04896285757422447;
  t184_n218: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t184_n224;
  t184_n219: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t184_n221;
  t184_n220: return -1.0578292608261108;
  t184_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t184_n223;
  t184_n222: return 0.11427240818738937;
  t184_n223: return -0.0015535200946033;
  t184_n224: return -0.008649052120745182;
  t184_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t184_n227;
  t184_n226: return -0.10179968923330307;
  t184_n227: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t184_n233;
  t184_n228: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t184_n230;
  t184_n229: return 0.042522333562374115;
  t184_n230: if (E.getNumReferences() >= 3332491264 /*20708.0*/) goto t184_n232;
  t184_n231: return 0.11916402727365494;
  t184_n232: return 0.043660640716552734;
  t184_n233: return 0.09605246037244797;
  t184_n234: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t184_n254;
  t184_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t184_n253;
  t184_n236: if (E.getNumReferences() >= 3339403904 /*35650.5*/) goto t184_n248;
  t184_n237: if (E.getNumReferences() >= 3339210368 /*34894.5*/) goto t184_n247;
  t184_n238: if (E.getNumReferences() >= 3336494336 /*28526.5*/) goto t184_n240;
  t184_n239: return -0.19575124979019165;
  t184_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t184_n242;
  t184_n241: return -0.12098034471273422;
  t184_n242: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t184_n244;
  t184_n243: return -0.4348093271255493;
  t184_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t184_n246;
  t184_n245: return 0.10420862585306168;
  t184_n246: return 0.058329880237579346;
  t184_n247: return 0.10999801754951477;
  t184_n248: if (E.getNumReferences() >= 3341955584 /*45618.0*/) goto t184_n252;
  t184_n249: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t184_n251;
  t184_n250: return -0.52498859167099;
  t184_n251: return 0.09745971858501434;
  t184_n252: return -0.04009340703487396;
  t184_n253: return -0.009367668069899082;
  t184_n254: return 0.03377360850572586;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree185(const Example& E) {
  t185_n0: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t185_n112;
  t185_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t185_n93;
  t185_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t185_n4;
  t185_n3: return -0.004016815684735775;
  t185_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n90;
  t185_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t185_n89;
  t185_n6: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t185_n88;
  t185_n7: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t185_n79;
  t185_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t185_n10;
  t185_n9: return -0.0031859613955020905;
  t185_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t185_n34;
  t185_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n29;
  t185_n12: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t185_n26;
  t185_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t185_n19;
  t185_n14: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t185_n16;
  t185_n15: return -0.05873775854706764;
  t185_n16: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t185_n18;
  t185_n17: return -0.45403987169265747;
  t185_n18: return -0.13427257537841797;
  t185_n19: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n25;
  t185_n20: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t185_n24;
  t185_n21: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t185_n23;
  t185_n22: return -0.21170924603939056;
  t185_n23: return 0.010239040479063988;
  t185_n24: return -0.011342586949467659;
  t185_n25: return 0.03236059099435806;
  t185_n26: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t185_n28;
  t185_n27: return 0.04074576497077942;
  t185_n28: return 0.13768692314624786;
  t185_n29: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t185_n33;
  t185_n30: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t185_n32;
  t185_n31: return -0.088398277759552;
  t185_n32: return 0.04782962426543236;
  t185_n33: return -0.16532225906848907;
  t185_n34: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t185_n36;
  t185_n35: return -0.17863978445529938;
  t185_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t185_n66;
  t185_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n39;
  t185_n38: return -0.18029943108558655;
  t185_n39: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t185_n45;
  t185_n40: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t185_n44;
  t185_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n43;
  t185_n42: return -0.0965985357761383;
  t185_n43: return 0.08581145852804184;
  t185_n44: return 0.14101749658584595;
  t185_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t185_n47;
  t185_n46: return -0.47410646080970764;
  t185_n47: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t185_n49;
  t185_n48: return 0.1600121557712555;
  t185_n49: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t185_n57;
  t185_n50: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n52;
  t185_n51: return 0.02053808607161045;
  t185_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n54;
  t185_n53: return 0.11102624982595444;
  t185_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n56;
  t185_n55: return 0.004039584193378687;
  t185_n56: return 0.11031181365251541;
  t185_n57: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t185_n65;
  t185_n58: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t185_n64;
  t185_n59: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t185_n63;
  t185_n60: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n62;
  t185_n61: return 0.11276090145111084;
  t185_n62: return 0.08380714058876038;
  t185_n63: return -0.00529521657153964;
  t185_n64: return -0.03591466322541237;
  t185_n65: return -0.04949536919593811;
  t185_n66: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t185_n78;
  t185_n67: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n77;
  t185_n68: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t185_n70;
  t185_n69: return 0.029401006177067757;
  t185_n70: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t185_n72;
  t185_n71: return -0.22320832312107086;
  t185_n72: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t185_n74;
  t185_n73: return 0.0926232635974884;
  t185_n74: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n76;
  t185_n75: return 0.022803036496043205;
  t185_n76: return 0.08137644827365875;
  t185_n77: return -0.007287429179996252;
  t185_n78: return -0.1268504410982132;
  t185_n79: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t185_n87;
  t185_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t185_n86;
  t185_n81: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t185_n83;
  t185_n82: return 0.032995663583278656;
  t185_n83: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t185_n85;
  t185_n84: return 0.11253079026937485;
  t185_n85: return 0.11886242777109146;
  t185_n86: return -0.05167246237397194;
  t185_n87: return -0.08878498524427414;
  t185_n88: return -0.07325030118227005;
  t185_n89: return -0.011448615230619907;
  t185_n90: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t185_n92;
  t185_n91: return 0.0037470299284905195;
  t185_n92: return -0.05907553434371948;
  t185_n93: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t185_n99;
  t185_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t185_n96;
  t185_n95: return 0.0019797824788838625;
  t185_n96: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t185_n98;
  t185_n97: return 0.027848904952406883;
  t185_n98: return -0.02428283728659153;
  t185_n99: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t185_n101;
  t185_n100: return -0.037006743252277374;
  t185_n101: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t185_n111;
  t185_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n104;
  t185_n103: return -0.004103535320609808;
  t185_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t185_n108;
  t185_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n107;
  t185_n106: return -0.07147955894470215;
  t185_n107: return -0.011094900779426098;
  t185_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n110;
  t185_n109: return -0.08093655109405518;
  t185_n110: return 0.0178377702832222;
  t185_n111: return -0.01283916924148798;
  t185_n112: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t185_n228;
  t185_n113: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t185_n211;
  t185_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t185_n162;
  t185_n115: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t185_n147;
  t185_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t185_n118;
  t185_n117: return 0.0008782442309893668;
  t185_n118: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t185_n140;
  t185_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t185_n121;
  t185_n120: return -0.5403375625610352;
  t185_n121: if (E.getNumReferences() >= 3284008960 /*380.0*/) goto t185_n123;
  t185_n122: return -0.0635373517870903;
  t185_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n125;
  t185_n124: return -0.17504698038101196;
  t185_n125: if (E.getNumReferences() >= 3296239616 /*994.5*/) goto t185_n137;
  t185_n126: if (E.getNumReferences() >= 3290546176 /*647.0*/) goto t185_n134;
  t185_n127: if (E.getNumReferences() >= 3287941120 /*500.0*/) goto t185_n133;
  t185_n128: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t185_n130;
  t185_n129: return -0.12066898494958878;
  t185_n130: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t185_n132;
  t185_n131: return 0.15082749724388123;
  t185_n132: return 0.036299291998147964;
  t185_n133: return -0.2975493371486664;
  t185_n134: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t185_n136;
  t185_n135: return 0.10179834812879562;
  t185_n136: return 0.03954039141535759;
  t185_n137: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t185_n139;
  t185_n138: return -0.3653782606124878;
  t185_n139: return 0.10516504943370819;
  t185_n140: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t185_n142;
  t185_n141: return -0.21587005257606506;
  t185_n142: if (E.getNumReferences() >= 3266904064 /*92.5*/) goto t185_n144;
  t185_n143: return 0.22151681780815125;
  t185_n144: if (E.getNumReferences() >= 3280568320 /*275.0*/) goto t185_n146;
  t185_n145: return 0.12520642578601837;
  t185_n146: return 0.011862309649586678;
  t185_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n149;
  t185_n148: return -0.010942126624286175;
  t185_n149: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t185_n151;
  t185_n150: return -0.12960213422775269;
  t185_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t185_n157;
  t185_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t185_n154;
  t185_n153: return -0.06444675475358963;
  t185_n154: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t185_n156;
  t185_n155: return -0.014983626082539558;
  t185_n156: return 0.12196018546819687;
  t185_n157: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t185_n159;
  t185_n158: return -0.3218836188316345;
  t185_n159: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t185_n161;
  t185_n160: return 0.0974937155842781;
  t185_n161: return 0.06167072057723999;
  t185_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t185_n206;
  t185_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t185_n205;
  t185_n164: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t185_n202;
  t185_n165: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t185_n177;
  t185_n166: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t185_n172;
  t185_n167: if (E.getNumReferences() >= 3339097344 /*34453.0*/) goto t185_n169;
  t185_n168: return -0.04889669269323349;
  t185_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t185_n171;
  t185_n170: return -0.009274343959987164;
  t185_n171: return 0.0773976594209671;
  t185_n172: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t185_n174;
  t185_n173: return -0.11769062280654907;
  t185_n174: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t185_n176;
  t185_n175: return 0.03311305120587349;
  t185_n176: return -0.21407131850719452;
  t185_n177: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t185_n179;
  t185_n178: return -0.10284741222858429;
  t185_n179: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t185_n181;
  t185_n180: return 0.11759629845619202;
  t185_n181: if (E.getNumReferences() >= 3332163840 /*20068.5*/) goto t185_n201;
  t185_n182: if (E.getNumReferences() >= 3305103360 /*2047.0*/) goto t185_n194;
  t185_n183: if (E.getNumReferences() >= 3292487680 /*765.5*/) goto t185_n189;
  t185_n184: if (E.getNumReferences() >= 3290152960 /*623.0*/) goto t185_n188;
  t185_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t185_n187;
  t185_n186: return -0.2297629565000534;
  t185_n187: return 0.10057603567838669;
  t185_n188: return 0.12241652607917786;
  t185_n189: if (E.getNumReferences() >= 3294076928 /*862.5*/) goto t185_n191;
  t185_n190: return -0.9793858528137207;
  t185_n191: if (E.getNumReferences() >= 3296215040 /*993.0*/) goto t185_n193;
  t185_n192: return 0.08399108797311783;
  t185_n193: return -0.0581575445830822;
  t185_n194: if (E.getNumReferences() >= 3306749952 /*2448.0*/) goto t185_n196;
  t185_n195: return 0.11330646276473999;
  t185_n196: if (E.getNumReferences() >= 3323779072 /*10038.0*/) goto t185_n200;
  t185_n197: if (E.getNumReferences() >= 3311661056 /*3647.0*/) goto t185_n199;
  t185_n198: return 0.1096503958106041;
  t185_n199: return -0.12145514041185379;
  t185_n200: return 0.08673889189958572;
  t185_n201: return -0.03000660240650177;
  t185_n202: if (E.getNumReferences() >= 3275325440 /*185.5*/) goto t185_n204;
  t185_n203: return 0.16898581385612488;
  t185_n204: return -0.31136807799339294;
  t185_n205: return 0.00770686287432909;
  t185_n206: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t185_n210;
  t185_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t185_n209;
  t185_n208: return 0.017184173688292503;
  t185_n209: return 0.03335610032081604;
  t185_n210: return -0.12328598648309708;
  t185_n211: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t185_n213;
  t185_n212: return -0.0013622869737446308;
  t185_n213: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t185_n227;
  t185_n214: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t185_n224;
  t185_n215: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t185_n217;
  t185_n216: return -0.11561789363622665;
  t185_n217: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t185_n219;
  t185_n218: return 0.14069314301013947;
  t185_n219: if (E.getNumReferences() >= 3272998912 /*150.0*/) goto t185_n221;
  t185_n220: return -0.024184560403227806;
  t185_n221: if (E.getNumReferences() >= 3273490432 /*157.5*/) goto t185_n223;
  t185_n222: return 0.10726751387119293;
  t185_n223: return 0.06846949458122253;
  t185_n224: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t185_n226;
  t185_n225: return 0.12714138627052307;
  t185_n226: return 0.05462047830224037;
  t185_n227: return 0.021590258926153183;
  t185_n228: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t185_n238;
  t185_n229: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t185_n237;
  t185_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t185_n232;
  t185_n231: return -0.12710942327976227;
  t185_n232: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t185_n234;
  t185_n233: return 0.01003093458712101;
  t185_n234: if (E.getNumReferences() >= 3272212480 /*138.0*/) goto t185_n236;
  t185_n235: return 0.12515433132648468;
  t185_n236: return -0.03431535139679909;
  t185_n237: return -0.1883072853088379;
  t185_n238: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t185_n240;
  t185_n239: return 0.0404503159224987;
  t185_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t185_n242;
  t185_n241: return 0.006417338270694017;
  t185_n242: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t185_n252;
  t185_n243: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t185_n251;
  t185_n244: if (E.getNumReferences() >= 3283353600 /*360.0*/) goto t185_n248;
  t185_n245: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t185_n247;
  t185_n246: return 0.5685080885887146;
  t185_n247: return -0.14451369643211365;
  t185_n248: if (E.getNumReferences() >= 3286253568 /*448.5*/) goto t185_n250;
  t185_n249: return 0.12063411623239517;
  t185_n250: return 0.08298827707767487;
  t185_n251: return 0.03867156058549881;
  t185_n252: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t185_n254;
  t185_n253: return 0.1521046906709671;
  t185_n254: return 0.07335355132818222;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree186(const Example& E) {
  t186_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t186_n230;
  t186_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t186_n229;
  t186_n2: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t186_n4;
  t186_n3: return 0.001782266073860228;
  t186_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t186_n214;
  t186_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t186_n61;
  t186_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t186_n8;
  t186_n7: return -0.00733170798048377;
  t186_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t186_n46;
  t186_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n31;
  t186_n10: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t186_n20;
  t186_n11: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t186_n13;
  t186_n12: return 0.013160674832761288;
  t186_n13: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t186_n15;
  t186_n14: return -0.32299068570137024;
  t186_n15: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t186_n17;
  t186_n16: return 0.11757487803697586;
  t186_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n19;
  t186_n18: return -0.11551551520824432;
  t186_n19: return 0.12586894631385803;
  t186_n20: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t186_n30;
  t186_n21: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t186_n25;
  t186_n22: if (E.getNumReferences() >= 3330598400 /*17011.0*/) goto t186_n24;
  t186_n23: return -0.06310763955116272;
  t186_n24: return 0.10377486795186996;
  t186_n25: if (E.getNumReferences() >= 3275456512 /*187.5*/) goto t186_n27;
  t186_n26: return 0.10698983073234558;
  t186_n27: if (E.getNumReferences() >= 3310170112 /*3283.0*/) goto t186_n29;
  t186_n28: return -0.37118855118751526;
  t186_n29: return 0.12138301134109497;
  t186_n30: return 0.1287004053592682;
  t186_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n35;
  t186_n32: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t186_n34;
  t186_n33: return -0.059170231223106384;
  t186_n34: return -0.2592608630657196;
  t186_n35: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t186_n39;
  t186_n36: if (E.getNumReferences() >= 3304484864 /*1971.5*/) goto t186_n38;
  t186_n37: return -0.025981983169913292;
  t186_n38: return -0.27973952889442444;
  t186_n39: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t186_n41;
  t186_n40: return 0.11256241053342819;
  t186_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t186_n45;
  t186_n42: if (E.getNumReferences() >= 3283976192 /*379.0*/) goto t186_n44;
  t186_n43: return 0.018280113115906715;
  t186_n44: return 0.09944209456443787;
  t186_n45: return -0.3632505536079407;
  t186_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t186_n48;
  t186_n47: return -0.018899334594607353;
  t186_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t186_n58;
  t186_n49: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t186_n51;
  t186_n50: return 0.12553058564662933;
  t186_n51: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t186_n57;
  t186_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n54;
  t186_n53: return -0.1741359680891037;
  t186_n54: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n56;
  t186_n55: return 0.10074833035469055;
  t186_n56: return -0.0029818692710250616;
  t186_n57: return 0.11419955641031265;
  t186_n58: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t186_n60;
  t186_n59: return -0.04087809845805168;
  t186_n60: return 0.12197928875684738;
  t186_n61: if (E.getNumReferences() >= 3280584704 /*275.5*/) goto t186_n213;
  t186_n62: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t186_n170;
  t186_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t186_n65;
  t186_n64: return -0.013857617974281311;
  t186_n65: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t186_n167;
  t186_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t186_n68;
  t186_n67: return 0.04664923995733261;
  t186_n68: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t186_n98;
  t186_n69: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t186_n97;
  t186_n70: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t186_n86;
  t186_n71: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t186_n73;
  t186_n72: return 0.13674421608448029;
  t186_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n81;
  t186_n74: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t186_n80;
  t186_n75: if (E.getNumReferences() >= 3271622656 /*129.0*/) goto t186_n79;
  t186_n76: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t186_n78;
  t186_n77: return 0.19830982387065887;
  t186_n78: return 0.138961523771286;
  t186_n79: return -0.11495674401521683;
  t186_n80: return 0.1041034460067749;
  t186_n81: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t186_n85;
  t186_n82: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t186_n84;
  t186_n83: return 0.11878706514835358;
  t186_n84: return 0.09462732821702957;
  t186_n85: return 0.030402828007936478;
  t186_n86: if (E.getNumReferences() >= 3267297280 /*95.5*/) goto t186_n94;
  t186_n87: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n91;
  t186_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t186_n90;
  t186_n89: return 0.0994776040315628;
  t186_n90: return 0.10850613564252853;
  t186_n91: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t186_n93;
  t186_n92: return -0.33802154660224915;
  t186_n93: return 0.07548215985298157;
  t186_n94: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t186_n96;
  t186_n95: return -0.2506146728992462;
  t186_n96: return 0.09739760309457779;
  t186_n97: return -0.1419524848461151;
  t186_n98: if (E.getNumReferences() >= 3279912960 /*255.5*/) goto t186_n164;
  t186_n99: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t186_n103;
  t186_n100: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t186_n102;
  t186_n101: return -0.30726513266563416;
  t186_n102: return 0.031221652403473854;
  t186_n103: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t186_n125;
  t186_n104: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t186_n118;
  t186_n105: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t186_n109;
  t186_n106: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t186_n108;
  t186_n107: return -0.13786262273788452;
  t186_n108: return 0.13386638462543488;
  t186_n109: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t186_n117;
  t186_n110: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t186_n114;
  t186_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function))) goto t186_n113;
  t186_n112: return -0.16444429755210876;
  t186_n113: return 0.13538114726543427;
  t186_n114: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t186_n116;
  t186_n115: return 0.28623124957084656;
  t186_n116: return -0.15610714256763458;
  t186_n117: return -0.013294008560478687;
  t186_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n120;
  t186_n119: return -0.017660239711403847;
  t186_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n122;
  t186_n121: return 0.12669984996318817;
  t186_n122: if (E.getNumReferences() >= 3270836224 /*122.5*/) goto t186_n124;
  t186_n123: return 0.7876565456390381;
  t186_n124: return 0.0515180379152298;
  t186_n125: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n127;
  t186_n126: return 0.006396535784006119;
  t186_n127: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t186_n145;
  t186_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t186_n142;
  t186_n129: if (E.getNumReferences() >= 3279028224 /*242.0*/) goto t186_n139;
  t186_n130: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t186_n132;
  t186_n131: return -0.12734171748161316;
  t186_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t186_n134;
  t186_n133: return 0.026240075007081032;
  t186_n134: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t186_n136;
  t186_n135: return -0.2620522081851959;
  t186_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t186_n138;
  t186_n137: return 0.19157004356384277;
  t186_n138: return 0.019441738724708557;
  t186_n139: if (E.getNumReferences() >= 3279388672 /*247.5*/) goto t186_n141;
  t186_n140: return 0.10572632402181625;
  t186_n141: return 0.056882359087467194;
  t186_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t186_n144;
  t186_n143: return 0.6092644333839417;
  t186_n144: return 0.11990684270858765;
  t186_n145: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t186_n163;
  t186_n146: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t186_n162;
  t186_n147: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t186_n161;
  t186_n148: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t186_n150;
  t186_n149: return 0.0942394956946373;
  t186_n150: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t186_n156;
  t186_n151: if (E.getNumReferences() >= 3272343552 /*140.0*/) goto t186_n155;
  t186_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n154;
  t186_n153: return -0.10995908081531525;
  t186_n154: return 0.4610445201396942;
  t186_n155: return 0.12380397319793701;
  t186_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n158;
  t186_n157: return -0.10785214602947235;
  t186_n158: if (E.getNumReferences() >= 3273818112 /*162.5*/) goto t186_n160;
  t186_n159: return 0.09923693537712097;
  t186_n160: return 0.44949325919151306;
  t186_n161: return -0.09038351476192474;
  t186_n162: return 0.13851827383041382;
  t186_n163: return -0.049582939594984055;
  t186_n164: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t186_n166;
  t186_n165: return 0.115471251308918;
  t186_n166: return -0.22281737625598907;
  t186_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t186_n169;
  t186_n168: return 0.0616641491651535;
  t186_n169: return 0.02075006440281868;
  t186_n170: if (E.getNumReferences() >= 3280076800 /*260.0*/) goto t186_n208;
  t186_n171: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t186_n173;
  t186_n172: return -0.1153697595000267;
  t186_n173: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t186_n207;
  t186_n174: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t186_n202;
  t186_n175: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t186_n197;
  t186_n176: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t186_n178;
  t186_n177: return -0.029317311942577362;
  t186_n178: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t186_n186;
  t186_n179: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t186_n183;
  t186_n180: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t186_n182;
  t186_n181: return 0.21149827539920807;
  t186_n182: return -0.33405712246894836;
  t186_n183: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t186_n185;
  t186_n184: return 0.10654521733522415;
  t186_n185: return 0.11411833018064499;
  t186_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t186_n190;
  t186_n187: if (E.getNumReferences() >= 3278471168 /*233.5*/) goto t186_n189;
  t186_n188: return 0.049746401607990265;
  t186_n189: return 0.28384751081466675;
  t186_n190: if (E.getNumReferences() >= 3269984256 /*116.0*/) goto t186_n192;
  t186_n191: return -0.08636771887540817;
  t186_n192: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t186_n196;
  t186_n193: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n195;
  t186_n194: return 0.13682201504707336;
  t186_n195: return -0.19927294552326202;
  t186_n196: return -0.06312176585197449;
  t186_n197: if (E.getNumReferences() >= 3265134592 /*79.0*/) goto t186_n199;
  t186_n198: return -0.10229342430830002;
  t186_n199: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t186_n201;
  t186_n200: return 0.12380918115377426;
  t186_n201: return 0.05492518097162247;
  t186_n202: if (E.getNumReferences() >= 3277422592 /*217.5*/) goto t186_n204;
  t186_n203: return -0.03974096104502678;
  t186_n204: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t186_n206;
  t186_n205: return 0.2296922206878662;
  t186_n206: return -0.03587697446346283;
  t186_n207: return 0.02966712974011898;
  t186_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t186_n212;
  t186_n209: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t186_n211;
  t186_n210: return 0.11925139278173447;
  t186_n211: return 0.11314435303211212;
  t186_n212: return -0.2752797603607178;
  t186_n213: return 0.0015567935770377517;
  t186_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t186_n224;
  t186_n215: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t186_n223;
  t186_n216: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t186_n218;
  t186_n217: return 0.027155403047800064;
  t186_n218: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t186_n222;
  t186_n219: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t186_n221;
  t186_n220: return -0.020017031580209732;
  t186_n221: return 0.10577955842018127;
  t186_n222: return 0.0028596408665180206;
  t186_n223: return 0.014259175397455692;
  t186_n224: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t186_n228;
  t186_n225: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t186_n227;
  t186_n226: return -0.029691819101572037;
  t186_n227: return 3.9555389881134033;
  t186_n228: return 0.09576333314180374;
  t186_n229: return -0.0012177583994343877;
  t186_n230: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t186_n254;
  t186_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t186_n233;
  t186_n232: return 0.004391705617308617;
  t186_n233: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t186_n247;
  t186_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t186_n244;
  t186_n235: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t186_n237;
  t186_n236: return 0.08534576743841171;
  t186_n237: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t186_n241;
  t186_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t186_n240;
  t186_n239: return -0.17852656543254852;
  t186_n240: return 0.09263347834348679;
  t186_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t186_n243;
  t186_n242: return 0.12073776870965958;
  t186_n243: return 0.11587531119585037;
  t186_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t186_n246;
  t186_n245: return 0.0958481952548027;
  t186_n246: return 0.05771293863654137;
  t186_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t186_n253;
  t186_n248: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t186_n250;
  t186_n249: return -0.47185882925987244;
  t186_n250: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t186_n252;
  t186_n251: return 0.11993293464183807;
  t186_n252: return 0.12502843141555786;
  t186_n253: return -0.010683135129511356;
  t186_n254: return 0.004165726248174906;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree187(const Example& E) {
  t187_n0: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t187_n2;
  t187_n1: return -0.00046644240501336753;
  t187_n2: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t187_n236;
  t187_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t187_n153;
  t187_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t187_n6;
  t187_n5: return 0.0012657862389460206;
  t187_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t187_n8;
  t187_n7: return 0.10118541121482849;
  t187_n8: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t187_n152;
  t187_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t187_n131;
  t187_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t187_n12;
  t187_n11: return -0.06318040192127228;
  t187_n12: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t187_n18;
  t187_n13: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t187_n15;
  t187_n14: return 0.017295213416218758;
  t187_n15: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t187_n17;
  t187_n16: return -0.3241463899612427;
  t187_n17: return 0.1340644806623459;
  t187_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t187_n54;
  t187_n19: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t187_n35;
  t187_n20: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n34;
  t187_n21: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t187_n33;
  t187_n22: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t187_n24;
  t187_n23: return 0.022375693544745445;
  t187_n24: if (E.getNumReferences() >= 3288694784 /*534.0*/) goto t187_n32;
  t187_n25: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t187_n29;
  t187_n26: if (E.getNumReferences() >= 3286335488 /*451.0*/) goto t187_n28;
  t187_n27: return 0.1480315625667572;
  t187_n28: return 0.03618667647242546;
  t187_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t187_n31;
  t187_n30: return -0.10055456310510635;
  t187_n31: return 0.11230430752038956;
  t187_n32: return 0.028902409598231316;
  t187_n33: return 0.0032243062742054462;
  t187_n34: return -0.04500287026166916;
  t187_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n53;
  t187_n36: if (E.getNumReferences() >= 3275358208 /*186.0*/) goto t187_n38;
  t187_n37: return -0.18517068028450012;
  t187_n38: if (E.getNumReferences() >= 3279716352 /*252.5*/) goto t187_n44;
  t187_n39: if (E.getNumReferences() >= 3278569472 /*235.0*/) goto t187_n43;
  t187_n40: if (E.getNumReferences() >= 3275653120 /*190.5*/) goto t187_n42;
  t187_n41: return 0.10820043087005615;
  t187_n42: return -0.18806852400302887;
  t187_n43: return 0.11209414154291153;
  t187_n44: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n48;
  t187_n45: if (E.getNumReferences() >= 3292758016 /*782.0*/) goto t187_n47;
  t187_n46: return 0.14496196806430817;
  t187_n47: return 0.12555967271327972;
  t187_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t187_n50;
  t187_n49: return -0.15912799537181854;
  t187_n50: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t187_n52;
  t187_n51: return 0.10735123604536057;
  t187_n52: return -0.16102057695388794;
  t187_n53: return -0.0546259768307209;
  t187_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t187_n56;
  t187_n55: return -0.01594160683453083;
  t187_n56: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t187_n72;
  t187_n57: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t187_n63;
  t187_n58: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t187_n62;
  t187_n59: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t187_n61;
  t187_n60: return 0.15791106224060059;
  t187_n61: return 0.055173568427562714;
  t187_n62: return -0.0086901243776083;
  t187_n63: if (E.getNumReferences() >= 3270836224 /*122.5*/) goto t187_n69;
  t187_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t187_n68;
  t187_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t187_n67;
  t187_n66: return -0.1261642873287201;
  t187_n67: return 0.11696066707372665;
  t187_n68: return 0.12329985201358795;
  t187_n69: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t187_n71;
  t187_n70: return 0.12019441276788712;
  t187_n71: return -0.11677715927362442;
  t187_n72: if (E.getNumReferences() >= 3278602240 /*235.5*/) goto t187_n76;
  t187_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t187_n75;
  t187_n74: return -0.0006026948685757816;
  t187_n75: return 0.07171722501516342;
  t187_n76: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t187_n92;
  t187_n77: if (E.getNumReferences() >= 3279912960 /*255.5*/) goto t187_n87;
  t187_n78: if (E.getNumReferences() >= 3279126528 /*243.5*/) goto t187_n86;
  t187_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n81;
  t187_n80: return -0.1452096402645111;
  t187_n81: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t187_n85;
  t187_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t187_n84;
  t187_n83: return 0.32909661531448364;
  t187_n84: return -0.23409052193164825;
  t187_n85: return 0.12200077623128891;
  t187_n86: return -0.11569412797689438;
  t187_n87: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t187_n91;
  t187_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n90;
  t187_n89: return -0.2875572741031647;
  t187_n90: return 0.13582485914230347;
  t187_n91: return 0.12010299414396286;
  t187_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t187_n118;
  t187_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t187_n95;
  t187_n94: return 0.04429960250854492;
  t187_n95: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t187_n97;
  t187_n96: return -0.06302307546138763;
  t187_n97: if (E.getNumReferences() >= 3281502208 /*303.5*/) goto t187_n99;
  t187_n98: return -0.08518396317958832;
  t187_n99: if (E.getNumReferences() >= 3281682432 /*309.0*/) goto t187_n101;
  t187_n100: return 0.12111898511648178;
  t187_n101: if (E.getNumReferences() >= 3284418560 /*392.5*/) goto t187_n103;
  t187_n102: return -0.03373561054468155;
  t187_n103: if (E.getNumReferences() >= 3302064128 /*1676.0*/) goto t187_n117;
  t187_n104: if (E.getNumReferences() >= 3292233728 /*750.0*/) goto t187_n112;
  t187_n105: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t187_n111;
  t187_n106: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n110;
  t187_n107: if (E.getNumReferences() >= 3286089728 /*443.5*/) goto t187_n109;
  t187_n108: return 0.03520903363823891;
  t187_n109: return 0.11713691800832748;
  t187_n110: return 0.06254663318395615;
  t187_n111: return 0.0108256246894598;
  t187_n112: if (E.getNumReferences() >= 3297796096 /*1155.0*/) goto t187_n116;
  t187_n113: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t187_n115;
  t187_n114: return 0.1323985457420349;
  t187_n115: return 0.08842974156141281;
  t187_n116: return 0.10030961781740189;
  t187_n117: return 0.04846611246466637;
  t187_n118: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t187_n128;
  t187_n119: if (E.getNumReferences() >= 3281944576 /*317.0*/) goto t187_n121;
  t187_n120: return 0.0821327194571495;
  t187_n121: if (E.getNumReferences() >= 3283599360 /*367.5*/) goto t187_n123;
  t187_n122: return 0.17609848082065582;
  t187_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t187_n127;
  t187_n124: if (E.getNumReferences() >= 3288760320 /*538.0*/) goto t187_n126;
  t187_n125: return 0.13119637966156006;
  t187_n126: return -0.10970784723758698;
  t187_n127: return 0.15386700630187988;
  t187_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n130;
  t187_n129: return 0.03668753430247307;
  t187_n130: return -0.22638100385665894;
  t187_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t187_n143;
  t187_n132: if (E.getNumReferences() >= 3330029056 /*16141.5*/) goto t187_n140;
  t187_n133: if (E.getNumReferences() >= 3293192192 /*808.5*/) goto t187_n137;
  t187_n134: if (E.getNumReferences() >= 3293093888 /*802.5*/) goto t187_n136;
  t187_n135: return -0.016972294077277184;
  t187_n136: return 0.11778029054403305;
  t187_n137: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t187_n139;
  t187_n138: return -0.10883177071809769;
  t187_n139: return 0.09914248436689377;
  t187_n140: if (E.getNumReferences() >= 3331594240 /*18956.0*/) goto t187_n142;
  t187_n141: return 0.11738230288028717;
  t187_n142: return 0.007805028464645147;
  t187_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t187_n147;
  t187_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n146;
  t187_n145: return -0.05921526625752449;
  t187_n146: return 0.05628411844372749;
  t187_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n151;
  t187_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t187_n150;
  t187_n149: return 0.11087051779031754;
  t187_n150: return 0.09944386035203934;
  t187_n151: return 0.036515973508358;
  t187_n152: return 0.014135024510324001;
  t187_n153: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t187_n189;
  t187_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t187_n172;
  t187_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t187_n157;
  t187_n156: return -0.04159403219819069;
  t187_n157: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t187_n161;
  t187_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t187_n160;
  t187_n159: return 0.10995606333017349;
  t187_n160: return 0.109839528799057;
  t187_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t187_n163;
  t187_n162: return 0.032277293503284454;
  t187_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t187_n165;
  t187_n164: return 0.045380253344774246;
  t187_n165: if (E.getNumReferences() >= 3289800704 /*601.5*/) goto t187_n167;
  t187_n166: return 0.06772036105394363;
  t187_n167: if (E.getNumReferences() >= 3291504640 /*705.5*/) goto t187_n171;
  t187_n168: if (E.getNumReferences() >= 3290923008 /*670.0*/) goto t187_n170;
  t187_n169: return 0.10267538577318192;
  t187_n170: return 0.12561668455600739;
  t187_n171: return 0.06710595637559891;
  t187_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t187_n180;
  t187_n173: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t187_n179;
  t187_n174: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t187_n176;
  t187_n175: return -0.04131636023521423;
  t187_n176: if (E.getNumReferences() >= 3291193344 /*686.5*/) goto t187_n178;
  t187_n177: return 0.12901362776756287;
  t187_n178: return 0.008170148357748985;
  t187_n179: return 0.1025586873292923;
  t187_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t187_n182;
  t187_n181: return 0.10126198083162308;
  t187_n182: if (E.getNumReferences() >= 3313785856 /*4235.5*/) goto t187_n188;
  t187_n183: if (E.getNumReferences() >= 3276242944 /*199.5*/) goto t187_n185;
  t187_n184: return 0.03827086091041565;
  t187_n185: if (E.getNumReferences() >= 3278143488 /*228.5*/) goto t187_n187;
  t187_n186: return 0.1064048483967781;
  t187_n187: return 0.07681070268154144;
  t187_n188: return -0.3052935302257538;
  t187_n189: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t187_n191;
  t187_n190: return -0.019254563376307487;
  t187_n191: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t187_n201;
  t187_n192: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t187_n194;
  t187_n193: return 0.00013674930960405618;
  t187_n194: if (E.getNumReferences() >= 3273261056 /*154.0*/) goto t187_n198;
  t187_n195: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t187_n197;
  t187_n196: return -0.163194939494133;
  t187_n197: return 0.14690986275672913;
  t187_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t187_n200;
  t187_n199: return -0.16437067091464996;
  t187_n200: return 0.05920817330479622;
  t187_n201: if (E.getSymbolScopeDistance() >= 3246915584 /*17.0*/) goto t187_n223;
  t187_n202: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t187_n222;
  t187_n203: if (E.getNumReferences() >= 3287072768 /*473.5*/) goto t187_n209;
  t187_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t187_n206;
  t187_n205: return 0.09243077039718628;
  t187_n206: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t187_n208;
  t187_n207: return 2.8538811206817627;
  t187_n208: return 0.18577782809734344;
  t187_n209: if (E.getNumReferences() >= 3288285184 /*510.5*/) goto t187_n211;
  t187_n210: return 0.13383227586746216;
  t187_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t187_n221;
  t187_n212: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t187_n218;
  t187_n213: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t187_n217;
  t187_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t187_n216;
  t187_n215: return 0.03210006654262543;
  t187_n216: return 0.23591859638690948;
  t187_n217: return -0.21356800198554993;
  t187_n218: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t187_n220;
  t187_n219: return 0.13062086701393127;
  t187_n220: return -0.23896293342113495;
  t187_n221: return 0.12838420271873474;
  t187_n222: return 0.13729743659496307;
  t187_n223: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t187_n235;
  t187_n224: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t187_n232;
  t187_n225: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t187_n227;
  t187_n226: return 0.013761309906840324;
  t187_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t187_n231;
  t187_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t187_n230;
  t187_n229: return -0.22428201138973236;
  t187_n230: return 0.07697849720716476;
  t187_n231: return 0.07056015729904175;
  t187_n232: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t187_n234;
  t187_n233: return -0.006593940779566765;
  t187_n234: return -0.07739370316267014;
  t187_n235: return 0.0489828921854496;
  t187_n236: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t187_n254;
  t187_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t187_n239;
  t187_n238: return 0.05171804130077362;
  t187_n239: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t187_n241;
  t187_n240: return 0.10709478706121445;
  t187_n241: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t187_n243;
  t187_n242: return 0.04971366748213768;
  t187_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t187_n249;
  t187_n244: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t187_n246;
  t187_n245: return 0.04157460108399391;
  t187_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t187_n248;
  t187_n247: return -0.0852891355752945;
  t187_n248: return 0.126091867685318;
  t187_n249: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t187_n251;
  t187_n250: return -0.015507016330957413;
  t187_n251: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t187_n253;
  t187_n252: return 0.13047629594802856;
  t187_n253: return 0.11732589453458786;
  t187_n254: return 0.02319086529314518;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree188(const Example& E) {
  t188_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t188_n214;
  t188_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t188_n129;
  t188_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n26;
  t188_n3: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t188_n5;
  t188_n4: return -0.003730676369741559;
  t188_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t188_n7;
  t188_n6: return -0.01363696251064539;
  t188_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t188_n9;
  t188_n8: return -0.021774772554636;
  t188_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t188_n25;
  t188_n10: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t188_n12;
  t188_n11: return 0.003206630004569888;
  t188_n12: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n24;
  t188_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t188_n21;
  t188_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n16;
  t188_n15: return -0.04140862077474594;
  t188_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n18;
  t188_n17: return 0.08019185811281204;
  t188_n18: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t188_n20;
  t188_n19: return 0.04598677530884743;
  t188_n20: return -0.019499029964208603;
  t188_n21: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t188_n23;
  t188_n22: return -0.005107576958835125;
  t188_n23: return 0.06105893850326538;
  t188_n24: return 0.00556687219068408;
  t188_n25: return -0.02351885847747326;
  t188_n26: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t188_n128;
  t188_n27: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t188_n115;
  t188_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t188_n110;
  t188_n29: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n87;
  t188_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n32;
  t188_n31: return -0.0021983699407428503;
  t188_n32: if (E.getNumReferences() >= 3281485824 /*303.0*/) goto t188_n82;
  t188_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t188_n75;
  t188_n34: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t188_n38;
  t188_n35: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n37;
  t188_n36: return 0.022569280117750168;
  t188_n37: return -0.06807295978069305;
  t188_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t188_n58;
  t188_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n41;
  t188_n40: return -0.015460309572517872;
  t188_n41: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t188_n57;
  t188_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t188_n52;
  t188_n43: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t188_n45;
  t188_n44: return 0.0385725162923336;
  t188_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n51;
  t188_n46: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t188_n48;
  t188_n47: return 0.09625967592000961;
  t188_n48: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t188_n50;
  t188_n49: return -0.1526423841714859;
  t188_n50: return 0.09579643607139587;
  t188_n51: return 0.15484118461608887;
  t188_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n56;
  t188_n53: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t188_n55;
  t188_n54: return 0.13447563350200653;
  t188_n55: return -0.3821552097797394;
  t188_n56: return 0.10030467063188553;
  t188_n57: return -0.030632706359028816;
  t188_n58: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t188_n70;
  t188_n59: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t188_n65;
  t188_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t188_n62;
  t188_n61: return 0.012601097114384174;
  t188_n62: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t188_n64;
  t188_n63: return 0.10092172771692276;
  t188_n64: return -0.0825372189283371;
  t188_n65: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t188_n69;
  t188_n66: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t188_n68;
  t188_n67: return 0.08593389391899109;
  t188_n68: return 0.00592559389770031;
  t188_n69: return -0.06818782538175583;
  t188_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t188_n72;
  t188_n71: return 0.15315662324428558;
  t188_n72: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t188_n74;
  t188_n73: return 0.14154185354709625;
  t188_n74: return 0.1627807319164276;
  t188_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n77;
  t188_n76: return -0.13869816064834595;
  t188_n77: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t188_n79;
  t188_n78: return 0.0519988089799881;
  t188_n79: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t188_n81;
  t188_n80: return 0.132859468460083;
  t188_n81: return 0.09848211705684662;
  t188_n82: if (E.getNumReferences() >= 3289022464 /*554.0*/) goto t188_n86;
  t188_n83: if (E.getNumReferences() >= 3284107264 /*383.0*/) goto t188_n85;
  t188_n84: return 0.11830876022577286;
  t188_n85: return 0.10425155609846115;
  t188_n86: return 0.014110476709902287;
  t188_n87: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t188_n91;
  t188_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n90;
  t188_n89: return -0.07893817126750946;
  t188_n90: return -0.008412557654082775;
  t188_n91: if (E.getNumReferences() >= 3278241792 /*230.0*/) goto t188_n99;
  t188_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t188_n94;
  t188_n93: return -0.042971715331077576;
  t188_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t188_n96;
  t188_n95: return -0.022789757698774338;
  t188_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n98;
  t188_n97: return 0.022854413837194443;
  t188_n98: return 0.13955479860305786;
  t188_n99: if (E.getNumReferences() >= 3278962688 /*241.0*/) goto t188_n101;
  t188_n100: return 0.11040925979614258;
  t188_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t188_n103;
  t188_n102: return -0.10765905678272247;
  t188_n103: if (E.getNumReferences() >= 3290464256 /*642.0*/) goto t188_n107;
  t188_n104: if (E.getNumReferences() >= 3280748544 /*280.5*/) goto t188_n106;
  t188_n105: return 0.10531022399663925;
  t188_n106: return 0.010758694261312485;
  t188_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t188_n109;
  t188_n108: return -0.04956215247511864;
  t188_n109: return 0.10105735063552856;
  t188_n110: if (E.getNumReferences() >= 3296002048 /*980.0*/) goto t188_n112;
  t188_n111: return -0.01481482945382595;
  t188_n112: if (E.getNumReferences() >= 3296616448 /*1017.5*/) goto t188_n114;
  t188_n113: return 0.09542827308177948;
  t188_n114: return -0.022482577711343765;
  t188_n115: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t188_n117;
  t188_n116: return 0.013513841666281223;
  t188_n117: if (E.getNumReferences() >= 3273654272 /*160.0*/) goto t188_n119;
  t188_n118: return 0.10794440656900406;
  t188_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t188_n121;
  t188_n120: return -0.006621612701565027;
  t188_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t188_n123;
  t188_n122: return 0.02713610604405403;
  t188_n123: if (E.getNumReferences() >= 3292078080 /*740.5*/) goto t188_n127;
  t188_n124: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t188_n126;
  t188_n125: return 0.04365888237953186;
  t188_n126: return 0.10243414342403412;
  t188_n127: return 0.04073135927319527;
  t188_n128: return 0.004023120738565922;
  t188_n129: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t188_n181;
  t188_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t188_n176;
  t188_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n167;
  t188_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t188_n154;
  t188_n133: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t188_n143;
  t188_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t188_n140;
  t188_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n139;
  t188_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n138;
  t188_n137: return -0.11565063148736954;
  t188_n138: return -0.16018174588680267;
  t188_n139: return -0.1078789085149765;
  t188_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t188_n142;
  t188_n141: return 0.01991686038672924;
  t188_n142: return 0.033885736018419266;
  t188_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n153;
  t188_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n146;
  t188_n145: return -0.06646876782178879;
  t188_n146: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t188_n152;
  t188_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n149;
  t188_n148: return 0.09277335554361343;
  t188_n149: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t188_n151;
  t188_n150: return 0.10190832614898682;
  t188_n151: return 0.06894893199205399;
  t188_n152: return -0.002001996384933591;
  t188_n153: return 0.013510113582015038;
  t188_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n158;
  t188_n155: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n157;
  t188_n156: return 0.011347639374434948;
  t188_n157: return 0.04179825261235237;
  t188_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n160;
  t188_n159: return 0.07711243629455566;
  t188_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n162;
  t188_n161: return 0.061718057841062546;
  t188_n162: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n166;
  t188_n163: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t188_n165;
  t188_n164: return 0.24483467638492584;
  t188_n165: return 0.12971976399421692;
  t188_n166: return -0.10150572657585144;
  t188_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n173;
  t188_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n172;
  t188_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n171;
  t188_n170: return -0.16467812657356262;
  t188_n171: return 0.02127045765519142;
  t188_n172: return -0.004476966802030802;
  t188_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t188_n175;
  t188_n174: return -0.0006162780337035656;
  t188_n175: return 0.01166662760078907;
  t188_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n180;
  t188_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n179;
  t188_n178: return 0.11374019086360931;
  t188_n179: return 0.011291583068668842;
  t188_n180: return -0.01970345713198185;
  t188_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t188_n191;
  t188_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t188_n188;
  t188_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n185;
  t188_n184: return -0.03246455639600754;
  t188_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n187;
  t188_n186: return -0.038152504712343216;
  t188_n187: return -0.023191427811980247;
  t188_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t188_n190;
  t188_n189: return -0.010672398842871189;
  t188_n190: return 0.014813595451414585;
  t188_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n197;
  t188_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t188_n194;
  t188_n193: return -0.13235528767108917;
  t188_n194: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n196;
  t188_n195: return 0.07279699295759201;
  t188_n196: return -0.046470966190099716;
  t188_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t188_n201;
  t188_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n200;
  t188_n199: return -0.13096649944782257;
  t188_n200: return 0.04827476292848587;
  t188_n201: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t188_n213;
  t188_n202: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t188_n206;
  t188_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n205;
  t188_n204: return -0.10467900335788727;
  t188_n205: return 0.0884697213768959;
  t188_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n208;
  t188_n207: return -0.01250266470015049;
  t188_n208: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t188_n212;
  t188_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n211;
  t188_n210: return 0.10629641264677048;
  t188_n211: return 0.1588486284017563;
  t188_n212: return 0.12714970111846924;
  t188_n213: return 0.08122647553682327;
  t188_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t188_n216;
  t188_n215: return -0.032140329480171204;
  t188_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t188_n218;
  t188_n217: return -0.002363086212426424;
  t188_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t188_n252;
  t188_n219: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t188_n225;
  t188_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n224;
  t188_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n223;
  t188_n222: return -0.04150150343775749;
  t188_n223: return 0.04409562796354294;
  t188_n224: return 0.05881880968809128;
  t188_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t188_n249;
  t188_n226: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t188_n232;
  t188_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t188_n229;
  t188_n228: return 0.025212114676833153;
  t188_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n231;
  t188_n230: return 0.0631205290555954;
  t188_n231: return 0.015936115756630898;
  t188_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t188_n238;
  t188_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n237;
  t188_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n236;
  t188_n235: return 0.05063987895846367;
  t188_n236: return 0.08162672817707062;
  t188_n237: return -0.0011963858269155025;
  t188_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t188_n242;
  t188_n239: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t188_n241;
  t188_n240: return 0.03354136273264885;
  t188_n241: return 0.07495719939470291;
  t188_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t188_n246;
  t188_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t188_n245;
  t188_n244: return -0.1361045241355896;
  t188_n245: return 0.09360917657613754;
  t188_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t188_n248;
  t188_n247: return -0.00015991665713954717;
  t188_n248: return 0.08770252019166946;
  t188_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t188_n251;
  t188_n250: return -0.004273523576557636;
  t188_n251: return 0.04794163256883621;
  t188_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t188_n254;
  t188_n253: return 0.11048618704080582;
  t188_n254: return 0.05551352724432945;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree189(const Example& E) {
  t189_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t189_n2;
  t189_n1: return -0.00036399468081071973;
  t189_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t189_n4;
  t189_n3: return 0.01172443013638258;
  t189_n4: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t189_n10;
  t189_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t189_n9;
  t189_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t189_n8;
  t189_n7: return -0.02863471396267414;
  t189_n8: return 0.09105028212070465;
  t189_n9: return 0.11522354185581207;
  t189_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t189_n12;
  t189_n11: return -0.0011811550939455628;
  t189_n12: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t189_n228;
  t189_n13: if (E.getNumReferences() >= 3315681280 /*5161.0*/) goto t189_n27;
  t189_n14: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t189_n18;
  t189_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n17;
  t189_n16: return -0.10667984932661057;
  t189_n17: return 0.008383634500205517;
  t189_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n22;
  t189_n19: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t189_n21;
  t189_n20: return 0.10191347450017929;
  t189_n21: return -0.09957420080900192;
  t189_n22: if (E.getNumReferences() >= 3312386048 /*3824.0*/) goto t189_n26;
  t189_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t189_n25;
  t189_n24: return 0.12393452972173691;
  t189_n25: return -0.09096372872591019;
  t189_n26: return -1.1102079153060913;
  t189_n27: if (E.getNumReferences() >= 3315769344 /*5204.0*/) goto t189_n37;
  t189_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t189_n34;
  t189_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n31;
  t189_n30: return -0.005309075582772493;
  t189_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t189_n33;
  t189_n32: return 0.09922939538955688;
  t189_n33: return -0.1198887974023819;
  t189_n34: if (E.getNumReferences() >= 3315727360 /*5183.5*/) goto t189_n36;
  t189_n35: return 0.09655473381280899;
  t189_n36: return 0.12537682056427002;
  t189_n37: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t189_n227;
  t189_n38: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t189_n204;
  t189_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t189_n41;
  t189_n40: return 0.014804106205701828;
  t189_n41: if (E.getNumReferences() >= 3334023936 /*23701.5*/) goto t189_n187;
  t189_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t189_n134;
  t189_n43: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t189_n97;
  t189_n44: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t189_n94;
  t189_n45: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t189_n57;
  t189_n46: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t189_n48;
  t189_n47: return -0.03868400678038597;
  t189_n48: if (E.getNumReferences() >= 3319636992 /*7092.5*/) goto t189_n54;
  t189_n49: if (E.getNumReferences() >= 3317832704 /*6211.5*/) goto t189_n53;
  t189_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n52;
  t189_n51: return 0.1560359001159668;
  t189_n52: return 0.11370043456554413;
  t189_n53: return -0.252521812915802;
  t189_n54: if (E.getNumReferences() >= 3320252416 /*7393.0*/) goto t189_n56;
  t189_n55: return 0.12955592572689056;
  t189_n56: return 0.07883001863956451;
  t189_n57: if (E.getNumReferences() >= 3320574976 /*7550.5*/) goto t189_n79;
  t189_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t189_n78;
  t189_n59: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t189_n75;
  t189_n60: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t189_n74;
  t189_n61: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t189_n63;
  t189_n62: return -0.1370147317647934;
  t189_n63: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t189_n65;
  t189_n64: return -0.35051703453063965;
  t189_n65: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t189_n67;
  t189_n66: return 0.1179148256778717;
  t189_n67: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t189_n73;
  t189_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t189_n72;
  t189_n69: if (E.getNumReferences() >= 3319047168 /*6804.5*/) goto t189_n71;
  t189_n70: return 0.1090007945895195;
  t189_n71: return -0.1470809280872345;
  t189_n72: return -0.13006068766117096;
  t189_n73: return 0.09224629402160645;
  t189_n74: return -0.06258303672075272;
  t189_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n77;
  t189_n76: return -0.02796366810798645;
  t189_n77: return 0.15607984364032745;
  t189_n78: return -0.03636224567890167;
  t189_n79: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n85;
  t189_n80: if (E.getNumReferences() >= 3320749056 /*7635.5*/) goto t189_n84;
  t189_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t189_n83;
  t189_n82: return 0.00827658362686634;
  t189_n83: return 0.14403650164604187;
  t189_n84: return -0.0670345351099968;
  t189_n85: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n91;
  t189_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t189_n90;
  t189_n87: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t189_n89;
  t189_n88: return -0.10918455570936203;
  t189_n89: return 0.11261899024248123;
  t189_n90: return 0.11090008914470673;
  t189_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t189_n93;
  t189_n92: return 0.07060972601175308;
  t189_n93: return 0.11140170693397522;
  t189_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n96;
  t189_n95: return -0.116575226187706;
  t189_n96: return 0.11905469000339508;
  t189_n97: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t189_n101;
  t189_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n100;
  t189_n99: return -0.08645741641521454;
  t189_n100: return 0.05079266428947449;
  t189_n101: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t189_n109;
  t189_n102: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t189_n108;
  t189_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t189_n107;
  t189_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n106;
  t189_n105: return 0.12417910993099213;
  t189_n106: return -0.11401525139808655;
  t189_n107: return -0.03457915410399437;
  t189_n108: return -0.046428170055150986;
  t189_n109: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t189_n125;
  t189_n110: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n112;
  t189_n111: return -0.09980462491512299;
  t189_n112: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n124;
  t189_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t189_n119;
  t189_n114: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t189_n116;
  t189_n115: return -0.11053500324487686;
  t189_n116: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t189_n118;
  t189_n117: return 0.1270218789577484;
  t189_n118: return -0.1153077483177185;
  t189_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n123;
  t189_n120: if (E.getNumReferences() >= 3329832960 /*15950.0*/) goto t189_n122;
  t189_n121: return 0.105321504175663;
  t189_n122: return 0.10014180839061737;
  t189_n123: return -0.06897987425327301;
  t189_n124: return -0.0385039858520031;
  t189_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t189_n127;
  t189_n126: return 0.018862618133425713;
  t189_n127: if (E.getNumReferences() >= 3331535872 /*18842.0*/) goto t189_n131;
  t189_n128: if (E.getNumReferences() >= 3331140096 /*18069.0*/) goto t189_n130;
  t189_n129: return 0.09831353276968002;
  t189_n130: return -0.11444570124149323;
  t189_n131: if (E.getNumReferences() >= 3331729664 /*19220.5*/) goto t189_n133;
  t189_n132: return 0.1161852777004242;
  t189_n133: return 0.04678849130868912;
  t189_n134: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t189_n152;
  t189_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t189_n137;
  t189_n136: return -0.17839248478412628;
  t189_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n145;
  t189_n138: if (E.getNumReferences() >= 3318524928 /*6549.5*/) goto t189_n140;
  t189_n139: return 0.12714987993240356;
  t189_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n142;
  t189_n141: return -0.20804913341999054;
  t189_n142: if (E.getNumReferences() >= 3323595264 /*9858.5*/) goto t189_n144;
  t189_n143: return -0.10429506748914719;
  t189_n144: return 0.11735110729932785;
  t189_n145: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t189_n149;
  t189_n146: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n148;
  t189_n147: return 0.10906316339969635;
  t189_n148: return 0.06052790582180023;
  t189_n149: if (E.getNumReferences() >= 3328500736 /*14649.0*/) goto t189_n151;
  t189_n150: return 0.13677996397018433;
  t189_n151: return 0.19664829969406128;
  t189_n152: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t189_n154;
  t189_n153: return 0.027856241911649704;
  t189_n154: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n162;
  t189_n155: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n157;
  t189_n156: return 0.021598560735583305;
  t189_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t189_n159;
  t189_n158: return 0.030601978302001953;
  t189_n159: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t189_n161;
  t189_n160: return 0.11619365960359573;
  t189_n161: return 0.11088556051254272;
  t189_n162: if (E.getNumReferences() >= 3322694144 /*8978.5*/) goto t189_n164;
  t189_n163: return 0.0019269773038104177;
  t189_n164: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t189_n166;
  t189_n165: return 0.11560484021902084;
  t189_n166: if (E.getNumReferences() >= 3324730368 /*10967.0*/) goto t189_n174;
  t189_n167: if (E.getNumReferences() >= 3324197888 /*10447.0*/) goto t189_n171;
  t189_n168: if (E.getNumReferences() >= 3323776512 /*10035.5*/) goto t189_n170;
  t189_n169: return 0.2542572319507599;
  t189_n170: return -0.2700662314891815;
  t189_n171: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t189_n173;
  t189_n172: return 0.09065856039524078;
  t189_n173: return 0.12726005911827087;
  t189_n174: if (E.getNumReferences() >= 3328404480 /*14555.0*/) goto t189_n176;
  t189_n175: return -0.21839463710784912;
  t189_n176: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n186;
  t189_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t189_n183;
  t189_n178: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t189_n182;
  t189_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n181;
  t189_n180: return -0.4067786931991577;
  t189_n181: return 0.0831221342086792;
  t189_n182: return 0.11957743018865585;
  t189_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n185;
  t189_n184: return 0.10230939835309982;
  t189_n185: return 0.08660639077425003;
  t189_n186: return 0.038773030042648315;
  t189_n187: if (E.getNumReferences() >= 3334293248 /*24227.5*/) goto t189_n201;
  t189_n188: if (E.getNumReferences() >= 3334224384 /*24093.0*/) goto t189_n198;
  t189_n189: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n191;
  t189_n190: return 0.08161254227161407;
  t189_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t189_n197;
  t189_n192: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t189_n196;
  t189_n193: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t189_n195;
  t189_n194: return 0.09275268763303757;
  t189_n195: return 0.06354279816150665;
  t189_n196: return -0.10449951142072678;
  t189_n197: return 0.11081051081418991;
  t189_n198: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n200;
  t189_n199: return 0.11088764667510986;
  t189_n200: return 0.06442433595657349;
  t189_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t189_n203;
  t189_n202: return 0.11175227165222168;
  t189_n203: return -0.17901504039764404;
  t189_n204: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t189_n224;
  t189_n205: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n217;
  t189_n206: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t189_n216;
  t189_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t189_n209;
  t189_n208: return -0.3252536654472351;
  t189_n209: if (E.getNumReferences() >= 3324040704 /*10293.5*/) goto t189_n215;
  t189_n210: if (E.getNumReferences() >= 3319659520 /*7103.5*/) goto t189_n214;
  t189_n211: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n213;
  t189_n212: return 0.0585707388818264;
  t189_n213: return 0.09727957099676132;
  t189_n214: return 0.09914737194776535;
  t189_n215: return -0.006449663545936346;
  t189_n216: return 0.05611953139305115;
  t189_n217: if (E.getNumReferences() >= 3318883328 /*6724.5*/) goto t189_n221;
  t189_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t189_n220;
  t189_n219: return 0.05046457424759865;
  t189_n220: return 0.10641957074403763;
  t189_n221: if (E.getNumReferences() >= 3323495424 /*9761.0*/) goto t189_n223;
  t189_n222: return -0.1001855880022049;
  t189_n223: return 0.04307005926966667;
  t189_n224: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n226;
  t189_n225: return -0.11796889454126358;
  t189_n226: return 0.04190710932016373;
  t189_n227: return 0.10086825489997864;
  t189_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t189_n248;
  t189_n229: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t189_n243;
  t189_n230: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t189_n242;
  t189_n231: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t189_n235;
  t189_n232: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t189_n234;
  t189_n233: return -0.012809663079679012;
  t189_n234: return 0.05331690236926079;
  t189_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t189_n237;
  t189_n236: return -0.08138769865036011;
  t189_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t189_n239;
  t189_n238: return 0.01324445754289627;
  t189_n239: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t189_n241;
  t189_n240: return 0.09614205360412598;
  t189_n241: return 0.017231162637472153;
  t189_n242: return 0.048118967562913895;
  t189_n243: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t189_n245;
  t189_n244: return -0.33113065361976624;
  t189_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t189_n247;
  t189_n246: return 0.060348719358444214;
  t189_n247: return 0.022848522290587425;
  t189_n248: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t189_n254;
  t189_n249: if (E.getNumReferences() >= 3342897664 /*49298.0*/) goto t189_n251;
  t189_n250: return 0.010642926208674908;
  t189_n251: if (E.getNumReferences() >= 3346297984 /*62580.5*/) goto t189_n253;
  t189_n252: return 0.12061794847249985;
  t189_n253: return -0.010094386525452137;
  t189_n254: return 0.019331149756908417;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree190(const Example& E) {
  t190_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t190_n2;
  t190_n1: return -0.00037183004315011203;
  t190_n2: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t190_n254;
  t190_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t190_n163;
  t190_n4: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n6;
  t190_n5: return 0.01802072674036026;
  t190_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n72;
  t190_n7: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t190_n59;
  t190_n8: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n36;
  t190_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n13;
  t190_n10: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n12;
  t190_n11: return 0.018861623480916023;
  t190_n12: return -0.03989424556493759;
  t190_n13: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t190_n29;
  t190_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n20;
  t190_n15: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n19;
  t190_n16: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n18;
  t190_n17: return 0.00801692996174097;
  t190_n18: return -0.26924532651901245;
  t190_n19: return -0.17868472635746002;
  t190_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n24;
  t190_n21: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t190_n23;
  t190_n22: return -0.21952542662620544;
  t190_n23: return 0.0395403616130352;
  t190_n24: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t190_n26;
  t190_n25: return -0.05981216952204704;
  t190_n26: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t190_n28;
  t190_n27: return 0.02240973897278309;
  t190_n28: return -1.9399462938308716;
  t190_n29: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n35;
  t190_n30: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n34;
  t190_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n33;
  t190_n32: return 0.1000649705529213;
  t190_n33: return 0.12684471905231476;
  t190_n34: return -0.401202917098999;
  t190_n35: return 0.021509353071451187;
  t190_n36: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t190_n58;
  t190_n37: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t190_n53;
  t190_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t190_n50;
  t190_n39: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n47;
  t190_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n46;
  t190_n41: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n43;
  t190_n42: return -0.14196492731571198;
  t190_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n45;
  t190_n44: return -0.9654711484909058;
  t190_n45: return 0.01986461877822876;
  t190_n46: return -0.0430031418800354;
  t190_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n49;
  t190_n48: return 0.12024897336959839;
  t190_n49: return -0.11904450505971909;
  t190_n50: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t190_n52;
  t190_n51: return 0.278547465801239;
  t190_n52: return 0.020178545266389847;
  t190_n53: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t190_n55;
  t190_n54: return 0.0036125537008047104;
  t190_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n57;
  t190_n56: return 0.10072584450244904;
  t190_n57: return -0.16343654692173004;
  t190_n58: return 0.13176128268241882;
  t190_n59: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t190_n65;
  t190_n60: if (E.getNumReferences() >= 3277717504 /*222.0*/) goto t190_n62;
  t190_n61: return 0.025166720151901245;
  t190_n62: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n64;
  t190_n63: return 0.13698631525039673;
  t190_n64: return 0.03232264518737793;
  t190_n65: if (E.getNumReferences() >= 3339407360 /*35664.0*/) goto t190_n71;
  t190_n66: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t190_n68;
  t190_n67: return -0.019347794353961945;
  t190_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n70;
  t190_n69: return -0.7807068228721619;
  t190_n70: return -0.11813672631978989;
  t190_n71: return 0.08228348940610886;
  t190_n72: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t190_n154;
  t190_n73: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n125;
  t190_n74: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n84;
  t190_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n79;
  t190_n76: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n78;
  t190_n77: return -0.16073328256607056;
  t190_n78: return -0.007877168245613575;
  t190_n79: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n81;
  t190_n80: return 0.05876263976097107;
  t190_n81: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t190_n83;
  t190_n82: return 0.8293270468711853;
  t190_n83: return 0.18629838526248932;
  t190_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t190_n94;
  t190_n85: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t190_n87;
  t190_n86: return -0.10302449762821198;
  t190_n87: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n89;
  t190_n88: return 0.10841555893421173;
  t190_n89: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t190_n93;
  t190_n90: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t190_n92;
  t190_n91: return 0.07757479697465897;
  t190_n92: return 0.11280368268489838;
  t190_n93: return 0.014349429868161678;
  t190_n94: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t190_n116;
  t190_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n97;
  t190_n96: return -0.03712943568825722;
  t190_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t190_n105;
  t190_n98: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t190_n100;
  t190_n99: return -0.01157109159976244;
  t190_n100: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n102;
  t190_n101: return 0.10290662199258804;
  t190_n102: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t190_n104;
  t190_n103: return -0.33138176798820496;
  t190_n104: return 1.5532363653182983;
  t190_n105: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t190_n115;
  t190_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n114;
  t190_n107: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n113;
  t190_n108: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t190_n112;
  t190_n109: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t190_n111;
  t190_n110: return 0.12295523285865784;
  t190_n111: return 0.13438349962234497;
  t190_n112: return 0.1430804431438446;
  t190_n113: return -0.08434567600488663;
  t190_n114: return 0.07114722579717636;
  t190_n115: return 0.024875197559595108;
  t190_n116: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n118;
  t190_n117: return -0.04120899364352226;
  t190_n118: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t190_n120;
  t190_n119: return 0.009797855280339718;
  t190_n120: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t190_n122;
  t190_n121: return 0.147582545876503;
  t190_n122: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t190_n124;
  t190_n123: return 0.02975742146372795;
  t190_n124: return 0.11963906139135361;
  t190_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n127;
  t190_n126: return -0.16300928592681885;
  t190_n127: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t190_n129;
  t190_n128: return -0.7329940795898438;
  t190_n129: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t190_n135;
  t190_n130: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t190_n134;
  t190_n131: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n133;
  t190_n132: return -0.04196186736226082;
  t190_n133: return 0.05253228545188904;
  t190_n134: return -0.34019753336906433;
  t190_n135: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n137;
  t190_n136: return 0.05246914178133011;
  t190_n137: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t190_n153;
  t190_n138: if (E.getNumReferences() >= 3265527808 /*82.0*/) goto t190_n152;
  t190_n139: if (E.getNumReferences() >= 3263823872 /*69.0*/) goto t190_n151;
  t190_n140: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t190_n150;
  t190_n141: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t190_n143;
  t190_n142: return -0.044162798672914505;
  t190_n143: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t190_n145;
  t190_n144: return 0.1264055371284485;
  t190_n145: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t190_n147;
  t190_n146: return -0.11916462332010269;
  t190_n147: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t190_n149;
  t190_n148: return -0.059382203966379166;
  t190_n149: return 0.0860566794872284;
  t190_n150: return -0.653089702129364;
  t190_n151: return 0.11259346455335617;
  t190_n152: return -0.7048563957214355;
  t190_n153: return 0.08836523443460464;
  t190_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t190_n156;
  t190_n155: return 0.12153998762369156;
  t190_n156: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t190_n158;
  t190_n157: return 0.11220818758010864;
  t190_n158: if (E.getNumReferences() >= 3287007232 /*471.5*/) goto t190_n160;
  t190_n159: return -0.23284167051315308;
  t190_n160: if (E.getNumReferences() >= 3288924160 /*548.0*/) goto t190_n162;
  t190_n161: return 0.1468205600976944;
  t190_n162: return -0.26498255133628845;
  t190_n163: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t190_n165;
  t190_n164: return 0.006209347862750292;
  t190_n165: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t190_n207;
  t190_n166: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t190_n168;
  t190_n167: return -0.02060949057340622;
  t190_n168: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t190_n188;
  t190_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n171;
  t190_n170: return -0.04489394649863243;
  t190_n171: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t190_n187;
  t190_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n176;
  t190_n173: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n175;
  t190_n174: return 0.06991683691740036;
  t190_n175: return -0.07849424332380295;
  t190_n176: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t190_n180;
  t190_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n179;
  t190_n178: return -0.33916619420051575;
  t190_n179: return 0.07526851445436478;
  t190_n180: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t190_n186;
  t190_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t190_n183;
  t190_n182: return -0.18370117247104645;
  t190_n183: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t190_n185;
  t190_n184: return 0.08818858116865158;
  t190_n185: return 0.13245801627635956;
  t190_n186: return -0.06418168544769287;
  t190_n187: return -0.11468446999788284;
  t190_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n194;
  t190_n189: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t190_n191;
  t190_n190: return -0.12503252923488617;
  t190_n191: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t190_n193;
  t190_n192: return 0.08388757705688477;
  t190_n193: return -0.08083996176719666;
  t190_n194: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t190_n204;
  t190_n195: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t190_n203;
  t190_n196: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t190_n200;
  t190_n197: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t190_n199;
  t190_n198: return 0.10572981834411621;
  t190_n199: return -0.17058111727237701;
  t190_n200: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t190_n202;
  t190_n201: return 0.1341351568698883;
  t190_n202: return 0.11978894472122192;
  t190_n203: return 0.11159104108810425;
  t190_n204: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t190_n206;
  t190_n205: return -0.1174759492278099;
  t190_n206: return 0.10043615847826004;
  t190_n207: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t190_n239;
  t190_n208: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t190_n238;
  t190_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t190_n231;
  t190_n210: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t190_n216;
  t190_n211: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t190_n215;
  t190_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t190_n214;
  t190_n213: return -0.2115284651517868;
  t190_n214: return 0.07118396461009979;
  t190_n215: return 0.02457071654498577;
  t190_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n222;
  t190_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n219;
  t190_n218: return 0.04079410061240196;
  t190_n219: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t190_n221;
  t190_n220: return -0.037799686193466187;
  t190_n221: return 0.09706006199121475;
  t190_n222: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t190_n230;
  t190_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n229;
  t190_n224: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t190_n228;
  t190_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t190_n227;
  t190_n226: return -0.44468948245048523;
  t190_n227: return 0.09835256636142731;
  t190_n228: return 0.09205294400453568;
  t190_n229: return 0.03947374224662781;
  t190_n230: return 0.009860390797257423;
  t190_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t190_n233;
  t190_n232: return 0.3494124710559845;
  t190_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t190_n237;
  t190_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t190_n236;
  t190_n235: return 0.14737381041049957;
  t190_n236: return 0.11857855319976807;
  t190_n237: return 0.1537100374698639;
  t190_n238: return -0.027745509520173073;
  t190_n239: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t190_n241;
  t190_n240: return -0.003711710451170802;
  t190_n241: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t190_n253;
  t190_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t190_n244;
  t190_n243: return 0.1058899387717247;
  t190_n244: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t190_n248;
  t190_n245: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t190_n247;
  t190_n246: return -0.12375029176473618;
  t190_n247: return 0.07473351061344147;
  t190_n248: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t190_n252;
  t190_n249: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t190_n251;
  t190_n250: return 0.10389994829893112;
  t190_n251: return 0.06938082724809647;
  t190_n252: return 0.03585141897201538;
  t190_n253: return 0.011823105625808239;
  t190_n254: return -0.0005472165648825467;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree191(const Example& E) {
  t191_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t191_n26;
  t191_n1: if (E.getNumReferences() >= 3349010432 /*80816.0*/) goto t191_n15;
  t191_n2: if (E.getNumReferences() >= 3348846016 /*79531.5*/) goto t191_n4;
  t191_n3: return -0.0001297541311942041;
  t191_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n6;
  t191_n5: return 0.01169893704354763;
  t191_n6: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n8;
  t191_n7: return 0.0118651008233428;
  t191_n8: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t191_n14;
  t191_n9: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t191_n13;
  t191_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n12;
  t191_n11: return 0.13053204119205475;
  t191_n12: return 0.10332778096199036;
  t191_n13: return -0.20143763720989227;
  t191_n14: return 0.12505796551704407;
  t191_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n17;
  t191_n16: return -0.046733684837818146;
  t191_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t191_n23;
  t191_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t191_n22;
  t191_n19: if (E.getNumReferences() >= 3349221056 /*82461.5*/) goto t191_n21;
  t191_n20: return -0.3604876697063446;
  t191_n21: return -0.13427108526229858;
  t191_n22: return 0.06055426597595215;
  t191_n23: if (E.getNumReferences() >= 3349481344 /*84495.0*/) goto t191_n25;
  t191_n24: return 0.017326723784208298;
  t191_n25: return -0.12328728288412094;
  t191_n26: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t191_n248;
  t191_n27: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t191_n201;
  t191_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t191_n176;
  t191_n29: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t191_n145;
  t191_n30: if (E.getNumReferences() >= 3353375936 /*114921.5*/) goto t191_n126;
  t191_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n85;
  t191_n32: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t191_n84;
  t191_n33: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t191_n41;
  t191_n34: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n40;
  t191_n35: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t191_n39;
  t191_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n38;
  t191_n37: return 0.08852383494377136;
  t191_n38: return 0.07429914176464081;
  t191_n39: return -0.06333870440721512;
  t191_n40: return -0.016217947006225586;
  t191_n41: if (E.getNumReferences() >= 3350349056 /*91274.0*/) goto t191_n47;
  t191_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n44;
  t191_n43: return -0.1238141879439354;
  t191_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n46;
  t191_n45: return 0.1105690523982048;
  t191_n46: return -0.10234072059392929;
  t191_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n79;
  t191_n48: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t191_n64;
  t191_n49: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t191_n63;
  t191_n50: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t191_n54;
  t191_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t191_n53;
  t191_n52: return -0.14599435031414032;
  t191_n53: return 0.04677218198776245;
  t191_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n58;
  t191_n55: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t191_n57;
  t191_n56: return 0.1030626893043518;
  t191_n57: return 0.08908560872077942;
  t191_n58: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t191_n60;
  t191_n59: return -0.7416446208953857;
  t191_n60: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t191_n62;
  t191_n61: return 0.07357277721166611;
  t191_n62: return -0.11188798397779465;
  t191_n63: return 0.020827781409025192;
  t191_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t191_n74;
  t191_n65: if (E.getNumReferences() >= 3351834112 /*102876.0*/) goto t191_n67;
  t191_n66: return -0.045493513345718384;
  t191_n67: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t191_n73;
  t191_n68: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t191_n72;
  t191_n69: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t191_n71;
  t191_n70: return 0.06460661441087723;
  t191_n71: return -0.23955577611923218;
  t191_n72: return 0.08992201834917068;
  t191_n73: return -0.1898101568222046;
  t191_n74: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t191_n78;
  t191_n75: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t191_n77;
  t191_n76: return -0.022527674213051796;
  t191_n77: return 0.13401171565055847;
  t191_n78: return 0.13280701637268066;
  t191_n79: if (E.getNumReferences() >= 3350460992 /*92148.5*/) goto t191_n83;
  t191_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n82;
  t191_n81: return 0.10422708094120026;
  t191_n82: return -0.03633487597107887;
  t191_n83: return -0.11027367413043976;
  t191_n84: return 0.021519774571061134;
  t191_n85: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n87;
  t191_n86: return 0.00802328996360302;
  t191_n87: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t191_n121;
  t191_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t191_n90;
  t191_n89: return -0.060743581503629684;
  t191_n90: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t191_n92;
  t191_n91: return 0.09862205386161804;
  t191_n92: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t191_n108;
  t191_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t191_n103;
  t191_n94: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t191_n96;
  t191_n95: return 0.03679914027452469;
  t191_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n102;
  t191_n97: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t191_n101;
  t191_n98: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t191_n100;
  t191_n99: return 0.08305387198925018;
  t191_n100: return 0.14189018309116364;
  t191_n101: return 0.08218677341938019;
  t191_n102: return 0.0963914766907692;
  t191_n103: if (E.getNumReferences() >= 3352491648 /*108013.0*/) goto t191_n107;
  t191_n104: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t191_n106;
  t191_n105: return 0.04687878489494324;
  t191_n106: return 0.06841582804918289;
  t191_n107: return -0.22154691815376282;
  t191_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n118;
  t191_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t191_n111;
  t191_n110: return -0.04652903601527214;
  t191_n111: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t191_n115;
  t191_n112: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t191_n114;
  t191_n113: return -2.1559653282165527;
  t191_n114: return 0.08755278587341309;
  t191_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n117;
  t191_n116: return 0.10129183530807495;
  t191_n117: return 0.0878627747297287;
  t191_n118: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t191_n120;
  t191_n119: return 0.05258181318640709;
  t191_n120: return -2.9826931953430176;
  t191_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t191_n123;
  t191_n122: return -0.05185474455356598;
  t191_n123: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t191_n125;
  t191_n124: return 0.07702705264091492;
  t191_n125: return 0.08530953526496887;
  t191_n126: if (E.getNumReferences() >= 3355264064 /*129672.5*/) goto t191_n134;
  t191_n127: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n129;
  t191_n128: return -0.2616109251976013;
  t191_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t191_n131;
  t191_n130: return -0.06876000016927719;
  t191_n131: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t191_n133;
  t191_n132: return 0.08022792637348175;
  t191_n133: return 0.03388826921582222;
  t191_n134: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t191_n144;
  t191_n135: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t191_n141;
  t191_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n138;
  t191_n137: return 0.10163265466690063;
  t191_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t191_n140;
  t191_n139: return 0.06392879039049149;
  t191_n140: return -0.19218063354492188;
  t191_n141: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n143;
  t191_n142: return 0.04564862325787544;
  t191_n143: return -0.1563921421766281;
  t191_n144: return -0.03190569207072258;
  t191_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n147;
  t191_n146: return -0.019870104268193245;
  t191_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n155;
  t191_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t191_n152;
  t191_n149: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n151;
  t191_n150: return 0.004501848015934229;
  t191_n151: return 0.0753999799489975;
  t191_n152: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t191_n154;
  t191_n153: return -0.10279015451669693;
  t191_n154: return 0.08321207761764526;
  t191_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t191_n159;
  t191_n156: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t191_n158;
  t191_n157: return -0.18584361672401428;
  t191_n158: return 0.11145269125699997;
  t191_n159: if (E.getNumReferences() >= 3359621216 /*196353.5*/) goto t191_n175;
  t191_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t191_n162;
  t191_n161: return 0.010651192627847195;
  t191_n162: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t191_n168;
  t191_n163: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n165;
  t191_n164: return -0.21380206942558289;
  t191_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t191_n167;
  t191_n166: return 0.10492578148841858;
  t191_n167: return 0.008100307546555996;
  t191_n168: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n174;
  t191_n169: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t191_n173;
  t191_n170: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t191_n172;
  t191_n171: return 0.11247123032808304;
  t191_n172: return 0.10848066955804825;
  t191_n173: return -0.12028038501739502;
  t191_n174: return 0.08312270790338516;
  t191_n175: return -0.12372381240129471;
  t191_n176: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t191_n178;
  t191_n177: return 0.054419733583927155;
  t191_n178: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t191_n182;
  t191_n179: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n181;
  t191_n180: return -0.13208819925785065;
  t191_n181: return -0.5768528580665588;
  t191_n182: if (E.getNumReferences() >= 3355522464 /*132310.5*/) goto t191_n198;
  t191_n183: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n185;
  t191_n184: return 0.021107885986566544;
  t191_n185: if (E.getNumReferences() >= 3354462528 /*123410.5*/) goto t191_n189;
  t191_n186: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t191_n188;
  t191_n187: return 0.07799927890300751;
  t191_n188: return -0.15191099047660828;
  t191_n189: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n193;
  t191_n190: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t191_n192;
  t191_n191: return 0.12747874855995178;
  t191_n192: return 0.06448664516210556;
  t191_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t191_n195;
  t191_n194: return 0.10095318406820297;
  t191_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t191_n197;
  t191_n196: return 0.1262647956609726;
  t191_n197: return 0.10274937003850937;
  t191_n198: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n200;
  t191_n199: return -0.03739601746201515;
  t191_n200: return -0.19775372743606567;
  t191_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t191_n237;
  t191_n202: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t191_n222;
  t191_n203: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t191_n211;
  t191_n204: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n206;
  t191_n205: return 0.013070895336568356;
  t191_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n210;
  t191_n207: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t191_n209;
  t191_n208: return 0.10744226723909378;
  t191_n209: return 0.0478372685611248;
  t191_n210: return -1.3042317628860474;
  t191_n211: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t191_n219;
  t191_n212: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t191_n218;
  t191_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t191_n217;
  t191_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n216;
  t191_n215: return 0.08982595056295395;
  t191_n216: return 0.04053816571831703;
  t191_n217: return 0.029036905616521835;
  t191_n218: return 0.03832484409213066;
  t191_n219: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t191_n221;
  t191_n220: return 0.05669360235333443;
  t191_n221: return 0.026679454371333122;
  t191_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t191_n224;
  t191_n223: return -0.0033540658187121153;
  t191_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t191_n234;
  t191_n225: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t191_n227;
  t191_n226: return 0.08456474542617798;
  t191_n227: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t191_n231;
  t191_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t191_n230;
  t191_n229: return 0.6775498986244202;
  t191_n230: return 0.07983196526765823;
  t191_n231: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t191_n233;
  t191_n232: return -0.17591996490955353;
  t191_n233: return 0.12831269204616547;
  t191_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t191_n236;
  t191_n235: return 0.01603144034743309;
  t191_n236: return 0.05436353012919426;
  t191_n237: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t191_n239;
  t191_n238: return 0.03816407918930054;
  t191_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t191_n241;
  t191_n240: return 0.10568984597921371;
  t191_n241: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t191_n243;
  t191_n242: return 0.050334036350250244;
  t191_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t191_n245;
  t191_n244: return -0.10907211154699326;
  t191_n245: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t191_n247;
  t191_n246: return 0.09463946521282196;
  t191_n247: return -0.042006660252809525;
  t191_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t191_n250;
  t191_n249: return -0.007834178395569324;
  t191_n250: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t191_n254;
  t191_n251: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t191_n253;
  t191_n252: return -0.20064540207386017;
  t191_n253: return -0.9632329940795898;
  t191_n254: return 0.018861528486013412;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree192(const Example& E) {
  t192_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t192_n248;
  t192_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t192_n247;
  t192_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t192_n4;
  t192_n3: return -0.005058130715042353;
  t192_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t192_n94;
  t192_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n93;
  t192_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t192_n80;
  t192_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t192_n33;
  t192_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t192_n20;
  t192_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n13;
  t192_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t192_n12;
  t192_n11: return -0.00613399175927043;
  t192_n12: return 0.03566127270460129;
  t192_n13: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t192_n15;
  t192_n14: return -0.06037995219230652;
  t192_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t192_n17;
  t192_n16: return 0.03376639261841774;
  t192_n17: if (E.getNumReferences() >= 3267100672 /*94.0*/) goto t192_n19;
  t192_n18: return -0.0016804623883217573;
  t192_n19: return -0.2800658941268921;
  t192_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n24;
  t192_n21: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t192_n23;
  t192_n22: return -0.12691952288150787;
  t192_n23: return 0.004207911901175976;
  t192_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t192_n26;
  t192_n25: return 0.009061528369784355;
  t192_n26: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t192_n32;
  t192_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t192_n29;
  t192_n28: return -0.057658858597278595;
  t192_n29: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n31;
  t192_n30: return 0.11620324105024338;
  t192_n31: return -0.41931089758872986;
  t192_n32: return -0.07376749813556671;
  t192_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t192_n43;
  t192_n34: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t192_n36;
  t192_n35: return -0.009450907818973064;
  t192_n36: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t192_n38;
  t192_n37: return 0.02606494538486004;
  t192_n38: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t192_n42;
  t192_n39: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t192_n41;
  t192_n40: return 0.11945576965808868;
  t192_n41: return 0.14726658165454865;
  t192_n42: return 0.12974846363067627;
  t192_n43: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t192_n45;
  t192_n44: return 0.028728563338518143;
  t192_n45: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t192_n49;
  t192_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n48;
  t192_n47: return 0.03649602830410004;
  t192_n48: return -0.1056237742304802;
  t192_n49: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t192_n75;
  t192_n50: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t192_n62;
  t192_n51: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t192_n53;
  t192_n52: return 0.030515681952238083;
  t192_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t192_n59;
  t192_n54: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t192_n58;
  t192_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n57;
  t192_n56: return 0.09298670291900635;
  t192_n57: return -0.04184556007385254;
  t192_n58: return 0.12801535427570343;
  t192_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t192_n61;
  t192_n60: return -0.7331138849258423;
  t192_n61: return 0.12329622358083725;
  t192_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t192_n72;
  t192_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n65;
  t192_n64: return -0.003094401676207781;
  t192_n65: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t192_n71;
  t192_n66: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t192_n70;
  t192_n67: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t192_n69;
  t192_n68: return 0.11422167718410492;
  t192_n69: return -0.05098200589418411;
  t192_n70: return 0.11599211394786835;
  t192_n71: return 0.10658109933137894;
  t192_n72: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t192_n74;
  t192_n73: return 0.11293022334575653;
  t192_n74: return 0.05023809149861336;
  t192_n75: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t192_n77;
  t192_n76: return -0.08128846436738968;
  t192_n77: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t192_n79;
  t192_n78: return 0.12907543778419495;
  t192_n79: return -0.00042185778147540987;
  t192_n80: if (E.getNumReferences() >= 3281272832 /*296.5*/) goto t192_n82;
  t192_n81: return 0.001643267460167408;
  t192_n82: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t192_n90;
  t192_n83: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t192_n87;
  t192_n84: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t192_n86;
  t192_n85: return -0.22044648230075836;
  t192_n86: return 0.11736618727445602;
  t192_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t192_n89;
  t192_n88: return 0.11813759058713913;
  t192_n89: return 0.11328981071710587;
  t192_n90: if (E.getNumReferences() >= 3281502208 /*303.5*/) goto t192_n92;
  t192_n91: return 0.16327694058418274;
  t192_n92: return 0.016557427123188972;
  t192_n93: return 0.008196642622351646;
  t192_n94: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t192_n152;
  t192_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t192_n97;
  t192_n96: return -0.004184075631201267;
  t192_n97: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t192_n129;
  t192_n98: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t192_n122;
  t192_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t192_n101;
  t192_n100: return 0.025623047724366188;
  t192_n101: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t192_n103;
  t192_n102: return 0.009853770025074482;
  t192_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n121;
  t192_n104: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t192_n112;
  t192_n105: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n111;
  t192_n106: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t192_n108;
  t192_n107: return 0.05036367475986481;
  t192_n108: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t192_n110;
  t192_n109: return 0.11367261409759521;
  t192_n110: return -0.1193108856678009;
  t192_n111: return 0.04109983891248703;
  t192_n112: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t192_n116;
  t192_n113: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n115;
  t192_n114: return 0.08156633377075195;
  t192_n115: return 0.01124223880469799;
  t192_n116: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t192_n118;
  t192_n117: return 0.08242727071046829;
  t192_n118: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t192_n120;
  t192_n119: return 0.11813835054636002;
  t192_n120: return -0.09957332164049149;
  t192_n121: return -0.1882905662059784;
  t192_n122: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t192_n124;
  t192_n123: return -0.060169391334056854;
  t192_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t192_n126;
  t192_n125: return 0.08576332032680511;
  t192_n126: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n128;
  t192_n127: return 0.1754177063703537;
  t192_n128: return -0.10819359123706818;
  t192_n129: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t192_n151;
  t192_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t192_n132;
  t192_n131: return -0.011524293571710587;
  t192_n132: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n150;
  t192_n133: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t192_n139;
  t192_n134: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t192_n136;
  t192_n135: return -0.41252630949020386;
  t192_n136: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n138;
  t192_n137: return 0.13301971554756165;
  t192_n138: return -0.14530865848064423;
  t192_n139: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t192_n149;
  t192_n140: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t192_n144;
  t192_n141: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t192_n143;
  t192_n142: return 0.08467915654182434;
  t192_n143: return -1.2583636045455933;
  t192_n144: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t192_n148;
  t192_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t192_n147;
  t192_n146: return 0.11409997195005417;
  t192_n147: return 0.12720003724098206;
  t192_n148: return 0.0740944892168045;
  t192_n149: return 0.04990680515766144;
  t192_n150: return -0.04610450565814972;
  t192_n151: return -0.07510194927453995;
  t192_n152: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n168;
  t192_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t192_n161;
  t192_n154: if (E.getNumReferences() >= 3274932224 /*179.5*/) goto t192_n160;
  t192_n155: if (E.getNumReferences() >= 3274473472 /*172.5*/) goto t192_n157;
  t192_n156: return -0.043129242956638336;
  t192_n157: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t192_n159;
  t192_n158: return -0.15889328718185425;
  t192_n159: return 0.11775092780590057;
  t192_n160: return -0.11866634339094162;
  t192_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t192_n165;
  t192_n162: if (E.getNumReferences() >= 3301953536 /*1662.5*/) goto t192_n164;
  t192_n163: return -0.0035083331167697906;
  t192_n164: return -0.1678009182214737;
  t192_n165: if (E.getNumReferences() >= 3305947136 /*2252.0*/) goto t192_n167;
  t192_n166: return 0.02170334756374359;
  t192_n167: return 0.14553318917751312;
  t192_n168: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t192_n246;
  t192_n169: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t192_n171;
  t192_n170: return 0.027214914560317993;
  t192_n171: if (E.getNumReferences() >= 3275194368 /*183.5*/) goto t192_n207;
  t192_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t192_n180;
  t192_n173: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t192_n179;
  t192_n174: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t192_n176;
  t192_n175: return 0.044026292860507965;
  t192_n176: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t192_n178;
  t192_n177: return -0.22968271374702454;
  t192_n178: return 0.13097618520259857;
  t192_n179: return 0.05822465941309929;
  t192_n180: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t192_n206;
  t192_n181: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t192_n203;
  t192_n182: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t192_n186;
  t192_n183: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t192_n185;
  t192_n184: return 0.1205490455031395;
  t192_n185: return 0.025382783263921738;
  t192_n186: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t192_n200;
  t192_n187: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t192_n199;
  t192_n188: if (E.getNumReferences() >= 3272376320 /*140.5*/) goto t192_n196;
  t192_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n191;
  t192_n190: return 0.055356092751026154;
  t192_n191: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t192_n195;
  t192_n192: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t192_n194;
  t192_n193: return 0.15158231556415558;
  t192_n194: return 0.130523219704628;
  t192_n195: return -0.20072995126247406;
  t192_n196: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t192_n198;
  t192_n197: return -0.12597578763961792;
  t192_n198: return 0.12087619304656982;
  t192_n199: return 0.014120208099484444;
  t192_n200: if (E.getNumReferences() >= 3274768384 /*177.0*/) goto t192_n202;
  t192_n201: return 0.12700727581977844;
  t192_n202: return 0.2203044295310974;
  t192_n203: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t192_n205;
  t192_n204: return -0.24623745679855347;
  t192_n205: return 0.13763149082660675;
  t192_n206: return 0.103324756026268;
  t192_n207: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t192_n245;
  t192_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t192_n236;
  t192_n209: if (E.getNumReferences() >= 3288203264 /*508.0*/) goto t192_n217;
  t192_n210: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t192_n212;
  t192_n211: return -0.05964173376560211;
  t192_n212: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t192_n216;
  t192_n213: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t192_n215;
  t192_n214: return 0.09715889394283295;
  t192_n215: return -0.1021253913640976;
  t192_n216: return 0.05727195367217064;
  t192_n217: if (E.getNumReferences() >= 3288522752 /*523.5*/) goto t192_n219;
  t192_n218: return 0.13620926439762115;
  t192_n219: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t192_n229;
  t192_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t192_n222;
  t192_n221: return -0.07127343118190765;
  t192_n222: if (E.getNumReferences() >= 3301138432 /*1563.0*/) goto t192_n228;
  t192_n223: if (E.getNumReferences() >= 3290349568 /*635.0*/) goto t192_n225;
  t192_n224: return 0.10288025438785553;
  t192_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n227;
  t192_n226: return 0.21584507822990417;
  t192_n227: return 0.10873010754585266;
  t192_n228: return -0.45337194204330444;
  t192_n229: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t192_n231;
  t192_n230: return 0.020763220265507698;
  t192_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t192_n233;
  t192_n232: return 0.043851085007190704;
  t192_n233: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t192_n235;
  t192_n234: return 0.12003874778747559;
  t192_n235: return 0.04801009222865105;
  t192_n236: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t192_n238;
  t192_n237: return 0.10408541560173035;
  t192_n238: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t192_n244;
  t192_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t192_n243;
  t192_n240: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t192_n242;
  t192_n241: return 0.11372073739767075;
  t192_n242: return -0.10468878597021103;
  t192_n243: return 0.06941788643598557;
  t192_n244: return -0.04156972095370293;
  t192_n245: return 0.0008257080335170031;
  t192_n246: return 0.006880785804241896;
  t192_n247: return -0.0011985574383288622;
  t192_n248: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t192_n250;
  t192_n249: return 0.01133088767528534;
  t192_n250: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t192_n254;
  t192_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t192_n253;
  t192_n252: return 0.061664432287216187;
  t192_n253: return 0.11273857206106186;
  t192_n254: return 0.0015382132260128856;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree193(const Example& E) {
  t193_n0: if (E.getNumReferences() >= 3305437184 /*2127.5*/) goto t193_n94;
  t193_n1: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t193_n93;
  t193_n2: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t193_n4;
  t193_n3: return -0.004858333617448807;
  t193_n4: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t193_n16;
  t193_n5: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n15;
  t193_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t193_n14;
  t193_n7: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t193_n13;
  t193_n8: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t193_n12;
  t193_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n11;
  t193_n10: return 0.03165510296821594;
  t193_n11: return 0.003599967574700713;
  t193_n12: return 0.019517920911312103;
  t193_n13: return 0.001957952743396163;
  t193_n14: return 0.0052179801277816296;
  t193_n15: return -0.0012109772069379687;
  t193_n16: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t193_n90;
  t193_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t193_n85;
  t193_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t193_n70;
  t193_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t193_n69;
  t193_n20: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t193_n50;
  t193_n21: if (E.getNumReferences() >= 3286056960 /*442.5*/) goto t193_n23;
  t193_n22: return 0.018452517688274384;
  t193_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t193_n37;
  t193_n24: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t193_n36;
  t193_n25: if (E.getNumReferences() >= 3288621056 /*529.5*/) goto t193_n35;
  t193_n26: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t193_n34;
  t193_n27: if (E.getNumReferences() >= 3286269952 /*449.0*/) goto t193_n29;
  t193_n28: return 0.13702835142612457;
  t193_n29: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t193_n31;
  t193_n30: return 0.031929899007081985;
  t193_n31: if (E.getNumReferences() >= 3288285184 /*510.5*/) goto t193_n33;
  t193_n32: return 0.10875625908374786;
  t193_n33: return -0.1890048235654831;
  t193_n34: return 0.11262300610542297;
  t193_n35: return 0.051663901656866074;
  t193_n36: return -0.011222929693758488;
  t193_n37: if (E.getNumReferences() >= 3289546752 /*586.0*/) goto t193_n39;
  t193_n38: return -0.13718825578689575;
  t193_n39: if (E.getNumReferences() >= 3293749248 /*842.5*/) goto t193_n47;
  t193_n40: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t193_n46;
  t193_n41: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t193_n45;
  t193_n42: if (E.getNumReferences() >= 3290275840 /*630.5*/) goto t193_n44;
  t193_n43: return 0.1652265340089798;
  t193_n44: return 0.09564634412527084;
  t193_n45: return -0.28643354773521423;
  t193_n46: return 0.13100850582122803;
  t193_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n49;
  t193_n48: return -0.2576806843280792;
  t193_n49: return 0.09891107678413391;
  t193_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t193_n54;
  t193_n51: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t193_n53;
  t193_n52: return 0.20588472485542297;
  t193_n53: return 0.06905611604452133;
  t193_n54: if (E.getNumReferences() >= 3289186304 /*564.0*/) goto t193_n64;
  t193_n55: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t193_n63;
  t193_n56: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t193_n62;
  t193_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t193_n59;
  t193_n58: return 0.07827695459127426;
  t193_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n61;
  t193_n60: return 0.10442449897527695;
  t193_n61: return 0.08665504306554794;
  t193_n62: return 0.13092373311519623;
  t193_n63: return 0.03388834744691849;
  t193_n64: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t193_n68;
  t193_n65: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t193_n67;
  t193_n66: return 0.13375291228294373;
  t193_n67: return 0.13017529249191284;
  t193_n68: return 0.04212208837270737;
  t193_n69: return 0.02533922903239727;
  t193_n70: if (E.getNumReferences() >= 3268083712 /*101.5*/) goto t193_n84;
  t193_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t193_n79;
  t193_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t193_n78;
  t193_n73: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n75;
  t193_n74: return -0.25310996174812317;
  t193_n75: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t193_n77;
  t193_n76: return 0.03888333588838577;
  t193_n77: return 0.10205201059579849;
  t193_n78: return 0.1124652847647667;
  t193_n79: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t193_n81;
  t193_n80: return 0.11262576282024384;
  t193_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t193_n83;
  t193_n82: return -1.4089674949645996;
  t193_n83: return 0.11370135843753815;
  t193_n84: return -0.01406221091747284;
  t193_n85: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t193_n89;
  t193_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t193_n88;
  t193_n87: return 0.024397965520620346;
  t193_n88: return 0.11638416349887848;
  t193_n89: return 0.04981774091720581;
  t193_n90: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t193_n92;
  t193_n91: return -0.12322156131267548;
  t193_n92: return 0.0036041205748915672;
  t193_n93: return -0.0010796734131872654;
  t193_n94: if (E.getNumReferences() >= 3305449472 /*2130.5*/) goto t193_n100;
  t193_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t193_n99;
  t193_n96: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n98;
  t193_n97: return -0.06177400425076485;
  t193_n98: return 0.10336799174547195;
  t193_n99: return 0.18173529207706451;
  t193_n100: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t193_n254;
  t193_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t193_n103;
  t193_n102: return 0.008004298433661461;
  t193_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t193_n245;
  t193_n104: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t193_n180;
  t193_n105: if (E.getNumReferences() >= 3344355328 /*54992.0*/) goto t193_n167;
  t193_n106: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t193_n164;
  t193_n107: if (E.getNumReferences() >= 3315905536 /*5270.5*/) goto t193_n109;
  t193_n108: return 0.008593929931521416;
  t193_n109: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t193_n143;
  t193_n110: if (E.getNumReferences() >= 3338025472 /*31517.0*/) goto t193_n142;
  t193_n111: if (E.getNumReferences() >= 3333053952 /*21807.0*/) goto t193_n135;
  t193_n112: if (E.getNumReferences() >= 3323087872 /*9363.0*/) goto t193_n132;
  t193_n113: if (E.getNumReferences() >= 3319356416 /*6955.5*/) goto t193_n117;
  t193_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t193_n116;
  t193_n115: return 0.007101776078343391;
  t193_n116: return 0.10593409091234207;
  t193_n117: if (E.getNumReferences() >= 3319490560 /*7021.0*/) goto t193_n119;
  t193_n118: return 0.11515478789806366;
  t193_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n129;
  t193_n120: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n122;
  t193_n121: return 0.09175771474838257;
  t193_n122: if (E.getNumReferences() >= 3322365952 /*8658.0*/) goto t193_n128;
  t193_n123: if (E.getNumReferences() >= 3321624576 /*8063.0*/) goto t193_n127;
  t193_n124: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t193_n126;
  t193_n125: return 0.26574188470840454;
  t193_n126: return 0.14569279551506042;
  t193_n127: return -0.2929460108280182;
  t193_n128: return 0.1066553145647049;
  t193_n129: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t193_n131;
  t193_n130: return 0.0036769118160009384;
  t193_n131: return 0.113920196890831;
  t193_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t193_n134;
  t193_n133: return 0.008368638344109058;
  t193_n134: return 0.1072646751999855;
  t193_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n141;
  t193_n136: if (E.getNumReferences() >= 3333945600 /*23548.5*/) goto t193_n140;
  t193_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n139;
  t193_n138: return 0.13865351676940918;
  t193_n139: return 0.09630802273750305;
  t193_n140: return 0.1598517745733261;
  t193_n141: return 0.0219232439994812;
  t193_n142: return -0.021430589258670807;
  t193_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t193_n161;
  t193_n144: if (E.getNumReferences() >= 3316411392 /*5517.5*/) goto t193_n158;
  t193_n145: if (E.getNumReferences() >= 3316164608 /*5397.0*/) goto t193_n147;
  t193_n146: return 0.0649038553237915;
  t193_n147: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t193_n151;
  t193_n148: if (E.getNumReferences() >= 3316251648 /*5439.5*/) goto t193_n150;
  t193_n149: return -0.35428622364997864;
  t193_n150: return 0.17470704019069672;
  t193_n151: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t193_n155;
  t193_n152: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n154;
  t193_n153: return 0.10384680330753326;
  t193_n154: return 0.0044473265297710896;
  t193_n155: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n157;
  t193_n156: return -0.05688447505235672;
  t193_n157: return 0.36475348472595215;
  t193_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t193_n160;
  t193_n159: return 0.017685119062662125;
  t193_n160: return 0.08197662979364395;
  t193_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n163;
  t193_n162: return 0.06469163298606873;
  t193_n163: return 0.024469753727316856;
  t193_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n166;
  t193_n165: return 0.0941537544131279;
  t193_n166: return 0.07090941816568375;
  t193_n167: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n179;
  t193_n168: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t193_n178;
  t193_n169: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n171;
  t193_n170: return 0.32559195160865784;
  t193_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t193_n173;
  t193_n172: return 0.2889363765716553;
  t193_n173: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n177;
  t193_n174: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t193_n176;
  t193_n175: return 0.08310974389314651;
  t193_n176: return 0.17251452803611755;
  t193_n177: return 0.10494682192802429;
  t193_n178: return 0.12919363379478455;
  t193_n179: return -0.0019593392498791218;
  t193_n180: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t193_n204;
  t193_n181: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t193_n193;
  t193_n182: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t193_n188;
  t193_n183: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t193_n185;
  t193_n184: return -0.09529290348291397;
  t193_n185: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t193_n187;
  t193_n186: return 0.1309811770915985;
  t193_n187: return 0.1297673135995865;
  t193_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t193_n192;
  t193_n189: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t193_n191;
  t193_n190: return -0.11187467724084854;
  t193_n191: return -0.388019323348999;
  t193_n192: return -0.09357279539108276;
  t193_n193: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t193_n199;
  t193_n194: if (E.getNumReferences() >= 3346400000 /*62979.0*/) goto t193_n196;
  t193_n195: return 0.054909732192754745;
  t193_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t193_n198;
  t193_n197: return -0.5471099019050598;
  t193_n198: return 0.06677157431840897;
  t193_n199: if (E.getNumReferences() >= 3346792960 /*64514.0*/) goto t193_n203;
  t193_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n202;
  t193_n201: return 0.11998046934604645;
  t193_n202: return 0.13407769799232483;
  t193_n203: return 0.052608389407396317;
  t193_n204: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t193_n232;
  t193_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t193_n229;
  t193_n206: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n210;
  t193_n207: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t193_n209;
  t193_n208: return 0.006277697626501322;
  t193_n209: return 0.12997406721115112;
  t193_n210: if (E.getNumReferences() >= 3350280192 /*90736.0*/) goto t193_n224;
  t193_n211: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t193_n213;
  t193_n212: return 0.0419568195939064;
  t193_n213: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t193_n219;
  t193_n214: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t193_n218;
  t193_n215: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n217;
  t193_n216: return 0.16471201181411743;
  t193_n217: return 0.043301377445459366;
  t193_n218: return 0.04496099427342415;
  t193_n219: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t193_n223;
  t193_n220: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t193_n222;
  t193_n221: return 0.1485464721918106;
  t193_n222: return 0.03838992491364479;
  t193_n223: return 0.09733376652002335;
  t193_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t193_n226;
  t193_n225: return 0.01492098905146122;
  t193_n226: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n228;
  t193_n227: return 0.11523889005184174;
  t193_n228: return 0.035681869834661484;
  t193_n229: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t193_n231;
  t193_n230: return 0.12678831815719604;
  t193_n231: return -0.4385615885257721;
  t193_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t193_n236;
  t193_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t193_n235;
  t193_n234: return -0.397688627243042;
  t193_n235: return -0.016423799097537994;
  t193_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t193_n238;
  t193_n237: return -0.6179294586181641;
  t193_n238: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t193_n240;
  t193_n239: return 0.009598036296665668;
  t193_n240: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t193_n242;
  t193_n241: return 0.09032092243432999;
  t193_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t193_n244;
  t193_n243: return 0.10687128454446793;
  t193_n244: return 0.11600559204816818;
  t193_n245: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t193_n253;
  t193_n246: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t193_n248;
  t193_n247: return -0.2232036292552948;
  t193_n248: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t193_n250;
  t193_n249: return 0.0880771204829216;
  t193_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t193_n252;
  t193_n251: return 0.1302260309457779;
  t193_n252: return 0.1379508227109909;
  t193_n253: return -0.03742384910583496;
  t193_n254: return 0.0011737266322597861;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree194(const Example& E) {
  t194_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t194_n2;
  t194_n1: return -0.00019983640231657773;
  t194_n2: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t194_n16;
  t194_n3: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n11;
  t194_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n6;
  t194_n5: return -0.08208077400922775;
  t194_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n10;
  t194_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t194_n9;
  t194_n8: return -0.1651926040649414;
  t194_n9: return 0.09269054234027863;
  t194_n10: return -0.22825689613819122;
  t194_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t194_n13;
  t194_n12: return 0.08598381280899048;
  t194_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n15;
  t194_n14: return 0.11682868748903275;
  t194_n15: return 0.12008219212293625;
  t194_n16: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t194_n18;
  t194_n17: return -0.0033836415968835354;
  t194_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t194_n254;
  t194_n19: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t194_n253;
  t194_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t194_n224;
  t194_n21: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t194_n147;
  t194_n22: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t194_n134;
  t194_n23: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t194_n111;
  t194_n24: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t194_n28;
  t194_n25: if (E.getNumReferences() >= 3342114944 /*46240.5*/) goto t194_n27;
  t194_n26: return -0.04168703034520149;
  t194_n27: return 0.02388695627450943;
  t194_n28: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n30;
  t194_n29: return 0.002988257445394993;
  t194_n30: if (E.getNumReferences() >= 3357271616 /*159641.0*/) goto t194_n110;
  t194_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t194_n35;
  t194_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n34;
  t194_n33: return -0.040469054132699966;
  t194_n34: return 0.02369603142142296;
  t194_n35: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t194_n41;
  t194_n36: if (E.getNumReferences() >= 3342384640 /*47294.0*/) goto t194_n40;
  t194_n37: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t194_n39;
  t194_n38: return 0.05883493646979332;
  t194_n39: return -0.05454319342970848;
  t194_n40: return -0.15411528944969177;
  t194_n41: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t194_n59;
  t194_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t194_n52;
  t194_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t194_n45;
  t194_n44: return -0.026482069864869118;
  t194_n45: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t194_n51;
  t194_n46: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t194_n50;
  t194_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n49;
  t194_n48: return 0.08752357959747314;
  t194_n49: return 0.20673176646232605;
  t194_n50: return 0.10061877965927124;
  t194_n51: return 0.0059186615981161594;
  t194_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n54;
  t194_n53: return -0.2313915193080902;
  t194_n54: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n58;
  t194_n55: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t194_n57;
  t194_n56: return 0.1400034874677658;
  t194_n57: return 0.12456391006708145;
  t194_n58: return -0.1403139978647232;
  t194_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n87;
  t194_n60: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t194_n64;
  t194_n61: if (E.getNumReferences() >= 3344816512 /*56793.5*/) goto t194_n63;
  t194_n62: return 0.06583459675312042;
  t194_n63: return -0.043955761939287186;
  t194_n64: if (E.getNumReferences() >= 3348327104 /*75477.5*/) goto t194_n68;
  t194_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t194_n67;
  t194_n66: return -0.08392040431499481;
  t194_n67: return 0.09558363258838654;
  t194_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t194_n70;
  t194_n69: return 0.024777621030807495;
  t194_n70: if (E.getNumReferences() >= 3348704768 /*78428.0*/) goto t194_n74;
  t194_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t194_n73;
  t194_n72: return -0.24804255366325378;
  t194_n73: return 0.12178853154182434;
  t194_n74: if (E.getNumReferences() >= 3351182400 /*97784.5*/) goto t194_n76;
  t194_n75: return -0.08498827368021011;
  t194_n76: if (E.getNumReferences() >= 3352208768 /*105803.0*/) goto t194_n86;
  t194_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n85;
  t194_n78: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t194_n84;
  t194_n79: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t194_n83;
  t194_n80: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n82;
  t194_n81: return 0.11728794872760773;
  t194_n82: return 0.09277079254388809;
  t194_n83: return -0.20901842415332794;
  t194_n84: return 0.10076658427715302;
  t194_n85: return -0.855132520198822;
  t194_n86: return 0.12799373269081116;
  t194_n87: if (E.getNumReferences() >= 3346307456 /*62617.5*/) goto t194_n101;
  t194_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t194_n90;
  t194_n89: return -0.2526993453502655;
  t194_n90: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n100;
  t194_n91: if (E.getNumReferences() >= 3345907328 /*61054.5*/) goto t194_n93;
  t194_n92: return -0.13284660875797272;
  t194_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n95;
  t194_n94: return 0.17153699696063995;
  t194_n95: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t194_n99;
  t194_n96: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t194_n98;
  t194_n97: return 0.18850000202655792;
  t194_n98: return 0.1693594753742218;
  t194_n99: return 0.07538644969463348;
  t194_n100: return 0.05928987264633179;
  t194_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t194_n103;
  t194_n102: return 0.014430047944188118;
  t194_n103: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t194_n109;
  t194_n104: if (E.getNumReferences() >= 3353034176 /*112251.5*/) goto t194_n108;
  t194_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n107;
  t194_n106: return 0.08924288302659988;
  t194_n107: return 0.012296284548938274;
  t194_n108: return -0.4121106266975403;
  t194_n109: return 0.09189702570438385;
  t194_n110: return -0.24673616886138916;
  t194_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n121;
  t194_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n114;
  t194_n113: return 0.03835234045982361;
  t194_n114: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n118;
  t194_n115: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t194_n117;
  t194_n116: return -0.17351655662059784;
  t194_n117: return 0.12438300251960754;
  t194_n118: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t194_n120;
  t194_n119: return 0.04568135738372803;
  t194_n120: return 0.10678915679454803;
  t194_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n125;
  t194_n122: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n124;
  t194_n123: return 0.04456792771816254;
  t194_n124: return 0.08565351366996765;
  t194_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n131;
  t194_n126: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t194_n130;
  t194_n127: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t194_n129;
  t194_n128: return 0.11099665611982346;
  t194_n129: return 0.10573211312294006;
  t194_n130: return -0.11822674423456192;
  t194_n131: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t194_n133;
  t194_n132: return 0.07853665947914124;
  t194_n133: return -0.21691080927848816;
  t194_n134: if (E.getNumReferences() >= 3344576000 /*55854.0*/) goto t194_n146;
  t194_n135: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t194_n137;
  t194_n136: return 0.015231349505484104;
  t194_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t194_n139;
  t194_n138: return 0.08137481659650803;
  t194_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n141;
  t194_n140: return 0.3541710078716278;
  t194_n141: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t194_n143;
  t194_n142: return 0.11716797947883606;
  t194_n143: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n145;
  t194_n144: return 0.16105054318904877;
  t194_n145: return 0.0917062908411026;
  t194_n146: return -0.030056888237595558;
  t194_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t194_n191;
  t194_n148: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t194_n184;
  t194_n149: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t194_n155;
  t194_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t194_n152;
  t194_n151: return -0.15346308052539825;
  t194_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t194_n154;
  t194_n153: return 0.04351089522242546;
  t194_n154: return 0.11889557540416718;
  t194_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n181;
  t194_n156: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t194_n176;
  t194_n157: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t194_n175;
  t194_n158: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t194_n164;
  t194_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t194_n161;
  t194_n160: return -0.030195197090506554;
  t194_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n163;
  t194_n162: return 0.04962644726037979;
  t194_n163: return 0.09954150766134262;
  t194_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t194_n168;
  t194_n165: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t194_n167;
  t194_n166: return 0.032173383980989456;
  t194_n167: return 0.07502651959657669;
  t194_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t194_n170;
  t194_n169: return 0.030098095536231995;
  t194_n170: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t194_n174;
  t194_n171: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t194_n173;
  t194_n172: return 0.1060318574309349;
  t194_n173: return -0.047908537089824677;
  t194_n174: return 0.022969216108322144;
  t194_n175: return 0.017065171152353287;
  t194_n176: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t194_n180;
  t194_n177: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n179;
  t194_n178: return -0.6762242317199707;
  t194_n179: return -0.03980272635817528;
  t194_n180: return 0.06229858100414276;
  t194_n181: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t194_n183;
  t194_n182: return -0.23938989639282227;
  t194_n183: return 0.04925679415464401;
  t194_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t194_n186;
  t194_n185: return -0.0031563127413392067;
  t194_n186: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t194_n188;
  t194_n187: return 1.0757086277008057;
  t194_n188: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t194_n190;
  t194_n189: return 0.026735633611679077;
  t194_n190: return 0.062900610268116;
  t194_n191: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t194_n219;
  t194_n192: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t194_n218;
  t194_n193: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t194_n195;
  t194_n194: return 0.06948653608560562;
  t194_n195: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t194_n197;
  t194_n196: return -0.10629314184188843;
  t194_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t194_n199;
  t194_n198: return -0.11296004801988602;
  t194_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n215;
  t194_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t194_n204;
  t194_n201: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t194_n203;
  t194_n202: return 0.10805914551019669;
  t194_n203: return -0.35275357961654663;
  t194_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t194_n208;
  t194_n205: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t194_n207;
  t194_n206: return 0.013573933392763138;
  t194_n207: return 0.10425090789794922;
  t194_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t194_n212;
  t194_n209: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t194_n211;
  t194_n210: return -0.1662767082452774;
  t194_n211: return 0.10465323179960251;
  t194_n212: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t194_n214;
  t194_n213: return 0.09005101025104523;
  t194_n214: return 0.06335301697254181;
  t194_n215: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t194_n217;
  t194_n216: return 0.05063067376613617;
  t194_n217: return -0.051741670817136765;
  t194_n218: return -0.06455900520086288;
  t194_n219: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t194_n221;
  t194_n220: return 0.08961034566164017;
  t194_n221: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t194_n223;
  t194_n222: return 0.0987483561038971;
  t194_n223: return 0.0890997126698494;
  t194_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t194_n226;
  t194_n225: return -0.03466985374689102;
  t194_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t194_n232;
  t194_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t194_n229;
  t194_n228: return 0.021840322762727737;
  t194_n229: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t194_n231;
  t194_n230: return -0.1121353805065155;
  t194_n231: return 0.11427861452102661;
  t194_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t194_n248;
  t194_n233: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t194_n247;
  t194_n234: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t194_n246;
  t194_n235: if (E.getNumReferences() >= 3344186496 /*54332.5*/) goto t194_n237;
  t194_n236: return 0.17520132660865784;
  t194_n237: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t194_n245;
  t194_n238: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t194_n242;
  t194_n239: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t194_n241;
  t194_n240: return 0.10776357352733612;
  t194_n241: return -0.11702004820108414;
  t194_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n244;
  t194_n243: return -0.22364374995231628;
  t194_n244: return 0.13011938333511353;
  t194_n245: return -0.2587938904762268;
  t194_n246: return 0.003173365956172347;
  t194_n247: return 0.1246781274676323;
  t194_n248: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t194_n252;
  t194_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t194_n251;
  t194_n250: return 0.11432109773159027;
  t194_n251: return 0.009755976498126984;
  t194_n252: return -0.12152841687202454;
  t194_n253: return -0.0025130624417215586;
  t194_n254: return -0.024799969047307968;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree195(const Example& E) {
  t195_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t195_n134;
  t195_n1: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t195_n3;
  t195_n2: return -0.0006172988214530051;
  t195_n3: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t195_n133;
  t195_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t195_n54;
  t195_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t195_n13;
  t195_n6: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t195_n10;
  t195_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n9;
  t195_n8: return 0.020500464364886284;
  t195_n9: return 0.08450008928775787;
  t195_n10: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t195_n12;
  t195_n11: return -0.056454602628946304;
  t195_n12: return -0.24142427742481232;
  t195_n13: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t195_n43;
  t195_n14: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t195_n30;
  t195_n15: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t195_n17;
  t195_n16: return -0.03996129333972931;
  t195_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n19;
  t195_n18: return -0.10816345363855362;
  t195_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n29;
  t195_n20: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t195_n24;
  t195_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n23;
  t195_n22: return -0.14260683953762054;
  t195_n23: return 0.13651694357395172;
  t195_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t195_n28;
  t195_n25: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t195_n27;
  t195_n26: return 0.03510245308279991;
  t195_n27: return 0.10562148690223694;
  t195_n28: return 0.12317927181720734;
  t195_n29: return 0.09791732579469681;
  t195_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n32;
  t195_n31: return -0.19367320835590363;
  t195_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n34;
  t195_n33: return 0.048885297030210495;
  t195_n34: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t195_n42;
  t195_n35: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t195_n37;
  t195_n36: return -0.0731210708618164;
  t195_n37: if (E.getNumReferences() >= 3342301952 /*46971.0*/) goto t195_n41;
  t195_n38: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n40;
  t195_n39: return 0.1583280861377716;
  t195_n40: return 0.05351124331355095;
  t195_n41: return -0.03362833708524704;
  t195_n42: return 0.10337208956480026;
  t195_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n47;
  t195_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n46;
  t195_n45: return -0.161595419049263;
  t195_n46: return 0.13473336398601532;
  t195_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n53;
  t195_n48: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t195_n50;
  t195_n49: return 0.23831889033317566;
  t195_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n52;
  t195_n51: return 0.8290144801139832;
  t195_n52: return 0.10079795867204666;
  t195_n53: return 0.0917130559682846;
  t195_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n72;
  t195_n55: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t195_n71;
  t195_n56: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t195_n70;
  t195_n57: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n59;
  t195_n58: return 0.009998387657105923;
  t195_n59: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t195_n61;
  t195_n60: return 0.11208921670913696;
  t195_n61: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t195_n67;
  t195_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t195_n66;
  t195_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n65;
  t195_n64: return -0.10070250183343887;
  t195_n65: return 0.07602298259735107;
  t195_n66: return 0.015627121552824974;
  t195_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t195_n69;
  t195_n68: return 0.0744517520070076;
  t195_n69: return 0.08939715474843979;
  t195_n70: return 0.02424299716949463;
  t195_n71: return 0.031518738716840744;
  t195_n72: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t195_n120;
  t195_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t195_n77;
  t195_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n76;
  t195_n75: return -0.07079961150884628;
  t195_n76: return 0.06084238737821579;
  t195_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t195_n95;
  t195_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n80;
  t195_n79: return 0.040485452860593796;
  t195_n80: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t195_n94;
  t195_n81: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t195_n89;
  t195_n82: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t195_n88;
  t195_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n85;
  t195_n84: return 0.25069761276245117;
  t195_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n87;
  t195_n86: return -0.06424444913864136;
  t195_n87: return 0.12861306965351105;
  t195_n88: return 0.025115950033068657;
  t195_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n93;
  t195_n90: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t195_n92;
  t195_n91: return 0.13288313150405884;
  t195_n92: return 0.12030206620693207;
  t195_n93: return -0.13862648606300354;
  t195_n94: return 0.12388943880796432;
  t195_n95: if (E.getNumReferences() >= 3342583296 /*48070.0*/) goto t195_n119;
  t195_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n112;
  t195_n97: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n105;
  t195_n98: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t195_n100;
  t195_n99: return 0.13669916987419128;
  t195_n100: if (E.getNumReferences() >= 3342374144 /*47253.0*/) goto t195_n104;
  t195_n101: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t195_n103;
  t195_n102: return 0.38407155871391296;
  t195_n103: return 0.13899695873260498;
  t195_n104: return 0.11588781327009201;
  t195_n105: if (E.getNumReferences() >= 3342374144 /*47253.0*/) goto t195_n109;
  t195_n106: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t195_n108;
  t195_n107: return 0.11786416918039322;
  t195_n108: return 0.06763219088315964;
  t195_n109: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n111;
  t195_n110: return 0.11162998527288437;
  t195_n111: return 0.07196138799190521;
  t195_n112: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t195_n118;
  t195_n113: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t195_n117;
  t195_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n116;
  t195_n115: return 0.11959661543369293;
  t195_n116: return 0.055387016385793686;
  t195_n117: return 0.13574668765068054;
  t195_n118: return -0.054353199899196625;
  t195_n119: return 0.0008354012970812619;
  t195_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t195_n122;
  t195_n121: return -0.15814252197742462;
  t195_n122: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n132;
  t195_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t195_n131;
  t195_n124: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n126;
  t195_n125: return 0.5407537221908569;
  t195_n126: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t195_n128;
  t195_n127: return 0.1792319118976593;
  t195_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t195_n130;
  t195_n129: return 0.15189075469970703;
  t195_n130: return 0.14855866134166718;
  t195_n131: return -0.12554243206977844;
  t195_n132: return 0.0876900851726532;
  t195_n133: return 0.002665842417627573;
  t195_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t195_n138;
  t195_n135: if (E.getNumReferences() >= 3317625856 /*6110.5*/) goto t195_n137;
  t195_n136: return -0.0040051620453596115;
  t195_n137: return -0.1460363268852234;
  t195_n138: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t195_n254;
  t195_n139: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t195_n163;
  t195_n140: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t195_n142;
  t195_n141: return 0.005329661071300507;
  t195_n142: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t195_n154;
  t195_n143: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t195_n145;
  t195_n144: return -0.008649606257677078;
  t195_n145: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t195_n151;
  t195_n146: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t195_n150;
  t195_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t195_n149;
  t195_n148: return -0.10416405647993088;
  t195_n149: return 0.1613553911447525;
  t195_n150: return -0.07741770893335342;
  t195_n151: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t195_n153;
  t195_n152: return -0.15144631266593933;
  t195_n153: return -0.1747686117887497;
  t195_n154: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t195_n160;
  t195_n155: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t195_n159;
  t195_n156: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t195_n158;
  t195_n157: return -0.1085275337100029;
  t195_n158: return -0.6876611709594727;
  t195_n159: return 0.01360538974404335;
  t195_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t195_n162;
  t195_n161: return 0.10680165886878967;
  t195_n162: return 0.09784070402383804;
  t195_n163: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t195_n227;
  t195_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t195_n172;
  t195_n165: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t195_n167;
  t195_n166: return 0.04722859337925911;
  t195_n167: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t195_n169;
  t195_n168: return 0.012369712814688683;
  t195_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t195_n171;
  t195_n170: return 0.06883733719587326;
  t195_n171: return 0.11277304589748383;
  t195_n172: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t195_n226;
  t195_n173: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t195_n221;
  t195_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t195_n212;
  t195_n175: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t195_n211;
  t195_n176: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t195_n204;
  t195_n177: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n179;
  t195_n178: return -0.2414136826992035;
  t195_n179: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t195_n191;
  t195_n180: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t195_n188;
  t195_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t195_n183;
  t195_n182: return -0.04471200332045555;
  t195_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t195_n185;
  t195_n184: return -0.08303086459636688;
  t195_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n187;
  t195_n186: return 0.019885176792740822;
  t195_n187: return 0.12110215425491333;
  t195_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t195_n190;
  t195_n189: return 0.11420426517724991;
  t195_n190: return 0.14071716368198395;
  t195_n191: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t195_n203;
  t195_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t195_n202;
  t195_n193: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t195_n197;
  t195_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t195_n196;
  t195_n195: return 0.11166975647211075;
  t195_n196: return -0.1737750619649887;
  t195_n197: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t195_n199;
  t195_n198: return 0.11744161695241928;
  t195_n199: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t195_n201;
  t195_n200: return 0.10708120465278625;
  t195_n201: return -0.7864907383918762;
  t195_n202: return -0.09842640906572342;
  t195_n203: return -0.21680191159248352;
  t195_n204: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t195_n206;
  t195_n205: return -0.027992350980639458;
  t195_n206: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t195_n208;
  t195_n207: return -0.002110391156747937;
  t195_n208: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t195_n210;
  t195_n209: return -0.0014798172051087022;
  t195_n210: return 0.11125742644071579;
  t195_n211: return -0.016194863244891167;
  t195_n212: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t195_n216;
  t195_n213: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t195_n215;
  t195_n214: return -0.1061943992972374;
  t195_n215: return 0.08826819807291031;
  t195_n216: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t195_n220;
  t195_n217: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t195_n219;
  t195_n218: return 0.12545067071914673;
  t195_n219: return -0.01457598339766264;
  t195_n220: return -0.10726620256900787;
  t195_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t195_n223;
  t195_n222: return -0.15401563048362732;
  t195_n223: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t195_n225;
  t195_n224: return -0.27181029319763184;
  t195_n225: return -0.00790038425475359;
  t195_n226: return 0.10329015552997589;
  t195_n227: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t195_n229;
  t195_n228: return -0.2453574687242508;
  t195_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t195_n251;
  t195_n230: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t195_n234;
  t195_n231: if (E.getNumReferences() >= 3361181120 /*220727.0*/) goto t195_n233;
  t195_n232: return 0.0007717356784269214;
  t195_n233: return 0.07329950481653214;
  t195_n234: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t195_n246;
  t195_n235: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t195_n237;
  t195_n236: return -0.5161000490188599;
  t195_n237: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t195_n241;
  t195_n238: if (E.getNumReferences() >= 3332682752 /*21082.0*/) goto t195_n240;
  t195_n239: return -0.0774393305182457;
  t195_n240: return 0.1185123547911644;
  t195_n241: if (E.getNumReferences() >= 3350603008 /*93258.0*/) goto t195_n245;
  t195_n242: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t195_n244;
  t195_n243: return -2.094815492630005;
  t195_n244: return -0.0950610339641571;
  t195_n245: return 0.049426138401031494;
  t195_n246: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t195_n248;
  t195_n247: return -0.22943823039531708;
  t195_n248: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t195_n250;
  t195_n249: return -0.1995338797569275;
  t195_n250: return 0.12098591774702072;
  t195_n251: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t195_n253;
  t195_n252: return 0.017757631838321686;
  t195_n253: return -0.11667540669441223;
  t195_n254: return 0.0032919663935899734;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree196(const Example& E) {
  t196_n0: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t196_n2;
  t196_n1: return -0.00020302203483879566;
  t196_n2: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t196_n106;
  t196_n3: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t196_n75;
  t196_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t196_n38;
  t196_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t196_n23;
  t196_n6: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t196_n22;
  t196_n7: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n17;
  t196_n8: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n10;
  t196_n9: return -0.06473498046398163;
  t196_n10: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n12;
  t196_n11: return 0.03773682564496994;
  t196_n12: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t196_n14;
  t196_n13: return 0.11055511236190796;
  t196_n14: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t196_n16;
  t196_n15: return -0.23202568292617798;
  t196_n16: return 0.1104075014591217;
  t196_n17: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t196_n21;
  t196_n18: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n20;
  t196_n19: return 0.08998259902000427;
  t196_n20: return -0.09911972284317017;
  t196_n21: return -0.04168112576007843;
  t196_n22: return -0.028846880421042442;
  t196_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n37;
  t196_n24: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n34;
  t196_n25: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t196_n27;
  t196_n26: return 0.20704972743988037;
  t196_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t196_n29;
  t196_n28: return -0.10160165280103683;
  t196_n29: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t196_n31;
  t196_n30: return 0.1300160139799118;
  t196_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n33;
  t196_n32: return -0.21607011556625366;
  t196_n33: return 0.11130847036838531;
  t196_n34: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n36;
  t196_n35: return 0.10639171302318573;
  t196_n36: return 0.06595299392938614;
  t196_n37: return -0.14579825103282928;
  t196_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n40;
  t196_n39: return 0.017236748710274696;
  t196_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t196_n74;
  t196_n41: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t196_n65;
  t196_n42: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t196_n48;
  t196_n43: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t196_n47;
  t196_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n46;
  t196_n45: return 0.11491484194993973;
  t196_n46: return 0.07044640183448792;
  t196_n47: return -0.1795492023229599;
  t196_n48: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n54;
  t196_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t196_n53;
  t196_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n52;
  t196_n51: return 0.07789012044668198;
  t196_n52: return 0.06807173043489456;
  t196_n53: return -0.10378134995698929;
  t196_n54: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t196_n60;
  t196_n55: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t196_n59;
  t196_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n58;
  t196_n57: return 0.07405781745910645;
  t196_n58: return 0.035179223865270615;
  t196_n59: return 0.015036522410809994;
  t196_n60: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t196_n62;
  t196_n61: return -0.1857803910970688;
  t196_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n64;
  t196_n63: return 0.11549290269613266;
  t196_n64: return 0.10346439480781555;
  t196_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n67;
  t196_n66: return -0.03981815651059151;
  t196_n67: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n73;
  t196_n68: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t196_n70;
  t196_n69: return 0.26095864176750183;
  t196_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n72;
  t196_n71: return 0.21252192556858063;
  t196_n72: return 0.19523859024047852;
  t196_n73: return 0.08992475271224976;
  t196_n74: return 0.02266082912683487;
  t196_n75: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n81;
  t196_n76: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t196_n78;
  t196_n77: return 0.06814474612474442;
  t196_n78: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t196_n80;
  t196_n79: return -0.39089030027389526;
  t196_n80: return 0.11358156055212021;
  t196_n81: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t196_n91;
  t196_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n90;
  t196_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n85;
  t196_n84: return -0.10280397534370422;
  t196_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t196_n87;
  t196_n86: return 0.09783078730106354;
  t196_n87: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t196_n89;
  t196_n88: return 0.12498420476913452;
  t196_n89: return 0.11831815540790558;
  t196_n90: return -0.026593998074531555;
  t196_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t196_n95;
  t196_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n94;
  t196_n93: return -0.034286919981241226;
  t196_n94: return 0.09889629483222961;
  t196_n95: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t196_n97;
  t196_n96: return 0.00933017861098051;
  t196_n97: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n105;
  t196_n98: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n100;
  t196_n99: return 0.1787400245666504;
  t196_n100: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t196_n102;
  t196_n101: return 0.1703227013349533;
  t196_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t196_n104;
  t196_n103: return 0.14180463552474976;
  t196_n104: return 0.14606937766075134;
  t196_n105: return 0.08290208131074905;
  t196_n106: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t196_n190;
  t196_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t196_n157;
  t196_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t196_n122;
  t196_n109: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n111;
  t196_n110: return -0.02200816199183464;
  t196_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t196_n117;
  t196_n112: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t196_n116;
  t196_n113: if (E.getNumReferences() >= 3346697088 /*64139.5*/) goto t196_n115;
  t196_n114: return -0.05642814189195633;
  t196_n115: return -0.18979796767234802;
  t196_n116: return -0.03336590901017189;
  t196_n117: if (E.getNumReferences() >= 3345933184 /*61155.5*/) goto t196_n121;
  t196_n118: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t196_n120;
  t196_n119: return 0.11374273151159286;
  t196_n120: return 0.1215478703379631;
  t196_n121: return 0.007518764119595289;
  t196_n122: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t196_n156;
  t196_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t196_n125;
  t196_n124: return -0.03336285427212715;
  t196_n125: if (E.getNumReferences() >= 3345144064 /*58073.0*/) goto t196_n127;
  t196_n126: return -0.09588347375392914;
  t196_n127: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t196_n147;
  t196_n128: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n130;
  t196_n129: return 0.03555838018655777;
  t196_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t196_n146;
  t196_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t196_n133;
  t196_n132: return 0.06830720603466034;
  t196_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t196_n145;
  t196_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t196_n140;
  t196_n135: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t196_n139;
  t196_n136: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t196_n138;
  t196_n137: return 0.1696188747882843;
  t196_n138: return 0.17718909680843353;
  t196_n139: return 0.0898512452840805;
  t196_n140: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n144;
  t196_n141: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t196_n143;
  t196_n142: return 0.12092146277427673;
  t196_n143: return 0.10350298136472702;
  t196_n144: return -0.10023660957813263;
  t196_n145: return 0.06019841507077217;
  t196_n146: return 0.11176382005214691;
  t196_n147: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t196_n151;
  t196_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n150;
  t196_n149: return 0.10146060585975647;
  t196_n150: return 0.142096146941185;
  t196_n151: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n155;
  t196_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n154;
  t196_n153: return 0.12095815688371658;
  t196_n154: return 0.10021830350160599;
  t196_n155: return 0.009962786920368671;
  t196_n156: return -0.025134950876235962;
  t196_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t196_n159;
  t196_n158: return -0.04822300747036934;
  t196_n159: if (E.getNumReferences() >= 3348219712 /*74638.5*/) goto t196_n177;
  t196_n160: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t196_n176;
  t196_n161: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t196_n171;
  t196_n162: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t196_n170;
  t196_n163: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t196_n169;
  t196_n164: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t196_n168;
  t196_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n167;
  t196_n166: return -0.3277548551559448;
  t196_n167: return 0.10534145683050156;
  t196_n168: return 0.11099737137556076;
  t196_n169: return -0.0037674515042454004;
  t196_n170: return -0.12814205884933472;
  t196_n171: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t196_n175;
  t196_n172: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n174;
  t196_n173: return 0.15414515137672424;
  t196_n174: return 0.1186022162437439;
  t196_n175: return 0.18729151785373688;
  t196_n176: return -0.08534485101699829;
  t196_n177: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t196_n179;
  t196_n178: return -0.23456524312496185;
  t196_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n181;
  t196_n180: return 0.08234942704439163;
  t196_n181: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t196_n183;
  t196_n182: return 0.09633205085992813;
  t196_n183: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t196_n185;
  t196_n184: return -0.14813587069511414;
  t196_n185: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t196_n189;
  t196_n186: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n188;
  t196_n187: return 0.09038130193948746;
  t196_n188: return 0.05450892075896263;
  t196_n189: return -0.09278777986764908;
  t196_n190: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t196_n254;
  t196_n191: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t196_n215;
  t196_n192: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t196_n214;
  t196_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t196_n195;
  t196_n194: return 0.009337881579995155;
  t196_n195: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t196_n201;
  t196_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t196_n198;
  t196_n197: return 0.006364563945680857;
  t196_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t196_n200;
  t196_n199: return 0.10915785282850266;
  t196_n200: return 0.06120174378156662;
  t196_n201: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t196_n213;
  t196_n202: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n212;
  t196_n203: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t196_n211;
  t196_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n206;
  t196_n205: return -0.10374343395233154;
  t196_n206: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n208;
  t196_n207: return 0.09335827827453613;
  t196_n208: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n210;
  t196_n209: return 0.11306073516607285;
  t196_n210: return 0.11449505388736725;
  t196_n211: return -0.0484762117266655;
  t196_n212: return 0.03834062069654465;
  t196_n213: return -0.004780489485710859;
  t196_n214: return 0.0048681991174817085;
  t196_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t196_n235;
  t196_n216: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n218;
  t196_n217: return 0.0310545414686203;
  t196_n218: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t196_n234;
  t196_n219: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n221;
  t196_n220: return -0.049059245735406876;
  t196_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t196_n231;
  t196_n222: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t196_n226;
  t196_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n225;
  t196_n224: return -0.10406531393527985;
  t196_n225: return 0.08920706063508987;
  t196_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t196_n228;
  t196_n227: return 0.04315715655684471;
  t196_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t196_n230;
  t196_n229: return 0.0822271928191185;
  t196_n230: return 0.10933924466371536;
  t196_n231: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t196_n233;
  t196_n232: return -0.07320843636989594;
  t196_n233: return 0.023902231827378273;
  t196_n234: return -0.019600557163357735;
  t196_n235: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t196_n237;
  t196_n236: return 0.017693467438220978;
  t196_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t196_n241;
  t196_n238: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n240;
  t196_n239: return -0.2301647961139679;
  t196_n240: return 0.10620898753404617;
  t196_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t196_n253;
  t196_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t196_n244;
  t196_n243: return -0.10901763290166855;
  t196_n244: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t196_n246;
  t196_n245: return -0.11029323935508728;
  t196_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t196_n248;
  t196_n247: return 0.0870581641793251;
  t196_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t196_n250;
  t196_n249: return -0.013266729190945625;
  t196_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t196_n252;
  t196_n251: return 0.034434277564287186;
  t196_n252: return 0.08936505019664764;
  t196_n253: return 0.006245040334761143;
  t196_n254: return -0.002770343329757452;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree197(const Example& E) {
  t197_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t197_n2;
  t197_n1: return -0.0002049272006843239;
  t197_n2: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t197_n12;
  t197_n3: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n5;
  t197_n4: return 0.06847895681858063;
  t197_n5: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t197_n7;
  t197_n6: return 0.12105785310268402;
  t197_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n9;
  t197_n8: return -0.11974213272333145;
  t197_n9: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n11;
  t197_n10: return 0.10690976679325104;
  t197_n11: return 0.07930976897478104;
  t197_n12: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t197_n50;
  t197_n13: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t197_n15;
  t197_n14: return -0.00895766168832779;
  t197_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n17;
  t197_n16: return 0.011919376440346241;
  t197_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t197_n39;
  t197_n18: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t197_n38;
  t197_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n35;
  t197_n20: if (E.getNumReferences() >= 3351268608 /*98458.0*/) goto t197_n22;
  t197_n21: return 0.01727430708706379;
  t197_n22: if (E.getNumReferences() >= 3361321216 /*222916.0*/) goto t197_n30;
  t197_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t197_n29;
  t197_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n26;
  t197_n25: return 0.14421118795871735;
  t197_n26: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t197_n28;
  t197_n27: return 0.09495095908641815;
  t197_n28: return -0.02927744761109352;
  t197_n29: return -0.1257515847682953;
  t197_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n32;
  t197_n31: return 0.019819283857941628;
  t197_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n34;
  t197_n33: return -0.1107100173830986;
  t197_n34: return 0.11898594349622726;
  t197_n35: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t197_n37;
  t197_n36: return -0.011768262833356857;
  t197_n37: return -0.3504181206226349;
  t197_n38: return -0.11245030909776688;
  t197_n39: if (E.getNumReferences() >= 3365247648 /*306389.0*/) goto t197_n47;
  t197_n40: if (E.getNumReferences() >= 3342715264 /*48585.5*/) goto t197_n42;
  t197_n41: return -0.45745617151260376;
  t197_n42: if (E.getNumReferences() >= 3346232448 /*62324.5*/) goto t197_n46;
  t197_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n45;
  t197_n44: return 0.09423363208770752;
  t197_n45: return 0.10813306272029877;
  t197_n46: return 0.03673981875181198;
  t197_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t197_n49;
  t197_n48: return 0.08720039576292038;
  t197_n49: return 0.10777366906404495;
  t197_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t197_n240;
  t197_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t197_n53;
  t197_n52: return 0.0038233590312302113;
  t197_n53: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t197_n239;
  t197_n54: if (E.getNumReferences() >= 3361959232 /*232885.0*/) goto t197_n184;
  t197_n55: if (E.getNumReferences() >= 3360267424 /*206450.5*/) goto t197_n153;
  t197_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n58;
  t197_n57: return 0.013595976866781712;
  t197_n58: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t197_n142;
  t197_n59: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t197_n137;
  t197_n60: if (E.getNumReferences() >= 3346274176 /*62487.5*/) goto t197_n106;
  t197_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t197_n93;
  t197_n62: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t197_n92;
  t197_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t197_n89;
  t197_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t197_n86;
  t197_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t197_n83;
  t197_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n76;
  t197_n67: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n71;
  t197_n68: if (E.getNumReferences() >= 3342798080 /*48909.0*/) goto t197_n70;
  t197_n69: return -0.4048270583152771;
  t197_n70: return 0.024372858926653862;
  t197_n71: if (E.getNumReferences() >= 3344702080 /*56346.5*/) goto t197_n75;
  t197_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n74;
  t197_n73: return -0.2154734581708908;
  t197_n74: return 0.0698782280087471;
  t197_n75: return -0.03641853854060173;
  t197_n76: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n82;
  t197_n77: if (E.getNumReferences() >= 3342798080 /*48909.0*/) goto t197_n81;
  t197_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t197_n80;
  t197_n79: return 0.111674465239048;
  t197_n80: return 0.11461059749126434;
  t197_n81: return 0.09402891248464584;
  t197_n82: return -0.027931103482842445;
  t197_n83: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n85;
  t197_n84: return -0.15051954984664917;
  t197_n85: return 0.1015748530626297;
  t197_n86: if (E.getNumReferences() >= 3342431232 /*47476.0*/) goto t197_n88;
  t197_n87: return 0.12043626606464386;
  t197_n88: return -0.12735632061958313;
  t197_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t197_n91;
  t197_n90: return 0.07370457798242569;
  t197_n91: return -0.1410348117351532;
  t197_n92: return -0.2915423810482025;
  t197_n93: if (E.getNumReferences() >= 3345968640 /*61294.0*/) goto t197_n103;
  t197_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t197_n96;
  t197_n95: return -0.31182119250297546;
  t197_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n98;
  t197_n97: return 0.08918303996324539;
  t197_n98: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t197_n100;
  t197_n99: return -0.023466400802135468;
  t197_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t197_n102;
  t197_n101: return 0.1220487654209137;
  t197_n102: return 0.10743271559476852;
  t197_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t197_n105;
  t197_n104: return 0.07968879491090775;
  t197_n105: return 0.10060480982065201;
  t197_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t197_n134;
  t197_n107: if (E.getNumReferences() >= 3350955776 /*96014.0*/) goto t197_n133;
  t197_n108: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t197_n132;
  t197_n109: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t197_n119;
  t197_n110: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n112;
  t197_n111: return -0.2840930223464966;
  t197_n112: if (E.getNumReferences() >= 3347876160 /*71954.5*/) goto t197_n114;
  t197_n113: return -0.24452264606952667;
  t197_n114: if (E.getNumReferences() >= 3348960256 /*80424.0*/) goto t197_n118;
  t197_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t197_n117;
  t197_n116: return 0.08615867048501968;
  t197_n117: return 0.10262201726436615;
  t197_n118: return -0.2597315311431885;
  t197_n119: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t197_n121;
  t197_n120: return -0.06193196028470993;
  t197_n121: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t197_n125;
  t197_n122: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n124;
  t197_n123: return 0.10708723962306976;
  t197_n124: return -0.05078069865703583;
  t197_n125: if (E.getNumReferences() >= 3348479616 /*76669.0*/) goto t197_n127;
  t197_n126: return -0.19756951928138733;
  t197_n127: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t197_n131;
  t197_n128: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n130;
  t197_n129: return 0.09860913455486298;
  t197_n130: return 0.1316646784543991;
  t197_n131: return -0.03261396288871765;
  t197_n132: return 0.04338795319199562;
  t197_n133: return -0.0571746900677681;
  t197_n134: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t197_n136;
  t197_n135: return -0.1347469836473465;
  t197_n136: return 0.09790772944688797;
  t197_n137: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t197_n141;
  t197_n138: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t197_n140;
  t197_n139: return -0.12051256000995636;
  t197_n140: return 0.07356825470924377;
  t197_n141: return 0.10277947038412094;
  t197_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n144;
  t197_n143: return -0.041766952723264694;
  t197_n144: if (E.getNumReferences() >= 3355904736 /*138283.5*/) goto t197_n152;
  t197_n145: if (E.getNumReferences() >= 3351190528 /*97848.0*/) goto t197_n149;
  t197_n146: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t197_n148;
  t197_n147: return -0.11991716921329498;
  t197_n148: return 0.19646286964416504;
  t197_n149: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t197_n151;
  t197_n150: return 0.12198083102703094;
  t197_n151: return 0.05681237205862999;
  t197_n152: return -0.27037036418914795;
  t197_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t197_n155;
  t197_n154: return 0.01330089196562767;
  t197_n155: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t197_n177;
  t197_n156: if (E.getNumReferences() >= 3360334912 /*207505.0*/) goto t197_n166;
  t197_n157: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t197_n165;
  t197_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n164;
  t197_n159: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t197_n161;
  t197_n160: return 0.014892206527292728;
  t197_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t197_n163;
  t197_n162: return -0.11813697218894958;
  t197_n163: return 0.09913364052772522;
  t197_n164: return 0.09072819352149963;
  t197_n165: return 0.11529283970594406;
  t197_n166: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n176;
  t197_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n169;
  t197_n168: return -0.10557779669761658;
  t197_n169: if (E.getNumReferences() >= 3361153472 /*220295.0*/) goto t197_n173;
  t197_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n172;
  t197_n171: return 0.10699617862701416;
  t197_n172: return -0.4134959876537323;
  t197_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n175;
  t197_n174: return -0.3059860169887543;
  t197_n175: return 0.06409143656492233;
  t197_n176: return -0.07391044497489929;
  t197_n177: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t197_n179;
  t197_n178: return 0.07910680025815964;
  t197_n179: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t197_n181;
  t197_n180: return 0.0943366140127182;
  t197_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n183;
  t197_n182: return 0.09313647449016571;
  t197_n183: return -0.12499213218688965;
  t197_n184: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t197_n186;
  t197_n185: return -0.008707515895366669;
  t197_n186: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t197_n208;
  t197_n187: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t197_n191;
  t197_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t197_n190;
  t197_n189: return 0.0635223537683487;
  t197_n190: return 0.09921331703662872;
  t197_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t197_n207;
  t197_n192: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t197_n194;
  t197_n193: return -0.14242097735404968;
  t197_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t197_n196;
  t197_n195: return -0.13969948887825012;
  t197_n196: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t197_n204;
  t197_n197: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t197_n201;
  t197_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t197_n200;
  t197_n199: return -0.024630796164274216;
  t197_n200: return 0.04921211674809456;
  t197_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t197_n203;
  t197_n202: return 0.03735116869211197;
  t197_n203: return 0.07242735475301743;
  t197_n204: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t197_n206;
  t197_n205: return -0.06336431950330734;
  t197_n206: return 0.05150245130062103;
  t197_n207: return -0.20734646916389465;
  t197_n208: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t197_n218;
  t197_n209: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t197_n217;
  t197_n210: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t197_n212;
  t197_n211: return 0.015384248457849026;
  t197_n212: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n216;
  t197_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t197_n215;
  t197_n214: return -0.15935248136520386;
  t197_n215: return -0.03295363858342171;
  t197_n216: return -0.41290420293807983;
  t197_n217: return 0.018681509420275688;
  t197_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t197_n234;
  t197_n219: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n229;
  t197_n220: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t197_n224;
  t197_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n223;
  t197_n222: return 0.11692751199007034;
  t197_n223: return -0.05864371359348297;
  t197_n224: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t197_n226;
  t197_n225: return -0.02225382626056671;
  t197_n226: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t197_n228;
  t197_n227: return 0.025000566616654396;
  t197_n228: return 0.028817985206842422;
  t197_n229: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t197_n231;
  t197_n230: return 0.06107282638549805;
  t197_n231: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t197_n233;
  t197_n232: return -0.3468068242073059;
  t197_n233: return 0.08722180128097534;
  t197_n234: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t197_n236;
  t197_n235: return 0.10548911988735199;
  t197_n236: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n238;
  t197_n237: return -0.2747407853603363;
  t197_n238: return 0.04191838949918747;
  t197_n239: return -0.06224804371595383;
  t197_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t197_n242;
  t197_n241: return -0.046064313501119614;
  t197_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t197_n254;
  t197_n243: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t197_n249;
  t197_n244: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t197_n246;
  t197_n245: return 0.03949030116200447;
  t197_n246: if (E.getNumReferences() >= 3346217728 /*62267.0*/) goto t197_n248;
  t197_n247: return 0.09705643355846405;
  t197_n248: return -0.0014125140151008964;
  t197_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t197_n253;
  t197_n250: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t197_n252;
  t197_n251: return 0.12223724275827408;
  t197_n252: return 0.09667182713747025;
  t197_n253: return 0.08301389962434769;
  t197_n254: return -0.06231631711125374;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree198(const Example& E) {
  t198_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t198_n162;
  t198_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t198_n3;
  t198_n2: return -0.0003628239210229367;
  t198_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n5;
  t198_n4: return -0.02145686373114586;
  t198_n5: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t198_n123;
  t198_n6: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t198_n8;
  t198_n7: return 0.008310966193675995;
  t198_n8: if (E.getNumReferences() >= 3284484096 /*394.5*/) goto t198_n110;
  t198_n9: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t198_n49;
  t198_n10: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t198_n14;
  t198_n11: if (E.getNumReferences() >= 3283648512 /*369.0*/) goto t198_n13;
  t198_n12: return -0.019412102177739143;
  t198_n13: return 0.10928968340158463;
  t198_n14: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t198_n48;
  t198_n15: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t198_n45;
  t198_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t198_n18;
  t198_n17: return 0.012392024509608746;
  t198_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t198_n20;
  t198_n19: return -0.031666044145822525;
  t198_n20: if (E.getNumReferences() >= 3273031680 /*150.5*/) goto t198_n30;
  t198_n21: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t198_n29;
  t198_n22: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n28;
  t198_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n25;
  t198_n24: return 0.09270348399877548;
  t198_n25: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t198_n27;
  t198_n26: return 0.34945687651634216;
  t198_n27: return 0.11324673891067505;
  t198_n28: return -0.10176991671323776;
  t198_n29: return 0.04502050578594208;
  t198_n30: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t198_n32;
  t198_n31: return 0.11719183623790741;
  t198_n32: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t198_n44;
  t198_n33: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n41;
  t198_n34: if (E.getNumReferences() >= 3278340096 /*231.5*/) goto t198_n36;
  t198_n35: return 0.021382829174399376;
  t198_n36: if (E.getNumReferences() >= 3280420864 /*270.5*/) goto t198_n38;
  t198_n37: return 0.143484964966774;
  t198_n38: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t198_n40;
  t198_n39: return 0.19588230550289154;
  t198_n40: return -0.22002601623535156;
  t198_n41: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t198_n43;
  t198_n42: return 0.13402435183525085;
  t198_n43: return -0.10123234242200851;
  t198_n44: return -0.04727638140320778;
  t198_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t198_n47;
  t198_n46: return 0.11005992442369461;
  t198_n47: return 0.10768821835517883;
  t198_n48: return 0.0070199486799538136;
  t198_n49: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t198_n55;
  t198_n50: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t198_n52;
  t198_n51: return -0.013584572821855545;
  t198_n52: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t198_n54;
  t198_n53: return 0.13828901946544647;
  t198_n54: return 0.040128193795681;
  t198_n55: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t198_n107;
  t198_n56: if (E.getNumReferences() >= 3283943424 /*378.0*/) goto t198_n104;
  t198_n57: if (E.getNumReferences() >= 3278733312 /*237.5*/) goto t198_n101;
  t198_n58: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t198_n98;
  t198_n59: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t198_n87;
  t198_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t198_n62;
  t198_n61: return 0.012759172357618809;
  t198_n62: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n84;
  t198_n63: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t198_n69;
  t198_n64: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t198_n68;
  t198_n65: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n67;
  t198_n66: return 0.12166900187730789;
  t198_n67: return -0.3467974066734314;
  t198_n68: return 0.12685440480709076;
  t198_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t198_n83;
  t198_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t198_n78;
  t198_n71: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t198_n77;
  t198_n72: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t198_n74;
  t198_n73: return -0.23324359953403473;
  t198_n74: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t198_n76;
  t198_n75: return 0.13212601840496063;
  t198_n76: return -0.11202404648065567;
  t198_n77: return 0.10718943178653717;
  t198_n78: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t198_n82;
  t198_n79: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t198_n81;
  t198_n80: return 0.5496679544448853;
  t198_n81: return -0.10952281951904297;
  t198_n82: return -0.05088523030281067;
  t198_n83: return 0.050106726586818695;
  t198_n84: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t198_n86;
  t198_n85: return 0.004438046365976334;
  t198_n86: return 0.12100841850042343;
  t198_n87: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n95;
  t198_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n92;
  t198_n89: if (E.getNumReferences() >= 3276603392 /*205.0*/) goto t198_n91;
  t198_n90: return -0.04431649670004845;
  t198_n91: return 0.8104863166809082;
  t198_n92: if (E.getNumReferences() >= 3275227136 /*184.0*/) goto t198_n94;
  t198_n93: return 0.06342873722314835;
  t198_n94: return 0.12520131468772888;
  t198_n95: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t198_n97;
  t198_n96: return -0.6008599400520325;
  t198_n97: return 0.023476561531424522;
  t198_n98: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t198_n100;
  t198_n99: return 0.11133313924074173;
  t198_n100: return 0.09665898233652115;
  t198_n101: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t198_n103;
  t198_n102: return -0.020755713805556297;
  t198_n103: return 0.10191407054662704;
  t198_n104: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n106;
  t198_n105: return -0.23518557846546173;
  t198_n106: return 0.0986367017030716;
  t198_n107: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n109;
  t198_n108: return 0.08124519139528275;
  t198_n109: return 0.1119004413485527;
  t198_n110: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n122;
  t198_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t198_n113;
  t198_n112: return -0.017413876950740814;
  t198_n113: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t198_n121;
  t198_n114: if (E.getNumReferences() >= 3309072384 /*3015.0*/) goto t198_n120;
  t198_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n119;
  t198_n116: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n118;
  t198_n117: return 0.08292298018932343;
  t198_n118: return -0.15029628574848175;
  t198_n119: return 0.0937093049287796;
  t198_n120: return 0.09989485889673233;
  t198_n121: return -0.04868387058377266;
  t198_n122: return 0.010986186563968658;
  t198_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t198_n125;
  t198_n124: return -0.0013719334965571761;
  t198_n125: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t198_n159;
  t198_n126: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t198_n138;
  t198_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t198_n129;
  t198_n128: return 0.009877219796180725;
  t198_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n131;
  t198_n130: return 0.057723455131053925;
  t198_n131: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t198_n137;
  t198_n132: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t198_n136;
  t198_n133: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t198_n135;
  t198_n134: return 0.07489346712827682;
  t198_n135: return 0.09522972255945206;
  t198_n136: return -0.11152935028076172;
  t198_n137: return 0.11212906986474991;
  t198_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n152;
  t198_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t198_n143;
  t198_n140: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t198_n142;
  t198_n141: return -0.8440048694610596;
  t198_n142: return -0.12423147261142731;
  t198_n143: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t198_n147;
  t198_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n146;
  t198_n145: return 0.09075822681188583;
  t198_n146: return 0.045124515891075134;
  t198_n147: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t198_n149;
  t198_n148: return -0.5069703459739685;
  t198_n149: if (E.getFileProximityDistance() >= 3250585600 /*24.0*/) goto t198_n151;
  t198_n150: return 0.08550652861595154;
  t198_n151: return 0.23168085515499115;
  t198_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n158;
  t198_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t198_n155;
  t198_n154: return 0.01390969380736351;
  t198_n155: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t198_n157;
  t198_n156: return 0.1059902086853981;
  t198_n157: return 0.1423821896314621;
  t198_n158: return -0.07934907078742981;
  t198_n159: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t198_n161;
  t198_n160: return 0.005585044156759977;
  t198_n161: return -0.10647173970937729;
  t198_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t198_n242;
  t198_n163: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t198_n235;
  t198_n164: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t198_n174;
  t198_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t198_n171;
  t198_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t198_n168;
  t198_n167: return -0.02718723937869072;
  t198_n168: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n170;
  t198_n169: return 0.0906534343957901;
  t198_n170: return -0.4569120705127716;
  t198_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t198_n173;
  t198_n172: return -0.016968337818980217;
  t198_n173: return 0.07410212606191635;
  t198_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t198_n208;
  t198_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n205;
  t198_n176: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t198_n200;
  t198_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n179;
  t198_n178: return -0.12864907085895538;
  t198_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t198_n197;
  t198_n180: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n186;
  t198_n181: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t198_n183;
  t198_n182: return 0.07698266953229904;
  t198_n183: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t198_n185;
  t198_n184: return 0.0023526467848569155;
  t198_n185: return -0.09500283747911453;
  t198_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n188;
  t198_n187: return -0.6376132965087891;
  t198_n188: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n192;
  t198_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n191;
  t198_n190: return 0.0014021070674061775;
  t198_n191: return 0.05207673832774162;
  t198_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n194;
  t198_n193: return 0.07654905319213867;
  t198_n194: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n196;
  t198_n195: return 0.042365662753582;
  t198_n196: return -0.05434444546699524;
  t198_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n199;
  t198_n198: return 0.006049415562301874;
  t198_n199: return -1.1033189296722412;
  t198_n200: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t198_n204;
  t198_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t198_n203;
  t198_n202: return -0.11390747129917145;
  t198_n203: return 0.10764851421117783;
  t198_n204: return 0.004679080564528704;
  t198_n205: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n207;
  t198_n206: return -0.055269233882427216;
  t198_n207: return 0.014597010798752308;
  t198_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n230;
  t198_n209: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t198_n227;
  t198_n210: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n216;
  t198_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t198_n213;
  t198_n212: return -0.35560569167137146;
  t198_n213: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t198_n215;
  t198_n214: return 0.21921047568321228;
  t198_n215: return 0.06407880038022995;
  t198_n216: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t198_n218;
  t198_n217: return -0.32426485419273376;
  t198_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t198_n224;
  t198_n219: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t198_n221;
  t198_n220: return -0.6152205467224121;
  t198_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n223;
  t198_n222: return -0.10187657922506332;
  t198_n223: return 0.10162670165300369;
  t198_n224: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t198_n226;
  t198_n225: return -0.35506242513656616;
  t198_n226: return 0.008927029557526112;
  t198_n227: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t198_n229;
  t198_n228: return -0.08183521032333374;
  t198_n229: return 0.06755568832159042;
  t198_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n232;
  t198_n231: return -0.17820584774017334;
  t198_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n234;
  t198_n233: return -0.16484425961971283;
  t198_n234: return 0.21973055601119995;
  t198_n235: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t198_n237;
  t198_n236: return 0.029859021306037903;
  t198_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t198_n239;
  t198_n238: return -0.12128010392189026;
  t198_n239: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t198_n241;
  t198_n240: return 0.04507727548480034;
  t198_n241: return 0.11442865431308746;
  t198_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t198_n250;
  t198_n243: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t198_n249;
  t198_n244: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t198_n248;
  t198_n245: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t198_n247;
  t198_n246: return 0.08426224440336227;
  t198_n247: return -0.6701565980911255;
  t198_n248: return 0.09794019162654877;
  t198_n249: return -0.0005998198175802827;
  t198_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t198_n254;
  t198_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t198_n253;
  t198_n252: return -0.2464367300271988;
  t198_n253: return -0.013008520938456059;
  t198_n254: return 0.01578020490705967;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree199(const Example& E) {
  t199_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t199_n170;
  t199_n1: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t199_n157;
  t199_n2: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t199_n132;
  t199_n3: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t199_n131;
  t199_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t199_n90;
  t199_n5: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t199_n59;
  t199_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n22;
  t199_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n9;
  t199_n8: return -0.011793685145676136;
  t199_n9: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t199_n13;
  t199_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t199_n12;
  t199_n11: return 0.014041433110833168;
  t199_n12: return 0.05112588778138161;
  t199_n13: if (E.getNumReferences() >= 3266183168 /*87.0*/) goto t199_n15;
  t199_n14: return 0.1389102190732956;
  t199_n15: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t199_n21;
  t199_n16: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t199_n20;
  t199_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n19;
  t199_n18: return 0.16111363470554352;
  t199_n19: return 0.11454609036445618;
  t199_n20: return 0.13016395270824432;
  t199_n21: return 0.024733390659093857;
  t199_n22: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t199_n36;
  t199_n23: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t199_n29;
  t199_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n28;
  t199_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n27;
  t199_n26: return -0.1265299916267395;
  t199_n27: return -0.013662959448993206;
  t199_n28: return 0.01695089228451252;
  t199_n29: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t199_n31;
  t199_n30: return -0.06250794231891632;
  t199_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t199_n33;
  t199_n32: return -0.019883016124367714;
  t199_n33: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t199_n35;
  t199_n34: return 0.023715414106845856;
  t199_n35: return 0.13278408348560333;
  t199_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t199_n50;
  t199_n37: if (E.getNumReferences() >= 3275849728 /*193.5*/) goto t199_n49;
  t199_n38: if (E.getNumReferences() >= 3275620352 /*190.0*/) goto t199_n48;
  t199_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t199_n43;
  t199_n40: if (E.getNumReferences() >= 3275030528 /*181.0*/) goto t199_n42;
  t199_n41: return -0.03772444650530815;
  t199_n42: return 0.09193149954080582;
  t199_n43: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t199_n47;
  t199_n44: if (E.getNumReferences() >= 3273916416 /*164.0*/) goto t199_n46;
  t199_n45: return 0.11597835272550583;
  t199_n46: return -0.16925954818725586;
  t199_n47: return 0.10257354378700256;
  t199_n48: return 0.1100807711482048;
  t199_n49: return -0.026708150282502174;
  t199_n50: if (E.getNumReferences() >= 3277914112 /*225.0*/) goto t199_n52;
  t199_n51: return -0.021970104426145554;
  t199_n52: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t199_n54;
  t199_n53: return 0.04017520323395729;
  t199_n54: if (E.getNumReferences() >= 3284221952 /*386.5*/) goto t199_n56;
  t199_n55: return 0.13381066918373108;
  t199_n56: if (E.getNumReferences() >= 3294429184 /*884.0*/) goto t199_n58;
  t199_n57: return 0.039308030158281326;
  t199_n58: return 0.16570833325386047;
  t199_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t199_n61;
  t199_n60: return -0.12365946173667908;
  t199_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t199_n63;
  t199_n62: return 0.02118709124624729;
  t199_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n71;
  t199_n64: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t199_n66;
  t199_n65: return 0.0036117727868258953;
  t199_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n70;
  t199_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t199_n69;
  t199_n68: return 0.00015646644169464707;
  t199_n69: return 0.11924507468938828;
  t199_n70: return 0.04521019384264946;
  t199_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t199_n73;
  t199_n72: return 0.049533162266016006;
  t199_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t199_n81;
  t199_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n76;
  t199_n75: return 0.01333782821893692;
  t199_n76: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n80;
  t199_n77: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t199_n79;
  t199_n78: return 0.10962851345539093;
  t199_n79: return -0.36785173416137695;
  t199_n80: return 0.010344229638576508;
  t199_n81: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t199_n87;
  t199_n82: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t199_n84;
  t199_n83: return -0.03007330559194088;
  t199_n84: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t199_n86;
  t199_n85: return 0.047079332172870636;
  t199_n86: return -0.15868908166885376;
  t199_n87: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t199_n89;
  t199_n88: return 0.13058796525001526;
  t199_n89: return 0.0037932998966425657;
  t199_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t199_n118;
  t199_n91: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t199_n93;
  t199_n92: return -0.005605393089354038;
  t199_n93: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n97;
  t199_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t199_n96;
  t199_n95: return 0.09498380869626999;
  t199_n96: return 0.09157587587833405;
  t199_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t199_n109;
  t199_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n104;
  t199_n99: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t199_n101;
  t199_n100: return -0.008373819291591644;
  t199_n101: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t199_n103;
  t199_n102: return 0.1248433068394661;
  t199_n103: return 0.013732679188251495;
  t199_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n108;
  t199_n105: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t199_n107;
  t199_n106: return 0.11264782398939133;
  t199_n107: return 0.07728574424982071;
  t199_n108: return -0.09471838921308517;
  t199_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n115;
  t199_n110: if (E.getNumReferences() >= 3272736768 /*146.0*/) goto t199_n112;
  t199_n111: return 0.053850896656513214;
  t199_n112: if (E.getNumReferences() >= 3282026496 /*319.5*/) goto t199_n114;
  t199_n113: return 0.11240243166685104;
  t199_n114: return 0.08654527366161346;
  t199_n115: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t199_n117;
  t199_n116: return 0.1456594318151474;
  t199_n117: return -0.053534962236881256;
  t199_n118: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t199_n130;
  t199_n119: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t199_n129;
  t199_n120: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n128;
  t199_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n123;
  t199_n122: return -0.10275627672672272;
  t199_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n127;
  t199_n124: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n126;
  t199_n125: return 0.11543257534503937;
  t199_n126: return 0.3623964190483093;
  t199_n127: return 0.26468175649642944;
  t199_n128: return 0.06981419771909714;
  t199_n129: return 0.08520977199077606;
  t199_n130: return 0.044025029987096786;
  t199_n131: return -0.0027822493575513363;
  t199_n132: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t199_n136;
  t199_n133: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t199_n135;
  t199_n134: return -0.054376643151044846;
  t199_n135: return -0.0005032608169130981;
  t199_n136: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t199_n146;
  t199_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t199_n139;
  t199_n138: return -0.02424135059118271;
  t199_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t199_n141;
  t199_n140: return 0.004155417438596487;
  t199_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n145;
  t199_n142: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t199_n144;
  t199_n143: return -0.21993999183177948;
  t199_n144: return 0.09194589406251907;
  t199_n145: return 0.02289370819926262;
  t199_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t199_n148;
  t199_n147: return 0.009057902731001377;
  t199_n148: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t199_n156;
  t199_n149: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n155;
  t199_n150: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t199_n154;
  t199_n151: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t199_n153;
  t199_n152: return 0.09071037918329239;
  t199_n153: return 0.06861001998186111;
  t199_n154: return 0.09756626933813095;
  t199_n155: return 0.06465838104486465;
  t199_n156: return -0.03530872240662575;
  t199_n157: if (E.getNumReferences() >= 3286630400 /*460.0*/) goto t199_n159;
  t199_n158: return -0.0336587056517601;
  t199_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n169;
  t199_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n168;
  t199_n161: if (E.getNumReferences() >= 3298754560 /*1272.0*/) goto t199_n165;
  t199_n162: if (E.getNumReferences() >= 3294642176 /*897.0*/) goto t199_n164;
  t199_n163: return 0.6085352897644043;
  t199_n164: return 0.20738470554351807;
  t199_n165: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t199_n167;
  t199_n166: return -0.11216844618320465;
  t199_n167: return 0.3601023852825165;
  t199_n168: return 0.04581015184521675;
  t199_n169: return -0.06760475039482117;
  t199_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t199_n238;
  t199_n171: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t199_n225;
  t199_n172: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t199_n182;
  t199_n173: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n179;
  t199_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t199_n176;
  t199_n175: return -0.02346820943057537;
  t199_n176: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n178;
  t199_n177: return 0.09127115458250046;
  t199_n178: return -0.35673338174819946;
  t199_n179: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t199_n181;
  t199_n180: return -0.018279148265719414;
  t199_n181: return 0.07257048040628433;
  t199_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n184;
  t199_n183: return -0.21147914230823517;
  t199_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n202;
  t199_n185: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t199_n187;
  t199_n186: return -0.019691571593284607;
  t199_n187: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n201;
  t199_n188: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t199_n196;
  t199_n189: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n193;
  t199_n190: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t199_n192;
  t199_n191: return 0.07298140972852707;
  t199_n192: return -0.09503155946731567;
  t199_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t199_n195;
  t199_n194: return 0.032951295375823975;
  t199_n195: return -0.11154083907604218;
  t199_n196: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t199_n200;
  t199_n197: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n199;
  t199_n198: return -0.23522166907787323;
  t199_n199: return -0.014812310226261616;
  t199_n200: return 0.00654907152056694;
  t199_n201: return 0.013577964156866074;
  t199_n202: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t199_n218;
  t199_n203: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t199_n205;
  t199_n204: return -0.26095589995384216;
  t199_n205: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t199_n217;
  t199_n206: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t199_n212;
  t199_n207: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n211;
  t199_n208: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t199_n210;
  t199_n209: return -0.08908198028802872;
  t199_n210: return 0.12453293800354004;
  t199_n211: return -0.4939887821674347;
  t199_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n214;
  t199_n213: return -0.10097763687372208;
  t199_n214: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n216;
  t199_n215: return 0.10249397158622742;
  t199_n216: return -0.027410227805376053;
  t199_n217: return 0.06517916917800903;
  t199_n218: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t199_n224;
  t199_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n221;
  t199_n220: return 0.05006612464785576;
  t199_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n223;
  t199_n222: return -0.5388970971107483;
  t199_n223: return 0.2822599709033966;
  t199_n224: return -0.16756296157836914;
  t199_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t199_n227;
  t199_n226: return 0.027782639488577843;
  t199_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t199_n237;
  t199_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t199_n236;
  t199_n229: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t199_n233;
  t199_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t199_n232;
  t199_n231: return -0.42715194821357727;
  t199_n232: return -0.28785890340805054;
  t199_n233: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t199_n235;
  t199_n234: return -0.2748449742794037;
  t199_n235: return 0.06745143234729767;
  t199_n236: return 0.042822543531656265;
  t199_n237: return 0.11321916431188583;
  t199_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t199_n246;
  t199_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t199_n245;
  t199_n240: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t199_n244;
  t199_n241: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t199_n243;
  t199_n242: return 0.07983796298503876;
  t199_n243: return -0.1606077253818512;
  t199_n244: return 0.09997273236513138;
  t199_n245: return 0.013445835560560226;
  t199_n246: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t199_n248;
  t199_n247: return -0.0686192587018013;
  t199_n248: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t199_n252;
  t199_n249: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t199_n251;
  t199_n250: return 0.09783339500427246;
  t199_n251: return -0.01614883355796337;
  t199_n252: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t199_n254;
  t199_n253: return -0.009878017008304596;
  t199_n254: return 0.02853081002831459;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree200(const Example& E) {
  t200_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t200_n174;
  t200_n1: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t200_n3;
  t200_n2: return -0.00040719524258747697;
  t200_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t200_n93;
  t200_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t200_n54;
  t200_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n21;
  t200_n6: if (E.getNumReferences() >= 3324922368 /*11154.5*/) goto t200_n8;
  t200_n7: return -0.009662346914410591;
  t200_n8: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t200_n20;
  t200_n9: if (E.getNumReferences() >= 3325242368 /*11467.0*/) goto t200_n17;
  t200_n10: if (E.getNumReferences() >= 3324978688 /*11209.5*/) goto t200_n12;
  t200_n11: return 0.027594076469540596;
  t200_n12: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t200_n14;
  t200_n13: return -0.013597220182418823;
  t200_n14: if (E.getNumReferences() >= 3325015040 /*11245.0*/) goto t200_n16;
  t200_n15: return 0.10076768696308136;
  t200_n16: return 0.10251886397600174;
  t200_n17: if (E.getNumReferences() >= 3368810912 /*417741.0*/) goto t200_n19;
  t200_n18: return 0.015869563445448875;
  t200_n19: return -0.02788316085934639;
  t200_n20: return 0.001006401376798749;
  t200_n21: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t200_n41;
  t200_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t200_n32;
  t200_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n25;
  t200_n24: return -0.08013244718313217;
  t200_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t200_n31;
  t200_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n28;
  t200_n27: return -0.00240090093575418;
  t200_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t200_n30;
  t200_n29: return 0.06891675293445587;
  t200_n30: return 0.10702499747276306;
  t200_n31: return -0.11874815076589584;
  t200_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n34;
  t200_n33: return 0.02521582692861557;
  t200_n34: if (E.getNumReferences() >= 3288375296 /*514.5*/) goto t200_n38;
  t200_n35: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t200_n37;
  t200_n36: return -0.4578693211078644;
  t200_n37: return 0.11089428514242172;
  t200_n38: if (E.getNumReferences() >= 3297292288 /*1093.5*/) goto t200_n40;
  t200_n39: return 0.07160279899835587;
  t200_n40: return 0.13958141207695007;
  t200_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t200_n45;
  t200_n42: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t200_n44;
  t200_n43: return 0.016061749309301376;
  t200_n44: return -0.19599084556102753;
  t200_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t200_n51;
  t200_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t200_n48;
  t200_n47: return -0.3478417992591858;
  t200_n48: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t200_n50;
  t200_n49: return 0.03870562091469765;
  t200_n50: return 0.08140164613723755;
  t200_n51: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t200_n53;
  t200_n52: return 0.097058966755867;
  t200_n53: return 0.05083946883678436;
  t200_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n60;
  t200_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n59;
  t200_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n58;
  t200_n57: return -0.02404453046619892;
  t200_n58: return -0.7521237134933472;
  t200_n59: return 0.07862231135368347;
  t200_n60: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t200_n76;
  t200_n61: if (E.getNumReferences() >= 3287891968 /*498.5*/) goto t200_n75;
  t200_n62: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t200_n66;
  t200_n63: if (E.getNumReferences() >= 3284582400 /*397.5*/) goto t200_n65;
  t200_n64: return 0.08999814838171005;
  t200_n65: return -0.18514394760131836;
  t200_n66: if (E.getNumReferences() >= 3285549056 /*427.0*/) goto t200_n68;
  t200_n67: return 0.12815919518470764;
  t200_n68: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t200_n74;
  t200_n69: if (E.getNumReferences() >= 3286089728 /*443.5*/) goto t200_n71;
  t200_n70: return -0.09302203357219696;
  t200_n71: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t200_n73;
  t200_n72: return 0.12317033857107162;
  t200_n73: return -0.44815200567245483;
  t200_n74: return -0.32383430004119873;
  t200_n75: return 0.12796635925769806;
  t200_n76: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t200_n92;
  t200_n77: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t200_n79;
  t200_n78: return -0.41919776797294617;
  t200_n79: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t200_n91;
  t200_n80: if (E.getNumReferences() >= 3296882688 /*1043.5*/) goto t200_n90;
  t200_n81: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t200_n83;
  t200_n82: return 0.035980224609375;
  t200_n83: if (E.getNumReferences() >= 3292848128 /*787.5*/) goto t200_n85;
  t200_n84: return 0.11148767918348312;
  t200_n85: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t200_n87;
  t200_n86: return -0.10457425564527512;
  t200_n87: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t200_n89;
  t200_n88: return 0.134748175740242;
  t200_n89: return -0.11112749576568604;
  t200_n90: return 0.11340342462062836;
  t200_n91: return 0.007730187848210335;
  t200_n92: return -0.1477203667163849;
  t200_n93: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t200_n161;
  t200_n94: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t200_n160;
  t200_n95: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t200_n145;
  t200_n96: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n106;
  t200_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t200_n99;
  t200_n98: return -0.2675946056842804;
  t200_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t200_n101;
  t200_n100: return -0.019987337291240692;
  t200_n101: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n105;
  t200_n102: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t200_n104;
  t200_n103: return -0.19970297813415527;
  t200_n104: return 0.1081521138548851;
  t200_n105: return 0.1054546982049942;
  t200_n106: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t200_n110;
  t200_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t200_n109;
  t200_n108: return -0.10578344017267227;
  t200_n109: return 0.09528617560863495;
  t200_n110: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t200_n140;
  t200_n111: if (E.getNumReferences() >= 3293093888 /*802.5*/) goto t200_n137;
  t200_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t200_n130;
  t200_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t200_n115;
  t200_n114: return 0.010697031393647194;
  t200_n115: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t200_n125;
  t200_n116: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t200_n120;
  t200_n117: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t200_n119;
  t200_n118: return -0.013346631079912186;
  t200_n119: return 0.10330014675855637;
  t200_n120: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n122;
  t200_n121: return 0.0971500352025032;
  t200_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t200_n124;
  t200_n123: return -0.32893604040145874;
  t200_n124: return 0.1007758378982544;
  t200_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n127;
  t200_n126: return -0.10430184006690979;
  t200_n127: if (E.getNumReferences() >= 3290292224 /*631.5*/) goto t200_n129;
  t200_n128: return 0.12610983848571777;
  t200_n129: return 0.12385508418083191;
  t200_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n136;
  t200_n131: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t200_n135;
  t200_n132: if (E.getNumReferences() >= 3290480640 /*643.0*/) goto t200_n134;
  t200_n133: return 0.11687019467353821;
  t200_n134: return 0.10352666676044464;
  t200_n135: return -0.09769793599843979;
  t200_n136: return 0.13024626672267914;
  t200_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n139;
  t200_n138: return 0.12608838081359863;
  t200_n139: return -0.2968344986438751;
  t200_n140: if (E.getNumReferences() >= 3295215616 /*932.0*/) goto t200_n144;
  t200_n141: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n143;
  t200_n142: return -0.15216290950775146;
  t200_n143: return -0.4418107569217682;
  t200_n144: return 0.03096916526556015;
  t200_n145: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t200_n151;
  t200_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n148;
  t200_n147: return -0.41609635949134827;
  t200_n148: if (E.getNumReferences() >= 3293388800 /*820.5*/) goto t200_n150;
  t200_n149: return 0.10704030841588974;
  t200_n150: return 0.09433823823928833;
  t200_n151: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n153;
  t200_n152: return -0.017312856391072273;
  t200_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t200_n157;
  t200_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t200_n156;
  t200_n155: return -0.06997493654489517;
  t200_n156: return 0.08372174948453903;
  t200_n157: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t200_n159;
  t200_n158: return 0.11033417284488678;
  t200_n159: return 0.04040052741765976;
  t200_n160: return 0.00037145978421904147;
  t200_n161: if (E.getNumReferences() >= 3289505792 /*583.5*/) goto t200_n173;
  t200_n162: if (E.getNumReferences() >= 3289260032 /*568.5*/) goto t200_n172;
  t200_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n171;
  t200_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t200_n166;
  t200_n165: return 0.08163942396640778;
  t200_n166: if (E.getNumReferences() >= 3285254144 /*418.0*/) goto t200_n168;
  t200_n167: return 0.10455629229545593;
  t200_n168: if (E.getNumReferences() >= 3287810048 /*496.0*/) goto t200_n170;
  t200_n169: return -0.06424299627542496;
  t200_n170: return 0.11506509780883789;
  t200_n171: return -0.08444564789533615;
  t200_n172: return 0.17366193234920502;
  t200_n173: return 0.026978034526109695;
  t200_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t200_n242;
  t200_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t200_n241;
  t200_n176: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t200_n236;
  t200_n177: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t200_n233;
  t200_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t200_n196;
  t200_n179: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t200_n181;
  t200_n180: return -0.10844459384679794;
  t200_n181: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t200_n191;
  t200_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t200_n184;
  t200_n183: return -0.5547927618026733;
  t200_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n190;
  t200_n185: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n187;
  t200_n186: return 0.005056262016296387;
  t200_n187: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t200_n189;
  t200_n188: return 0.0035454982426017523;
  t200_n189: return 0.05670947581529617;
  t200_n190: return -0.534878134727478;
  t200_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n195;
  t200_n192: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n194;
  t200_n193: return 0.23144197463989258;
  t200_n194: return 0.061205800622701645;
  t200_n195: return -0.055401671677827835;
  t200_n196: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t200_n216;
  t200_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n203;
  t200_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t200_n202;
  t200_n199: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t200_n201;
  t200_n200: return 0.13532572984695435;
  t200_n201: return -0.6721227765083313;
  t200_n202: return 0.06481960415840149;
  t200_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t200_n215;
  t200_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t200_n210;
  t200_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t200_n207;
  t200_n206: return -0.08708500117063522;
  t200_n207: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t200_n209;
  t200_n208: return 0.05851421132683754;
  t200_n209: return -0.033992599695920944;
  t200_n210: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n214;
  t200_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t200_n213;
  t200_n212: return 0.048994265496730804;
  t200_n213: return 0.08910602331161499;
  t200_n214: return 0.01686248742043972;
  t200_n215: return 0.12156980484724045;
  t200_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n226;
  t200_n217: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t200_n223;
  t200_n218: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n222;
  t200_n219: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t200_n221;
  t200_n220: return 0.05098274350166321;
  t200_n221: return -0.06312844902276993;
  t200_n222: return -0.298735111951828;
  t200_n223: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t200_n225;
  t200_n224: return -0.31464478373527527;
  t200_n225: return 0.0630483403801918;
  t200_n226: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t200_n230;
  t200_n227: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t200_n229;
  t200_n228: return 0.061335448175668716;
  t200_n229: return -0.06283080577850342;
  t200_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t200_n232;
  t200_n231: return 0.046680279076099396;
  t200_n232: return 0.09778705984354019;
  t200_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n235;
  t200_n234: return -0.03723974525928497;
  t200_n235: return -0.0038117794319987297;
  t200_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n240;
  t200_n237: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t200_n239;
  t200_n238: return -0.02326800487935543;
  t200_n239: return 0.08717440068721771;
  t200_n240: return 0.020330894738435745;
  t200_n241: return 0.09055062383413315;
  t200_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t200_n250;
  t200_n243: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t200_n249;
  t200_n244: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t200_n248;
  t200_n245: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t200_n247;
  t200_n246: return 0.06812115758657455;
  t200_n247: return -0.15175892412662506;
  t200_n248: return 0.09492678195238113;
  t200_n249: return -0.0011831175070255995;
  t200_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t200_n254;
  t200_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t200_n253;
  t200_n252: return -0.16994914412498474;
  t200_n253: return -0.00396287627518177;
  t200_n254: return 0.014248006045818329;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree201(const Example& E) {
  t201_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t201_n244;
  t201_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t201_n3;
  t201_n2: return -0.00047630988410674036;
  t201_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t201_n5;
  t201_n4: return -0.020651962608098984;
  t201_n5: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t201_n47;
  t201_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n32;
  t201_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n9;
  t201_n8: return -0.031234797090291977;
  t201_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t201_n23;
  t201_n10: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t201_n12;
  t201_n11: return -0.005883995909243822;
  t201_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t201_n14;
  t201_n13: return 0.02414948120713234;
  t201_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t201_n16;
  t201_n15: return -0.1070014238357544;
  t201_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n18;
  t201_n17: return 0.0583610013127327;
  t201_n18: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t201_n22;
  t201_n19: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n21;
  t201_n20: return 0.0958184003829956;
  t201_n21: return -0.1305142641067505;
  t201_n22: return -0.14398688077926636;
  t201_n23: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t201_n25;
  t201_n24: return 0.020633716136217117;
  t201_n25: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n27;
  t201_n26: return 0.009522299282252789;
  t201_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n29;
  t201_n28: return -0.06988529860973358;
  t201_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n31;
  t201_n30: return 0.0034042024053633213;
  t201_n31: return -0.12430871278047562;
  t201_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Namespace))) goto t201_n46;
  t201_n33: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t201_n43;
  t201_n34: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t201_n40;
  t201_n35: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t201_n37;
  t201_n36: return 0.027325663715600967;
  t201_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n39;
  t201_n38: return 0.01176818273961544;
  t201_n39: return 0.10403822362422943;
  t201_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t201_n42;
  t201_n41: return 0.15584753453731537;
  t201_n42: return -0.07660208642482758;
  t201_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t201_n45;
  t201_n44: return -0.010564321652054787;
  t201_n45: return -0.015106831677258015;
  t201_n46: return 0.061324089765548706;
  t201_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t201_n61;
  t201_n48: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t201_n60;
  t201_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n51;
  t201_n50: return -0.08307820558547974;
  t201_n51: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t201_n59;
  t201_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t201_n54;
  t201_n53: return 0.052608489990234375;
  t201_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n58;
  t201_n55: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n57;
  t201_n56: return 0.13191205263137817;
  t201_n57: return 0.11210702359676361;
  t201_n58: return 0.016776930540800095;
  t201_n59: return -0.11934904009103775;
  t201_n60: return 0.00021293730242177844;
  t201_n61: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t201_n189;
  t201_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n64;
  t201_n63: return -0.03691780939698219;
  t201_n64: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t201_n172;
  t201_n65: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t201_n87;
  t201_n66: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t201_n74;
  t201_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n69;
  t201_n68: return -0.0006814105436205864;
  t201_n69: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t201_n71;
  t201_n70: return 0.004518701694905758;
  t201_n71: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n73;
  t201_n72: return 0.037177640944719315;
  t201_n73: return 0.10476706922054291;
  t201_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t201_n76;
  t201_n75: return 0.035150814801454544;
  t201_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t201_n78;
  t201_n77: return -0.10397011041641235;
  t201_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n80;
  t201_n79: return -0.016626425087451935;
  t201_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n82;
  t201_n81: return 0.0668802410364151;
  t201_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n86;
  t201_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n85;
  t201_n84: return -0.044243887066841125;
  t201_n85: return 0.024830272421240807;
  t201_n86: return 0.01617601327598095;
  t201_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n167;
  t201_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n90;
  t201_n89: return 0.11046609282493591;
  t201_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n100;
  t201_n91: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t201_n99;
  t201_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n94;
  t201_n93: return -0.18966834247112274;
  t201_n94: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t201_n96;
  t201_n95: return -0.028266282752156258;
  t201_n96: if (E.getNumReferences() >= 3270246400 /*118.0*/) goto t201_n98;
  t201_n97: return 0.12146101146936417;
  t201_n98: return -0.024373851716518402;
  t201_n99: return 0.09922514110803604;
  t201_n100: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t201_n120;
  t201_n101: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n115;
  t201_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t201_n106;
  t201_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n105;
  t201_n104: return -0.2812710404396057;
  t201_n105: return 0.22685612738132477;
  t201_n106: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n110;
  t201_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n109;
  t201_n108: return -0.1986079216003418;
  t201_n109: return 0.11877632886171341;
  t201_n110: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t201_n114;
  t201_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n113;
  t201_n112: return -0.33209228515625;
  t201_n113: return 0.16963447630405426;
  t201_n114: return 0.1350494921207428;
  t201_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n119;
  t201_n116: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n118;
  t201_n117: return 0.10262347757816315;
  t201_n118: return 0.0731617882847786;
  t201_n119: return 0.1172204539179802;
  t201_n120: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t201_n156;
  t201_n121: if (E.getNumReferences() >= 3268673536 /*106.0*/) goto t201_n155;
  t201_n122: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t201_n128;
  t201_n123: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t201_n127;
  t201_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t201_n126;
  t201_n125: return 0.09519120305776596;
  t201_n126: return 0.5164667963981628;
  t201_n127: return -0.09019327163696289;
  t201_n128: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t201_n136;
  t201_n129: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t201_n135;
  t201_n130: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n132;
  t201_n131: return -0.02377961575984955;
  t201_n132: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n134;
  t201_n133: return 0.10427368432283401;
  t201_n134: return 0.18188223242759705;
  t201_n135: return -0.0031540836207568645;
  t201_n136: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t201_n154;
  t201_n137: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t201_n153;
  t201_n138: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t201_n148;
  t201_n139: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t201_n143;
  t201_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n142;
  t201_n141: return 0.21293038129806519;
  t201_n142: return 0.13644184172153473;
  t201_n143: if (E.getNumReferences() >= 3246915584 /*17.0*/) goto t201_n145;
  t201_n144: return -0.036501444876194;
  t201_n145: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n147;
  t201_n146: return 0.10753285139799118;
  t201_n147: return 0.115845687687397;
  t201_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t201_n150;
  t201_n149: return 0.12745270133018494;
  t201_n150: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t201_n152;
  t201_n151: return 0.1079799234867096;
  t201_n152: return -0.14331559836864471;
  t201_n153: return 0.07231254875659943;
  t201_n154: return -0.050296034663915634;
  t201_n155: return -0.1857909858226776;
  t201_n156: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n164;
  t201_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n159;
  t201_n158: return 0.1213027834892273;
  t201_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n163;
  t201_n160: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n162;
  t201_n161: return 0.04954739287495613;
  t201_n162: return 0.10508548468351364;
  t201_n163: return 0.13441722095012665;
  t201_n164: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t201_n166;
  t201_n165: return 0.13334481418132782;
  t201_n166: return 0.16770081222057343;
  t201_n167: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t201_n169;
  t201_n168: return 0.05412573367357254;
  t201_n169: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t201_n171;
  t201_n170: return 0.10170585662126541;
  t201_n171: return -2.5279407501220703;
  t201_n172: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t201_n176;
  t201_n173: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t201_n175;
  t201_n174: return -0.002667909488081932;
  t201_n175: return -0.059947021305561066;
  t201_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n178;
  t201_n177: return -0.0052080461755394936;
  t201_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n180;
  t201_n179: return 0.10757023841142654;
  t201_n180: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t201_n188;
  t201_n181: if (E.getNumReferences() >= 3229614080 /*4.0*/) goto t201_n183;
  t201_n182: return 0.016508983448147774;
  t201_n183: if (E.getNumReferences() >= 3257925632 /*44.0*/) goto t201_n187;
  t201_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t201_n186;
  t201_n185: return 0.12457022070884705;
  t201_n186: return 0.08913838863372803;
  t201_n187: return 0.0803370326757431;
  t201_n188: return 0.0006641975487582386;
  t201_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t201_n197;
  t201_n190: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n192;
  t201_n191: return -0.0005617315182462335;
  t201_n192: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t201_n196;
  t201_n193: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t201_n195;
  t201_n194: return -0.006125560961663723;
  t201_n195: return -0.07941841334104538;
  t201_n196: return 0.02732391469180584;
  t201_n197: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t201_n199;
  t201_n198: return 0.017030807211995125;
  t201_n199: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t201_n205;
  t201_n200: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t201_n202;
  t201_n201: return -0.15263499319553375;
  t201_n202: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n204;
  t201_n203: return 0.1354769468307495;
  t201_n204: return 0.054250650107860565;
  t201_n205: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t201_n209;
  t201_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t201_n208;
  t201_n207: return 0.02970978058874607;
  t201_n208: return 0.20321883261203766;
  t201_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t201_n211;
  t201_n210: return -0.017637385055422783;
  t201_n211: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t201_n215;
  t201_n212: if (E.getNumReferences() >= 3255435264 /*34.5*/) goto t201_n214;
  t201_n213: return -0.031619805842638016;
  t201_n214: return 0.11041481792926788;
  t201_n215: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t201_n243;
  t201_n216: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t201_n230;
  t201_n217: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t201_n219;
  t201_n218: return 0.014305219985544682;
  t201_n219: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n221;
  t201_n220: return 0.05810430273413658;
  t201_n221: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t201_n223;
  t201_n222: return 0.05525245890021324;
  t201_n223: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t201_n229;
  t201_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t201_n226;
  t201_n225: return -0.14324845373630524;
  t201_n226: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t201_n228;
  t201_n227: return 0.1179121807217598;
  t201_n228: return 0.019900141283869743;
  t201_n229: return -0.04383092001080513;
  t201_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t201_n232;
  t201_n231: return 0.008638624101877213;
  t201_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t201_n242;
  t201_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t201_n235;
  t201_n234: return 0.018621103838086128;
  t201_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t201_n239;
  t201_n236: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t201_n238;
  t201_n237: return 0.11149800568819046;
  t201_n238: return 0.09242136031389236;
  t201_n239: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t201_n241;
  t201_n240: return 0.07976624369621277;
  t201_n241: return 0.02024233154952526;
  t201_n242: return -0.058991286903619766;
  t201_n243: return 0.002316157566383481;
  t201_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t201_n246;
  t201_n245: return 0.007135366555303335;
  t201_n246: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t201_n254;
  t201_n247: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t201_n253;
  t201_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t201_n252;
  t201_n249: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t201_n251;
  t201_n250: return 0.06431876122951508;
  t201_n251: return -0.14445452392101288;
  t201_n252: return 0.1008845865726471;
  t201_n253: return -0.0008709663525223732;
  t201_n254: return 0.008364851586520672;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree202(const Example& E) {
  t202_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t202_n254;
  t202_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t202_n3;
  t202_n2: return -0.000392021203879267;
  t202_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n5;
  t202_n4: return -0.020546546205878258;
  t202_n5: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t202_n253;
  t202_n6: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t202_n176;
  t202_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n21;
  t202_n8: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n10;
  t202_n9: return 0.025431349873542786;
  t202_n10: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t202_n12;
  t202_n11: return -0.010474073700606823;
  t202_n12: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t202_n20;
  t202_n13: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t202_n15;
  t202_n14: return 0.015953585505485535;
  t202_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n19;
  t202_n16: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t202_n18;
  t202_n17: return 0.10663313418626785;
  t202_n18: return -0.021021706983447075;
  t202_n19: return 0.0718604028224945;
  t202_n20: return 0.014327243901789188;
  t202_n21: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t202_n71;
  t202_n22: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t202_n60;
  t202_n23: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n29;
  t202_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n26;
  t202_n25: return 0.019530437886714935;
  t202_n26: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t202_n28;
  t202_n27: return -0.02870994433760643;
  t202_n28: return 0.026728054508566856;
  t202_n29: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t202_n59;
  t202_n30: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t202_n42;
  t202_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n39;
  t202_n32: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n36;
  t202_n33: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n35;
  t202_n34: return -0.05015278607606888;
  t202_n35: return -0.13671055436134338;
  t202_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n38;
  t202_n37: return 0.04896999150514603;
  t202_n38: return -0.017691675573587418;
  t202_n39: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n41;
  t202_n40: return 0.2717243731021881;
  t202_n41: return 0.01260468177497387;
  t202_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n52;
  t202_n43: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t202_n45;
  t202_n44: return 0.11815714836120605;
  t202_n45: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t202_n51;
  t202_n46: if (E.getNumReferences() >= 3277094912 /*212.5*/) goto t202_n50;
  t202_n47: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t202_n49;
  t202_n48: return 0.09418761730194092;
  t202_n49: return -0.40954989194869995;
  t202_n50: return 0.12077296525239944;
  t202_n51: return -0.0338008813560009;
  t202_n52: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t202_n54;
  t202_n53: return -0.10172433406114578;
  t202_n54: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t202_n58;
  t202_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n57;
  t202_n56: return -0.15420381724834442;
  t202_n57: return 0.12863722443580627;
  t202_n58: return 0.0029230352956801653;
  t202_n59: return 0.13407723605632782;
  t202_n60: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n68;
  t202_n61: if (E.getNumReferences() >= 3332773120 /*21258.5*/) goto t202_n67;
  t202_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n66;
  t202_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n65;
  t202_n64: return -0.10243230313062668;
  t202_n65: return -0.3753570020198822;
  t202_n66: return -0.04708632081747055;
  t202_n67: return 0.11495395749807358;
  t202_n68: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t202_n70;
  t202_n69: return 0.1042371541261673;
  t202_n70: return -0.1076095923781395;
  t202_n71: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t202_n169;
  t202_n72: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t202_n160;
  t202_n73: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t202_n147;
  t202_n74: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t202_n92;
  t202_n75: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n79;
  t202_n76: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n78;
  t202_n77: return -0.02151193656027317;
  t202_n78: return -0.41180410981178284;
  t202_n79: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t202_n87;
  t202_n80: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n82;
  t202_n81: return 0.05984000116586685;
  t202_n82: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n84;
  t202_n83: return 0.07101621478796005;
  t202_n84: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t202_n86;
  t202_n85: return -0.11073615401983261;
  t202_n86: return 0.3095932602882385;
  t202_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n91;
  t202_n88: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n90;
  t202_n89: return -0.13243135809898376;
  t202_n90: return -0.0963142067193985;
  t202_n91: return 0.049084920436143875;
  t202_n92: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n102;
  t202_n93: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t202_n95;
  t202_n94: return -0.08604786545038223;
  t202_n95: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n97;
  t202_n96: return 0.10194612294435501;
  t202_n97: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t202_n99;
  t202_n98: return -0.1866455078125;
  t202_n99: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t202_n101;
  t202_n100: return 0.0988018661737442;
  t202_n101: return -0.14379720389842987;
  t202_n102: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t202_n138;
  t202_n103: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t202_n117;
  t202_n104: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t202_n116;
  t202_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n107;
  t202_n106: return -0.005292579066008329;
  t202_n107: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t202_n115;
  t202_n108: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n110;
  t202_n109: return -0.020810218527913094;
  t202_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n112;
  t202_n111: return 0.11614035815000534;
  t202_n112: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t202_n114;
  t202_n113: return 0.3005189597606659;
  t202_n114: return -0.047438979148864746;
  t202_n115: return -0.0004653522337321192;
  t202_n116: return -0.03233924135565758;
  t202_n117: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t202_n137;
  t202_n118: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t202_n130;
  t202_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n123;
  t202_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n122;
  t202_n121: return -0.14967665076255798;
  t202_n122: return -0.10642863810062408;
  t202_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n125;
  t202_n124: return 0.14039413630962372;
  t202_n125: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t202_n127;
  t202_n126: return -0.056577153503894806;
  t202_n127: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t202_n129;
  t202_n128: return 0.1247502788901329;
  t202_n129: return -0.10042941570281982;
  t202_n130: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t202_n132;
  t202_n131: return 0.13789357244968414;
  t202_n132: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t202_n134;
  t202_n133: return -0.03899272158741951;
  t202_n134: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n136;
  t202_n135: return 0.173732727766037;
  t202_n136: return 0.1176210567355156;
  t202_n137: return 0.016466598957777023;
  t202_n138: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t202_n142;
  t202_n139: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n141;
  t202_n140: return -0.6253217458724976;
  t202_n141: return 0.0024388842284679413;
  t202_n142: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t202_n146;
  t202_n143: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t202_n145;
  t202_n144: return -0.22135639190673828;
  t202_n145: return 0.14149077236652374;
  t202_n146: return -0.005164178553968668;
  t202_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n149;
  t202_n148: return -1.1131967306137085;
  t202_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n151;
  t202_n150: return 0.2980473041534424;
  t202_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t202_n159;
  t202_n152: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t202_n158;
  t202_n153: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t202_n157;
  t202_n154: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t202_n156;
  t202_n155: return 0.09587884694337845;
  t202_n156: return 0.05607042461633682;
  t202_n157: return -0.013476797379553318;
  t202_n158: return -0.48523440957069397;
  t202_n159: return 0.11382262408733368;
  t202_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n166;
  t202_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n165;
  t202_n162: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t202_n164;
  t202_n163: return -0.16498684883117676;
  t202_n164: return -0.4348449409008026;
  t202_n165: return -0.09280028939247131;
  t202_n166: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t202_n168;
  t202_n167: return -0.028880596160888672;
  t202_n168: return 0.031699128448963165;
  t202_n169: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n171;
  t202_n170: return 0.11657475680112839;
  t202_n171: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t202_n173;
  t202_n172: return 0.10956519097089767;
  t202_n173: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n175;
  t202_n174: return 0.08614609390497208;
  t202_n175: return -0.061129890382289886;
  t202_n176: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t202_n180;
  t202_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t202_n179;
  t202_n178: return -0.12940238416194916;
  t202_n179: return 0.007057188544422388;
  t202_n180: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t202_n232;
  t202_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t202_n183;
  t202_n182: return 0.02697604149580002;
  t202_n183: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t202_n185;
  t202_n184: return -0.007079871837049723;
  t202_n185: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t202_n193;
  t202_n186: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t202_n188;
  t202_n187: return 0.1266094297170639;
  t202_n188: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t202_n190;
  t202_n189: return -0.0629008561372757;
  t202_n190: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t202_n192;
  t202_n191: return 0.09022194892168045;
  t202_n192: return 0.05763941630721092;
  t202_n193: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t202_n223;
  t202_n194: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t202_n214;
  t202_n195: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t202_n197;
  t202_n196: return -0.1675855815410614;
  t202_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n201;
  t202_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t202_n200;
  t202_n199: return -0.2819025218486786;
  t202_n200: return 0.07519113272428513;
  t202_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t202_n213;
  t202_n202: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t202_n212;
  t202_n203: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t202_n205;
  t202_n204: return 0.1014089286327362;
  t202_n205: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t202_n207;
  t202_n206: return -0.027563277631998062;
  t202_n207: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t202_n211;
  t202_n208: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t202_n210;
  t202_n209: return 0.08653315901756287;
  t202_n210: return -0.058416418731212616;
  t202_n211: return -0.5225893259048462;
  t202_n212: return 0.11094887554645538;
  t202_n213: return -0.14154313504695892;
  t202_n214: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t202_n222;
  t202_n215: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t202_n221;
  t202_n216: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t202_n218;
  t202_n217: return -0.10057640075683594;
  t202_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n220;
  t202_n219: return 0.09928549081087112;
  t202_n220: return 0.07748521119356155;
  t202_n221: return 0.11398769915103912;
  t202_n222: return -0.09411483258008957;
  t202_n223: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t202_n225;
  t202_n224: return -0.08721726387739182;
  t202_n225: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t202_n227;
  t202_n226: return -0.19217398762702942;
  t202_n227: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t202_n231;
  t202_n228: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t202_n230;
  t202_n229: return 0.12368885427713394;
  t202_n230: return 0.050787486135959625;
  t202_n231: return 0.016926156356930733;
  t202_n232: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t202_n250;
  t202_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t202_n241;
  t202_n234: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n240;
  t202_n235: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t202_n237;
  t202_n236: return -0.18159723281860352;
  t202_n237: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t202_n239;
  t202_n238: return 0.12364489585161209;
  t202_n239: return -0.024701323360204697;
  t202_n240: return 0.09911344200372696;
  t202_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t202_n249;
  t202_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t202_n246;
  t202_n243: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t202_n245;
  t202_n244: return 0.09773346036672592;
  t202_n245: return 0.07031174749135971;
  t202_n246: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t202_n248;
  t202_n247: return 0.08177152276039124;
  t202_n248: return -0.3197402358055115;
  t202_n249: return -0.028537483885884285;
  t202_n250: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t202_n252;
  t202_n251: return 0.06423261761665344;
  t202_n252: return 0.011914726346731186;
  t202_n253: return 0.0003895792178809643;
  t202_n254: return 0.007739389315247536;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree203(const Example& E) {
  t203_n0: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t203_n254;
  t203_n1: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t203_n241;
  t203_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t203_n4;
  t203_n3: return -0.07001685351133347;
  t203_n4: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t203_n6;
  t203_n5: return -0.001069108140654862;
  t203_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t203_n34;
  t203_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Other))) goto t203_n11;
  t203_n8: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t203_n10;
  t203_n9: return -0.015707531943917274;
  t203_n10: return -0.004269205033779144;
  t203_n11: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t203_n33;
  t203_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n16;
  t203_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n15;
  t203_n14: return 0.07858257740736008;
  t203_n15: return 0.025970419868826866;
  t203_n16: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t203_n18;
  t203_n17: return 0.020848432555794716;
  t203_n18: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t203_n32;
  t203_n19: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t203_n21;
  t203_n20: return 0.061219025403261185;
  t203_n21: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t203_n25;
  t203_n22: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t203_n24;
  t203_n23: return 0.10719464719295502;
  t203_n24: return 0.08842584490776062;
  t203_n25: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t203_n27;
  t203_n26: return -0.011043858714401722;
  t203_n27: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t203_n29;
  t203_n28: return 0.11826110631227493;
  t203_n29: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t203_n31;
  t203_n30: return 0.008819677866995335;
  t203_n31: return 0.13203583657741547;
  t203_n32: return -0.11302810162305832;
  t203_n33: return -0.03406423702836037;
  t203_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t203_n212;
  t203_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t203_n47;
  t203_n36: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t203_n40;
  t203_n37: if (E.getNumReferences() >= 3249012736 /*21.0*/) goto t203_n39;
  t203_n38: return -0.08527097851037979;
  t203_n39: return 0.10761498659849167;
  t203_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t203_n42;
  t203_n41: return -0.018741009756922722;
  t203_n42: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t203_n44;
  t203_n43: return -0.05030452087521553;
  t203_n44: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t203_n46;
  t203_n45: return 0.10492318123579025;
  t203_n46: return 0.04837169125676155;
  t203_n47: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t203_n211;
  t203_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t203_n64;
  t203_n49: if (E.getNumReferences() >= 3277193216 /*214.0*/) goto t203_n61;
  t203_n50: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t203_n60;
  t203_n51: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t203_n57;
  t203_n52: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t203_n54;
  t203_n53: return -0.021546589210629463;
  t203_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n56;
  t203_n55: return -0.2731027603149414;
  t203_n56: return -0.038747262209653854;
  t203_n57: if (E.getNumReferences() >= 3269132288 /*109.5*/) goto t203_n59;
  t203_n58: return 0.14069095253944397;
  t203_n59: return 0.04652441665530205;
  t203_n60: return -0.26008278131484985;
  t203_n61: if (E.getNumReferences() >= 3277848576 /*224.0*/) goto t203_n63;
  t203_n62: return 0.09280730783939362;
  t203_n63: return 0.002450913656502962;
  t203_n64: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t203_n208;
  t203_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n113;
  t203_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n82;
  t203_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t203_n69;
  t203_n68: return 0.03187849000096321;
  t203_n69: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t203_n77;
  t203_n70: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t203_n74;
  t203_n71: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t203_n73;
  t203_n72: return -0.09773164242506027;
  t203_n73: return 0.08698362112045288;
  t203_n74: if (E.getNumReferences() >= 3270377472 /*119.0*/) goto t203_n76;
  t203_n75: return 0.1106627881526947;
  t203_n76: return 0.03476638346910477;
  t203_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t203_n79;
  t203_n78: return 0.023855380713939667;
  t203_n79: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t203_n81;
  t203_n80: return 0.12351249158382416;
  t203_n81: return -0.23355883359909058;
  t203_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t203_n86;
  t203_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t203_n85;
  t203_n84: return -0.1608843207359314;
  t203_n85: return -0.09660622477531433;
  t203_n86: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t203_n98;
  t203_n87: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t203_n97;
  t203_n88: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t203_n94;
  t203_n89: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t203_n93;
  t203_n90: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t203_n92;
  t203_n91: return 0.09874720126390457;
  t203_n92: return -0.12102296203374863;
  t203_n93: return -0.33819615840911865;
  t203_n94: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t203_n96;
  t203_n95: return 0.1267314851284027;
  t203_n96: return -0.5076966285705566;
  t203_n97: return 0.10413751006126404;
  t203_n98: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t203_n108;
  t203_n99: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t203_n101;
  t203_n100: return -0.15072515606880188;
  t203_n101: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t203_n107;
  t203_n102: if (E.getNumReferences() >= 3263299584 /*65.0*/) goto t203_n106;
  t203_n103: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t203_n105;
  t203_n104: return 0.09894946962594986;
  t203_n105: return -0.2399912029504776;
  t203_n106: return 0.11795897781848907;
  t203_n107: return -0.04994627460837364;
  t203_n108: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t203_n112;
  t203_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n111;
  t203_n110: return -0.41311731934547424;
  t203_n111: return 0.11614057421684265;
  t203_n112: return -0.4917946457862854;
  t203_n113: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t203_n207;
  t203_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t203_n152;
  t203_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t203_n151;
  t203_n116: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t203_n122;
  t203_n117: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t203_n119;
  t203_n118: return 0.03690040111541748;
  t203_n119: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t203_n121;
  t203_n120: return -0.04743293672800064;
  t203_n121: return 0.04641037806868553;
  t203_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t203_n128;
  t203_n123: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t203_n127;
  t203_n124: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t203_n126;
  t203_n125: return -0.2032732516527176;
  t203_n126: return 0.12471210211515427;
  t203_n127: return -0.015373938716948032;
  t203_n128: if (E.getNumReferences() >= 3289767936 /*599.5*/) goto t203_n142;
  t203_n129: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t203_n139;
  t203_n130: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t203_n132;
  t203_n131: return -0.06270124763250351;
  t203_n132: if (E.getNumReferences() >= 3271163904 /*125.0*/) goto t203_n138;
  t203_n133: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t203_n135;
  t203_n134: return 0.024718446657061577;
  t203_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t203_n137;
  t203_n136: return 0.10964567214250565;
  t203_n137: return -0.24272985756397247;
  t203_n138: return -0.03254718333482742;
  t203_n139: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n141;
  t203_n140: return -0.25791865587234497;
  t203_n141: return 0.009174668230116367;
  t203_n142: if (E.getNumReferences() >= 3293167616 /*807.0*/) goto t203_n148;
  t203_n143: if (E.getNumReferences() >= 3292635136 /*774.5*/) goto t203_n147;
  t203_n144: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t203_n146;
  t203_n145: return 0.09523293375968933;
  t203_n146: return 0.0044600204564630985;
  t203_n147: return 0.09941401332616806;
  t203_n148: if (E.getNumReferences() >= 3296649216 /*1019.5*/) goto t203_n150;
  t203_n149: return -0.3356894254684448;
  t203_n150: return -0.003472345881164074;
  t203_n151: return 0.027970878407359123;
  t203_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t203_n204;
  t203_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t203_n185;
  t203_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t203_n160;
  t203_n155: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t203_n157;
  t203_n156: return -0.060866374522447586;
  t203_n157: if (E.getNumReferences() >= 3268804608 /*107.0*/) goto t203_n159;
  t203_n158: return 0.11832994222640991;
  t203_n159: return 0.013701925985515118;
  t203_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t203_n178;
  t203_n161: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t203_n177;
  t203_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n172;
  t203_n163: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t203_n165;
  t203_n164: return 0.19069983065128326;
  t203_n165: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t203_n167;
  t203_n166: return 0.05857449769973755;
  t203_n167: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t203_n171;
  t203_n168: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t203_n170;
  t203_n169: return 0.15460141003131866;
  t203_n170: return 0.12643741071224213;
  t203_n171: return -0.000344025349477306;
  t203_n172: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t203_n176;
  t203_n173: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t203_n175;
  t203_n174: return 0.18423554301261902;
  t203_n175: return -0.1833265721797943;
  t203_n176: return 0.060600396245718;
  t203_n177: return -0.0781233161687851;
  t203_n178: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t203_n182;
  t203_n179: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t203_n181;
  t203_n180: return 0.009707543067634106;
  t203_n181: return 0.08446159213781357;
  t203_n182: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t203_n184;
  t203_n183: return -0.10447164624929428;
  t203_n184: return 0.12452411651611328;
  t203_n185: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t203_n189;
  t203_n186: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n188;
  t203_n187: return 0.056155260652303696;
  t203_n188: return 0.11779310554265976;
  t203_n189: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t203_n191;
  t203_n190: return 0.054456256330013275;
  t203_n191: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t203_n201;
  t203_n192: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t203_n196;
  t203_n193: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t203_n195;
  t203_n194: return 0.09893069416284561;
  t203_n195: return -0.017664290964603424;
  t203_n196: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t203_n198;
  t203_n197: return 0.12546870112419128;
  t203_n198: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t203_n200;
  t203_n199: return 0.12453731894493103;
  t203_n200: return -0.007627296261489391;
  t203_n201: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t203_n203;
  t203_n202: return -0.1804688274860382;
  t203_n203: return 0.10501769185066223;
  t203_n204: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t203_n206;
  t203_n205: return 0.18283188343048096;
  t203_n206: return 0.14116662740707397;
  t203_n207: return -0.01603839360177517;
  t203_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t203_n210;
  t203_n209: return 0.027564693242311478;
  t203_n210: return -0.03238387778401375;
  t203_n211: return 0.0007103539537638426;
  t203_n212: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t203_n220;
  t203_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t203_n215;
  t203_n214: return -0.05193287879228592;
  t203_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t203_n217;
  t203_n216: return 0.004684971179813147;
  t203_n217: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t203_n219;
  t203_n218: return 0.0869184359908104;
  t203_n219: return 0.021947575733065605;
  t203_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t203_n232;
  t203_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t203_n223;
  t203_n222: return 0.0048154969699680805;
  t203_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n227;
  t203_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t203_n226;
  t203_n225: return 0.025093426927924156;
  t203_n226: return 0.04000544920563698;
  t203_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t203_n229;
  t203_n228: return -0.004522291943430901;
  t203_n229: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t203_n231;
  t203_n230: return 0.025130782276391983;
  t203_n231: return -0.018524421378970146;
  t203_n232: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t203_n240;
  t203_n233: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n239;
  t203_n234: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t203_n238;
  t203_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t203_n237;
  t203_n236: return 0.09194625914096832;
  t203_n237: return 0.0959152951836586;
  t203_n238: return 0.049499012529850006;
  t203_n239: return 0.06190428137779236;
  t203_n240: return -0.040968891233205795;
  t203_n241: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t203_n243;
  t203_n242: return -0.03519764542579651;
  t203_n243: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t203_n253;
  t203_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t203_n252;
  t203_n245: if (E.getNumReferences() >= 3298754560 /*1272.0*/) goto t203_n251;
  t203_n246: if (E.getNumReferences() >= 3294642176 /*897.0*/) goto t203_n250;
  t203_n247: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t203_n249;
  t203_n248: return -0.18817374110221863;
  t203_n249: return 0.5471271872520447;
  t203_n250: return 0.21484492719173431;
  t203_n251: return 0.07575211673974991;
  t203_n252: return 0.06344889104366302;
  t203_n253: return -0.06715303659439087;
  t203_n254: return 0.006851886864751577;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree204(const Example& E) {
  t204_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t204_n2;
  t204_n1: return -0.0010963560780510306;
  t204_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t204_n34;
  t204_n3: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t204_n21;
  t204_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t204_n20;
  t204_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t204_n7;
  t204_n6: return -0.0711849257349968;
  t204_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n19;
  t204_n8: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t204_n18;
  t204_n9: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t204_n17;
  t204_n10: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t204_n12;
  t204_n11: return -0.2646870017051697;
  t204_n12: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t204_n14;
  t204_n13: return 0.10979988425970078;
  t204_n14: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t204_n16;
  t204_n15: return 0.0937657430768013;
  t204_n16: return -0.7697036266326904;
  t204_n17: return 0.09204669296741486;
  t204_n18: return -0.44721490144729614;
  t204_n19: return -0.020586606115102768;
  t204_n20: return -0.003962843678891659;
  t204_n21: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t204_n33;
  t204_n22: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t204_n28;
  t204_n23: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t204_n25;
  t204_n24: return 0.0025958979967981577;
  t204_n25: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n27;
  t204_n26: return 0.10233745723962784;
  t204_n27: return 0.1061476320028305;
  t204_n28: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t204_n30;
  t204_n29: return 0.029491014778614044;
  t204_n30: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t204_n32;
  t204_n31: return -0.36295580863952637;
  t204_n32: return 0.07101372629404068;
  t204_n33: return -0.013606654480099678;
  t204_n34: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t204_n108;
  t204_n35: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t204_n41;
  t204_n36: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t204_n40;
  t204_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n39;
  t204_n38: return -0.00812511146068573;
  t204_n39: return 0.006912569515407085;
  t204_n40: return -0.0029214732348918915;
  t204_n41: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t204_n103;
  t204_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t204_n102;
  t204_n43: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t204_n91;
  t204_n44: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t204_n90;
  t204_n45: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t204_n89;
  t204_n46: if (E.getNumReferences() >= 3290464256 /*642.0*/) goto t204_n84;
  t204_n47: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t204_n49;
  t204_n48: return -0.03488090634346008;
  t204_n49: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t204_n61;
  t204_n50: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t204_n52;
  t204_n51: return -0.1609598845243454;
  t204_n52: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t204_n60;
  t204_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t204_n55;
  t204_n54: return 0.031987182796001434;
  t204_n55: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t204_n59;
  t204_n56: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t204_n58;
  t204_n57: return 0.10598579049110413;
  t204_n58: return -0.19904688000679016;
  t204_n59: return 0.0999307706952095;
  t204_n60: return -0.08891782909631729;
  t204_n61: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t204_n73;
  t204_n62: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t204_n70;
  t204_n63: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t204_n65;
  t204_n64: return -0.06496193259954453;
  t204_n65: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t204_n67;
  t204_n66: return -0.7120181322097778;
  t204_n67: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t204_n69;
  t204_n68: return 0.11613253504037857;
  t204_n69: return 0.10735166072845459;
  t204_n70: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n72;
  t204_n71: return 0.08232500404119492;
  t204_n72: return -0.1313568651676178;
  t204_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n75;
  t204_n74: return -0.0312974750995636;
  t204_n75: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t204_n83;
  t204_n76: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t204_n82;
  t204_n77: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t204_n79;
  t204_n78: return 0.06947941333055496;
  t204_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t204_n81;
  t204_n80: return 0.1449146866798401;
  t204_n81: return -0.17249280214309692;
  t204_n82: return 0.11963776499032974;
  t204_n83: return -0.0135641535744071;
  t204_n84: if (E.getNumReferences() >= 3298725888 /*1268.5*/) goto t204_n88;
  t204_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t204_n87;
  t204_n86: return 0.11106114834547043;
  t204_n87: return 0.07700547575950623;
  t204_n88: return -0.07914097607135773;
  t204_n89: return 0.04083215817809105;
  t204_n90: return -0.07814992964267731;
  t204_n91: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t204_n101;
  t204_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t204_n98;
  t204_n93: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t204_n97;
  t204_n94: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t204_n96;
  t204_n95: return 0.12128569930791855;
  t204_n96: return 0.051809608936309814;
  t204_n97: return 0.0024388963356614113;
  t204_n98: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t204_n100;
  t204_n99: return 0.028625503182411194;
  t204_n100: return -0.09804204851388931;
  t204_n101: return -0.006407593376934528;
  t204_n102: return 0.026990137994289398;
  t204_n103: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t204_n105;
  t204_n104: return 0.013408572413027287;
  t204_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t204_n107;
  t204_n106: return 0.07165194302797318;
  t204_n107: return -0.019617535173892975;
  t204_n108: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t204_n242;
  t204_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t204_n241;
  t204_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t204_n240;
  t204_n111: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t204_n123;
  t204_n112: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t204_n114;
  t204_n113: return -0.014430858194828033;
  t204_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t204_n118;
  t204_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t204_n117;
  t204_n116: return -0.05928156524896622;
  t204_n117: return -0.023894408717751503;
  t204_n118: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t204_n122;
  t204_n119: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t204_n121;
  t204_n120: return 0.011307849548757076;
  t204_n121: return 0.10342016816139221;
  t204_n122: return -0.09151016175746918;
  t204_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t204_n239;
  t204_n124: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t204_n146;
  t204_n125: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t204_n135;
  t204_n126: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t204_n128;
  t204_n127: return 0.0029458908829838037;
  t204_n128: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t204_n132;
  t204_n129: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t204_n131;
  t204_n130: return 0.10118865966796875;
  t204_n131: return 0.12099126726388931;
  t204_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n134;
  t204_n133: return 0.05446150153875351;
  t204_n134: return 0.11727790534496307;
  t204_n135: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n137;
  t204_n136: return -0.17428363859653473;
  t204_n137: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t204_n139;
  t204_n138: return -0.027245130389928818;
  t204_n139: if (E.getNumReferences() >= 3327628800 /*13797.5*/) goto t204_n145;
  t204_n140: if (E.getNumReferences() >= 3327574016 /*13744.0*/) goto t204_n144;
  t204_n141: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t204_n143;
  t204_n142: return 0.06523814052343369;
  t204_n143: return -0.37656113505363464;
  t204_n144: return 0.1529272496700287;
  t204_n145: return 0.006647639442235231;
  t204_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t204_n224;
  t204_n147: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t204_n217;
  t204_n148: if (E.getNumReferences() >= 3281698816 /*309.5*/) goto t204_n184;
  t204_n149: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n169;
  t204_n150: if (E.getNumReferences() >= 3272474624 /*142.0*/) goto t204_n168;
  t204_n151: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t204_n161;
  t204_n152: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t204_n160;
  t204_n153: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n155;
  t204_n154: return 0.005777588579803705;
  t204_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n157;
  t204_n156: return -0.13377000391483307;
  t204_n157: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t204_n159;
  t204_n158: return -0.040522798895835876;
  t204_n159: return 0.07142258435487747;
  t204_n160: return -0.5743013024330139;
  t204_n161: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t204_n163;
  t204_n162: return 0.0874486193060875;
  t204_n163: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t204_n165;
  t204_n164: return -0.6019573211669922;
  t204_n165: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t204_n167;
  t204_n166: return 0.09955229610204697;
  t204_n167: return -0.8018255829811096;
  t204_n168: return -0.6640889644622803;
  t204_n169: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t204_n183;
  t204_n170: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t204_n178;
  t204_n171: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t204_n173;
  t204_n172: return -0.06688416749238968;
  t204_n173: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t204_n175;
  t204_n174: return 0.09801968187093735;
  t204_n175: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t204_n177;
  t204_n176: return -0.01467046607285738;
  t204_n177: return 0.0844988077878952;
  t204_n178: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t204_n182;
  t204_n179: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t204_n181;
  t204_n180: return 0.034811485558748245;
  t204_n181: return 0.11282128840684891;
  t204_n182: return -0.09471707791090012;
  t204_n183: return -0.6365606188774109;
  t204_n184: if (E.getNumReferences() >= 3283763200 /*372.5*/) goto t204_n188;
  t204_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t204_n187;
  t204_n186: return 0.11493932455778122;
  t204_n187: return -0.00533424923196435;
  t204_n188: if (E.getNumReferences() >= 3294494720 /*888.0*/) goto t204_n196;
  t204_n189: if (E.getNumReferences() >= 3293356032 /*818.5*/) goto t204_n195;
  t204_n190: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t204_n192;
  t204_n191: return -0.15784913301467896;
  t204_n192: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t204_n194;
  t204_n193: return 0.09872069209814072;
  t204_n194: return -0.005182112101465464;
  t204_n195: return 0.10421105474233627;
  t204_n196: if (E.getNumReferences() >= 3336764160 /*29053.5*/) goto t204_n212;
  t204_n197: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t204_n209;
  t204_n198: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t204_n200;
  t204_n199: return -0.2519446015357971;
  t204_n200: if (E.getNumReferences() >= 3323915776 /*10171.5*/) goto t204_n208;
  t204_n201: if (E.getNumReferences() >= 3301511168 /*1608.5*/) goto t204_n205;
  t204_n202: if (E.getNumReferences() >= 3296882688 /*1043.5*/) goto t204_n204;
  t204_n203: return 0.10990212857723236;
  t204_n204: return -0.45704302191734314;
  t204_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n207;
  t204_n206: return 0.09381222724914551;
  t204_n207: return 0.02040606550872326;
  t204_n208: return -0.4082866609096527;
  t204_n209: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n211;
  t204_n210: return -0.457282692193985;
  t204_n211: return -0.08578485250473022;
  t204_n212: if (E.getNumReferences() >= 3348072384 /*73487.5*/) goto t204_n216;
  t204_n213: if (E.getNumReferences() >= 3342563200 /*47991.5*/) goto t204_n215;
  t204_n214: return 0.022360196337103844;
  t204_n215: return 0.09190305322408676;
  t204_n216: return -0.05840012803673744;
  t204_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t204_n223;
  t204_n218: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t204_n222;
  t204_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n221;
  t204_n220: return 0.0462905578315258;
  t204_n221: return -0.10876984149217606;
  t204_n222: return -0.18747185170650482;
  t204_n223: return -0.2127077728509903;
  t204_n224: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t204_n228;
  t204_n225: if (E.getNumReferences() >= 3221225472 /*2.0*/) goto t204_n227;
  t204_n226: return 0.10263665020465851;
  t204_n227: return 0.11245419830083847;
  t204_n228: if (E.getNumReferences() >= 3273555968 /*158.5*/) goto t204_n234;
  t204_n229: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t204_n233;
  t204_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n232;
  t204_n231: return -1.4933841228485107;
  t204_n232: return -0.02989800088107586;
  t204_n233: return -0.0025578744243830442;
  t204_n234: if (E.getNumReferences() >= 3285680128 /*431.0*/) goto t204_n238;
  t204_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t204_n237;
  t204_n236: return 0.1056140884757042;
  t204_n237: return 0.10217089205980301;
  t204_n238: return 0.0462900772690773;
  t204_n239: return 0.02373264729976654;
  t204_n240: return 0.019157802686095238;
  t204_n241: return 0.01758388988673687;
  t204_n242: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t204_n244;
  t204_n243: return -2.418523217784241e-05;
  t204_n244: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t204_n248;
  t204_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t204_n247;
  t204_n246: return 0.05160350725054741;
  t204_n247: return 0.1083984225988388;
  t204_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t204_n250;
  t204_n249: return -0.006782049313187599;
  t204_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t204_n252;
  t204_n251: return 0.020161915570497513;
  t204_n252: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t204_n254;
  t204_n253: return 0.09316638857126236;
  t204_n254: return 0.038224752992391586;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree205(const Example& E) {
  t205_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t205_n254;
  t205_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t205_n3;
  t205_n2: return -0.0035477662459015846;
  t205_n3: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t205_n29;
  t205_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t205_n28;
  t205_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n23;
  t205_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n22;
  t205_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t205_n11;
  t205_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t205_n10;
  t205_n9: return 0.01886044256389141;
  t205_n10: return -0.0679062083363533;
  t205_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n13;
  t205_n12: return -0.010460665449500084;
  t205_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t205_n15;
  t205_n14: return 0.005604830104857683;
  t205_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n21;
  t205_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t205_n18;
  t205_n17: return -0.0550861731171608;
  t205_n18: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n20;
  t205_n19: return 0.11019105464220047;
  t205_n20: return -0.31903377175331116;
  t205_n21: return -0.0678732767701149;
  t205_n22: return 0.013131817802786827;
  t205_n23: if (E.getNumReferences() >= 3281272832 /*296.5*/) goto t205_n25;
  t205_n24: return 0.0005456277285702527;
  t205_n25: if (E.getNumReferences() >= 3281747968 /*311.0*/) goto t205_n27;
  t205_n26: return 0.13034245371818542;
  t205_n27: return 0.034457914531230927;
  t205_n28: return 0.00675943773239851;
  t205_n29: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t205_n95;
  t205_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t205_n32;
  t205_n31: return -0.0030549010261893272;
  t205_n32: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t205_n66;
  t205_n33: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t205_n63;
  t205_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t205_n58;
  t205_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t205_n57;
  t205_n36: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n56;
  t205_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t205_n47;
  t205_n38: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t205_n40;
  t205_n39: return -0.0861697643995285;
  t205_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t205_n42;
  t205_n41: return 0.005463155452162027;
  t205_n42: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t205_n46;
  t205_n43: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n45;
  t205_n44: return 0.09558075666427612;
  t205_n45: return -0.038364559412002563;
  t205_n46: return 0.11317384243011475;
  t205_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t205_n55;
  t205_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t205_n50;
  t205_n49: return 0.005533803254365921;
  t205_n50: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n54;
  t205_n51: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t205_n53;
  t205_n52: return 0.07757734507322311;
  t205_n53: return 0.10486366599798203;
  t205_n54: return -0.2776702344417572;
  t205_n55: return 0.0954868346452713;
  t205_n56: return 0.0458683967590332;
  t205_n57: return 0.05358774587512016;
  t205_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t205_n60;
  t205_n59: return 0.04352068901062012;
  t205_n60: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n62;
  t205_n61: return 0.11226142942905426;
  t205_n62: return 0.11130339652299881;
  t205_n63: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t205_n65;
  t205_n64: return -0.03697868064045906;
  t205_n65: return 0.013159425929188728;
  t205_n66: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t205_n90;
  t205_n67: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t205_n69;
  t205_n68: return 0.02856064774096012;
  t205_n69: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t205_n87;
  t205_n70: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t205_n86;
  t205_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t205_n83;
  t205_n72: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n82;
  t205_n73: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t205_n81;
  t205_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n78;
  t205_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n77;
  t205_n76: return -0.18622790277004242;
  t205_n77: return 0.1041909009218216;
  t205_n78: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t205_n80;
  t205_n79: return 0.29756954312324524;
  t205_n80: return 0.10714169591665268;
  t205_n81: return 0.08021235466003418;
  t205_n82: return -0.5348299741744995;
  t205_n83: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n85;
  t205_n84: return -0.18686848878860474;
  t205_n85: return 0.1179603785276413;
  t205_n86: return 0.024948392063379288;
  t205_n87: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n89;
  t205_n88: return 0.1168108806014061;
  t205_n89: return -0.5182708501815796;
  t205_n90: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n92;
  t205_n91: return 0.05567968636751175;
  t205_n92: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t205_n94;
  t205_n93: return 0.06389977782964706;
  t205_n94: return 0.1037294864654541;
  t205_n95: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t205_n125;
  t205_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t205_n120;
  t205_n97: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t205_n103;
  t205_n98: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t205_n100;
  t205_n99: return -0.008405827917158604;
  t205_n100: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t205_n102;
  t205_n101: return 0.1071009635925293;
  t205_n102: return 0.00684643629938364;
  t205_n103: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t205_n111;
  t205_n104: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n106;
  t205_n105: return -0.0535847432911396;
  t205_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n110;
  t205_n107: if (E.getNumReferences() >= 3291021312 /*676.0*/) goto t205_n109;
  t205_n108: return -0.12150327116250992;
  t205_n109: return -0.6768559813499451;
  t205_n110: return 0.01645197905600071;
  t205_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t205_n113;
  t205_n112: return -0.015505786053836346;
  t205_n113: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t205_n115;
  t205_n114: return -0.035544198006391525;
  t205_n115: if (E.getNumReferences() >= 3283238912 /*356.5*/) goto t205_n117;
  t205_n116: return 0.11663801968097687;
  t205_n117: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n119;
  t205_n118: return -0.2533969283103943;
  t205_n119: return 0.08129493147134781;
  t205_n120: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t205_n122;
  t205_n121: return -0.0030390487518161535;
  t205_n122: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t205_n124;
  t205_n123: return -0.014236174523830414;
  t205_n124: return 0.034948382526636124;
  t205_n125: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t205_n219;
  t205_n126: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t205_n178;
  t205_n127: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t205_n177;
  t205_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n130;
  t205_n129: return -0.025919213891029358;
  t205_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t205_n174;
  t205_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t205_n133;
  t205_n132: return -0.16904820501804352;
  t205_n133: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t205_n163;
  t205_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n150;
  t205_n135: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t205_n149;
  t205_n136: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t205_n138;
  t205_n137: return -0.052434369921684265;
  t205_n138: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t205_n140;
  t205_n139: return -0.012674164958298206;
  t205_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n142;
  t205_n141: return -0.07218658179044724;
  t205_n142: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t205_n144;
  t205_n143: return 0.0982392281293869;
  t205_n144: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t205_n146;
  t205_n145: return -0.09448806196451187;
  t205_n146: if (E.getNumReferences() >= 3250061312 /*23.0*/) goto t205_n148;
  t205_n147: return 0.1103091910481453;
  t205_n148: return 0.02045746147632599;
  t205_n149: return 0.10525403171777725;
  t205_n150: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t205_n162;
  t205_n151: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t205_n157;
  t205_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t205_n154;
  t205_n153: return -0.03849552571773529;
  t205_n154: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t205_n156;
  t205_n155: return -0.3878748118877411;
  t205_n156: return 0.1155475601553917;
  t205_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n161;
  t205_n158: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t205_n160;
  t205_n159: return -0.3153485357761383;
  t205_n160: return 0.05161213502287865;
  t205_n161: return 0.09130112826824188;
  t205_n162: return -0.02633504755795002;
  t205_n163: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t205_n173;
  t205_n164: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n168;
  t205_n165: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n167;
  t205_n166: return 0.04238598793745041;
  t205_n167: return 0.10043366253376007;
  t205_n168: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t205_n172;
  t205_n169: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t205_n171;
  t205_n170: return 0.03221307694911957;
  t205_n171: return 0.08747874200344086;
  t205_n172: return 0.12038431316614151;
  t205_n173: return -0.02020624838769436;
  t205_n174: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t205_n176;
  t205_n175: return 0.1120791956782341;
  t205_n176: return -0.05030927434563637;
  t205_n177: return 0.05645355209708214;
  t205_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t205_n182;
  t205_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n181;
  t205_n180: return 0.06251613795757294;
  t205_n181: return -0.00698026642203331;
  t205_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t205_n214;
  t205_n183: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t205_n205;
  t205_n184: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t205_n200;
  t205_n185: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t205_n199;
  t205_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t205_n192;
  t205_n187: if (E.getNumReferences() >= 3267231744 /*95.0*/) goto t205_n189;
  t205_n188: return -0.11888431757688522;
  t205_n189: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t205_n191;
  t205_n190: return 0.13727715611457825;
  t205_n191: return -0.1296735554933548;
  t205_n192: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t205_n196;
  t205_n193: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t205_n195;
  t205_n194: return 0.3656020164489746;
  t205_n195: return 0.11410264670848846;
  t205_n196: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t205_n198;
  t205_n197: return -0.04228447750210762;
  t205_n198: return 0.15749594569206238;
  t205_n199: return 0.11426349729299545;
  t205_n200: if (E.getNumReferences() >= 3289128960 /*560.5*/) goto t205_n202;
  t205_n201: return -0.0561734177172184;
  t205_n202: if (E.getNumReferences() >= 3292184576 /*747.0*/) goto t205_n204;
  t205_n203: return 0.12126725167036057;
  t205_n204: return 0.0491623654961586;
  t205_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t205_n209;
  t205_n206: if (E.getNumReferences() >= 3318051840 /*6318.5*/) goto t205_n208;
  t205_n207: return 0.059083350002765656;
  t205_n208: return 0.11862736195325851;
  t205_n209: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t205_n213;
  t205_n210: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t205_n212;
  t205_n211: return 0.10282683372497559;
  t205_n212: return 0.11512108147144318;
  t205_n213: return 0.09529612213373184;
  t205_n214: if (E.getNumReferences() >= 3276406784 /*202.0*/) goto t205_n216;
  t205_n215: return -0.03593844175338745;
  t205_n216: if (E.getNumReferences() >= 3277160448 /*213.5*/) goto t205_n218;
  t205_n217: return 0.1081932932138443;
  t205_n218: return 0.03969117999076843;
  t205_n219: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t205_n225;
  t205_n220: if (E.getNumReferences() >= 3335646464 /*26870.5*/) goto t205_n224;
  t205_n221: if (E.getNumReferences() >= 3334899200 /*25411.0*/) goto t205_n223;
  t205_n222: return 0.02410721965134144;
  t205_n223: return 0.09914339333772659;
  t205_n224: return -0.13698039948940277;
  t205_n225: if (E.getNumReferences() >= 3279519744 /*249.5*/) goto t205_n239;
  t205_n226: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t205_n238;
  t205_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t205_n229;
  t205_n228: return -0.2247072011232376;
  t205_n229: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t205_n237;
  t205_n230: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t205_n232;
  t205_n231: return 0.025906644761562347;
  t205_n232: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t205_n236;
  t205_n233: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t205_n235;
  t205_n234: return 0.10201434046030045;
  t205_n235: return 0.04272887483239174;
  t205_n236: return 0.05804390832781792;
  t205_n237: return -0.11159816384315491;
  t205_n238: return 0.01758561283349991;
  t205_n239: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t205_n253;
  t205_n240: if (E.getNumReferences() >= 3336492544 /*28523.0*/) goto t205_n250;
  t205_n241: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t205_n245;
  t205_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t205_n244;
  t205_n243: return -0.09301857650279999;
  t205_n244: return 0.07598742842674255;
  t205_n245: if (E.getNumReferences() >= 3286794240 /*465.0*/) goto t205_n249;
  t205_n246: if (E.getNumReferences() >= 3283976192 /*379.0*/) goto t205_n248;
  t205_n247: return -0.018219074234366417;
  t205_n248: return 0.12439907342195511;
  t205_n249: return -0.02356892265379429;
  t205_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t205_n252;
  t205_n251: return 0.057075291872024536;
  t205_n252: return 0.09172344952821732;
  t205_n253: return -0.10742436349391937;
  t205_n254: return -0.0006409995257854462;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree206(const Example& E) {
  t206_n0: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t206_n146;
  t206_n1: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t206_n53;
  t206_n2: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t206_n4;
  t206_n3: return 0.00030466675525531173;
  t206_n4: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t206_n6;
  t206_n5: return 0.002995490562170744;
  t206_n6: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t206_n8;
  t206_n7: return -0.04431024193763733;
  t206_n8: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t206_n52;
  t206_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n11;
  t206_n10: return -0.0036049981135874987;
  t206_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t206_n13;
  t206_n12: return -0.02023189701139927;
  t206_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n15;
  t206_n14: return -0.08387969434261322;
  t206_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t206_n39;
  t206_n16: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t206_n20;
  t206_n17: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t206_n19;
  t206_n18: return 0.008643695153295994;
  t206_n19: return 0.03568631783127785;
  t206_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n30;
  t206_n21: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t206_n25;
  t206_n22: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t206_n24;
  t206_n23: return -0.014352276921272278;
  t206_n24: return -0.38761410117149353;
  t206_n25: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t206_n27;
  t206_n26: return -0.045622818171978;
  t206_n27: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t206_n29;
  t206_n28: return -0.023206450045108795;
  t206_n29: return 0.1437995433807373;
  t206_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t206_n32;
  t206_n31: return -0.011189529672265053;
  t206_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t206_n34;
  t206_n33: return 0.03248169273138046;
  t206_n34: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t206_n38;
  t206_n35: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t206_n37;
  t206_n36: return -0.14497621357440948;
  t206_n37: return 0.11900793761014938;
  t206_n38: return 0.17449761927127838;
  t206_n39: if (E.getFileProximityDistance() >= 3254517760 /*31.5*/) goto t206_n51;
  t206_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t206_n50;
  t206_n41: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t206_n45;
  t206_n42: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t206_n44;
  t206_n43: return 0.02758372388780117;
  t206_n44: return -0.10453066974878311;
  t206_n45: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t206_n47;
  t206_n46: return -0.0917573869228363;
  t206_n47: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t206_n49;
  t206_n48: return 0.11328768730163574;
  t206_n49: return 0.15946070849895477;
  t206_n50: return 0.017613016068935394;
  t206_n51: return 0.10894112288951874;
  t206_n52: return -0.014681218191981316;
  t206_n53: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t206_n115;
  t206_n54: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t206_n80;
  t206_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n77;
  t206_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t206_n58;
  t206_n57: return -0.013997654430568218;
  t206_n58: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n60;
  t206_n59: return 0.007749956101179123;
  t206_n60: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t206_n62;
  t206_n61: return -0.102098748087883;
  t206_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n72;
  t206_n63: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t206_n67;
  t206_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t206_n66;
  t206_n65: return -0.07478085905313492;
  t206_n66: return 0.08687093108892441;
  t206_n67: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t206_n71;
  t206_n68: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t206_n70;
  t206_n69: return 0.10155478119850159;
  t206_n70: return -0.10064344108104706;
  t206_n71: return -0.047463156282901764;
  t206_n72: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t206_n74;
  t206_n73: return -0.18618425726890564;
  t206_n74: if (E.getNumReferences() >= 3272474624 /*142.0*/) goto t206_n76;
  t206_n75: return 0.0962190330028534;
  t206_n76: return 0.04502183571457863;
  t206_n77: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n79;
  t206_n78: return 0.006115940399467945;
  t206_n79: return 0.016477437689900398;
  t206_n80: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t206_n114;
  t206_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n83;
  t206_n82: return -0.007474459707736969;
  t206_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t206_n85;
  t206_n84: return 0.008726809173822403;
  t206_n85: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t206_n87;
  t206_n86: return -0.01276147086173296;
  t206_n87: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t206_n89;
  t206_n88: return 0.03148956969380379;
  t206_n89: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t206_n113;
  t206_n90: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t206_n94;
  t206_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n93;
  t206_n92: return 0.14016193151474;
  t206_n93: return 0.10919283330440521;
  t206_n94: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t206_n112;
  t206_n95: if (E.getNumReferences() >= 3273687040 /*160.5*/) goto t206_n111;
  t206_n96: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t206_n98;
  t206_n97: return 0.10892102867364883;
  t206_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n100;
  t206_n99: return -0.21550269424915314;
  t206_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n102;
  t206_n101: return 0.027614939957857132;
  t206_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t206_n104;
  t206_n103: return 0.05478754639625549;
  t206_n104: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t206_n108;
  t206_n105: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t206_n107;
  t206_n106: return 0.09820151329040527;
  t206_n107: return 0.10882662981748581;
  t206_n108: if (E.getNumReferences() >= 3269459968 /*112.0*/) goto t206_n110;
  t206_n109: return -0.17516399919986725;
  t206_n110: return 0.10274002701044083;
  t206_n111: return 0.010007492266595364;
  t206_n112: return 0.03326047584414482;
  t206_n113: return 0.07958962768316269;
  t206_n114: return -0.0021893857046961784;
  t206_n115: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t206_n127;
  t206_n116: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t206_n126;
  t206_n117: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t206_n125;
  t206_n118: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t206_n120;
  t206_n119: return -0.11236179620027542;
  t206_n120: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t206_n124;
  t206_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t206_n123;
  t206_n122: return -0.02400903031229973;
  t206_n123: return 0.12142115086317062;
  t206_n124: return -0.020032566040754318;
  t206_n125: return 0.0377773754298687;
  t206_n126: return 0.013825050555169582;
  t206_n127: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t206_n143;
  t206_n128: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t206_n134;
  t206_n129: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t206_n131;
  t206_n130: return -0.0043007200583815575;
  t206_n131: if (E.getNumReferences() >= 3314521088 /*4594.5*/) goto t206_n133;
  t206_n132: return 0.15949225425720215;
  t206_n133: return 0.10081212967634201;
  t206_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t206_n136;
  t206_n135: return 0.0666273683309555;
  t206_n136: if (E.getNumReferences() >= 3288948736 /*549.5*/) goto t206_n140;
  t206_n137: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t206_n139;
  t206_n138: return 0.08400831371545792;
  t206_n139: return 0.14385637640953064;
  t206_n140: if (E.getNumReferences() >= 3299913728 /*1413.5*/) goto t206_n142;
  t206_n141: return 0.16062921285629272;
  t206_n142: return 0.014845959842205048;
  t206_n143: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t206_n145;
  t206_n144: return 0.11609015613794327;
  t206_n145: return 0.045305803418159485;
  t206_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t206_n180;
  t206_n147: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t206_n149;
  t206_n148: return -0.03724260628223419;
  t206_n149: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t206_n177;
  t206_n150: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n174;
  t206_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n155;
  t206_n152: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t206_n154;
  t206_n153: return -0.08677950501441956;
  t206_n154: return 0.02297508344054222;
  t206_n155: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t206_n161;
  t206_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t206_n160;
  t206_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n159;
  t206_n158: return 0.03598761558532715;
  t206_n159: return 0.09153573960065842;
  t206_n160: return 0.08024707436561584;
  t206_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n163;
  t206_n162: return -0.12084899842739105;
  t206_n163: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t206_n171;
  t206_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t206_n170;
  t206_n165: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t206_n167;
  t206_n166: return 0.08359964191913605;
  t206_n167: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n169;
  t206_n168: return -0.05288542062044144;
  t206_n169: return 0.03398735821247101;
  t206_n170: return 0.05607308819890022;
  t206_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n173;
  t206_n172: return 0.08749064058065414;
  t206_n173: return 0.09243574738502502;
  t206_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n176;
  t206_n175: return -0.03634935989975929;
  t206_n176: return -0.0024381475523114204;
  t206_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n179;
  t206_n178: return -0.2127414345741272;
  t206_n179: return 0.019211038947105408;
  t206_n180: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t206_n196;
  t206_n181: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n185;
  t206_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n184;
  t206_n183: return -0.2653038501739502;
  t206_n184: return 0.0629509910941124;
  t206_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t206_n189;
  t206_n186: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n188;
  t206_n187: return 0.037605345249176025;
  t206_n188: return 0.09729444980621338;
  t206_n189: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t206_n191;
  t206_n190: return 0.11541631817817688;
  t206_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n195;
  t206_n192: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n194;
  t206_n193: return -0.35806435346603394;
  t206_n194: return 0.051114119589328766;
  t206_n195: return 0.04420414939522743;
  t206_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t206_n204;
  t206_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t206_n199;
  t206_n198: return 0.1690506786108017;
  t206_n199: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t206_n203;
  t206_n200: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n202;
  t206_n201: return 0.05060715228319168;
  t206_n202: return 0.09684379398822784;
  t206_n203: return 0.013633021153509617;
  t206_n204: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t206_n230;
  t206_n205: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n215;
  t206_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n212;
  t206_n207: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t206_n209;
  t206_n208: return 0.0312991589307785;
  t206_n209: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t206_n211;
  t206_n210: return -0.11832619458436966;
  t206_n211: return 0.06332023441791534;
  t206_n212: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t206_n214;
  t206_n213: return 0.022915048524737358;
  t206_n214: return -0.18948401510715485;
  t206_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t206_n217;
  t206_n216: return -0.3555296063423157;
  t206_n217: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t206_n225;
  t206_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n220;
  t206_n219: return -0.06241333484649658;
  t206_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t206_n224;
  t206_n221: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t206_n223;
  t206_n222: return 0.04820972681045532;
  t206_n223: return -0.005891005974262953;
  t206_n224: return -0.15632393956184387;
  t206_n225: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t206_n227;
  t206_n226: return 0.07001382857561111;
  t206_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t206_n229;
  t206_n228: return -0.14747102558612823;
  t206_n229: return 0.0677383616566658;
  t206_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t206_n250;
  t206_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t206_n249;
  t206_n232: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t206_n240;
  t206_n233: if (E.getNumReferences() >= 3382462060 /*1280205.5*/) goto t206_n237;
  t206_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t206_n236;
  t206_n235: return -0.0854288637638092;
  t206_n236: return 0.055669281631708145;
  t206_n237: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t206_n239;
  t206_n238: return 0.026705816388130188;
  t206_n239: return -0.06650904566049576;
  t206_n240: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t206_n242;
  t206_n241: return -0.11160854995250702;
  t206_n242: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t206_n244;
  t206_n243: return 0.06519957631826401;
  t206_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t206_n248;
  t206_n245: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t206_n247;
  t206_n246: return -0.0560855008661747;
  t206_n247: return 0.04768288508057594;
  t206_n248: return 0.033247824758291245;
  t206_n249: return -0.20496970415115356;
  t206_n250: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t206_n254;
  t206_n251: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t206_n253;
  t206_n252: return 0.09079285711050034;
  t206_n253: return -0.08015575259923935;
  t206_n254: return 0.017608022317290306;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree207(const Example& E) {
  t207_n0: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t207_n242;
  t207_n1: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t207_n3;
  t207_n2: return -0.0010836465517058969;
  t207_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t207_n241;
  t207_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t207_n76;
  t207_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t207_n45;
  t207_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t207_n8;
  t207_n7: return -0.007868895307183266;
  t207_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t207_n10;
  t207_n9: return -0.03745245188474655;
  t207_n10: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t207_n38;
  t207_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t207_n13;
  t207_n12: return -0.002521607792004943;
  t207_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n33;
  t207_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t207_n18;
  t207_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t207_n17;
  t207_n16: return -0.3619915246963501;
  t207_n17: return 0.07339594513177872;
  t207_n18: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t207_n24;
  t207_n19: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t207_n21;
  t207_n20: return 0.058266881853342056;
  t207_n21: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t207_n23;
  t207_n22: return 0.10410748422145844;
  t207_n23: return -0.002662548329681158;
  t207_n24: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t207_n32;
  t207_n25: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t207_n31;
  t207_n26: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n28;
  t207_n27: return -0.06242894008755684;
  t207_n28: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t207_n30;
  t207_n29: return 0.0367981493473053;
  t207_n30: return -0.17794597148895264;
  t207_n31: return 0.09157723188400269;
  t207_n32: return -0.1830906718969345;
  t207_n33: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t207_n37;
  t207_n34: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n36;
  t207_n35: return 0.030217107385396957;
  t207_n36: return -0.12343194335699081;
  t207_n37: return 0.023992205038666725;
  t207_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t207_n44;
  t207_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n41;
  t207_n40: return 0.01863795518875122;
  t207_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t207_n43;
  t207_n42: return 0.025502551347017288;
  t207_n43: return 0.0694282278418541;
  t207_n44: return 0.0256210770457983;
  t207_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t207_n47;
  t207_n46: return -0.09849271178245544;
  t207_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t207_n49;
  t207_n48: return -0.03001004084944725;
  t207_n49: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t207_n65;
  t207_n50: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t207_n52;
  t207_n51: return 0.03688960149884224;
  t207_n52: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t207_n54;
  t207_n53: return 0.03910455107688904;
  t207_n54: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t207_n60;
  t207_n55: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n57;
  t207_n56: return 0.0995776578783989;
  t207_n57: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n59;
  t207_n58: return -0.37962576746940613;
  t207_n59: return 0.07592754811048508;
  t207_n60: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t207_n64;
  t207_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n63;
  t207_n62: return 0.1450325846672058;
  t207_n63: return 0.15031063556671143;
  t207_n64: return 0.11678744852542877;
  t207_n65: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t207_n75;
  t207_n66: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t207_n74;
  t207_n67: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t207_n69;
  t207_n68: return 0.02698829397559166;
  t207_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t207_n71;
  t207_n70: return -0.025538699701428413;
  t207_n71: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t207_n73;
  t207_n72: return -0.07556804269552231;
  t207_n73: return -0.001447806367650628;
  t207_n74: return -0.10558327287435532;
  t207_n75: return 0.004778995644301176;
  t207_n76: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t207_n228;
  t207_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t207_n101;
  t207_n78: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t207_n100;
  t207_n79: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t207_n81;
  t207_n80: return -0.02267676405608654;
  t207_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n89;
  t207_n82: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t207_n84;
  t207_n83: return 0.01961805671453476;
  t207_n84: if (E.getNumReferences() >= 3292217344 /*749.0*/) goto t207_n86;
  t207_n85: return -0.04217939078807831;
  t207_n86: if (E.getNumReferences() >= 3294355456 /*879.5*/) goto t207_n88;
  t207_n87: return 0.09333177655935287;
  t207_n88: return 0.031022757291793823;
  t207_n89: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t207_n95;
  t207_n90: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t207_n94;
  t207_n91: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t207_n93;
  t207_n92: return 0.10982923209667206;
  t207_n93: return 0.04203549027442932;
  t207_n94: return 0.10966211557388306;
  t207_n95: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t207_n99;
  t207_n96: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t207_n98;
  t207_n97: return 0.08434725552797318;
  t207_n98: return 0.024528922513127327;
  t207_n99: return -0.7611399292945862;
  t207_n100: return 0.014229596592485905;
  t207_n101: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t207_n141;
  t207_n102: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t207_n104;
  t207_n103: return 0.023578330874443054;
  t207_n104: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t207_n106;
  t207_n105: return 0.008274541236460209;
  t207_n106: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t207_n124;
  t207_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t207_n117;
  t207_n108: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n116;
  t207_n109: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n111;
  t207_n110: return -0.34166237711906433;
  t207_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t207_n115;
  t207_n112: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t207_n114;
  t207_n113: return 0.12026259303092957;
  t207_n114: return -0.10990370810031891;
  t207_n115: return 0.11780568212270737;
  t207_n116: return -0.1223856508731842;
  t207_n117: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t207_n123;
  t207_n118: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n122;
  t207_n119: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t207_n121;
  t207_n120: return -0.12006104737520218;
  t207_n121: return 0.12341353297233582;
  t207_n122: return -0.023761656135320663;
  t207_n123: return 0.11687703430652618;
  t207_n124: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t207_n126;
  t207_n125: return 0.0007205422152765095;
  t207_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n134;
  t207_n127: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n129;
  t207_n128: return 0.08105167746543884;
  t207_n129: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t207_n131;
  t207_n130: return -0.27352187037467957;
  t207_n131: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t207_n133;
  t207_n132: return 0.09757094085216522;
  t207_n133: return 0.04665127396583557;
  t207_n134: if (E.getNumReferences() >= 3277848576 /*224.0*/) goto t207_n136;
  t207_n135: return 0.01041356660425663;
  t207_n136: if (E.getNumReferences() >= 3285565440 /*427.5*/) goto t207_n140;
  t207_n137: if (E.getNumReferences() >= 3283468288 /*363.5*/) goto t207_n139;
  t207_n138: return 0.0865730494260788;
  t207_n139: return 0.12328927963972092;
  t207_n140: return -0.034440454095602036;
  t207_n141: if (E.getNumReferences() >= 3281682432 /*309.0*/) goto t207_n189;
  t207_n142: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n158;
  t207_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t207_n155;
  t207_n144: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t207_n146;
  t207_n145: return -0.004609002266079187;
  t207_n146: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t207_n148;
  t207_n147: return -0.7399060130119324;
  t207_n148: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t207_n152;
  t207_n149: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t207_n151;
  t207_n150: return -0.05524807795882225;
  t207_n151: return 0.09704115241765976;
  t207_n152: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t207_n154;
  t207_n153: return -0.2948804199695587;
  t207_n154: return 0.004263921175152063;
  t207_n155: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t207_n157;
  t207_n156: return 0.09906167536973953;
  t207_n157: return 0.021306414157152176;
  t207_n158: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t207_n188;
  t207_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t207_n171;
  t207_n160: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t207_n162;
  t207_n161: return -0.3404685854911804;
  t207_n162: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n170;
  t207_n163: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n165;
  t207_n164: return -0.004828606732189655;
  t207_n165: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t207_n169;
  t207_n166: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t207_n168;
  t207_n167: return 0.10107937455177307;
  t207_n168: return 0.06573403626680374;
  t207_n169: return -0.05898715555667877;
  t207_n170: return -0.06843451410531998;
  t207_n171: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t207_n175;
  t207_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t207_n174;
  t207_n173: return 0.1096217930316925;
  t207_n174: return -0.06304028630256653;
  t207_n175: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t207_n185;
  t207_n176: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t207_n182;
  t207_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n179;
  t207_n178: return -0.020272724330425262;
  t207_n179: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t207_n181;
  t207_n180: return 0.12619294226169586;
  t207_n181: return -0.054739195853471756;
  t207_n182: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t207_n184;
  t207_n183: return 0.10574911534786224;
  t207_n184: return 0.1056370660662651;
  t207_n185: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t207_n187;
  t207_n186: return -0.4772903323173523;
  t207_n187: return 0.01289462298154831;
  t207_n188: return -0.08863622695207596;
  t207_n189: if (E.getNumReferences() >= 3283763200 /*372.5*/) goto t207_n201;
  t207_n190: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t207_n198;
  t207_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n193;
  t207_n192: return 0.11488017439842224;
  t207_n193: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t207_n197;
  t207_n194: if (E.getNumReferences() >= 3283419136 /*362.0*/) goto t207_n196;
  t207_n195: return -0.1106596440076828;
  t207_n196: return 0.12640169262886047;
  t207_n197: return 0.12645691633224487;
  t207_n198: if (E.getNumReferences() >= 3283550208 /*366.0*/) goto t207_n200;
  t207_n199: return -0.2900792360305786;
  t207_n200: return 0.10090555995702744;
  t207_n201: if (E.getNumReferences() >= 3293421568 /*822.5*/) goto t207_n209;
  t207_n202: if (E.getNumReferences() >= 3293257728 /*812.5*/) goto t207_n208;
  t207_n203: if (E.getNumReferences() >= 3291242496 /*689.5*/) goto t207_n207;
  t207_n204: if (E.getNumReferences() >= 3291013120 /*675.5*/) goto t207_n206;
  t207_n205: return 0.050858620554208755;
  t207_n206: return 0.10807520151138306;
  t207_n207: return -0.0946434885263443;
  t207_n208: return 0.11256863176822662;
  t207_n209: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t207_n213;
  t207_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t207_n212;
  t207_n211: return -0.048810068517923355;
  t207_n212: return 0.0609462596476078;
  t207_n213: if (E.getNumReferences() >= 3350636352 /*93518.5*/) goto t207_n227;
  t207_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t207_n216;
  t207_n215: return 0.0030309208668768406;
  t207_n216: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t207_n226;
  t207_n217: if (E.getNumReferences() >= 3342139776 /*46337.5*/) goto t207_n221;
  t207_n218: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t207_n220;
  t207_n219: return -0.042293667793273926;
  t207_n220: return 0.07718449831008911;
  t207_n221: if (E.getNumReferences() >= 3347181120 /*66524.5*/) goto t207_n225;
  t207_n222: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t207_n224;
  t207_n223: return 0.0929814949631691;
  t207_n224: return 0.13274706900119781;
  t207_n225: return 0.0494009330868721;
  t207_n226: return 0.10099977254867554;
  t207_n227: return -0.05447947978973389;
  t207_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t207_n230;
  t207_n229: return 0.008750151842832565;
  t207_n230: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t207_n236;
  t207_n231: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t207_n233;
  t207_n232: return -0.1749553084373474;
  t207_n233: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t207_n235;
  t207_n234: return 0.10045239329338074;
  t207_n235: return 0.08755211532115936;
  t207_n236: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t207_n240;
  t207_n237: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t207_n239;
  t207_n238: return 0.1115797609090805;
  t207_n239: return -0.09744933247566223;
  t207_n240: return 0.03135960176587105;
  t207_n241: return 0.00353439268656075;
  t207_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t207_n244;
  t207_n243: return 0.005678664427250624;
  t207_n244: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t207_n252;
  t207_n245: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t207_n249;
  t207_n246: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t207_n248;
  t207_n247: return -0.4062214195728302;
  t207_n248: return 0.025344526395201683;
  t207_n249: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t207_n251;
  t207_n250: return 0.10187803208827972;
  t207_n251: return 0.05959952250123024;
  t207_n252: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t207_n254;
  t207_n253: return 0.014127714559435844;
  t207_n254: return -0.3529350757598877;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree208(const Example& E) {
  t208_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t208_n200;
  t208_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t208_n199;
  t208_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t208_n50;
  t208_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n35;
  t208_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t208_n6;
  t208_n5: return -0.007929716259241104;
  t208_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n8;
  t208_n7: return -0.030052881687879562;
  t208_n8: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n32;
  t208_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n29;
  t208_n10: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n28;
  t208_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n25;
  t208_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t208_n24;
  t208_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n15;
  t208_n14: return -0.6035733222961426;
  t208_n15: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t208_n23;
  t208_n16: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t208_n22;
  t208_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n21;
  t208_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n20;
  t208_n19: return 0.11019840836524963;
  t208_n20: return 0.2772600054740906;
  t208_n21: return 0.17119383811950684;
  t208_n22: return 0.05843434855341911;
  t208_n23: return 0.0655573159456253;
  t208_n24: return 0.07791076600551605;
  t208_n25: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t208_n27;
  t208_n26: return 0.08751055598258972;
  t208_n27: return -0.09210959821939468;
  t208_n28: return 0.0266452357172966;
  t208_n29: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t208_n31;
  t208_n30: return -0.0499877892434597;
  t208_n31: return 0.03372820094227791;
  t208_n32: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n34;
  t208_n33: return 0.026314804330468178;
  t208_n34: return -0.1017257422208786;
  t208_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n49;
  t208_n36: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t208_n48;
  t208_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n39;
  t208_n38: return 0.015743335708975792;
  t208_n39: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n41;
  t208_n40: return 0.028989968821406364;
  t208_n41: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t208_n43;
  t208_n42: return -0.011502997018396854;
  t208_n43: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t208_n45;
  t208_n44: return 0.022938229143619537;
  t208_n45: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t208_n47;
  t208_n46: return 0.25574514269828796;
  t208_n47: return 0.15364684164524078;
  t208_n48: return -0.003028303384780884;
  t208_n49: return 1.732500641082879e-05;
  t208_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t208_n198;
  t208_n51: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t208_n109;
  t208_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n56;
  t208_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n55;
  t208_n54: return -0.06662417948246002;
  t208_n55: return -0.17462460696697235;
  t208_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n58;
  t208_n57: return 0.0033876204397529364;
  t208_n58: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t208_n100;
  t208_n59: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t208_n65;
  t208_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t208_n62;
  t208_n61: return -0.03687388077378273;
  t208_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n64;
  t208_n63: return -0.009410233236849308;
  t208_n64: return -0.06448911130428314;
  t208_n65: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t208_n99;
  t208_n66: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t208_n98;
  t208_n67: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t208_n69;
  t208_n68: return 0.035989124327898026;
  t208_n69: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t208_n97;
  t208_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n74;
  t208_n71: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t208_n73;
  t208_n72: return -0.004740554839372635;
  t208_n73: return -0.21595795452594757;
  t208_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n92;
  t208_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t208_n83;
  t208_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t208_n78;
  t208_n77: return 0.04854409769177437;
  t208_n78: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t208_n82;
  t208_n79: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t208_n81;
  t208_n80: return 0.19816450774669647;
  t208_n81: return 0.19548073410987854;
  t208_n82: return 0.017313197255134583;
  t208_n83: if (E.getNumReferences() >= 3258449920 /*46.0*/) goto t208_n85;
  t208_n84: return 0.11870185285806656;
  t208_n85: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t208_n91;
  t208_n86: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t208_n88;
  t208_n87: return -0.16974686086177826;
  t208_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t208_n90;
  t208_n89: return -0.1405518651008606;
  t208_n90: return 0.0840344950556755;
  t208_n91: return 0.10459866374731064;
  t208_n92: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t208_n96;
  t208_n93: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t208_n95;
  t208_n94: return -0.03467744588851929;
  t208_n95: return 0.10368507355451584;
  t208_n96: return -0.16643939912319183;
  t208_n97: return 0.2210206389427185;
  t208_n98: return -0.025116905570030212;
  t208_n99: return -0.03699225187301636;
  t208_n100: if (E.getNumReferences() >= 3295461376 /*947.0*/) goto t208_n108;
  t208_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n103;
  t208_n102: return -0.03431965783238411;
  t208_n103: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t208_n107;
  t208_n104: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n106;
  t208_n105: return 0.13116565346717834;
  t208_n106: return -0.06189578399062157;
  t208_n107: return -0.035231683403253555;
  t208_n108: return 0.0938367173075676;
  t208_n109: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t208_n111;
  t208_n110: return 0.013460252434015274;
  t208_n111: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t208_n113;
  t208_n112: return 0.10262931138277054;
  t208_n113: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t208_n197;
  t208_n114: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t208_n126;
  t208_n115: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t208_n125;
  t208_n116: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t208_n118;
  t208_n117: return 0.04020227864384651;
  t208_n118: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t208_n120;
  t208_n119: return -0.09391450136899948;
  t208_n120: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t208_n124;
  t208_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n123;
  t208_n122: return -0.301787793636322;
  t208_n123: return 0.11862265318632126;
  t208_n124: return 0.08545906841754913;
  t208_n125: return -0.019472122192382812;
  t208_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t208_n194;
  t208_n127: if (E.getNumReferences() >= 3269656576 /*113.5*/) goto t208_n157;
  t208_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n156;
  t208_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t208_n147;
  t208_n130: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t208_n146;
  t208_n131: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t208_n135;
  t208_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t208_n134;
  t208_n133: return 0.011087562888860703;
  t208_n134: return 0.10401852428913116;
  t208_n135: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t208_n137;
  t208_n136: return 0.0588640421628952;
  t208_n137: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t208_n145;
  t208_n138: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t208_n144;
  t208_n139: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t208_n141;
  t208_n140: return 0.10174012184143066;
  t208_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t208_n143;
  t208_n142: return 0.27072811126708984;
  t208_n143: return 0.1602676659822464;
  t208_n144: return -0.21442362666130066;
  t208_n145: return 0.10241318494081497;
  t208_n146: return -0.0692971795797348;
  t208_n147: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t208_n155;
  t208_n148: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t208_n150;
  t208_n149: return 0.08248329162597656;
  t208_n150: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t208_n154;
  t208_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n153;
  t208_n152: return 0.15798071026802063;
  t208_n153: return 0.12306199222803116;
  t208_n154: return -0.10291524976491928;
  t208_n155: return 0.04468744993209839;
  t208_n156: return -0.006859892513602972;
  t208_n157: if (E.getNumReferences() >= 3269787648 /*114.5*/) goto t208_n161;
  t208_n158: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t208_n160;
  t208_n159: return -0.10153726488351822;
  t208_n160: return 0.12404785305261612;
  t208_n161: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t208_n191;
  t208_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n188;
  t208_n163: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t208_n181;
  t208_n164: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t208_n178;
  t208_n165: if (E.getNumReferences() >= 3283697664 /*370.5*/) goto t208_n177;
  t208_n166: if (E.getNumReferences() >= 3275227136 /*184.0*/) goto t208_n174;
  t208_n167: if (E.getNumReferences() >= 3272998912 /*150.0*/) goto t208_n173;
  t208_n168: if (E.getNumReferences() >= 3272146944 /*137.0*/) goto t208_n172;
  t208_n169: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t208_n171;
  t208_n170: return 0.12865231931209564;
  t208_n171: return -0.4780237376689911;
  t208_n172: return 0.2391093373298645;
  t208_n173: return -0.20671959221363068;
  t208_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t208_n176;
  t208_n175: return 0.1225530356168747;
  t208_n176: return 0.13616862893104553;
  t208_n177: return 0.07116031646728516;
  t208_n178: if (E.getNumReferences() >= 3287564288 /*488.5*/) goto t208_n180;
  t208_n179: return -0.0777750089764595;
  t208_n180: return 0.109553262591362;
  t208_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n183;
  t208_n182: return -0.21517546474933624;
  t208_n183: if (E.getNumReferences() >= 3274866688 /*178.5*/) goto t208_n187;
  t208_n184: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t208_n186;
  t208_n185: return 0.07850000262260437;
  t208_n186: return 0.127778559923172;
  t208_n187: return 0.02171245403587818;
  t208_n188: if (E.getNumReferences() >= 3279486976 /*249.0*/) goto t208_n190;
  t208_n189: return -0.14946699142456055;
  t208_n190: return 0.0843239575624466;
  t208_n191: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t208_n193;
  t208_n192: return -2.1929075717926025;
  t208_n193: return 0.036476779729127884;
  t208_n194: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t208_n196;
  t208_n195: return -0.05763304606080055;
  t208_n196: return 0.11664365231990814;
  t208_n197: return 0.0264977365732193;
  t208_n198: return 0.018262416124343872;
  t208_n199: return -0.00108834367711097;
  t208_n200: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t208_n224;
  t208_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t208_n203;
  t208_n202: return 0.0017677274299785495;
  t208_n203: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t208_n217;
  t208_n204: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t208_n214;
  t208_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n207;
  t208_n206: return 0.07534658908843994;
  t208_n207: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t208_n211;
  t208_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t208_n210;
  t208_n209: return -0.15269224345684052;
  t208_n210: return 0.08317548781633377;
  t208_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t208_n213;
  t208_n212: return 0.11733664572238922;
  t208_n213: return 0.11521323025226593;
  t208_n214: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n216;
  t208_n215: return 0.09224221110343933;
  t208_n216: return 0.052034150809049606;
  t208_n217: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t208_n223;
  t208_n218: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t208_n220;
  t208_n219: return -0.28751876950263977;
  t208_n220: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t208_n222;
  t208_n221: return 0.11667528003454208;
  t208_n222: return 0.11714904755353928;
  t208_n223: return -0.013398288749158382;
  t208_n224: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t208_n254;
  t208_n225: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t208_n227;
  t208_n226: return -0.012126963585615158;
  t208_n227: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t208_n253;
  t208_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t208_n244;
  t208_n229: if (E.getNumReferences() >= 3337711104 /*30903.0*/) goto t208_n235;
  t208_n230: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t208_n232;
  t208_n231: return -0.07246875762939453;
  t208_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t208_n234;
  t208_n233: return -0.224242702126503;
  t208_n234: return 0.0806955099105835;
  t208_n235: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t208_n243;
  t208_n236: if (E.getNumReferences() >= 3338157568 /*31775.0*/) goto t208_n238;
  t208_n237: return 0.034233931452035904;
  t208_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t208_n240;
  t208_n239: return 0.09642582386732101;
  t208_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t208_n242;
  t208_n241: return 0.04433480277657509;
  t208_n242: return 0.07721369713544846;
  t208_n243: return 0.012367373332381248;
  t208_n244: if (E.getNumReferences() >= 3351268608 /*98458.0*/) goto t208_n246;
  t208_n245: return 0.007677852641791105;
  t208_n246: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t208_n252;
  t208_n247: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t208_n251;
  t208_n248: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t208_n250;
  t208_n249: return 0.6916908025741577;
  t208_n250: return 0.08085692673921585;
  t208_n251: return 0.046499043703079224;
  t208_n252: return -0.1035330519080162;
  t208_n253: return 0.08199305087327957;
  t208_n254: return 0.007041280623525381;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree209(const Example& E) {
  t209_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t209_n2;
  t209_n1: return -0.0003465033369138837;
  t209_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t209_n8;
  t209_n3: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t209_n7;
  t209_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t209_n6;
  t209_n5: return -0.13543663918972015;
  t209_n6: return -0.0160287544131279;
  t209_n7: return 0.0008366018300876021;
  t209_n8: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t209_n28;
  t209_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t209_n11;
  t209_n10: return 0.013153286650776863;
  t209_n11: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t209_n23;
  t209_n12: if (E.getNumReferences() >= 3333870080 /*23401.0*/) goto t209_n18;
  t209_n13: if (E.getNumReferences() >= 3319278592 /*6917.5*/) goto t209_n15;
  t209_n14: return -0.00020976568339392543;
  t209_n15: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t209_n17;
  t209_n16: return -77.64083862304688;
  t209_n17: return -0.1996905505657196;
  t209_n18: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t209_n22;
  t209_n19: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t209_n21;
  t209_n20: return 0.14888238906860352;
  t209_n21: return 0.11757349967956543;
  t209_n22: return 0.04041058570146561;
  t209_n23: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t209_n25;
  t209_n24: return -0.0010687881149351597;
  t209_n25: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t209_n27;
  t209_n26: return 0.010404223576188087;
  t209_n27: return 0.02894306369125843;
  t209_n28: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t209_n254;
  t209_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t209_n201;
  t209_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t209_n64;
  t209_n31: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t209_n63;
  t209_n32: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n34;
  t209_n33: return -0.016232207417488098;
  t209_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t209_n48;
  t209_n35: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t209_n47;
  t209_n36: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t209_n44;
  t209_n37: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n43;
  t209_n38: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t209_n42;
  t209_n39: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t209_n41;
  t209_n40: return 0.13135604560375214;
  t209_n41: return 0.11758440732955933;
  t209_n42: return 0.5387771129608154;
  t209_n43: return 0.020576437935233116;
  t209_n44: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t209_n46;
  t209_n45: return 0.0;
  t209_n46: return 4.179494857788086;
  t209_n47: return 0.10147550702095032;
  t209_n48: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t209_n62;
  t209_n49: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t209_n53;
  t209_n50: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t209_n52;
  t209_n51: return -0.1357921063899994;
  t209_n52: return 0.1650443971157074;
  t209_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n57;
  t209_n54: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t209_n56;
  t209_n55: return -0.08247492462396622;
  t209_n56: return 0.16026712954044342;
  t209_n57: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t209_n61;
  t209_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n60;
  t209_n59: return 0.001492500538006425;
  t209_n60: return 0.13301414251327515;
  t209_n61: return 0.8903722167015076;
  t209_n62: return -0.04123705253005028;
  t209_n63: return -0.07590065151453018;
  t209_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t209_n66;
  t209_n65: return 0.00038580954424105585;
  t209_n66: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t209_n200;
  t209_n67: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t209_n143;
  t209_n68: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t209_n142;
  t209_n69: if (E.getNumReferences() >= 3278340096 /*231.5*/) goto t209_n127;
  t209_n70: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t209_n78;
  t209_n71: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n75;
  t209_n72: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t209_n74;
  t209_n73: return 0.02004646509885788;
  t209_n74: return 0.09024535864591599;
  t209_n75: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t209_n77;
  t209_n76: return -0.028520731255412102;
  t209_n77: return -0.09687400609254837;
  t209_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n82;
  t209_n79: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t209_n81;
  t209_n80: return 0.03740652650594711;
  t209_n81: return -0.011433849111199379;
  t209_n82: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n104;
  t209_n83: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t209_n97;
  t209_n84: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t209_n88;
  t209_n85: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n87;
  t209_n86: return -0.1044330894947052;
  t209_n87: return 0.01700557768344879;
  t209_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t209_n96;
  t209_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n95;
  t209_n90: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t209_n92;
  t209_n91: return -0.019931234419345856;
  t209_n92: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n94;
  t209_n93: return 0.09965702891349792;
  t209_n94: return 0.15214113891124725;
  t209_n95: return 0.06685300916433334;
  t209_n96: return 0.10777236521244049;
  t209_n97: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n99;
  t209_n98: return 0.11837547272443771;
  t209_n99: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t209_n103;
  t209_n100: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t209_n102;
  t209_n101: return 0.19672620296478271;
  t209_n102: return -0.4234304428100586;
  t209_n103: return 0.1096452921628952;
  t209_n104: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t209_n126;
  t209_n105: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t209_n117;
  t209_n106: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n112;
  t209_n107: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n111;
  t209_n108: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t209_n110;
  t209_n109: return -0.14892715215682983;
  t209_n110: return -0.0364539697766304;
  t209_n111: return 0.009138679131865501;
  t209_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t209_n116;
  t209_n113: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t209_n115;
  t209_n114: return -0.10497815161943436;
  t209_n115: return 0.16719986498355865;
  t209_n116: return 0.11280497908592224;
  t209_n117: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t209_n125;
  t209_n118: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t209_n120;
  t209_n119: return 0.11913590133190155;
  t209_n120: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t209_n122;
  t209_n121: return 0.08468074351549149;
  t209_n122: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t209_n124;
  t209_n123: return 0.084744393825531;
  t209_n124: return 0.12557491660118103;
  t209_n125: return 0.021694505587220192;
  t209_n126: return 0.12429366260766983;
  t209_n127: if (E.getNumReferences() >= 3278503936 /*234.0*/) goto t209_n131;
  t209_n128: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n130;
  t209_n129: return 0.1363212615251541;
  t209_n130: return -0.10065226256847382;
  t209_n131: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n133;
  t209_n132: return -0.0038913642056286335;
  t209_n133: if (E.getNumReferences() >= 3284353024 /*390.5*/) goto t209_n139;
  t209_n134: if (E.getNumReferences() >= 3282960384 /*348.0*/) goto t209_n136;
  t209_n135: return 0.08723988384008408;
  t209_n136: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t209_n138;
  t209_n137: return 0.020879192277789116;
  t209_n138: return 0.12989969551563263;
  t209_n139: if (E.getNumReferences() >= 3334366208 /*24370.0*/) goto t209_n141;
  t209_n140: return 0.030592693015933037;
  t209_n141: return 0.07497244328260422;
  t209_n142: return -0.03951631113886833;
  t209_n143: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t209_n185;
  t209_n144: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t209_n160;
  t209_n145: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t209_n147;
  t209_n146: return -0.016318337991833687;
  t209_n147: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t209_n157;
  t209_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n156;
  t209_n149: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n151;
  t209_n150: return 0.024448905140161514;
  t209_n151: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t209_n153;
  t209_n152: return -0.01368767861276865;
  t209_n153: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t209_n155;
  t209_n154: return 0.05452549830079079;
  t209_n155: return 0.025257233530282974;
  t209_n156: return -0.005159960128366947;
  t209_n157: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t209_n159;
  t209_n158: return 0.11049284040927887;
  t209_n159: return 0.1055283397436142;
  t209_n160: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t209_n172;
  t209_n161: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n167;
  t209_n162: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t209_n166;
  t209_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t209_n165;
  t209_n164: return 0.019568277522921562;
  t209_n165: return 0.06687229126691818;
  t209_n166: return 0.016869371756911278;
  t209_n167: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t209_n169;
  t209_n168: return -0.07253467291593552;
  t209_n169: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t209_n171;
  t209_n170: return 0.033546652644872665;
  t209_n171: return 0.15775418281555176;
  t209_n172: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t209_n184;
  t209_n173: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n183;
  t209_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t209_n176;
  t209_n175: return 0.07990877330303192;
  t209_n176: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t209_n178;
  t209_n177: return 0.02359831891953945;
  t209_n178: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n182;
  t209_n179: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t209_n181;
  t209_n180: return 0.06602393835783005;
  t209_n181: return -0.34246620535850525;
  t209_n182: return -0.12799367308616638;
  t209_n183: return 0.05276767164468765;
  t209_n184: return 0.004780441056936979;
  t209_n185: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t209_n189;
  t209_n186: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t209_n188;
  t209_n187: return 0.06324028223752975;
  t209_n188: return -0.06460803747177124;
  t209_n189: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t209_n193;
  t209_n190: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t209_n192;
  t209_n191: return -0.10214801877737045;
  t209_n192: return 0.11569949984550476;
  t209_n193: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t209_n195;
  t209_n194: return -0.0020317945163697004;
  t209_n195: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t209_n199;
  t209_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n198;
  t209_n197: return -0.10769367218017578;
  t209_n198: return 0.14581738412380219;
  t209_n199: return 0.037463437765836716;
  t209_n200: return -0.06049693003296852;
  t209_n201: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t209_n253;
  t209_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t209_n212;
  t209_n203: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t209_n205;
  t209_n204: return 0.0006702806567773223;
  t209_n205: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t209_n207;
  t209_n206: return 0.02871757559478283;
  t209_n207: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n209;
  t209_n208: return -0.09091237932443619;
  t209_n209: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t209_n211;
  t209_n210: return -0.14887316524982452;
  t209_n211: return 0.028714284300804138;
  t209_n212: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t209_n250;
  t209_n213: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t209_n233;
  t209_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t209_n218;
  t209_n215: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t209_n217;
  t209_n216: return -0.11173708736896515;
  t209_n217: return 0.07038748264312744;
  t209_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t209_n226;
  t209_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n223;
  t209_n220: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t209_n222;
  t209_n221: return 0.09719358384609222;
  t209_n222: return 0.07017568498849869;
  t209_n223: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t209_n225;
  t209_n224: return 0.0910455659031868;
  t209_n225: return -0.24611681699752808;
  t209_n226: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t209_n232;
  t209_n227: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t209_n229;
  t209_n228: return 0.14266616106033325;
  t209_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n231;
  t209_n230: return 0.12757045030593872;
  t209_n231: return 0.037185512483119965;
  t209_n232: return 0.0470869280397892;
  t209_n233: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t209_n245;
  t209_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t209_n236;
  t209_n235: return 0.031975433230400085;
  t209_n236: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t209_n240;
  t209_n237: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t209_n239;
  t209_n238: return 0.07479264587163925;
  t209_n239: return 0.08757364004850388;
  t209_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t209_n244;
  t209_n241: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t209_n243;
  t209_n242: return -1.966653823852539;
  t209_n243: return -0.03526495769619942;
  t209_n244: return 0.08317942172288895;
  t209_n245: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t209_n247;
  t209_n246: return 0.19294607639312744;
  t209_n247: if (E.getNumReferences() >= 3328351232 /*14503.0*/) goto t209_n249;
  t209_n248: return 0.07741569727659225;
  t209_n249: return -0.46834471821784973;
  t209_n250: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t209_n252;
  t209_n251: return -0.044456083327531815;
  t209_n252: return 0.009175770916044712;
  t209_n253: return 0.004855211824178696;
  t209_n254: return -0.06807418912649155;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree210(const Example& E) {
  t210_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t210_n240;
  t210_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t210_n91;
  t210_n2: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t210_n6;
  t210_n3: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t210_n5;
  t210_n4: return 0.007184136193245649;
  t210_n5: return -0.005805002525448799;
  t210_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t210_n84;
  t210_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n83;
  t210_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t210_n66;
  t210_n9: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t210_n21;
  t210_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t210_n16;
  t210_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t210_n15;
  t210_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n14;
  t210_n13: return -0.11359472572803497;
  t210_n14: return -0.1534944325685501;
  t210_n15: return -0.1067289263010025;
  t210_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t210_n20;
  t210_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n19;
  t210_n18: return 0.0327276773750782;
  t210_n19: return -0.02362982928752899;
  t210_n20: return 0.03294089064002037;
  t210_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t210_n45;
  t210_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t210_n38;
  t210_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n31;
  t210_n24: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n30;
  t210_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n29;
  t210_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n28;
  t210_n27: return -0.02771194465458393;
  t210_n28: return -0.07469461858272552;
  t210_n29: return -0.021338215097784996;
  t210_n30: return -0.006165829487144947;
  t210_n31: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t210_n37;
  t210_n32: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n34;
  t210_n33: return 0.09008818119764328;
  t210_n34: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t210_n36;
  t210_n35: return 0.09464267641305923;
  t210_n36: return 0.06184849143028259;
  t210_n37: return -0.05405690148472786;
  t210_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n40;
  t210_n39: return -0.060669660568237305;
  t210_n40: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n44;
  t210_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n43;
  t210_n42: return 0.023147305473685265;
  t210_n43: return -0.0032456654589623213;
  t210_n44: return -0.005789491347968578;
  t210_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t210_n65;
  t210_n46: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n50;
  t210_n47: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t210_n49;
  t210_n48: return 0.005291637033224106;
  t210_n49: return 0.016832904890179634;
  t210_n50: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t210_n64;
  t210_n51: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t210_n61;
  t210_n52: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t210_n58;
  t210_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t210_n55;
  t210_n54: return 0.018214061856269836;
  t210_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n57;
  t210_n56: return 0.10822399705648422;
  t210_n57: return -0.0650385245680809;
  t210_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n60;
  t210_n59: return -0.11154388636350632;
  t210_n60: return 0.21212908625602722;
  t210_n61: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n63;
  t210_n62: return -0.1641658991575241;
  t210_n63: return -0.25119316577911377;
  t210_n64: return -0.00781001104041934;
  t210_n65: return 0.03511415421962738;
  t210_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n68;
  t210_n67: return 0.011496446095407009;
  t210_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t210_n78;
  t210_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t210_n77;
  t210_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t210_n72;
  t210_n71: return 0.029213694855570793;
  t210_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n74;
  t210_n73: return 0.12706013023853302;
  t210_n74: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t210_n76;
  t210_n75: return 0.1803228110074997;
  t210_n76: return 0.06360983103513718;
  t210_n77: return 0.02532162517309189;
  t210_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t210_n82;
  t210_n79: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t210_n81;
  t210_n80: return 0.2378663271665573;
  t210_n81: return 0.1243465319275856;
  t210_n82: return -0.10131021589040756;
  t210_n83: return -0.013252598233520985;
  t210_n84: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n90;
  t210_n85: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n87;
  t210_n86: return 0.10878200083971024;
  t210_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n89;
  t210_n88: return -0.6851146817207336;
  t210_n89: return 0.02644304931163788;
  t210_n90: return -0.0411803238093853;
  t210_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t210_n107;
  t210_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t210_n106;
  t210_n93: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t210_n95;
  t210_n94: return -0.06510976701974869;
  t210_n95: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t210_n97;
  t210_n96: return -0.01055991929024458;
  t210_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t210_n99;
  t210_n98: return -0.0840660110116005;
  t210_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n105;
  t210_n100: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t210_n102;
  t210_n101: return -0.189814493060112;
  t210_n102: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t210_n104;
  t210_n103: return 0.10009827464818954;
  t210_n104: return -0.10544013231992722;
  t210_n105: return 0.09495095908641815;
  t210_n106: return 0.0009074579575099051;
  t210_n107: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t210_n235;
  t210_n108: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t210_n112;
  t210_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t210_n111;
  t210_n110: return 0.00034292152849957347;
  t210_n111: return 0.10642938315868378;
  t210_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n120;
  t210_n113: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t210_n119;
  t210_n114: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t210_n116;
  t210_n115: return 0.10436601936817169;
  t210_n116: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t210_n118;
  t210_n117: return -0.0354156419634819;
  t210_n118: return -1.3581041097640991;
  t210_n119: return -0.022736448794603348;
  t210_n120: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t210_n232;
  t210_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t210_n231;
  t210_n122: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t210_n148;
  t210_n123: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n145;
  t210_n124: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t210_n132;
  t210_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t210_n131;
  t210_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n128;
  t210_n127: return -0.14166752994060516;
  t210_n128: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t210_n130;
  t210_n129: return -0.5204707384109497;
  t210_n130: return 0.027917688712477684;
  t210_n131: return 0.009861885569989681;
  t210_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t210_n136;
  t210_n133: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n135;
  t210_n134: return -0.014073362573981285;
  t210_n135: return 0.019379017874598503;
  t210_n136: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n140;
  t210_n137: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n139;
  t210_n138: return 0.046814270317554474;
  t210_n139: return 0.009248413145542145;
  t210_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n144;
  t210_n141: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t210_n143;
  t210_n142: return -0.004246761091053486;
  t210_n143: return -0.04522773623466492;
  t210_n144: return 0.05896487459540367;
  t210_n145: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t210_n147;
  t210_n146: return -0.07437112927436829;
  t210_n147: return 0.15089809894561768;
  t210_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t210_n174;
  t210_n149: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t210_n173;
  t210_n150: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t210_n164;
  t210_n151: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t210_n163;
  t210_n152: if (E.getNumReferences() >= 3252682752 /*28.0*/) goto t210_n160;
  t210_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n159;
  t210_n154: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t210_n158;
  t210_n155: if (E.getNumReferences() >= 3229614080 /*4.0*/) goto t210_n157;
  t210_n156: return 0.09572633355855942;
  t210_n157: return 0.029781091958284378;
  t210_n158: return -0.21524783968925476;
  t210_n159: return -0.07796575874090195;
  t210_n160: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t210_n162;
  t210_n161: return 0.13118195533752441;
  t210_n162: return -0.03984343260526657;
  t210_n163: return -0.3002808690071106;
  t210_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n170;
  t210_n165: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t210_n169;
  t210_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n168;
  t210_n167: return 0.11577632278203964;
  t210_n168: return 0.059836067259311676;
  t210_n169: return 0.07023251801729202;
  t210_n170: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t210_n172;
  t210_n171: return -0.026954876258969307;
  t210_n172: return 0.088923379778862;
  t210_n173: return -0.013942532241344452;
  t210_n174: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t210_n224;
  t210_n175: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t210_n189;
  t210_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n178;
  t210_n177: return 0.05440707132220268;
  t210_n178: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n182;
  t210_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t210_n181;
  t210_n180: return 0.05907880887389183;
  t210_n181: return 0.06397019326686859;
  t210_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t210_n184;
  t210_n183: return -0.10330642759799957;
  t210_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t210_n186;
  t210_n185: return 0.02756471373140812;
  t210_n186: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n188;
  t210_n187: return 0.09717992693185806;
  t210_n188: return -0.14778541028499603;
  t210_n189: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t210_n207;
  t210_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t210_n198;
  t210_n191: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t210_n193;
  t210_n192: return 0.42307406663894653;
  t210_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n195;
  t210_n194: return 0.1290668100118637;
  t210_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t210_n197;
  t210_n196: return 0.0007603028789162636;
  t210_n197: return 0.13539406657218933;
  t210_n198: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t210_n200;
  t210_n199: return 0.7350807189941406;
  t210_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n202;
  t210_n201: return -0.32403311133384705;
  t210_n202: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t210_n206;
  t210_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t210_n205;
  t210_n204: return -0.15193313360214233;
  t210_n205: return 0.11325732618570328;
  t210_n206: return 0.010443628765642643;
  t210_n207: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n209;
  t210_n208: return 0.03502590209245682;
  t210_n209: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t210_n211;
  t210_n210: return -0.26442381739616394;
  t210_n211: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t210_n215;
  t210_n212: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t210_n214;
  t210_n213: return 0.11526091396808624;
  t210_n214: return 0.03263884037733078;
  t210_n215: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t210_n217;
  t210_n216: return -0.20476983487606049;
  t210_n217: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t210_n223;
  t210_n218: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t210_n222;
  t210_n219: if (E.getNumReferences() >= 3240099840 /*10.0*/) goto t210_n221;
  t210_n220: return 0.11584669351577759;
  t210_n221: return 0.1006685271859169;
  t210_n222: return 0.11083454638719559;
  t210_n223: return 0.011183395981788635;
  t210_n224: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n226;
  t210_n225: return -0.026062900200486183;
  t210_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t210_n228;
  t210_n227: return -0.020047632977366447;
  t210_n228: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t210_n230;
  t210_n229: return 0.04901443421840668;
  t210_n230: return 0.013953210785984993;
  t210_n231: return 0.00604663509875536;
  t210_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t210_n234;
  t210_n233: return 0.034731440246105194;
  t210_n234: return 0.014800726436078548;
  t210_n235: if (E.getNumReferences() >= 3282354176 /*329.5*/) goto t210_n237;
  t210_n236: return -0.02185334451496601;
  t210_n237: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t210_n239;
  t210_n238: return 0.1151675432920456;
  t210_n239: return 0.024226421490311623;
  t210_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t210_n254;
  t210_n241: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t210_n243;
  t210_n242: return -0.005065925884991884;
  t210_n243: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t210_n253;
  t210_n244: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t210_n250;
  t210_n245: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t210_n247;
  t210_n246: return 0.005484310910105705;
  t210_n247: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t210_n249;
  t210_n248: return 0.09569509327411652;
  t210_n249: return 0.1006852388381958;
  t210_n250: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t210_n252;
  t210_n251: return -0.21327656507492065;
  t210_n252: return 0.014570512808859348;
  t210_n253: return -0.010552647523581982;
  t210_n254: return 0.0024400686379522085;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree211(const Example& E) {
  t211_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t211_n2;
  t211_n1: return -0.00034280316322110593;
  t211_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t211_n6;
  t211_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t211_n5;
  t211_n4: return -0.07600048184394836;
  t211_n5: return 0.011051119305193424;
  t211_n6: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t211_n10;
  t211_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t211_n9;
  t211_n8: return 0.05281812325119972;
  t211_n9: return 0.10715220868587494;
  t211_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t211_n12;
  t211_n11: return -0.003724026959389448;
  t211_n12: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t211_n250;
  t211_n13: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t211_n227;
  t211_n14: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t211_n16;
  t211_n15: return 0.00814634095877409;
  t211_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t211_n180;
  t211_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t211_n77;
  t211_n18: if (E.getNumReferences() >= 3338619904 /*32678.0*/) goto t211_n66;
  t211_n19: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t211_n21;
  t211_n20: return -0.129803866147995;
  t211_n21: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t211_n65;
  t211_n22: if (E.getNumReferences() >= 3331378176 /*18534.0*/) goto t211_n54;
  t211_n23: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t211_n53;
  t211_n24: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t211_n52;
  t211_n25: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t211_n29;
  t211_n26: if (E.getNumReferences() >= 3312386048 /*3824.0*/) goto t211_n28;
  t211_n27: return 0.12664274871349335;
  t211_n28: return -0.07637408375740051;
  t211_n29: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n51;
  t211_n30: if (E.getNumReferences() >= 3329585664 /*15708.5*/) goto t211_n50;
  t211_n31: if (E.getNumReferences() >= 3325018624 /*11248.5*/) goto t211_n43;
  t211_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t211_n34;
  t211_n33: return 0.03271617367863655;
  t211_n34: if (E.getNumReferences() >= 3315421184 /*5034.0*/) goto t211_n38;
  t211_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t211_n37;
  t211_n36: return -0.863402783870697;
  t211_n37: return 0.035410359501838684;
  t211_n38: if (E.getNumReferences() >= 3322780160 /*9062.5*/) goto t211_n42;
  t211_n39: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n41;
  t211_n40: return 0.10759830474853516;
  t211_n41: return 0.036926236003637314;
  t211_n42: return 0.06894124299287796;
  t211_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n49;
  t211_n44: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n46;
  t211_n45: return 0.09811899811029434;
  t211_n46: if (E.getNumReferences() >= 3328893952 /*15033.0*/) goto t211_n48;
  t211_n47: return 0.13498499989509583;
  t211_n48: return -0.12574262917041779;
  t211_n49: return 0.10809896886348724;
  t211_n50: return -0.24305488169193268;
  t211_n51: return -0.007153818849474192;
  t211_n52: return -0.0516209751367569;
  t211_n53: return -0.0837269201874733;
  t211_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n64;
  t211_n55: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t211_n57;
  t211_n56: return 0.04613684490323067;
  t211_n57: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t211_n61;
  t211_n58: if (E.getNumReferences() >= 3332774144 /*21260.5*/) goto t211_n60;
  t211_n59: return 0.11614754050970078;
  t211_n60: return 0.1115524023771286;
  t211_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n63;
  t211_n62: return 0.07260771840810776;
  t211_n63: return 0.10311765968799591;
  t211_n64: return -0.05430222675204277;
  t211_n65: return -0.11261744052171707;
  t211_n66: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t211_n76;
  t211_n67: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t211_n71;
  t211_n68: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n70;
  t211_n69: return 0.08920980989933014;
  t211_n70: return -0.0028698768001049757;
  t211_n71: if (E.getNumReferences() >= 3338736000 /*33041.5*/) goto t211_n75;
  t211_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n74;
  t211_n73: return -0.11459625512361526;
  t211_n74: return 0.11848372966051102;
  t211_n75: return 0.039685655385255814;
  t211_n76: return -0.12060762941837311;
  t211_n77: if (E.getNumReferences() >= 3340439680 /*39696.5*/) goto t211_n179;
  t211_n78: if (E.getNumReferences() >= 3338038016 /*31541.5*/) goto t211_n160;
  t211_n79: if (E.getNumReferences() >= 3329258496 /*15389.0*/) goto t211_n137;
  t211_n80: if (E.getNumReferences() >= 3328425472 /*14575.5*/) goto t211_n128;
  t211_n81: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n101;
  t211_n82: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t211_n86;
  t211_n83: if (E.getNumReferences() >= 3308642304 /*2910.0*/) goto t211_n85;
  t211_n84: return -0.26457729935646057;
  t211_n85: return 0.012462579645216465;
  t211_n86: if (E.getNumReferences() >= 3318990848 /*6777.0*/) goto t211_n94;
  t211_n87: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t211_n91;
  t211_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t211_n90;
  t211_n89: return 0.079757921397686;
  t211_n90: return 0.111492820084095;
  t211_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n93;
  t211_n92: return 0.12136856466531754;
  t211_n93: return 0.08109903335571289;
  t211_n94: if (E.getNumReferences() >= 3325044224 /*11273.5*/) goto t211_n96;
  t211_n95: return 0.01442534290254116;
  t211_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t211_n98;
  t211_n97: return 0.020566174760460854;
  t211_n98: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t211_n100;
  t211_n99: return 0.11808637529611588;
  t211_n100: return 0.08063694834709167;
  t211_n101: if (E.getNumReferences() >= 3308173312 /*2795.5*/) goto t211_n105;
  t211_n102: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t211_n104;
  t211_n103: return 0.13261355459690094;
  t211_n104: return 0.038967907428741455;
  t211_n105: if (E.getNumReferences() >= 3320574976 /*7550.5*/) goto t211_n111;
  t211_n106: if (E.getNumReferences() >= 3320417280 /*7473.5*/) goto t211_n110;
  t211_n107: if (E.getNumReferences() >= 3316514816 /*5568.0*/) goto t211_n109;
  t211_n108: return -0.005203723441809416;
  t211_n109: return 0.058509886264801025;
  t211_n110: return 0.1148066446185112;
  t211_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n123;
  t211_n112: if (E.getNumReferences() >= 3325662720 /*11877.5*/) goto t211_n120;
  t211_n113: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n115;
  t211_n114: return -0.31298479437828064;
  t211_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n117;
  t211_n116: return -0.13381317257881165;
  t211_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t211_n119;
  t211_n118: return -0.5430344939231873;
  t211_n119: return 0.10239288955926895;
  t211_n120: if (E.getNumReferences() >= 3325985280 /*12192.5*/) goto t211_n122;
  t211_n121: return 0.14983539283275604;
  t211_n122: return -0.06922974437475204;
  t211_n123: if (E.getNumReferences() >= 3323087360 /*9362.5*/) goto t211_n127;
  t211_n124: if (E.getNumReferences() >= 3321165824 /*7839.0*/) goto t211_n126;
  t211_n125: return -0.546727180480957;
  t211_n126: return 0.11391594260931015;
  t211_n127: return -0.02081524021923542;
  t211_n128: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t211_n134;
  t211_n129: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t211_n131;
  t211_n130: return -0.04680541530251503;
  t211_n131: if (E.getNumReferences() >= 3328686080 /*14830.0*/) goto t211_n133;
  t211_n132: return 0.11390171200037003;
  t211_n133: return 0.10034305602312088;
  t211_n134: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n136;
  t211_n135: return 0.12971511483192444;
  t211_n136: return 0.1745920032262802;
  t211_n137: if (E.getNumReferences() >= 3332353792 /*20439.5*/) goto t211_n153;
  t211_n138: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n140;
  t211_n139: return -0.11700206995010376;
  t211_n140: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t211_n144;
  t211_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t211_n143;
  t211_n142: return -0.8110145926475525;
  t211_n143: return 0.09581031650304794;
  t211_n144: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t211_n152;
  t211_n145: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t211_n147;
  t211_n146: return 0.027486121281981468;
  t211_n147: if (E.getNumReferences() >= 3331103232 /*17997.0*/) goto t211_n151;
  t211_n148: if (E.getNumReferences() >= 3329836032 /*15953.0*/) goto t211_n150;
  t211_n149: return 0.06274215131998062;
  t211_n150: return 0.10809224843978882;
  t211_n151: return -0.4560227394104004;
  t211_n152: return -0.32519662380218506;
  t211_n153: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t211_n159;
  t211_n154: if (E.getNumReferences() >= 3336773376 /*29071.5*/) goto t211_n158;
  t211_n155: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t211_n157;
  t211_n156: return 0.021538112312555313;
  t211_n157: return 0.07045447081327438;
  t211_n158: return -0.08420618623495102;
  t211_n159: return -0.20334933698177338;
  t211_n160: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t211_n166;
  t211_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n163;
  t211_n162: return 0.09384621679782867;
  t211_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n165;
  t211_n164: return 0.04236747696995735;
  t211_n165: return 0.08365986496210098;
  t211_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t211_n168;
  t211_n167: return 0.013080926612019539;
  t211_n168: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n170;
  t211_n169: return 0.09987849742174149;
  t211_n170: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t211_n174;
  t211_n171: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t211_n173;
  t211_n172: return 0.0639449879527092;
  t211_n173: return -0.17232026159763336;
  t211_n174: if (E.getNumReferences() >= 3339230592 /*34973.5*/) goto t211_n176;
  t211_n175: return -0.05739501491189003;
  t211_n176: if (E.getNumReferences() >= 3339662592 /*36661.0*/) goto t211_n178;
  t211_n177: return 0.1125185638666153;
  t211_n178: return 0.009024559520184994;
  t211_n179: return -0.11521992087364197;
  t211_n180: if (E.getNumReferences() >= 3320613888 /*7569.5*/) goto t211_n200;
  t211_n181: if (E.getNumReferences() >= 3314667520 /*4666.0*/) goto t211_n199;
  t211_n182: if (E.getNumReferences() >= 3313434624 /*4080.0*/) goto t211_n196;
  t211_n183: if (E.getNumReferences() >= 3312861184 /*3940.0*/) goto t211_n195;
  t211_n184: if (E.getNumReferences() >= 3312044032 /*3740.5*/) goto t211_n194;
  t211_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t211_n187;
  t211_n186: return 0.018695656210184097;
  t211_n187: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t211_n193;
  t211_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t211_n190;
  t211_n189: return -0.4568278193473816;
  t211_n190: if (E.getNumReferences() >= 3309334528 /*3079.0*/) goto t211_n192;
  t211_n191: return 0.10949040949344635;
  t211_n192: return -0.08714193850755692;
  t211_n193: return 0.10743113607168198;
  t211_n194: return 0.1199222281575203;
  t211_n195: return -0.3930237889289856;
  t211_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t211_n198;
  t211_n197: return 0.034540772438049316;
  t211_n198: return 0.10737422108650208;
  t211_n199: return -0.06603178381919861;
  t211_n200: if (E.getNumReferences() >= 3327153152 /*13333.0*/) goto t211_n218;
  t211_n201: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t211_n205;
  t211_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t211_n204;
  t211_n203: return 0.07678180187940598;
  t211_n204: return 0.10880625247955322;
  t211_n205: if (E.getNumReferences() >= 3322342912 /*8635.5*/) goto t211_n209;
  t211_n206: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t211_n208;
  t211_n207: return 0.0635736808180809;
  t211_n208: return 0.11638810485601425;
  t211_n209: if (E.getNumReferences() >= 3324232192 /*10480.5*/) goto t211_n211;
  t211_n210: return 0.010297494009137154;
  t211_n211: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t211_n217;
  t211_n212: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t211_n216;
  t211_n213: if (E.getNumReferences() >= 3324847616 /*11081.5*/) goto t211_n215;
  t211_n214: return 0.11211082339286804;
  t211_n215: return 0.1123732402920723;
  t211_n216: return -0.024774711579084396;
  t211_n217: return 0.04998670518398285;
  t211_n218: if (E.getNumReferences() >= 3336670976 /*28871.5*/) goto t211_n220;
  t211_n219: return 0.023349424824118614;
  t211_n220: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t211_n226;
  t211_n221: if (E.getNumReferences() >= 3339203200 /*34866.5*/) goto t211_n225;
  t211_n222: if (E.getNumReferences() >= 3338937088 /*33827.0*/) goto t211_n224;
  t211_n223: return 0.10163851827383041;
  t211_n224: return 0.12229029089212418;
  t211_n225: return 0.06749463826417923;
  t211_n226: return -0.17188115417957306;
  t211_n227: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t211_n235;
  t211_n228: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t211_n230;
  t211_n229: return -0.16464141011238098;
  t211_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n234;
  t211_n231: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t211_n233;
  t211_n232: return 0.11920545250177383;
  t211_n233: return 0.12024819105863571;
  t211_n234: return -0.13358068466186523;
  t211_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t211_n239;
  t211_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t211_n238;
  t211_n237: return -0.316056489944458;
  t211_n238: return 0.03782785311341286;
  t211_n239: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t211_n241;
  t211_n240: return -0.09027489274740219;
  t211_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t211_n249;
  t211_n242: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t211_n244;
  t211_n243: return 0.15811240673065186;
  t211_n244: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t211_n246;
  t211_n245: return 0.15299099683761597;
  t211_n246: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t211_n248;
  t211_n247: return 0.14035923779010773;
  t211_n248: return -0.13746154308319092;
  t211_n249: return 0.06429271399974823;
  t211_n250: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t211_n252;
  t211_n251: return -0.005044121760874987;
  t211_n252: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t211_n254;
  t211_n253: return 0.06194707006216049;
  t211_n254: return -0.25445178151130676;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree212(const Example& E) {
  t212_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t212_n2;
  t212_n1: return -0.00024227119865827262;
  t212_n2: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t212_n26;
  t212_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t212_n5;
  t212_n4: return 0.0021666993852704763;
  t212_n5: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t212_n19;
  t212_n6: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t212_n16;
  t212_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n9;
  t212_n8: return 0.0701599195599556;
  t212_n9: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t212_n15;
  t212_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t212_n12;
  t212_n11: return 0.042806509882211685;
  t212_n12: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t212_n14;
  t212_n13: return -0.5804339051246643;
  t212_n14: return 0.11154245585203171;
  t212_n15: return 0.19756686687469482;
  t212_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t212_n18;
  t212_n17: return 0.08912091702222824;
  t212_n18: return 0.04920370504260063;
  t212_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t212_n25;
  t212_n20: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t212_n22;
  t212_n21: return -0.26831361651420593;
  t212_n22: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t212_n24;
  t212_n23: return 0.11431409418582916;
  t212_n24: return 0.11046456545591354;
  t212_n25: return -0.01137707382440567;
  t212_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t212_n28;
  t212_n27: return -0.003050510073080659;
  t212_n28: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t212_n118;
  t212_n29: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t212_n31;
  t212_n30: return 0.008543040603399277;
  t212_n31: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t212_n117;
  t212_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t212_n94;
  t212_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n93;
  t212_n34: if (E.getNumReferences() >= 3333043200 /*21786.0*/) goto t212_n54;
  t212_n35: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t212_n47;
  t212_n36: if (E.getNumReferences() >= 3332703744 /*21123.0*/) goto t212_n38;
  t212_n37: return -0.04531959444284439;
  t212_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t212_n40;
  t212_n39: return -0.1600242704153061;
  t212_n40: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t212_n46;
  t212_n41: if (E.getNumReferences() >= 3332892672 /*21492.0*/) goto t212_n45;
  t212_n42: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t212_n44;
  t212_n43: return 0.09165424853563309;
  t212_n44: return 0.09544993937015533;
  t212_n45: return 0.08278928697109222;
  t212_n46: return -0.43282201886177063;
  t212_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t212_n53;
  t212_n48: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t212_n52;
  t212_n49: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t212_n51;
  t212_n50: return 0.11366850137710571;
  t212_n51: return -0.10614126175642014;
  t212_n52: return 0.022841040045022964;
  t212_n53: return 0.1033555343747139;
  t212_n54: if (E.getNumReferences() >= 3340289792 /*39111.0*/) goto t212_n56;
  t212_n55: return -0.05481288582086563;
  t212_n56: if (E.getNumReferences() >= 3340611840 /*40369.0*/) goto t212_n62;
  t212_n57: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t212_n59;
  t212_n58: return 0.06247694417834282;
  t212_n59: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t212_n61;
  t212_n60: return 0.25470808148384094;
  t212_n61: return -0.11382563412189484;
  t212_n62: if (E.getNumReferences() >= 3344648832 /*56138.5*/) goto t212_n66;
  t212_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t212_n65;
  t212_n64: return -0.02210906706750393;
  t212_n65: return 0.05485249310731888;
  t212_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n92;
  t212_n67: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t212_n75;
  t212_n68: if (E.getNumReferences() >= 3349612032 /*85516.0*/) goto t212_n70;
  t212_n69: return -0.13171687722206116;
  t212_n70: if (E.getNumReferences() >= 3356105632 /*141422.5*/) goto t212_n74;
  t212_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t212_n73;
  t212_n72: return -0.06198028847575188;
  t212_n73: return 0.041745174676179886;
  t212_n74: return -0.05486854165792465;
  t212_n75: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t212_n91;
  t212_n76: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t212_n90;
  t212_n77: if (E.getNumReferences() >= 3366258096 /*337965.5*/) goto t212_n89;
  t212_n78: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t212_n86;
  t212_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t212_n85;
  t212_n80: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t212_n84;
  t212_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t212_n83;
  t212_n82: return -1.666892170906067;
  t212_n83: return 0.14768746495246887;
  t212_n84: return -0.19868230819702148;
  t212_n85: return 0.07102274894714355;
  t212_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t212_n88;
  t212_n87: return -1.6483917236328125;
  t212_n88: return -0.12124619632959366;
  t212_n89: return 0.01859564147889614;
  t212_n90: return 0.08668447285890579;
  t212_n91: return -0.014303416945040226;
  t212_n92: return -0.0027234903536736965;
  t212_n93: return 0.0006217919290065765;
  t212_n94: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t212_n104;
  t212_n95: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t212_n97;
  t212_n96: return -0.08241885900497437;
  t212_n97: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n101;
  t212_n98: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t212_n100;
  t212_n99: return 0.13080167770385742;
  t212_n100: return 0.18490338325500488;
  t212_n101: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t212_n103;
  t212_n102: return 0.14738331735134125;
  t212_n103: return 0.10541584342718124;
  t212_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t212_n106;
  t212_n105: return -0.0023547462187707424;
  t212_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t212_n114;
  t212_n107: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t212_n113;
  t212_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t212_n112;
  t212_n109: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t212_n111;
  t212_n110: return 0.026746833696961403;
  t212_n111: return -0.41944748163223267;
  t212_n112: return 0.04904739186167717;
  t212_n113: return 0.03306254372000694;
  t212_n114: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t212_n116;
  t212_n115: return 0.11360988020896912;
  t212_n116: return -0.0049309078603982925;
  t212_n117: return 0.14936725795269012;
  t212_n118: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t212_n252;
  t212_n119: if (E.getNumReferences() >= 3337910528 /*31292.5*/) goto t212_n153;
  t212_n120: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t212_n152;
  t212_n121: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t212_n123;
  t212_n122: return -0.021710488945245743;
  t212_n123: if (E.getNumReferences() >= 3332396032 /*20522.0*/) goto t212_n133;
  t212_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t212_n132;
  t212_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t212_n131;
  t212_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t212_n128;
  t212_n127: return -0.31419506669044495;
  t212_n128: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t212_n130;
  t212_n129: return -0.42176157236099243;
  t212_n130: return 0.11305063217878342;
  t212_n131: return 0.12764038145542145;
  t212_n132: return 0.11837613582611084;
  t212_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t212_n147;
  t212_n134: if (E.getNumReferences() >= 3334173440 /*23993.5*/) goto t212_n146;
  t212_n135: if (E.getNumReferences() >= 3333190144 /*22073.0*/) goto t212_n145;
  t212_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t212_n138;
  t212_n137: return 0.2750869691371918;
  t212_n138: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n140;
  t212_n139: return -0.12331593781709671;
  t212_n140: if (E.getNumReferences() >= 3333150720 /*21996.0*/) goto t212_n142;
  t212_n141: return 0.04112645983695984;
  t212_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t212_n144;
  t212_n143: return 0.11106878519058228;
  t212_n144: return 0.05607255920767784;
  t212_n145: return -0.008150896057486534;
  t212_n146: return 0.10030964016914368;
  t212_n147: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t212_n149;
  t212_n148: return 0.06307941675186157;
  t212_n149: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n151;
  t212_n150: return 0.11582539975643158;
  t212_n151: return 0.09587429463863373;
  t212_n152: return -0.026805054396390915;
  t212_n153: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t212_n159;
  t212_n154: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t212_n156;
  t212_n155: return 0.09999288618564606;
  t212_n156: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n158;
  t212_n157: return 0.04092106223106384;
  t212_n158: return 0.08225734531879425;
  t212_n159: if (E.getNumReferences() >= 3341362816 /*43302.5*/) goto t212_n209;
  t212_n160: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t212_n200;
  t212_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t212_n179;
  t212_n162: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n170;
  t212_n163: if (E.getNumReferences() >= 3338965376 /*33937.5*/) goto t212_n165;
  t212_n164: return -0.17273680865764618;
  t212_n165: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t212_n167;
  t212_n166: return 0.03671666607260704;
  t212_n167: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t212_n169;
  t212_n168: return 0.18307898938655853;
  t212_n169: return 0.10397421568632126;
  t212_n170: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t212_n172;
  t212_n171: return -0.17257709801197052;
  t212_n172: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t212_n174;
  t212_n173: return 0.07165277749300003;
  t212_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n176;
  t212_n175: return -0.11287416517734528;
  t212_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t212_n178;
  t212_n177: return 0.08748944103717804;
  t212_n178: return 0.11585824191570282;
  t212_n179: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n199;
  t212_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t212_n194;
  t212_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n183;
  t212_n182: return 0.03292141854763031;
  t212_n183: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t212_n189;
  t212_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t212_n186;
  t212_n185: return 0.072577565908432;
  t212_n186: if (E.getNumReferences() >= 3339662592 /*36661.0*/) goto t212_n188;
  t212_n187: return 0.11165206134319305;
  t212_n188: return 0.06582724303007126;
  t212_n189: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t212_n191;
  t212_n190: return -0.1412384808063507;
  t212_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t212_n193;
  t212_n192: return -0.5677974820137024;
  t212_n193: return 0.08650339394807816;
  t212_n194: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t212_n198;
  t212_n195: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t212_n197;
  t212_n196: return -0.001021073549054563;
  t212_n197: return 0.109201580286026;
  t212_n198: return 0.049468033015728;
  t212_n199: return 0.1130000427365303;
  t212_n200: if (E.getNumReferences() >= 3338840320 /*33449.0*/) goto t212_n202;
  t212_n201: return -0.15795683860778809;
  t212_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t212_n206;
  t212_n203: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n205;
  t212_n204: return 0.07129666954278946;
  t212_n205: return 0.12230691313743591;
  t212_n206: if (E.getFileProximityDistance() >= 3249537024 /*22.0*/) goto t212_n208;
  t212_n207: return 0.014091435819864273;
  t212_n208: return -0.4039778709411621;
  t212_n209: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t212_n215;
  t212_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t212_n212;
  t212_n211: return -0.06865368783473969;
  t212_n212: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t212_n214;
  t212_n213: return -0.06876403093338013;
  t212_n214: return 0.09989161789417267;
  t212_n215: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t212_n229;
  t212_n216: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t212_n226;
  t212_n217: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t212_n219;
  t212_n218: return 0.029627038165926933;
  t212_n219: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t212_n225;
  t212_n220: if (E.getNumReferences() >= 3346276992 /*62498.5*/) goto t212_n224;
  t212_n221: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t212_n223;
  t212_n222: return 0.08750510960817337;
  t212_n223: return 0.11650906503200531;
  t212_n224: return 0.09249580651521683;
  t212_n225: return -0.013722024857997894;
  t212_n226: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t212_n228;
  t212_n227: return 0.10366365313529968;
  t212_n228: return -0.2946960926055908;
  t212_n229: if (E.getNumReferences() >= 3344616064 /*56010.5*/) goto t212_n231;
  t212_n230: return 0.08377189934253693;
  t212_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t212_n245;
  t212_n232: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t212_n242;
  t212_n233: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t212_n241;
  t212_n234: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t212_n236;
  t212_n235: return -0.017432617023587227;
  t212_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t212_n240;
  t212_n237: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t212_n239;
  t212_n238: return 0.012342731468379498;
  t212_n239: return 0.1276673823595047;
  t212_n240: return 0.10638733953237534;
  t212_n241: return -0.03303537145256996;
  t212_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t212_n244;
  t212_n243: return 0.07193852961063385;
  t212_n244: return 0.016352398321032524;
  t212_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t212_n247;
  t212_n246: return 0.04111986979842186;
  t212_n247: if (E.getNumReferences() >= 3346307456 /*62617.5*/) goto t212_n249;
  t212_n248: return 0.09943270683288574;
  t212_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t212_n251;
  t212_n250: return 0.022835224866867065;
  t212_n251: return 0.09106514602899551;
  t212_n252: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t212_n254;
  t212_n253: return -0.3171546757221222;
  t212_n254: return 0.0019244570285081863;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree213(const Example& E) {
  t213_n0: if (E.getNumReferences() >= 3372619744 /*549246.0*/) goto t213_n232;
  t213_n1: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t213_n103;
  t213_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t213_n102;
  t213_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t213_n5;
  t213_n4: return -0.038584329187870026;
  t213_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t213_n49;
  t213_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t213_n8;
  t213_n7: return -0.11134029924869537;
  t213_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n10;
  t213_n9: return 0.03589673340320587;
  t213_n10: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t213_n38;
  t213_n11: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t213_n13;
  t213_n12: return 0.038780685514211655;
  t213_n13: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t213_n27;
  t213_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n16;
  t213_n15: return -0.06326399743556976;
  t213_n16: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t213_n18;
  t213_n17: return 0.0037079579196870327;
  t213_n18: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n20;
  t213_n19: return -0.18766431510448456;
  t213_n20: if (E.getNumReferences() >= 3278012416 /*226.5*/) goto t213_n24;
  t213_n21: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t213_n23;
  t213_n22: return 0.1112707182765007;
  t213_n23: return 0.057256799191236496;
  t213_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n26;
  t213_n25: return 0.09663420170545578;
  t213_n26: return -0.10344807803630829;
  t213_n27: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t213_n29;
  t213_n28: return 0.014559306204319;
  t213_n29: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n31;
  t213_n30: return 0.1106511801481247;
  t213_n31: if (E.getNumReferences() >= 3288924160 /*548.0*/) goto t213_n37;
  t213_n32: if (E.getNumReferences() >= 3287007232 /*471.5*/) goto t213_n36;
  t213_n33: if (E.getNumReferences() >= 3282731008 /*341.0*/) goto t213_n35;
  t213_n34: return 0.10148146748542786;
  t213_n35: return -0.16463883221149445;
  t213_n36: return 0.11957104504108429;
  t213_n37: return -0.15373878180980682;
  t213_n38: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t213_n40;
  t213_n39: return -0.15105360746383667;
  t213_n40: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t213_n42;
  t213_n41: return 0.11245090514421463;
  t213_n42: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t213_n46;
  t213_n43: if (E.getNumReferences() >= 3249537024 /*22.0*/) goto t213_n45;
  t213_n44: return 0.14695754647254944;
  t213_n45: return -0.3558984696865082;
  t213_n46: if (E.getNumReferences() >= 3288883200 /*545.5*/) goto t213_n48;
  t213_n47: return 0.10898718982934952;
  t213_n48: return -0.10586269199848175;
  t213_n49: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t213_n51;
  t213_n50: return 0.0010674773948267102;
  t213_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n53;
  t213_n52: return -0.025171570479869843;
  t213_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t213_n55;
  t213_n54: return -0.06462769955396652;
  t213_n55: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t213_n93;
  t213_n56: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t213_n58;
  t213_n57: return -0.04213368147611618;
  t213_n58: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t213_n86;
  t213_n59: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t213_n85;
  t213_n60: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t213_n78;
  t213_n61: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n69;
  t213_n62: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n68;
  t213_n63: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t213_n65;
  t213_n64: return 0.12537048757076263;
  t213_n65: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t213_n67;
  t213_n66: return -0.12013889849185944;
  t213_n67: return 0.10819972306489944;
  t213_n68: return -0.11299606412649155;
  t213_n69: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t213_n77;
  t213_n70: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t213_n76;
  t213_n71: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t213_n75;
  t213_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t213_n74;
  t213_n73: return 0.004870756063610315;
  t213_n74: return 0.08671628683805466;
  t213_n75: return 0.15114310383796692;
  t213_n76: return -0.22427263855934143;
  t213_n77: return 0.1110190898180008;
  t213_n78: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t213_n84;
  t213_n79: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t213_n83;
  t213_n80: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t213_n82;
  t213_n81: return 0.12094075232744217;
  t213_n82: return -0.11828576773405075;
  t213_n83: return 0.12104195356369019;
  t213_n84: return -0.11936046183109283;
  t213_n85: return 0.10740459710359573;
  t213_n86: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t213_n88;
  t213_n87: return -0.010994750075042248;
  t213_n88: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n92;
  t213_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t213_n91;
  t213_n90: return 0.11075722426176071;
  t213_n91: return -0.11053092777729034;
  t213_n92: return 0.06779972463846207;
  t213_n93: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t213_n95;
  t213_n94: return 0.025401171296834946;
  t213_n95: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t213_n99;
  t213_n96: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t213_n98;
  t213_n97: return 0.08577165007591248;
  t213_n98: return -0.007268555462360382;
  t213_n99: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t213_n101;
  t213_n100: return -0.10173819214105606;
  t213_n101: return 0.12139065563678741;
  t213_n102: return 0.0007787266513332725;
  t213_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t213_n121;
  t213_n104: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t213_n120;
  t213_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t213_n107;
  t213_n106: return -0.010821524076163769;
  t213_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t213_n117;
  t213_n108: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t213_n116;
  t213_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n115;
  t213_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n112;
  t213_n111: return 0.08788023889064789;
  t213_n112: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t213_n114;
  t213_n113: return -0.03482140973210335;
  t213_n114: return 0.07851678878068924;
  t213_n115: return 0.05363922938704491;
  t213_n116: return -0.04978804290294647;
  t213_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t213_n119;
  t213_n118: return -0.09235583990812302;
  t213_n119: return 0.03852672874927521;
  t213_n120: return -0.00033507472835481167;
  t213_n121: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t213_n219;
  t213_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t213_n218;
  t213_n123: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t213_n181;
  t213_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n128;
  t213_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n127;
  t213_n126: return -0.015590827912092209;
  t213_n127: return -0.18161889910697937;
  t213_n128: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t213_n130;
  t213_n129: return -0.06319733709096909;
  t213_n130: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t213_n180;
  t213_n131: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n133;
  t213_n132: return -0.03019639477133751;
  t213_n133: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t213_n139;
  t213_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t213_n136;
  t213_n135: return 0.2544310986995697;
  t213_n136: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n138;
  t213_n137: return 0.10707499086856842;
  t213_n138: return 0.09112580120563507;
  t213_n139: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t213_n153;
  t213_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n144;
  t213_n141: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t213_n143;
  t213_n142: return -0.9978860020637512;
  t213_n143: return -0.11291554570198059;
  t213_n144: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t213_n152;
  t213_n145: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t213_n147;
  t213_n146: return -0.24286161363124847;
  t213_n147: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t213_n151;
  t213_n148: if (E.getNumReferences() >= 3276406784 /*202.0*/) goto t213_n150;
  t213_n149: return 0.16355963051319122;
  t213_n150: return 0.12571360170841217;
  t213_n151: return -0.42285728454589844;
  t213_n152: return -0.23861336708068848;
  t213_n153: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n173;
  t213_n154: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t213_n164;
  t213_n155: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t213_n161;
  t213_n156: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t213_n158;
  t213_n157: return -0.23168642818927765;
  t213_n158: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n160;
  t213_n159: return 0.13862237334251404;
  t213_n160: return -0.107292540371418;
  t213_n161: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t213_n163;
  t213_n162: return 0.11016970872879028;
  t213_n163: return 0.0747750774025917;
  t213_n164: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t213_n166;
  t213_n165: return -0.08174756169319153;
  t213_n166: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t213_n170;
  t213_n167: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t213_n169;
  t213_n168: return 0.11605176329612732;
  t213_n169: return -0.10188496857881546;
  t213_n170: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t213_n172;
  t213_n171: return -0.1844882369041443;
  t213_n172: return 0.03304218128323555;
  t213_n173: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t213_n177;
  t213_n174: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t213_n176;
  t213_n175: return 0.047180525958538055;
  t213_n176: return -0.14470501244068146;
  t213_n177: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t213_n179;
  t213_n178: return 0.08210038393735886;
  t213_n179: return -0.19566710293293;
  t213_n180: return -0.4765380322933197;
  t213_n181: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t213_n207;
  t213_n182: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t213_n194;
  t213_n183: if (E.getNumReferences() >= 3359775840 /*198769.5*/) goto t213_n193;
  t213_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n186;
  t213_n185: return -0.060306597501039505;
  t213_n186: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t213_n192;
  t213_n187: if (E.getNumReferences() >= 3280764928 /*281.0*/) goto t213_n191;
  t213_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t213_n190;
  t213_n189: return 0.09754377603530884;
  t213_n190: return -0.07009054720401764;
  t213_n191: return -0.05732571333646774;
  t213_n192: return -0.2788011133670807;
  t213_n193: return -0.5354407429695129;
  t213_n194: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n196;
  t213_n195: return -0.33015358448028564;
  t213_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t213_n206;
  t213_n197: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n203;
  t213_n198: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t213_n200;
  t213_n199: return 0.07615012675523758;
  t213_n200: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t213_n202;
  t213_n201: return 0.150972381234169;
  t213_n202: return -0.6933717727661133;
  t213_n203: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t213_n205;
  t213_n204: return 0.09257926046848297;
  t213_n205: return 0.10916110128164291;
  t213_n206: return 0.033111974596977234;
  t213_n207: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t213_n209;
  t213_n208: return -0.05468262359499931;
  t213_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t213_n211;
  t213_n210: return 0.0027049221098423004;
  t213_n211: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t213_n215;
  t213_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t213_n214;
  t213_n213: return -0.030440034344792366;
  t213_n214: return 0.014172902330756187;
  t213_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n217;
  t213_n216: return -0.06369675695896149;
  t213_n217: return 0.10233376175165176;
  t213_n218: return 0.004626577254384756;
  t213_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t213_n221;
  t213_n220: return 0.007392421830445528;
  t213_n221: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t213_n231;
  t213_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t213_n230;
  t213_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t213_n229;
  t213_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n228;
  t213_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n227;
  t213_n226: return 0.08369781821966171;
  t213_n227: return 0.09023391455411911;
  t213_n228: return 0.07229241728782654;
  t213_n229: return 0.06930773705244064;
  t213_n230: return 0.049424923956394196;
  t213_n231: return -0.028760729357600212;
  t213_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t213_n236;
  t213_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t213_n235;
  t213_n234: return -0.13766084611415863;
  t213_n235: return 0.005970544181764126;
  t213_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t213_n242;
  t213_n237: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t213_n239;
  t213_n238: return -0.00678854389116168;
  t213_n239: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t213_n241;
  t213_n240: return 0.10280074179172516;
  t213_n241: return 0.06506579369306564;
  t213_n242: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t213_n254;
  t213_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t213_n253;
  t213_n244: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t213_n252;
  t213_n245: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t213_n247;
  t213_n246: return 0.05677603930234909;
  t213_n247: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t213_n249;
  t213_n248: return -0.029898451641201973;
  t213_n249: if (E.getNumReferences() >= 3377570160 /*858647.0*/) goto t213_n251;
  t213_n250: return -0.055007968097925186;
  t213_n251: return 0.0883178561925888;
  t213_n252: return -0.006333341356366873;
  t213_n253: return -0.15371762216091156;
  t213_n254: return -0.264944463968277;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree214(const Example& E) {
  t214_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t214_n2;
  t214_n1: return -0.0002870055614039302;
  t214_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t214_n4;
  t214_n3: return 0.010888426564633846;
  t214_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t214_n6;
  t214_n5: return -0.03147226199507713;
  t214_n6: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t214_n8;
  t214_n7: return 0.004626988898962736;
  t214_n8: if (E.getNumReferences() >= 3322645504 /*8931.0*/) goto t214_n52;
  t214_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t214_n43;
  t214_n10: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t214_n28;
  t214_n11: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t214_n21;
  t214_n12: if (E.getNumReferences() >= 3322376704 /*8668.5*/) goto t214_n20;
  t214_n13: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t214_n17;
  t214_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n16;
  t214_n15: return -0.31714561581611633;
  t214_n16: return -0.09070657193660736;
  t214_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n19;
  t214_n18: return -0.2510635554790497;
  t214_n19: return 0.73582923412323;
  t214_n20: return 0.11404082924127579;
  t214_n21: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n25;
  t214_n22: if (E.getNumReferences() >= 3320899584 /*7709.0*/) goto t214_n24;
  t214_n23: return 0.08346317708492279;
  t214_n24: return -0.31004348397254944;
  t214_n25: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t214_n27;
  t214_n26: return -0.039201971143484116;
  t214_n27: return 0.11466765403747559;
  t214_n28: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t214_n40;
  t214_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n35;
  t214_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t214_n32;
  t214_n31: return -0.026712778955698013;
  t214_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t214_n34;
  t214_n33: return -0.043770261108875275;
  t214_n34: return 0.107777900993824;
  t214_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t214_n39;
  t214_n36: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t214_n38;
  t214_n37: return 0.11965706944465637;
  t214_n38: return 0.06596916913986206;
  t214_n39: return 0.116131491959095;
  t214_n40: if (E.getNumReferences() >= 3322247680 /*8542.5*/) goto t214_n42;
  t214_n41: return -0.002935549942776561;
  t214_n42: return 0.111217200756073;
  t214_n43: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t214_n49;
  t214_n44: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n46;
  t214_n45: return -0.017583901062607765;
  t214_n46: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n48;
  t214_n47: return 0.12964873015880585;
  t214_n48: return 0.03324296697974205;
  t214_n49: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t214_n51;
  t214_n50: return 0.11587226390838623;
  t214_n51: return 0.16062039136886597;
  t214_n52: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t214_n74;
  t214_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n63;
  t214_n54: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n56;
  t214_n55: return -0.27370280027389526;
  t214_n56: if (E.getNumReferences() >= 3338315520 /*32083.5*/) goto t214_n60;
  t214_n57: if (E.getNumReferences() >= 3326275072 /*12475.5*/) goto t214_n59;
  t214_n58: return 0.07983597368001938;
  t214_n59: return -0.12832263112068176;
  t214_n60: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t214_n62;
  t214_n61: return 0.06855403631925583;
  t214_n62: return 0.10810581594705582;
  t214_n63: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t214_n65;
  t214_n64: return 0.12000680714845657;
  t214_n65: if (E.getNumReferences() >= 3330091008 /*16202.0*/) goto t214_n73;
  t214_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n68;
  t214_n67: return 0.015592486597597599;
  t214_n68: if (E.getNumReferences() >= 3326753280 /*12942.5*/) goto t214_n70;
  t214_n69: return -0.08533131331205368;
  t214_n70: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t214_n72;
  t214_n71: return 0.17762616276741028;
  t214_n72: return 0.027869468554854393;
  t214_n73: return 0.03607572615146637;
  t214_n74: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t214_n198;
  t214_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t214_n173;
  t214_n76: if (E.getNumReferences() >= 3326609920 /*12802.5*/) goto t214_n116;
  t214_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t214_n105;
  t214_n78: if (E.getNumReferences() >= 3325253120 /*11477.5*/) goto t214_n96;
  t214_n79: if (E.getNumReferences() >= 3324362240 /*10607.5*/) goto t214_n95;
  t214_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n82;
  t214_n81: return 0.008382498286664486;
  t214_n82: if (E.getNumReferences() >= 3323899904 /*10156.0*/) goto t214_n84;
  t214_n83: return -0.07643213868141174;
  t214_n84: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t214_n86;
  t214_n85: return -0.08064107596874237;
  t214_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n88;
  t214_n87: return 0.09850802272558212;
  t214_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n94;
  t214_n89: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t214_n93;
  t214_n90: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n92;
  t214_n91: return 0.1293942779302597;
  t214_n92: return 0.08496277034282684;
  t214_n93: return 0.0734051987528801;
  t214_n94: return 0.014162966050207615;
  t214_n95: return -0.11723638325929642;
  t214_n96: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n102;
  t214_n97: if (E.getNumReferences() >= 3325340672 /*11563.0*/) goto t214_n99;
  t214_n98: return 0.13306504487991333;
  t214_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t214_n101;
  t214_n100: return 0.06680074334144592;
  t214_n101: return 0.0834677517414093;
  t214_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n104;
  t214_n103: return -0.06234924495220184;
  t214_n104: return 0.09800145030021667;
  t214_n105: if (E.getNumReferences() >= 3325920768 /*12129.5*/) goto t214_n115;
  t214_n106: if (E.getNumReferences() >= 3323780096 /*10039.0*/) goto t214_n110;
  t214_n107: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n109;
  t214_n108: return 0.19238445162773132;
  t214_n109: return 0.09549697488546371;
  t214_n110: if (E.getNumReferences() >= 3324083200 /*10335.0*/) goto t214_n112;
  t214_n111: return -0.0697799026966095;
  t214_n112: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n114;
  t214_n113: return 0.08319392055273056;
  t214_n114: return -0.13908341526985168;
  t214_n115: return 0.11377004534006119;
  t214_n116: if (E.getNumReferences() >= 3335927040 /*27418.5*/) goto t214_n120;
  t214_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n119;
  t214_n118: return -0.31896698474884033;
  t214_n119: return -0.02839004062116146;
  t214_n120: if (E.getNumReferences() >= 3341598080 /*44221.5*/) goto t214_n152;
  t214_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t214_n137;
  t214_n122: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t214_n124;
  t214_n123: return -0.020913079380989075;
  t214_n124: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t214_n134;
  t214_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n127;
  t214_n126: return -0.18024486303329468;
  t214_n127: if (E.getNumReferences() >= 3337728256 /*30936.5*/) goto t214_n129;
  t214_n128: return -0.1043701171875;
  t214_n129: if (E.getNumReferences() >= 3339108096 /*34495.0*/) goto t214_n133;
  t214_n130: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n132;
  t214_n131: return 0.11823244392871857;
  t214_n132: return 0.10882297903299332;
  t214_n133: return 0.07193925231695175;
  t214_n134: if (E.getNumReferences() >= 3337658112 /*30799.5*/) goto t214_n136;
  t214_n135: return 0.10868385434150696;
  t214_n136: return 0.009166796691715717;
  t214_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n141;
  t214_n138: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n140;
  t214_n139: return 0.06419187784194946;
  t214_n140: return 0.1110871359705925;
  t214_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t214_n143;
  t214_n142: return 0.128351092338562;
  t214_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n151;
  t214_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t214_n146;
  t214_n145: return -0.027395905926823616;
  t214_n146: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n148;
  t214_n147: return 0.11294347792863846;
  t214_n148: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t214_n150;
  t214_n149: return -0.2120169997215271;
  t214_n150: return 0.11812745779752731;
  t214_n151: return 0.02794891782104969;
  t214_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t214_n154;
  t214_n153: return 0.0044952561147511005;
  t214_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n168;
  t214_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n167;
  t214_n156: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t214_n158;
  t214_n157: return 0.10603711009025574;
  t214_n158: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t214_n162;
  t214_n159: if (E.getNumReferences() >= 3362744896 /*245161.0*/) goto t214_n161;
  t214_n160: return 0.057787202298641205;
  t214_n161: return -0.9194465279579163;
  t214_n162: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n166;
  t214_n163: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t214_n165;
  t214_n164: return 0.06287538260221481;
  t214_n165: return 0.09742517024278641;
  t214_n166: return -0.3007591962814331;
  t214_n167: return -0.03357306867837906;
  t214_n168: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t214_n172;
  t214_n169: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t214_n171;
  t214_n170: return 0.05574890598654747;
  t214_n171: return 0.12912911176681519;
  t214_n172: return 0.027890991419553757;
  t214_n173: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t214_n183;
  t214_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n180;
  t214_n175: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t214_n179;
  t214_n176: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t214_n178;
  t214_n177: return 0.09937608242034912;
  t214_n178: return -0.07205113768577576;
  t214_n179: return -0.026530073955655098;
  t214_n180: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n182;
  t214_n181: return 0.09924060106277466;
  t214_n182: return 0.047594599425792694;
  t214_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n193;
  t214_n184: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t214_n190;
  t214_n185: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t214_n189;
  t214_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n188;
  t214_n187: return -0.18646296858787537;
  t214_n188: return 0.12039343267679214;
  t214_n189: return 0.026387637481093407;
  t214_n190: if (E.getNumReferences() >= 3334366208 /*24370.0*/) goto t214_n192;
  t214_n191: return 0.11264252662658691;
  t214_n192: return 0.02717312052845955;
  t214_n193: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t214_n197;
  t214_n194: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t214_n196;
  t214_n195: return -0.8891561627388;
  t214_n196: return 0.04908740893006325;
  t214_n197: return -1.617780089378357;
  t214_n198: if (E.getNumReferences() >= 3328154112 /*14310.5*/) goto t214_n202;
  t214_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n201;
  t214_n200: return -0.08260529488325119;
  t214_n201: return 0.07058478891849518;
  t214_n202: if (E.getNumReferences() >= 3329227264 /*15358.5*/) goto t214_n208;
  t214_n203: if (E.getNumReferences() >= 3329011200 /*15147.5*/) goto t214_n205;
  t214_n204: return -0.019525377079844475;
  t214_n205: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t214_n207;
  t214_n206: return 0.07615108042955399;
  t214_n207: return 0.1089276671409607;
  t214_n208: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t214_n210;
  t214_n209: return -0.06473667919635773;
  t214_n210: if (E.getNumReferences() >= 3335347712 /*26287.0*/) goto t214_n236;
  t214_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t214_n213;
  t214_n212: return -0.6715956926345825;
  t214_n213: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t214_n235;
  t214_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t214_n228;
  t214_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n219;
  t214_n216: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t214_n218;
  t214_n217: return 0.003469789167866111;
  t214_n218: return -1.0621860027313232;
  t214_n219: if (E.getNumReferences() >= 3333913856 /*23486.5*/) goto t214_n225;
  t214_n220: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n224;
  t214_n221: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t214_n223;
  t214_n222: return 0.09740115702152252;
  t214_n223: return -0.1317017674446106;
  t214_n224: return 0.11795584112405777;
  t214_n225: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t214_n227;
  t214_n226: return 0.10800046473741531;
  t214_n227: return -0.11789735406637192;
  t214_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t214_n230;
  t214_n229: return 0.069916270673275;
  t214_n230: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t214_n232;
  t214_n231: return 0.05694553628563881;
  t214_n232: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t214_n234;
  t214_n233: return 0.1446147859096527;
  t214_n234: return 0.10448028892278671;
  t214_n235: return 0.12190419435501099;
  t214_n236: if (E.getNumReferences() >= 3336475136 /*28489.0*/) goto t214_n240;
  t214_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t214_n239;
  t214_n238: return -0.12273971736431122;
  t214_n239: return -1.1725796461105347;
  t214_n240: if (E.getNumReferences() >= 3336705792 /*28939.5*/) goto t214_n244;
  t214_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t214_n243;
  t214_n242: return 0.11483010649681091;
  t214_n243: return -0.09398112446069717;
  t214_n244: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t214_n246;
  t214_n245: return 0.021622629836201668;
  t214_n246: if (E.getNumReferences() >= 3365641360 /*318692.5*/) goto t214_n254;
  t214_n247: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t214_n251;
  t214_n248: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t214_n250;
  t214_n249: return -0.01802697405219078;
  t214_n250: return -0.2600855529308319;
  t214_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t214_n253;
  t214_n252: return 0.03576497361063957;
  t214_n253: return 0.09489196538925171;
  t214_n254: return -0.24114148318767548;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree215(const Example& E) {
  t215_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t215_n116;
  t215_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t215_n115;
  t215_n2: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t215_n4;
  t215_n3: return -0.000525520765222609;
  t215_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t215_n22;
  t215_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n7;
  t215_n6: return -0.005703703500330448;
  t215_n7: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t215_n17;
  t215_n8: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t215_n10;
  t215_n9: return -0.04722366854548454;
  t215_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n16;
  t215_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t215_n13;
  t215_n12: return -0.0781206265091896;
  t215_n13: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n15;
  t215_n14: return 0.11791439354419708;
  t215_n15: return 0.054243385791778564;
  t215_n16: return 0.005245584063231945;
  t215_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t215_n21;
  t215_n18: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t215_n20;
  t215_n19: return -0.34689968824386597;
  t215_n20: return 0.11722911149263382;
  t215_n21: return -0.022749802097678185;
  t215_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t215_n34;
  t215_n23: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t215_n29;
  t215_n24: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t215_n26;
  t215_n25: return -0.002081454498693347;
  t215_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t215_n28;
  t215_n27: return 0.026640422642230988;
  t215_n28: return 0.07987623661756516;
  t215_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n33;
  t215_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t215_n32;
  t215_n31: return -0.014779129065573215;
  t215_n32: return 0.038701944053173065;
  t215_n33: return -0.003305490128695965;
  t215_n34: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t215_n112;
  t215_n35: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t215_n71;
  t215_n36: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t215_n40;
  t215_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t215_n39;
  t215_n38: return -0.039769336581230164;
  t215_n39: return 0.0009115125285461545;
  t215_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n46;
  t215_n41: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n45;
  t215_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n44;
  t215_n43: return 0.046948984265327454;
  t215_n44: return 0.03934329003095627;
  t215_n45: return -0.0455891489982605;
  t215_n46: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t215_n58;
  t215_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag))) goto t215_n53;
  t215_n48: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n52;
  t215_n49: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n51;
  t215_n50: return 0.025111375376582146;
  t215_n51: return 0.04895181953907013;
  t215_n52: return -0.07105673104524612;
  t215_n53: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n55;
  t215_n54: return 0.07682692259550095;
  t215_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n57;
  t215_n56: return 0.031781598925590515;
  t215_n57: return -0.056963417679071426;
  t215_n58: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t215_n70;
  t215_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n69;
  t215_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t215_n62;
  t215_n61: return 0.024763165041804314;
  t215_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n64;
  t215_n63: return 0.08749526739120483;
  t215_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n66;
  t215_n65: return -0.029231049120426178;
  t215_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n68;
  t215_n67: return 0.1331503540277481;
  t215_n68: return 0.12108322232961655;
  t215_n69: return 0.06975090503692627;
  t215_n70: return -0.06495261937379837;
  t215_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t215_n91;
  t215_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n74;
  t215_n73: return 0.05505101755261421;
  t215_n74: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n90;
  t215_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n89;
  t215_n76: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t215_n88;
  t215_n77: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t215_n83;
  t215_n78: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t215_n80;
  t215_n79: return 0.09805168211460114;
  t215_n80: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t215_n82;
  t215_n81: return 0.12400797009468079;
  t215_n82: return 0.09088419377803802;
  t215_n83: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n85;
  t215_n84: return 0.07802753150463104;
  t215_n85: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t215_n87;
  t215_n86: return 0.1225515753030777;
  t215_n87: return 0.07526053488254547;
  t215_n88: return -0.24628549814224243;
  t215_n89: return 0.08126703649759293;
  t215_n90: return 0.051772166043519974;
  t215_n91: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t215_n107;
  t215_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n100;
  t215_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t215_n95;
  t215_n94: return 0.022901147603988647;
  t215_n95: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t215_n99;
  t215_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n98;
  t215_n97: return 0.15617425739765167;
  t215_n98: return 0.11502187699079514;
  t215_n99: return 0.08307646214962006;
  t215_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n104;
  t215_n101: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n103;
  t215_n102: return 0.12737838923931122;
  t215_n103: return 0.10415448993444443;
  t215_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n106;
  t215_n105: return -0.021040260791778564;
  t215_n106: return 0.11027085036039352;
  t215_n107: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t215_n109;
  t215_n108: return 0.02897081896662712;
  t215_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n111;
  t215_n110: return 0.13387419283390045;
  t215_n111: return -0.11587819457054138;
  t215_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t215_n114;
  t215_n113: return -0.4163915514945984;
  t215_n114: return -0.014813479036092758;
  t215_n115: return 0.0032182878348976374;
  t215_n116: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t215_n148;
  t215_n117: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t215_n119;
  t215_n118: return -0.14818058907985687;
  t215_n119: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t215_n133;
  t215_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable))) goto t215_n122;
  t215_n121: return -0.05432320386171341;
  t215_n122: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t215_n132;
  t215_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n125;
  t215_n124: return 0.0027383421547710896;
  t215_n125: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t215_n127;
  t215_n126: return 0.009675953537225723;
  t215_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t215_n129;
  t215_n128: return 0.011303222738206387;
  t215_n129: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t215_n131;
  t215_n130: return 0.5786706209182739;
  t215_n131: return 0.07186882197856903;
  t215_n132: return -0.007896797731518745;
  t215_n133: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t215_n141;
  t215_n134: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t215_n140;
  t215_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n139;
  t215_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t215_n138;
  t215_n137: return -0.16018126904964447;
  t215_n138: return -0.10080654919147491;
  t215_n139: return 0.0364135280251503;
  t215_n140: return -0.019617266952991486;
  t215_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n147;
  t215_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t215_n144;
  t215_n143: return -0.046192195266485214;
  t215_n144: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t215_n146;
  t215_n145: return 0.21823851764202118;
  t215_n146: return -0.08865360915660858;
  t215_n147: return 0.006617765408009291;
  t215_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t215_n150;
  t215_n149: return -0.037581317126750946;
  t215_n150: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t215_n252;
  t215_n151: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t215_n251;
  t215_n152: if (E.getNumReferences() >= 3272671232 /*145.0*/) goto t215_n238;
  t215_n153: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t215_n203;
  t215_n154: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t215_n196;
  t215_n155: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t215_n191;
  t215_n156: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n180;
  t215_n157: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t215_n161;
  t215_n158: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t215_n160;
  t215_n159: return 0.0008853496983647346;
  t215_n160: return 0.09077930450439453;
  t215_n161: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t215_n173;
  t215_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n164;
  t215_n163: return -0.12330087274312973;
  t215_n164: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t215_n168;
  t215_n165: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t215_n167;
  t215_n166: return 0.13132409751415253;
  t215_n167: return -0.2301696389913559;
  t215_n168: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t215_n170;
  t215_n169: return 0.1214355081319809;
  t215_n170: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n172;
  t215_n171: return -0.23792606592178345;
  t215_n172: return 0.10693183541297913;
  t215_n173: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t215_n179;
  t215_n174: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t215_n178;
  t215_n175: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t215_n177;
  t215_n176: return -0.14392079412937164;
  t215_n177: return 0.12296503782272339;
  t215_n178: return 0.13665416836738586;
  t215_n179: return 0.02031880058348179;
  t215_n180: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t215_n182;
  t215_n181: return -0.028128651902079582;
  t215_n182: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t215_n190;
  t215_n183: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t215_n187;
  t215_n184: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t215_n186;
  t215_n185: return 0.11477971076965332;
  t215_n186: return -0.1523343175649643;
  t215_n187: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t215_n189;
  t215_n188: return 0.11050964891910553;
  t215_n189: return -0.05804747715592384;
  t215_n190: return -0.02226955257356167;
  t215_n191: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n195;
  t215_n192: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t215_n194;
  t215_n193: return 0.092868372797966;
  t215_n194: return 0.11613620817661285;
  t215_n195: return -0.19371113181114197;
  t215_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n198;
  t215_n197: return -0.2551135718822479;
  t215_n198: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t215_n202;
  t215_n199: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t215_n201;
  t215_n200: return -0.2399294525384903;
  t215_n201: return 0.24399256706237793;
  t215_n202: return 0.02443704381585121;
  t215_n203: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t215_n207;
  t215_n204: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t215_n206;
  t215_n205: return 0.09969279170036316;
  t215_n206: return 0.12191115319728851;
  t215_n207: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t215_n211;
  t215_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n210;
  t215_n209: return 0.12552326917648315;
  t215_n210: return -0.13855110108852386;
  t215_n211: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t215_n235;
  t215_n212: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t215_n214;
  t215_n213: return -0.17821940779685974;
  t215_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t215_n216;
  t215_n215: return 0.021591361612081528;
  t215_n216: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t215_n232;
  t215_n217: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t215_n229;
  t215_n218: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t215_n224;
  t215_n219: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t215_n223;
  t215_n220: if (E.getNumReferences() >= 3258449920 /*46.0*/) goto t215_n222;
  t215_n221: return 0.10352117568254471;
  t215_n222: return 0.07686344534158707;
  t215_n223: return 0.11775027960538864;
  t215_n224: if (E.getNumReferences() >= 3261857792 /*59.0*/) goto t215_n226;
  t215_n225: return 0.09951978921890259;
  t215_n226: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t215_n228;
  t215_n227: return -0.10272402316331863;
  t215_n228: return 0.20010511577129364;
  t215_n229: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t215_n231;
  t215_n230: return -0.04739130660891533;
  t215_n231: return 0.09895189851522446;
  t215_n232: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t215_n234;
  t215_n233: return -0.03213965892791748;
  t215_n234: return 0.11231318861246109;
  t215_n235: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t215_n237;
  t215_n236: return 0.10536052286624908;
  t215_n237: return -0.6354130506515503;
  t215_n238: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t215_n240;
  t215_n239: return -0.02157493121922016;
  t215_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t215_n250;
  t215_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t215_n249;
  t215_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t215_n248;
  t215_n243: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t215_n247;
  t215_n244: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t215_n246;
  t215_n245: return 0.13393111526966095;
  t215_n246: return 0.10933859646320343;
  t215_n247: return -0.42699167132377625;
  t215_n248: return -0.14027515053749084;
  t215_n249: return 0.05877300351858139;
  t215_n250: return 0.027630774304270744;
  t215_n251: return 0.09270725399255753;
  t215_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t215_n254;
  t215_n253: return -0.060805656015872955;
  t215_n254: return 0.14794358611106873;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree216(const Example& E) {
  t216_n0: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t216_n2;
  t216_n1: return -0.00042227344238199294;
  t216_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t216_n220;
  t216_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t216_n5;
  t216_n4: return 0.00130683823954314;
  t216_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t216_n9;
  t216_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t216_n8;
  t216_n7: return 0.09830807894468307;
  t216_n8: return 0.01201418973505497;
  t216_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t216_n11;
  t216_n10: return -0.03915531933307648;
  t216_n11: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t216_n63;
  t216_n12: if (E.getNumReferences() >= 3278536704 /*234.5*/) goto t216_n48;
  t216_n13: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t216_n15;
  t216_n14: return -0.016588326543569565;
  t216_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t216_n39;
  t216_n16: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t216_n20;
  t216_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n19;
  t216_n18: return 0.13927271962165833;
  t216_n19: return 0.010114709846675396;
  t216_n20: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t216_n36;
  t216_n21: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t216_n35;
  t216_n22: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t216_n34;
  t216_n23: if (E.getNumReferences() >= 3275653120 /*190.5*/) goto t216_n33;
  t216_n24: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t216_n32;
  t216_n25: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t216_n31;
  t216_n26: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t216_n30;
  t216_n27: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t216_n29;
  t216_n28: return 0.10052326321601868;
  t216_n29: return 0.026352858170866966;
  t216_n30: return -0.3122096657752991;
  t216_n31: return 0.10496004670858383;
  t216_n32: return -0.15510249137878418;
  t216_n33: return 0.09672574698925018;
  t216_n34: return 0.00376117299310863;
  t216_n35: return -0.24792984127998352;
  t216_n36: if (E.getNumReferences() >= 3273850880 /*163.0*/) goto t216_n38;
  t216_n37: return 0.10442865639925003;
  t216_n38: return -0.16130518913269043;
  t216_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t216_n41;
  t216_n40: return -0.012590248137712479;
  t216_n41: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t216_n47;
  t216_n42: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t216_n44;
  t216_n43: return 0.047591567039489746;
  t216_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t216_n46;
  t216_n45: return 0.06953401118516922;
  t216_n46: return 0.11562833935022354;
  t216_n47: return -0.021152131259441376;
  t216_n48: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t216_n62;
  t216_n49: if (E.getNumReferences() >= 3279912960 /*255.5*/) goto t216_n59;
  t216_n50: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t216_n58;
  t216_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t216_n57;
  t216_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t216_n54;
  t216_n53: return -0.052552588284015656;
  t216_n54: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t216_n56;
  t216_n55: return 0.1148427352309227;
  t216_n56: return -0.7943275570869446;
  t216_n57: return -0.2794155180454254;
  t216_n58: return 0.10251065343618393;
  t216_n59: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t216_n61;
  t216_n60: return -0.11292600631713867;
  t216_n61: return 0.11089223623275757;
  t216_n62: return 0.037896525114774704;
  t216_n63: if (E.getNumReferences() >= 3289112576 /*559.5*/) goto t216_n89;
  t216_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t216_n66;
  t216_n65: return 0.02887973189353943;
  t216_n66: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t216_n78;
  t216_n67: if (E.getNumReferences() >= 3274080256 /*166.5*/) goto t216_n77;
  t216_n68: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t216_n76;
  t216_n69: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t216_n71;
  t216_n70: return -0.593458354473114;
  t216_n71: if (E.getNumReferences() >= 3270901760 /*123.0*/) goto t216_n75;
  t216_n72: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t216_n74;
  t216_n73: return 0.11164126545190811;
  t216_n74: return -0.0562642402946949;
  t216_n75: return 0.01523909904062748;
  t216_n76: return 0.09853635728359222;
  t216_n77: return -0.17112213373184204;
  t216_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t216_n84;
  t216_n79: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t216_n83;
  t216_n80: if (E.getNumReferences() >= 3278635008 /*236.0*/) goto t216_n82;
  t216_n81: return -0.02366204932332039;
  t216_n82: return 0.13154250383377075;
  t216_n83: return -0.13233669102191925;
  t216_n84: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t216_n88;
  t216_n85: if (E.getNumReferences() >= 3282501632 /*334.0*/) goto t216_n87;
  t216_n86: return 0.10017126053571701;
  t216_n87: return -0.11612596362829208;
  t216_n88: return 0.019580548629164696;
  t216_n89: if (E.getNumReferences() >= 3289604096 /*589.5*/) goto t216_n107;
  t216_n90: if (E.getNumReferences() >= 3289571328 /*587.5*/) goto t216_n104;
  t216_n91: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t216_n99;
  t216_n92: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t216_n98;
  t216_n93: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t216_n95;
  t216_n94: return 0.04130119830369949;
  t216_n95: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n97;
  t216_n96: return 0.3567471206188202;
  t216_n97: return -0.11600849777460098;
  t216_n98: return -0.07924554497003555;
  t216_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t216_n101;
  t216_n100: return 0.016801225021481514;
  t216_n101: if (E.getNumReferences() >= 3289243648 /*567.5*/) goto t216_n103;
  t216_n102: return -0.10600447654724121;
  t216_n103: return 0.11984860152006149;
  t216_n104: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t216_n106;
  t216_n105: return 0.13968107104301453;
  t216_n106: return -0.10692309588193893;
  t216_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t216_n119;
  t216_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t216_n110;
  t216_n109: return 0.012611269019544125;
  t216_n110: if (E.getNumReferences() >= 3296239616 /*994.5*/) goto t216_n116;
  t216_n111: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t216_n115;
  t216_n112: if (E.getNumReferences() >= 3292110848 /*742.5*/) goto t216_n114;
  t216_n113: return 0.05285589396953583;
  t216_n114: return 0.11980435997247696;
  t216_n115: return -0.08768893778324127;
  t216_n116: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t216_n118;
  t216_n117: return -0.09506994485855103;
  t216_n118: return 0.0950111448764801;
  t216_n119: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t216_n163;
  t216_n120: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t216_n160;
  t216_n121: if (E.getNumReferences() >= 3333837824 /*23338.0*/) goto t216_n159;
  t216_n122: if (E.getNumReferences() >= 3330759936 /*17326.5*/) goto t216_n154;
  t216_n123: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t216_n151;
  t216_n124: if (E.getNumReferences() >= 3306760192 /*2450.5*/) goto t216_n136;
  t216_n125: if (E.getNumReferences() >= 3301900288 /*1656.0*/) goto t216_n135;
  t216_n126: if (E.getNumReferences() >= 3301597184 /*1619.0*/) goto t216_n132;
  t216_n127: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t216_n129;
  t216_n128: return 0.02310439758002758;
  t216_n129: if (E.getNumReferences() >= 3294109696 /*864.5*/) goto t216_n131;
  t216_n130: return 0.10425969213247299;
  t216_n131: return -0.08993607759475708;
  t216_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n134;
  t216_n133: return -0.10790238529443741;
  t216_n134: return 0.10989313572645187;
  t216_n135: return -0.16692885756492615;
  t216_n136: if (E.getNumReferences() >= 3309787136 /*3189.5*/) goto t216_n146;
  t216_n137: if (E.getNumReferences() >= 3308374016 /*2844.5*/) goto t216_n141;
  t216_n138: if (E.getNumReferences() >= 3306817536 /*2464.5*/) goto t216_n140;
  t216_n139: return 0.125457301735878;
  t216_n140: return 0.017130622640252113;
  t216_n141: if (E.getNumReferences() >= 3308611584 /*2902.5*/) goto t216_n143;
  t216_n142: return 0.12309537827968597;
  t216_n143: if (E.getNumReferences() >= 3309082624 /*3017.5*/) goto t216_n145;
  t216_n144: return -0.03400636091828346;
  t216_n145: return 0.1149035319685936;
  t216_n146: if (E.getNumReferences() >= 3315510272 /*5077.5*/) goto t216_n148;
  t216_n147: return -0.09219524264335632;
  t216_n148: if (E.getNumReferences() >= 3315605504 /*5124.0*/) goto t216_n150;
  t216_n149: return 0.12102101743221283;
  t216_n150: return 0.043705809861421585;
  t216_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t216_n153;
  t216_n152: return -0.04917812719941139;
  t216_n153: return 0.09713238477706909;
  t216_n154: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t216_n156;
  t216_n155: return 0.1833306849002838;
  t216_n156: if (E.getNumReferences() >= 3331838976 /*19434.0*/) goto t216_n158;
  t216_n157: return 0.11225274205207825;
  t216_n158: return -0.3427664041519165;
  t216_n159: return -0.10945812612771988;
  t216_n160: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t216_n162;
  t216_n161: return 0.1271008849143982;
  t216_n162: return -0.16739386320114136;
  t216_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t216_n165;
  t216_n164: return -0.12618006765842438;
  t216_n165: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t216_n215;
  t216_n166: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t216_n168;
  t216_n167: return 0.06918357312679291;
  t216_n168: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t216_n212;
  t216_n169: if (E.getNumReferences() >= 3296313344 /*999.0*/) goto t216_n171;
  t216_n170: return -0.04604402557015419;
  t216_n171: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t216_n185;
  t216_n172: if (E.getNumReferences() >= 3298521088 /*1243.5*/) goto t216_n184;
  t216_n173: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t216_n183;
  t216_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t216_n176;
  t216_n175: return 0.31670746207237244;
  t216_n176: if (E.getNumReferences() >= 3297247232 /*1088.0*/) goto t216_n178;
  t216_n177: return 0.09612846374511719;
  t216_n178: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t216_n182;
  t216_n179: if (E.getNumReferences() >= 3298324480 /*1219.5*/) goto t216_n181;
  t216_n180: return 0.10760222375392914;
  t216_n181: return 0.13080532848834991;
  t216_n182: return -0.1001506969332695;
  t216_n183: return -0.11622685194015503;
  t216_n184: return 0.11830680072307587;
  t216_n185: if (E.getNumReferences() >= 3305877504 /*2235.0*/) goto t216_n187;
  t216_n186: return -0.1306433230638504;
  t216_n187: if (E.getNumReferences() >= 3318623232 /*6597.5*/) goto t216_n203;
  t216_n188: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t216_n200;
  t216_n189: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t216_n195;
  t216_n190: if (E.getNumReferences() >= 3305918464 /*2245.0*/) goto t216_n192;
  t216_n191: return 0.11638836562633514;
  t216_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t216_n194;
  t216_n193: return -0.1718549281358719;
  t216_n194: return 0.10190563648939133;
  t216_n195: if (E.getNumReferences() >= 3313764352 /*4225.0*/) goto t216_n197;
  t216_n196: return 0.1131841391324997;
  t216_n197: if (E.getNumReferences() >= 3315306496 /*4978.0*/) goto t216_n199;
  t216_n198: return 0.12106145173311234;
  t216_n199: return -0.10175427049398422;
  t216_n200: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t216_n202;
  t216_n201: return 0.11464734375476837;
  t216_n202: return -0.36252033710479736;
  t216_n203: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n211;
  t216_n204: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t216_n210;
  t216_n205: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t216_n207;
  t216_n206: return 0.07455689460039139;
  t216_n207: if (E.getNumReferences() >= 3322382336 /*8674.0*/) goto t216_n209;
  t216_n208: return -0.17359142005443573;
  t216_n209: return 0.11067979037761688;
  t216_n210: return -0.11481009423732758;
  t216_n211: return -0.11455903947353363;
  t216_n212: if (E.getNumReferences() >= 3293552640 /*830.5*/) goto t216_n214;
  t216_n213: return 0.10167878866195679;
  t216_n214: return 0.01252567395567894;
  t216_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t216_n217;
  t216_n216: return -0.04822327941656113;
  t216_n217: if (E.getNumReferences() >= 3293609984 /*834.0*/) goto t216_n219;
  t216_n218: return 0.16220572590827942;
  t216_n219: return -0.1592671424150467;
  t216_n220: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t216_n254;
  t216_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t216_n245;
  t216_n222: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t216_n224;
  t216_n223: return -0.03619561344385147;
  t216_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t216_n226;
  t216_n225: return 0.028749406337738037;
  t216_n226: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t216_n228;
  t216_n227: return -0.03201901540160179;
  t216_n228: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t216_n238;
  t216_n229: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t216_n237;
  t216_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t216_n236;
  t216_n231: if (E.getNumReferences() >= 3270770688 /*122.0*/) goto t216_n235;
  t216_n232: if (E.getNumReferences() >= 3270246400 /*118.0*/) goto t216_n234;
  t216_n233: return -0.1409142017364502;
  t216_n234: return 0.6049086451530457;
  t216_n235: return -0.1897868514060974;
  t216_n236: return 0.10252285748720169;
  t216_n237: return 0.12700653076171875;
  t216_n238: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t216_n240;
  t216_n239: return 0.019850503653287888;
  t216_n240: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t216_n242;
  t216_n241: return 0.042784105986356735;
  t216_n242: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t216_n244;
  t216_n243: return 0.13322442770004272;
  t216_n244: return -0.11470934003591537;
  t216_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t216_n249;
  t216_n246: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t216_n248;
  t216_n247: return 0.03112628124654293;
  t216_n248: return 0.09359526634216309;
  t216_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t216_n251;
  t216_n250: return 0.09836075454950333;
  t216_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t216_n253;
  t216_n252: return 0.08233433216810226;
  t216_n253: return -0.0030659001786261797;
  t216_n254: return -0.0014829770661890507;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree217(const Example& E) {
  t217_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t217_n2;
  t217_n1: return -0.0010031349956989288;
  t217_n2: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t217_n144;
  t217_n3: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t217_n117;
  t217_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t217_n114;
  t217_n5: if (E.getNumReferences() >= 3329800192 /*15918.0*/) goto t217_n99;
  t217_n6: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t217_n68;
  t217_n7: if (E.getNumReferences() >= 3295674368 /*960.0*/) goto t217_n63;
  t217_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t217_n14;
  t217_n9: if (E.getNumReferences() >= 3267952640 /*100.5*/) goto t217_n13;
  t217_n10: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t217_n12;
  t217_n11: return -0.011030449531972408;
  t217_n12: return 0.09890769422054291;
  t217_n13: return -0.257757306098938;
  t217_n14: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t217_n44;
  t217_n15: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t217_n43;
  t217_n16: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n42;
  t217_n17: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n27;
  t217_n18: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t217_n24;
  t217_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t217_n23;
  t217_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n22;
  t217_n21: return -0.10686174780130386;
  t217_n22: return 0.06086302548646927;
  t217_n23: return 0.07435676455497742;
  t217_n24: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t217_n26;
  t217_n25: return 0.11575817316770554;
  t217_n26: return -0.10760723054409027;
  t217_n27: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t217_n41;
  t217_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t217_n34;
  t217_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n31;
  t217_n30: return -0.8908320069313049;
  t217_n31: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n33;
  t217_n32: return 0.13768517971038818;
  t217_n33: return 0.054045505821704865;
  t217_n34: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n38;
  t217_n35: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t217_n37;
  t217_n36: return -0.6958440542221069;
  t217_n37: return 0.026372721418738365;
  t217_n38: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t217_n40;
  t217_n39: return 0.09897935390472412;
  t217_n40: return 0.18252570927143097;
  t217_n41: return -0.27257469296455383;
  t217_n42: return -1.2592651844024658;
  t217_n43: return 0.20504413545131683;
  t217_n44: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t217_n48;
  t217_n45: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t217_n47;
  t217_n46: return 0.11302939057350159;
  t217_n47: return 0.06895532459020615;
  t217_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n56;
  t217_n49: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t217_n53;
  t217_n50: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t217_n52;
  t217_n51: return 0.0687347948551178;
  t217_n52: return 0.10341648012399673;
  t217_n53: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t217_n55;
  t217_n54: return -0.2681749165058136;
  t217_n55: return 0.11425712704658508;
  t217_n56: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t217_n58;
  t217_n57: return -0.3635408878326416;
  t217_n58: if (E.getNumReferences() >= 3257401344 /*42.0*/) goto t217_n60;
  t217_n59: return -0.25347670912742615;
  t217_n60: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t217_n62;
  t217_n61: return 0.09865635633468628;
  t217_n62: return 0.046441081911325455;
  t217_n63: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t217_n65;
  t217_n64: return 0.09104075282812119;
  t217_n65: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t217_n67;
  t217_n66: return 0.11114445328712463;
  t217_n67: return -0.1254349648952484;
  t217_n68: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t217_n80;
  t217_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t217_n71;
  t217_n70: return -0.07910459488630295;
  t217_n71: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t217_n77;
  t217_n72: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t217_n76;
  t217_n73: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t217_n75;
  t217_n74: return -0.3958820700645447;
  t217_n75: return 0.061292462050914764;
  t217_n76: return -0.06126067042350769;
  t217_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n79;
  t217_n78: return -0.059861645102500916;
  t217_n79: return 0.11363227665424347;
  t217_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n98;
  t217_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t217_n83;
  t217_n82: return -0.031238365918397903;
  t217_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t217_n87;
  t217_n84: if (E.getNumReferences() >= 3278503936 /*234.0*/) goto t217_n86;
  t217_n85: return -0.1401977837085724;
  t217_n86: return 0.11028064787387848;
  t217_n87: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t217_n93;
  t217_n88: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t217_n90;
  t217_n89: return -0.8342272639274597;
  t217_n90: if (E.getNumReferences() >= 3273392128 /*156.0*/) goto t217_n92;
  t217_n91: return 0.10595227777957916;
  t217_n92: return -0.18355968594551086;
  t217_n93: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t217_n95;
  t217_n94: return -0.006247977260500193;
  t217_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n97;
  t217_n96: return -0.16308417916297913;
  t217_n97: return 0.073468878865242;
  t217_n98: return -0.003453671233728528;
  t217_n99: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t217_n113;
  t217_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n106;
  t217_n101: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t217_n103;
  t217_n102: return 0.008809611201286316;
  t217_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n105;
  t217_n104: return 0.11070871353149414;
  t217_n105: return 0.03657947853207588;
  t217_n106: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t217_n108;
  t217_n107: return -0.040783192962408066;
  t217_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t217_n110;
  t217_n109: return 0.10729249566793442;
  t217_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n112;
  t217_n111: return 0.10530047118663788;
  t217_n112: return 0.10305453091859818;
  t217_n113: return 0.013590898364782333;
  t217_n114: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t217_n116;
  t217_n115: return -0.02598574198782444;
  t217_n116: return -0.08945970982313156;
  t217_n117: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t217_n133;
  t217_n118: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t217_n122;
  t217_n119: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t217_n121;
  t217_n120: return -0.023838022723793983;
  t217_n121: return 0.49289724230766296;
  t217_n122: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t217_n124;
  t217_n123: return 0.04007376730442047;
  t217_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t217_n126;
  t217_n125: return -0.10649235546588898;
  t217_n126: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t217_n128;
  t217_n127: return 0.11469950526952744;
  t217_n128: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t217_n132;
  t217_n129: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t217_n131;
  t217_n130: return 0.12704268097877502;
  t217_n131: return -0.04082195460796356;
  t217_n132: return -0.06189645454287529;
  t217_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t217_n135;
  t217_n134: return -0.03629394620656967;
  t217_n135: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t217_n143;
  t217_n136: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n138;
  t217_n137: return 0.028643686324357986;
  t217_n138: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n142;
  t217_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t217_n141;
  t217_n140: return 0.010588440112769604;
  t217_n141: return 0.1252843290567398;
  t217_n142: return 0.022069983184337616;
  t217_n143: return 0.003770767478272319;
  t217_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t217_n146;
  t217_n145: return 0.007766024209558964;
  t217_n146: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t217_n254;
  t217_n147: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t217_n157;
  t217_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n156;
  t217_n149: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t217_n153;
  t217_n150: if (E.getNumReferences() >= 3272376320 /*140.5*/) goto t217_n152;
  t217_n151: return -0.02314353920519352;
  t217_n152: return -0.6600161790847778;
  t217_n153: if (E.getNumReferences() >= 3273785344 /*162.0*/) goto t217_n155;
  t217_n154: return 0.1106143668293953;
  t217_n155: return 0.027319997549057007;
  t217_n156: return -0.007872313261032104;
  t217_n157: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t217_n159;
  t217_n158: return -0.00014054676285013556;
  t217_n159: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t217_n229;
  t217_n160: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t217_n218;
  t217_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t217_n213;
  t217_n162: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t217_n164;
  t217_n163: return 0.007477906066924334;
  t217_n164: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t217_n212;
  t217_n165: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t217_n207;
  t217_n166: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t217_n196;
  t217_n167: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t217_n191;
  t217_n168: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t217_n172;
  t217_n169: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t217_n171;
  t217_n170: return -0.04247983545064926;
  t217_n171: return 0.08035223186016083;
  t217_n172: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t217_n182;
  t217_n173: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n181;
  t217_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n176;
  t217_n175: return -0.14628155529499054;
  t217_n176: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n180;
  t217_n177: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t217_n179;
  t217_n178: return 0.11212100833654404;
  t217_n179: return 0.12297334522008896;
  t217_n180: return 0.08515968918800354;
  t217_n181: return 0.018086303025484085;
  t217_n182: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n184;
  t217_n183: return 0.008254573680460453;
  t217_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown))) goto t217_n186;
  t217_n185: return -0.14905470609664917;
  t217_n186: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n188;
  t217_n187: return 0.11188908666372299;
  t217_n188: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n190;
  t217_n189: return 0.10005778074264526;
  t217_n190: return -0.19504573941230774;
  t217_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t217_n193;
  t217_n192: return 0.0005025587161071599;
  t217_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n195;
  t217_n194: return 0.10999051481485367;
  t217_n195: return -0.11071505397558212;
  t217_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t217_n198;
  t217_n197: return 0.11667162925004959;
  t217_n198: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t217_n206;
  t217_n199: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n205;
  t217_n200: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n204;
  t217_n201: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t217_n203;
  t217_n202: return 0.1300220638513565;
  t217_n203: return 0.22597482800483704;
  t217_n204: return -0.19305267930030823;
  t217_n205: return -0.24544860422611237;
  t217_n206: return 0.12004285305738449;
  t217_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t217_n209;
  t217_n208: return -0.30434420704841614;
  t217_n209: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t217_n211;
  t217_n210: return 0.1130967065691948;
  t217_n211: return 0.011811706237494946;
  t217_n212: return -0.018895236775279045;
  t217_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t217_n215;
  t217_n214: return 0.018444141373038292;
  t217_n215: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n217;
  t217_n216: return 0.2458890825510025;
  t217_n217: return 0.11400172859430313;
  t217_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t217_n220;
  t217_n219: return -0.06402811408042908;
  t217_n220: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t217_n222;
  t217_n221: return -0.04912007227540016;
  t217_n222: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t217_n226;
  t217_n223: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t217_n225;
  t217_n224: return 0.2009124457836151;
  t217_n225: return 0.08995403349399567;
  t217_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t217_n228;
  t217_n227: return -0.10020433366298676;
  t217_n228: return 0.06687547266483307;
  t217_n229: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t217_n231;
  t217_n230: return -0.0921948105096817;
  t217_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t217_n233;
  t217_n232: return -0.32329773902893066;
  t217_n233: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t217_n235;
  t217_n234: return -0.14221078157424927;
  t217_n235: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t217_n243;
  t217_n236: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t217_n240;
  t217_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t217_n239;
  t217_n238: return 0.08753617107868195;
  t217_n239: return 0.08083885163068771;
  t217_n240: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t217_n242;
  t217_n241: return 0.12764301896095276;
  t217_n242: return -0.0026930232997983694;
  t217_n243: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t217_n247;
  t217_n244: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t217_n246;
  t217_n245: return 0.10426784306764603;
  t217_n246: return 0.041132230311632156;
  t217_n247: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t217_n249;
  t217_n248: return -0.28356197476387024;
  t217_n249: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t217_n251;
  t217_n250: return -0.15060824155807495;
  t217_n251: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t217_n253;
  t217_n252: return 0.04848538339138031;
  t217_n253: return 0.13108155131340027;
  t217_n254: return 0.0011126826284453273;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree218(const Example& E) {
  t218_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t218_n240;
  t218_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t218_n3;
  t218_n2: return -0.06687980145215988;
  t218_n3: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t218_n5;
  t218_n4: return -0.0006514281267300248;
  t218_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t218_n29;
  t218_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t218_n8;
  t218_n7: return -0.008412761613726616;
  t218_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n26;
  t218_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n13;
  t218_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n12;
  t218_n11: return 0.07308908551931381;
  t218_n12: return 0.012602676637470722;
  t218_n13: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t218_n15;
  t218_n14: return 0.013083326630294323;
  t218_n15: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t218_n25;
  t218_n16: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t218_n18;
  t218_n17: return 0.057400405406951904;
  t218_n18: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t218_n22;
  t218_n19: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t218_n21;
  t218_n20: return 0.10722745209932327;
  t218_n21: return 0.0841783955693245;
  t218_n22: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t218_n24;
  t218_n23: return 0.041778892278671265;
  t218_n24: return 0.1284351944923401;
  t218_n25: return -0.10117891430854797;
  t218_n26: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n28;
  t218_n27: return 0.02324928715825081;
  t218_n28: return -0.09350517392158508;
  t218_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t218_n237;
  t218_n30: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t218_n236;
  t218_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t218_n51;
  t218_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n34;
  t218_n33: return 0.00016481344937346876;
  t218_n34: if (E.getNumReferences() >= 3318672384 /*6621.5*/) goto t218_n48;
  t218_n35: if (E.getNumReferences() >= 3287138304 /*475.5*/) goto t218_n47;
  t218_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n40;
  t218_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t218_n39;
  t218_n38: return -0.012250641360878944;
  t218_n39: return 0.06755246967077255;
  t218_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n46;
  t218_n41: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n45;
  t218_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t218_n44;
  t218_n43: return -0.028001265600323677;
  t218_n44: return 0.11587221175432205;
  t218_n45: return -0.10962562263011932;
  t218_n46: return -0.029052678495645523;
  t218_n47: return -0.11366710066795349;
  t218_n48: if (E.getNumReferences() >= 3319227392 /*6892.5*/) goto t218_n50;
  t218_n49: return 0.0965060144662857;
  t218_n50: return 0.03228959068655968;
  t218_n51: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t218_n231;
  t218_n52: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t218_n224;
  t218_n53: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t218_n59;
  t218_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t218_n56;
  t218_n55: return -0.016199467703700066;
  t218_n56: if (E.getNumReferences() >= 3261857792 /*59.0*/) goto t218_n58;
  t218_n57: return 0.047186970710754395;
  t218_n58: return 0.10033006221055984;
  t218_n59: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t218_n213;
  t218_n60: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t218_n184;
  t218_n61: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t218_n159;
  t218_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t218_n108;
  t218_n63: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t218_n97;
  t218_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t218_n84;
  t218_n65: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n83;
  t218_n66: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n68;
  t218_n67: return -0.004584428854286671;
  t218_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t218_n80;
  t218_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t218_n73;
  t218_n70: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t218_n72;
  t218_n71: return -0.229216068983078;
  t218_n72: return 0.9254810214042664;
  t218_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t218_n77;
  t218_n74: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n76;
  t218_n75: return 0.08588660508394241;
  t218_n76: return -0.07741519808769226;
  t218_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n79;
  t218_n78: return -0.06623642891645432;
  t218_n79: return 0.11348358541727066;
  t218_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n82;
  t218_n81: return 0.10516740381717682;
  t218_n82: return 0.05051616206765175;
  t218_n83: return -0.02982134371995926;
  t218_n84: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t218_n96;
  t218_n85: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n87;
  t218_n86: return -0.10797982662916183;
  t218_n87: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t218_n95;
  t218_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t218_n94;
  t218_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t218_n91;
  t218_n90: return -0.021138230338692665;
  t218_n91: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n93;
  t218_n92: return 0.11805906891822815;
  t218_n93: return 0.041306912899017334;
  t218_n94: return 0.11592099815607071;
  t218_n95: return -0.30796077847480774;
  t218_n96: return 0.12291610240936279;
  t218_n97: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n107;
  t218_n98: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t218_n102;
  t218_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n101;
  t218_n100: return 0.026617661118507385;
  t218_n101: return -0.09514368325471878;
  t218_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n104;
  t218_n103: return -0.2717358469963074;
  t218_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n106;
  t218_n105: return 0.11983019858598709;
  t218_n106: return -0.05431463569402695;
  t218_n107: return -0.25015997886657715;
  t218_n108: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t218_n158;
  t218_n109: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t218_n151;
  t218_n110: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t218_n150;
  t218_n111: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n113;
  t218_n112: return 0.03035021387040615;
  t218_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t218_n149;
  t218_n114: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t218_n124;
  t218_n115: if (E.getSymbolScopeDistance() >= 3247439872 /*18.0*/) goto t218_n123;
  t218_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n118;
  t218_n117: return 0.02914039045572281;
  t218_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n120;
  t218_n119: return 0.19384004175662994;
  t218_n120: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n122;
  t218_n121: return 0.13332802057266235;
  t218_n122: return 0.04408691078424454;
  t218_n123: return -0.0666075274348259;
  t218_n124: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t218_n146;
  t218_n125: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n141;
  t218_n126: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n138;
  t218_n127: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n137;
  t218_n128: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n132;
  t218_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n131;
  t218_n130: return 0.1066240444779396;
  t218_n131: return -0.10120614618062973;
  t218_n132: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n134;
  t218_n133: return 0.09771717339754105;
  t218_n134: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n136;
  t218_n135: return 0.11109385639429092;
  t218_n136: return 0.190725639462471;
  t218_n137: return -0.24954010546207428;
  t218_n138: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t218_n140;
  t218_n139: return 0.07146910578012466;
  t218_n140: return 0.08680617064237595;
  t218_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n143;
  t218_n142: return 0.019850362092256546;
  t218_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n145;
  t218_n144: return 0.09857508540153503;
  t218_n145: return -0.231610506772995;
  t218_n146: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n148;
  t218_n147: return 0.11607499420642853;
  t218_n148: return 0.10751819610595703;
  t218_n149: return 0.026524176821112633;
  t218_n150: return -0.07909636944532394;
  t218_n151: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n157;
  t218_n152: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n156;
  t218_n153: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n155;
  t218_n154: return -0.10636147111654282;
  t218_n155: return 0.10549511760473251;
  t218_n156: return 0.06536810100078583;
  t218_n157: return 0.04336750507354736;
  t218_n158: return -0.0701555609703064;
  t218_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol))) goto t218_n161;
  t218_n160: return 0.032450634986162186;
  t218_n161: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t218_n175;
  t218_n162: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t218_n174;
  t218_n163: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t218_n173;
  t218_n164: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t218_n170;
  t218_n165: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n167;
  t218_n166: return 0.010321947745978832;
  t218_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t218_n169;
  t218_n168: return -0.013276267796754837;
  t218_n169: return 0.08716744184494019;
  t218_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n172;
  t218_n171: return 0.11165037751197815;
  t218_n172: return 0.031122339889407158;
  t218_n173: return -0.22127094864845276;
  t218_n174: return -0.12431056797504425;
  t218_n175: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t218_n181;
  t218_n176: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n178;
  t218_n177: return 0.12619896233081818;
  t218_n178: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t218_n180;
  t218_n179: return 0.060200221836566925;
  t218_n180: return 0.12404216825962067;
  t218_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n183;
  t218_n182: return -0.15922458469867706;
  t218_n183: return 0.12720297276973724;
  t218_n184: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t218_n210;
  t218_n185: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t218_n197;
  t218_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t218_n194;
  t218_n187: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t218_n189;
  t218_n188: return 0.062277309596538544;
  t218_n189: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n193;
  t218_n190: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t218_n192;
  t218_n191: return 0.1143137738108635;
  t218_n192: return 0.10803039371967316;
  t218_n193: return 0.01666252501308918;
  t218_n194: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n196;
  t218_n195: return 0.1125621572136879;
  t218_n196: return -0.16042672097682953;
  t218_n197: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t218_n199;
  t218_n198: return -0.10770215094089508;
  t218_n199: if (E.getNumReferences() >= 3263037440 /*63.5*/) goto t218_n205;
  t218_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t218_n204;
  t218_n201: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t218_n203;
  t218_n202: return -0.2170666605234146;
  t218_n203: return 0.10064862668514252;
  t218_n204: return 0.10823383182287216;
  t218_n205: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t218_n207;
  t218_n206: return -0.0205352995544672;
  t218_n207: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t218_n209;
  t218_n208: return -0.167428120970726;
  t218_n209: return 0.11330174654722214;
  t218_n210: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t218_n212;
  t218_n211: return 0.1076781302690506;
  t218_n212: return -0.4846667945384979;
  t218_n213: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t218_n223;
  t218_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Type))) goto t218_n216;
  t218_n215: return 0.008229152299463749;
  t218_n216: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t218_n222;
  t218_n217: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t218_n219;
  t218_n218: return -0.16571053862571716;
  t218_n219: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t218_n221;
  t218_n220: return 0.10704030841588974;
  t218_n221: return 0.08608710765838623;
  t218_n222: return 0.04329262301325798;
  t218_n223: return -0.015886416658759117;
  t218_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t218_n230;
  t218_n225: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t218_n229;
  t218_n226: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t218_n228;
  t218_n227: return 0.23929741978645325;
  t218_n228: return 0.11283261328935623;
  t218_n229: return 0.07327662408351898;
  t218_n230: return -0.17137601971626282;
  t218_n231: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t218_n233;
  t218_n232: return -0.016408124938607216;
  t218_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t218_n235;
  t218_n234: return -0.20551742613315582;
  t218_n235: return 0.09723502397537231;
  t218_n236: return 0.002026056870818138;
  t218_n237: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n239;
  t218_n238: return 0.08399609476327896;
  t218_n239: return 0.0247713141143322;
  t218_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t218_n242;
  t218_n241: return -0.11660344898700714;
  t218_n242: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t218_n244;
  t218_n243: return -0.07861847430467606;
  t218_n244: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t218_n254;
  t218_n245: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t218_n251;
  t218_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t218_n250;
  t218_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t218_n249;
  t218_n248: return 0.02008635737001896;
  t218_n249: return -0.46099480986595154;
  t218_n250: return 0.06916245818138123;
  t218_n251: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t218_n253;
  t218_n252: return 0.08635368198156357;
  t218_n253: return -0.07138938456773758;
  t218_n254: return -0.13652417063713074;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree219(const Example& E) {
  t219_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t219_n2;
  t219_n1: return -0.0002871798351407051;
  t219_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t219_n158;
  t219_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t219_n135;
  t219_n4: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t219_n6;
  t219_n5: return 0.11026639491319656;
  t219_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t219_n52;
  t219_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n41;
  t219_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t219_n12;
  t219_n9: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t219_n11;
  t219_n10: return -0.006861788686364889;
  t219_n11: return -0.13774138689041138;
  t219_n12: if (E.getNumReferences() >= 3320384512 /*7457.5*/) goto t219_n14;
  t219_n13: return 0.09488743543624878;
  t219_n14: if (E.getNumReferences() >= 3349201152 /*82306.0*/) goto t219_n16;
  t219_n15: return 0.015709228813648224;
  t219_n16: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t219_n36;
  t219_n17: if (E.getNumReferences() >= 3349883520 /*87637.0*/) goto t219_n27;
  t219_n18: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n20;
  t219_n19: return -0.016346676275134087;
  t219_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n26;
  t219_n21: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t219_n25;
  t219_n22: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t219_n24;
  t219_n23: return 0.07001525908708572;
  t219_n24: return 0.10888645052909851;
  t219_n25: return -0.3074924647808075;
  t219_n26: return -0.019098928198218346;
  t219_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n35;
  t219_n28: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t219_n32;
  t219_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n31;
  t219_n30: return 0.09135683625936508;
  t219_n31: return -0.48587432503700256;
  t219_n32: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t219_n34;
  t219_n33: return 0.07272022217512131;
  t219_n34: return -0.21524745225906372;
  t219_n35: return -0.02864597737789154;
  t219_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t219_n40;
  t219_n37: if (E.getNumReferences() >= 3350654080 /*93657.0*/) goto t219_n39;
  t219_n38: return -0.06303388625383377;
  t219_n39: return 0.012696568854153156;
  t219_n40: return 0.08377932757139206;
  t219_n41: if (E.getNumReferences() >= 3341720320 /*44699.0*/) goto t219_n51;
  t219_n42: if (E.getNumReferences() >= 3339920896 /*37670.0*/) goto t219_n48;
  t219_n43: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t219_n45;
  t219_n44: return -0.029708590358495712;
  t219_n45: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t219_n47;
  t219_n46: return -0.2964493930339813;
  t219_n47: return 0.10708092153072357;
  t219_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n50;
  t219_n49: return 0.107644222676754;
  t219_n50: return 0.11331918835639954;
  t219_n51: return -0.07998481392860413;
  t219_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n62;
  t219_n53: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n55;
  t219_n54: return 0.01086331158876419;
  t219_n55: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t219_n61;
  t219_n56: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t219_n58;
  t219_n57: return -0.11421144008636475;
  t219_n58: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n60;
  t219_n59: return 0.02444169670343399;
  t219_n60: return -2.398956775665283;
  t219_n61: return 0.13521896302700043;
  t219_n62: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n118;
  t219_n63: if (E.getNumReferences() >= 3331587072 /*18942.0*/) goto t219_n77;
  t219_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t219_n66;
  t219_n65: return 0.045178692787885666;
  t219_n66: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t219_n72;
  t219_n67: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t219_n69;
  t219_n68: return 0.18270361423492432;
  t219_n69: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t219_n71;
  t219_n70: return -0.11076626181602478;
  t219_n71: return 0.07390555739402771;
  t219_n72: if (E.getNumReferences() >= 3326120448 /*12324.5*/) goto t219_n76;
  t219_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n75;
  t219_n74: return -0.9260445237159729;
  t219_n75: return -0.23514436185359955;
  t219_n76: return -0.10233938694000244;
  t219_n77: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t219_n85;
  t219_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n82;
  t219_n79: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t219_n81;
  t219_n80: return 0.11284606903791428;
  t219_n81: return 0.1032600924372673;
  t219_n82: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t219_n84;
  t219_n83: return 0.06822185218334198;
  t219_n84: return -0.12429855018854141;
  t219_n85: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n113;
  t219_n86: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t219_n112;
  t219_n87: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t219_n103;
  t219_n88: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t219_n90;
  t219_n89: return -0.22139011323451996;
  t219_n90: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t219_n100;
  t219_n91: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t219_n93;
  t219_n92: return -0.07560726255178452;
  t219_n93: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t219_n99;
  t219_n94: if (E.getNumReferences() >= 3333914624 /*23488.0*/) goto t219_n98;
  t219_n95: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n97;
  t219_n96: return 0.09780397266149521;
  t219_n97: return 0.09623435139656067;
  t219_n98: return -0.10039415955543518;
  t219_n99: return -0.3841157555580139;
  t219_n100: if (E.getNumReferences() >= 3332280320 /*20296.0*/) goto t219_n102;
  t219_n101: return 0.18709148466587067;
  t219_n102: return 0.024239961057901382;
  t219_n103: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t219_n109;
  t219_n104: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t219_n108;
  t219_n105: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n107;
  t219_n106: return 0.08318104594945908;
  t219_n107: return 0.07049217820167542;
  t219_n108: return 0.17355823516845703;
  t219_n109: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t219_n111;
  t219_n110: return 0.07108030468225479;
  t219_n111: return 0.0285797156393528;
  t219_n112: return -0.02753720059990883;
  t219_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n117;
  t219_n114: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t219_n116;
  t219_n115: return 0.06531620025634766;
  t219_n116: return 0.11296183615922928;
  t219_n117: return 0.057102516293525696;
  t219_n118: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t219_n120;
  t219_n119: return 0.13587334752082825;
  t219_n120: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t219_n124;
  t219_n121: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t219_n123;
  t219_n122: return -0.05269906669855118;
  t219_n123: return 0.043505940586328506;
  t219_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n128;
  t219_n125: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t219_n127;
  t219_n126: return 0.1001744419336319;
  t219_n127: return 0.03831495717167854;
  t219_n128: if (E.getNumReferences() >= 3345021312 /*57593.5*/) goto t219_n134;
  t219_n129: if (E.getNumReferences() >= 3331398400 /*18573.5*/) goto t219_n131;
  t219_n130: return -0.12262364476919174;
  t219_n131: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n133;
  t219_n132: return 0.1062595546245575;
  t219_n133: return 0.1280936300754547;
  t219_n134: return 0.004729022271931171;
  t219_n135: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n137;
  t219_n136: return -0.002846933901309967;
  t219_n137: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t219_n157;
  t219_n138: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t219_n148;
  t219_n139: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t219_n141;
  t219_n140: return -0.20554961264133453;
  t219_n141: if (E.getNumReferences() >= 3321499648 /*8002.0*/) goto t219_n143;
  t219_n142: return 0.30057641863822937;
  t219_n143: if (E.getNumReferences() >= 3338025472 /*31517.0*/) goto t219_n147;
  t219_n144: if (E.getNumReferences() >= 3335809536 /*27189.0*/) goto t219_n146;
  t219_n145: return 0.1039772555232048;
  t219_n146: return 0.10814107954502106;
  t219_n147: return -0.07208351045846939;
  t219_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n150;
  t219_n149: return 0.03908349946141243;
  t219_n150: if (E.getNumReferences() >= 3321825280 /*8161.0*/) goto t219_n156;
  t219_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n155;
  t219_n152: if (E.getNumReferences() >= 3321156608 /*7834.5*/) goto t219_n154;
  t219_n153: return 0.39890602231025696;
  t219_n154: return 0.44075411558151245;
  t219_n155: return 0.039460401982069016;
  t219_n156: return 0.043814778327941895;
  t219_n157: return 0.010941838845610619;
  t219_n158: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t219_n160;
  t219_n159: return 2.9804268706357107e-05;
  t219_n160: if (E.getNumReferences() >= 3322645504 /*8931.0*/) goto t219_n204;
  t219_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t219_n195;
  t219_n162: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t219_n178;
  t219_n163: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t219_n175;
  t219_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t219_n170;
  t219_n165: if (E.getNumReferences() >= 3322376704 /*8668.5*/) goto t219_n167;
  t219_n166: return -0.18174302577972412;
  t219_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n169;
  t219_n168: return 0.11883532255887985;
  t219_n169: return 0.07918595522642136;
  t219_n170: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n172;
  t219_n171: return -0.004703013226389885;
  t219_n172: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t219_n174;
  t219_n173: return -0.029648859053850174;
  t219_n174: return 0.11272532492876053;
  t219_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t219_n177;
  t219_n176: return -0.03407619893550873;
  t219_n177: return 0.13278351724147797;
  t219_n178: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t219_n190;
  t219_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t219_n185;
  t219_n180: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t219_n182;
  t219_n181: return -0.023239461705088615;
  t219_n182: if (E.getNumReferences() >= 3321866240 /*8181.0*/) goto t219_n184;
  t219_n183: return -0.260050892829895;
  t219_n184: return 0.1071646511554718;
  t219_n185: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t219_n189;
  t219_n186: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t219_n188;
  t219_n187: return 0.11798951029777527;
  t219_n188: return 0.06292439252138138;
  t219_n189: return 0.11586657911539078;
  t219_n190: if (E.getNumReferences() >= 3322247680 /*8542.5*/) goto t219_n194;
  t219_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t219_n193;
  t219_n192: return -0.1371629536151886;
  t219_n193: return 0.11046294122934341;
  t219_n194: return 0.11029962450265884;
  t219_n195: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t219_n203;
  t219_n196: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t219_n202;
  t219_n197: if (E.getNumReferences() >= 3322246144 /*8541.0*/) goto t219_n199;
  t219_n198: return 0.07555744051933289;
  t219_n199: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t219_n201;
  t219_n200: return 0.10968028008937836;
  t219_n201: return 0.15030264854431152;
  t219_n202: return 0.04173419624567032;
  t219_n203: return -0.09052210301160812;
  t219_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t219_n208;
  t219_n205: if (E.getNumReferences() >= 3323132416 /*9406.5*/) goto t219_n207;
  t219_n206: return -0.11592847853899002;
  t219_n207: return 0.006013138219714165;
  t219_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t219_n238;
  t219_n209: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t219_n233;
  t219_n210: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t219_n232;
  t219_n211: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n221;
  t219_n212: if (E.getNumReferences() >= 3327551488 /*13722.0*/) goto t219_n214;
  t219_n213: return -0.3162260949611664;
  t219_n214: if (E.getNumReferences() >= 3329865216 /*15981.5*/) goto t219_n216;
  t219_n215: return 0.07771018892526627;
  t219_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t219_n218;
  t219_n217: return -0.10151152312755585;
  t219_n218: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t219_n220;
  t219_n219: return 0.08465130627155304;
  t219_n220: return -3.4845457077026367;
  t219_n221: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t219_n223;
  t219_n222: return 0.03126731887459755;
  t219_n223: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t219_n231;
  t219_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t219_n226;
  t219_n225: return 0.047633517533540726;
  t219_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t219_n230;
  t219_n227: if (E.getNumReferences() >= 3336739328 /*29005.0*/) goto t219_n229;
  t219_n228: return 0.100936159491539;
  t219_n229: return -0.3158840239048004;
  t219_n230: return 0.09113325923681259;
  t219_n231: return -0.3347320258617401;
  t219_n232: return -0.10274117439985275;
  t219_n233: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t219_n235;
  t219_n234: return -0.009352530352771282;
  t219_n235: if (E.getNumReferences() >= 3363327264 /*254260.5*/) goto t219_n237;
  t219_n236: return 0.10551467537879944;
  t219_n237: return 0.03570140153169632;
  t219_n238: if (E.getNumReferences() >= 3326588928 /*12782.0*/) goto t219_n254;
  t219_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t219_n241;
  t219_n240: return -0.24669089913368225;
  t219_n241: if (E.getNumReferences() >= 3326458880 /*12655.0*/) goto t219_n253;
  t219_n242: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t219_n246;
  t219_n243: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t219_n245;
  t219_n244: return 0.07210563123226166;
  t219_n245: return 0.285317063331604;
  t219_n246: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t219_n250;
  t219_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t219_n249;
  t219_n248: return 0.08132252842187881;
  t219_n249: return -0.05605793744325638;
  t219_n250: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t219_n252;
  t219_n251: return -0.8455421328544617;
  t219_n252: return 0.04745645448565483;
  t219_n253: return 0.11655451357364655;
  t219_n254: return 0.005353926215320826;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree220(const Example& E) {
  t220_n0: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t220_n20;
  t220_n1: if (E.getNumReferences() >= 3348896192 /*79923.5*/) goto t220_n3;
  t220_n2: return -0.00011469097080407664;
  t220_n3: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n5;
  t220_n4: return -0.035371746867895126;
  t220_n5: if (E.getNumReferences() >= 3349481344 /*84495.0*/) goto t220_n13;
  t220_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n12;
  t220_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t220_n11;
  t220_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t220_n10;
  t220_n9: return -0.2617010772228241;
  t220_n10: return -0.1006150022149086;
  t220_n11: return 0.0489719994366169;
  t220_n12: return 0.05412977561354637;
  t220_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n19;
  t220_n14: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t220_n18;
  t220_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n17;
  t220_n16: return -0.45676857233047485;
  t220_n17: return -0.10037455707788467;
  t220_n18: return 0.0017019491642713547;
  t220_n19: return -0.08948282897472382;
  t220_n20: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t220_n120;
  t220_n21: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t220_n107;
  t220_n22: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t220_n76;
  t220_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t220_n51;
  t220_n24: if (E.getNumReferences() >= 3350198272 /*90096.0*/) goto t220_n50;
  t220_n25: if (E.getNumReferences() >= 3350124096 /*89516.5*/) goto t220_n37;
  t220_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n28;
  t220_n27: return 0.04137412831187248;
  t220_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n30;
  t220_n29: return 0.03665551543235779;
  t220_n30: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n32;
  t220_n31: return 0.09125558286905289;
  t220_n32: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t220_n36;
  t220_n33: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n35;
  t220_n34: return 0.1396683156490326;
  t220_n35: return 0.03297015279531479;
  t220_n36: return 0.09501620382070541;
  t220_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n47;
  t220_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n46;
  t220_n39: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t220_n45;
  t220_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n44;
  t220_n41: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t220_n43;
  t220_n42: return 0.08638467639684677;
  t220_n43: return 0.06940591335296631;
  t220_n44: return 0.0803641676902771;
  t220_n45: return -0.1383601427078247;
  t220_n46: return -0.43895044922828674;
  t220_n47: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t220_n49;
  t220_n48: return 0.08054228872060776;
  t220_n49: return -0.23430590331554413;
  t220_n50: return 0.0007682097493670881;
  t220_n51: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t220_n53;
  t220_n52: return -0.045019492506980896;
  t220_n53: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t220_n75;
  t220_n54: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n70;
  t220_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t220_n69;
  t220_n56: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t220_n64;
  t220_n57: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t220_n59;
  t220_n58: return 0.08944042772054672;
  t220_n59: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n61;
  t220_n60: return 0.11000984907150269;
  t220_n61: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n63;
  t220_n62: return 0.10965163260698318;
  t220_n63: return 0.1126919761300087;
  t220_n64: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n68;
  t220_n65: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n67;
  t220_n66: return 0.0;
  t220_n67: return 0.08760581910610199;
  t220_n68: return 0.07132317870855331;
  t220_n69: return -0.002471319632604718;
  t220_n70: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t220_n72;
  t220_n71: return -0.2413262575864792;
  t220_n72: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n74;
  t220_n73: return 0.05213816463947296;
  t220_n74: return -0.04640104994177818;
  t220_n75: return 0.008235620334744453;
  t220_n76: if (E.getNumReferences() >= 3359104096 /*188273.5*/) goto t220_n104;
  t220_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t220_n103;
  t220_n78: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t220_n80;
  t220_n79: return 0.009480662643909454;
  t220_n80: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n82;
  t220_n81: return 0.009549867361783981;
  t220_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n86;
  t220_n83: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n85;
  t220_n84: return -0.01632174663245678;
  t220_n85: return 0.08875591307878494;
  t220_n86: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t220_n88;
  t220_n87: return 0.10822810232639313;
  t220_n88: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t220_n102;
  t220_n89: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n91;
  t220_n90: return -0.10212647914886475;
  t220_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n93;
  t220_n92: return -0.10667525976896286;
  t220_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n101;
  t220_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n100;
  t220_n95: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t220_n97;
  t220_n96: return 0.09915022552013397;
  t220_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n99;
  t220_n98: return 0.10294072329998016;
  t220_n99: return 0.07060275226831436;
  t220_n100: return -0.3011460304260254;
  t220_n101: return 0.04024690389633179;
  t220_n102: return -0.17411789298057556;
  t220_n103: return -0.031596675515174866;
  t220_n104: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n106;
  t220_n105: return 0.047747571021318436;
  t220_n106: return 0.02852672152221203;
  t220_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t220_n117;
  t220_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n114;
  t220_n109: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n111;
  t220_n110: return 0.08710474520921707;
  t220_n111: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t220_n113;
  t220_n112: return -0.23069927096366882;
  t220_n113: return 0.0016129252035170794;
  t220_n114: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n116;
  t220_n115: return -0.07447045296430588;
  t220_n116: return -0.6501142382621765;
  t220_n117: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t220_n119;
  t220_n118: return 0.10501088947057724;
  t220_n119: return -0.08090001344680786;
  t220_n120: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t220_n122;
  t220_n121: return -0.023808812722563744;
  t220_n122: if (E.getNumReferences() >= 3364994640 /*298482.5*/) goto t220_n252;
  t220_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t220_n205;
  t220_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t220_n130;
  t220_n125: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t220_n129;
  t220_n126: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t220_n128;
  t220_n127: return -0.3131501376628876;
  t220_n128: return 0.10431929677724838;
  t220_n129: return -0.04405118152499199;
  t220_n130: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n132;
  t220_n131: return 0.013870862312614918;
  t220_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n182;
  t220_n133: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t220_n157;
  t220_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n142;
  t220_n135: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n139;
  t220_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n138;
  t220_n137: return -0.12748420238494873;
  t220_n138: return -0.06451963633298874;
  t220_n139: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t220_n141;
  t220_n140: return -0.20741139352321625;
  t220_n141: return 0.09414362162351608;
  t220_n142: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t220_n152;
  t220_n143: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n151;
  t220_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n150;
  t220_n145: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t220_n147;
  t220_n146: return -0.1220133826136589;
  t220_n147: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n149;
  t220_n148: return 1.4760808944702148;
  t220_n149: return 0.6874833703041077;
  t220_n150: return -0.6557489633560181;
  t220_n151: return 0.13652096688747406;
  t220_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n154;
  t220_n153: return 0.05084993317723274;
  t220_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n156;
  t220_n155: return -0.23554450273513794;
  t220_n156: return 0.08616385608911514;
  t220_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t220_n169;
  t220_n158: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n160;
  t220_n159: return 0.07451033592224121;
  t220_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n166;
  t220_n161: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t220_n165;
  t220_n162: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t220_n164;
  t220_n163: return 0.10022382438182831;
  t220_n164: return -0.1986335664987564;
  t220_n165: return 0.10394538938999176;
  t220_n166: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t220_n168;
  t220_n167: return 0.08103229850530624;
  t220_n168: return -0.023198138922452927;
  t220_n169: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t220_n173;
  t220_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t220_n172;
  t220_n171: return -0.02231059968471527;
  t220_n172: return 0.401966392993927;
  t220_n173: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t220_n181;
  t220_n174: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t220_n176;
  t220_n175: return -0.31142884492874146;
  t220_n176: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n180;
  t220_n177: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t220_n179;
  t220_n178: return 0.07938862591981888;
  t220_n179: return 0.04859745502471924;
  t220_n180: return 0.03240375593304634;
  t220_n181: return -0.05657605081796646;
  t220_n182: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t220_n200;
  t220_n183: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t220_n199;
  t220_n184: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n190;
  t220_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t220_n187;
  t220_n186: return 0.06901320815086365;
  t220_n187: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n189;
  t220_n188: return -0.8137394785881042;
  t220_n189: return 0.03529081866145134;
  t220_n190: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n192;
  t220_n191: return -0.19763709604740143;
  t220_n192: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t220_n194;
  t220_n193: return 0.06005599722266197;
  t220_n194: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t220_n196;
  t220_n195: return -0.09215755015611649;
  t220_n196: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t220_n198;
  t220_n197: return 0.10035436600446701;
  t220_n198: return 0.07965850085020065;
  t220_n199: return -0.1650937795639038;
  t220_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t220_n202;
  t220_n201: return 0.028174985200166702;
  t220_n202: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t220_n204;
  t220_n203: return 0.11032072454690933;
  t220_n204: return 0.07074002921581268;
  t220_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t220_n235;
  t220_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n224;
  t220_n207: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t220_n209;
  t220_n208: return 0.017008451744914055;
  t220_n209: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t220_n211;
  t220_n210: return -0.17547406256198883;
  t220_n211: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t220_n217;
  t220_n212: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n216;
  t220_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t220_n215;
  t220_n214: return 0.08146420866250992;
  t220_n215: return 0.1280319094657898;
  t220_n216: return -0.002228338271379471;
  t220_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n219;
  t220_n218: return 0.02842656895518303;
  t220_n219: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t220_n221;
  t220_n220: return 0.04969435930252075;
  t220_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t220_n223;
  t220_n222: return -0.12232983112335205;
  t220_n223: return 0.1530240923166275;
  t220_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t220_n226;
  t220_n225: return -0.00675103859975934;
  t220_n226: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t220_n228;
  t220_n227: return 0.004424034617841244;
  t220_n228: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t220_n232;
  t220_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t220_n231;
  t220_n230: return 0.09397722035646439;
  t220_n231: return 0.10471799224615097;
  t220_n232: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n234;
  t220_n233: return 0.041284963488578796;
  t220_n234: return 0.09271013736724854;
  t220_n235: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t220_n243;
  t220_n236: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t220_n242;
  t220_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t220_n241;
  t220_n238: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t220_n240;
  t220_n239: return -0.40902242064476013;
  t220_n240: return 0.03200112655758858;
  t220_n241: return 0.10795408487319946;
  t220_n242: return -0.032796263694763184;
  t220_n243: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t220_n251;
  t220_n244: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t220_n250;
  t220_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t220_n247;
  t220_n246: return -0.5836882591247559;
  t220_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t220_n249;
  t220_n248: return -0.0658218115568161;
  t220_n249: return -0.24609962105751038;
  t220_n250: return 0.0571601465344429;
  t220_n251: return 0.0621040053665638;
  t220_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t220_n254;
  t220_n253: return -0.0047187479212880135;
  t220_n254: return 0.01402661856263876;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree221(const Example& E) {
  t221_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t221_n2;
  t221_n1: return -0.0004431523266248405;
  t221_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t221_n150;
  t221_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t221_n5;
  t221_n4: return 0.0014763042563572526;
  t221_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t221_n85;
  t221_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace))) goto t221_n14;
  t221_n7: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t221_n9;
  t221_n8: return -0.02680337429046631;
  t221_n9: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t221_n13;
  t221_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t221_n12;
  t221_n11: return -0.15710371732711792;
  t221_n12: return 0.13631659746170044;
  t221_n13: return 0.018443288281559944;
  t221_n14: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t221_n36;
  t221_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t221_n29;
  t221_n16: if (E.getNumReferences() >= 3269197824 /*110.0*/) goto t221_n18;
  t221_n17: return -0.21687090396881104;
  t221_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n22;
  t221_n19: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t221_n21;
  t221_n20: return 0.05918824300169945;
  t221_n21: return -0.31386277079582214;
  t221_n22: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n28;
  t221_n23: if (E.getNumReferences() >= 3275915264 /*194.5*/) goto t221_n27;
  t221_n24: if (E.getNumReferences() >= 3273195520 /*153.0*/) goto t221_n26;
  t221_n25: return 0.030193991959095;
  t221_n26: return 0.11177805066108704;
  t221_n27: return 0.005216841120272875;
  t221_n28: return -0.01479509100317955;
  t221_n29: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t221_n35;
  t221_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t221_n34;
  t221_n31: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t221_n33;
  t221_n32: return 0.1331404447555542;
  t221_n33: return -0.19149574637413025;
  t221_n34: return 0.09971196949481964;
  t221_n35: return -0.11986604332923889;
  t221_n36: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t221_n58;
  t221_n37: if (E.getNumReferences() >= 3265265664 /*80.0*/) goto t221_n51;
  t221_n38: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t221_n44;
  t221_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n43;
  t221_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t221_n42;
  t221_n41: return -0.1817041039466858;
  t221_n42: return 0.36115437746047974;
  t221_n43: return 0.10609369724988937;
  t221_n44: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t221_n48;
  t221_n45: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t221_n47;
  t221_n46: return -0.08277030289173126;
  t221_n47: return 0.1160583645105362;
  t221_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n50;
  t221_n49: return 0.10381554067134857;
  t221_n50: return -0.0062139201909303665;
  t221_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n55;
  t221_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n54;
  t221_n53: return 0.3387133777141571;
  t221_n54: return 0.11108193546533585;
  t221_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n57;
  t221_n56: return 0.1053261086344719;
  t221_n57: return -0.28326138854026794;
  t221_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n80;
  t221_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n69;
  t221_n60: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t221_n68;
  t221_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t221_n63;
  t221_n62: return -0.19798709452152252;
  t221_n63: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t221_n67;
  t221_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t221_n66;
  t221_n65: return 0.2597881257534027;
  t221_n66: return -0.17352396249771118;
  t221_n67: return 0.10593632608652115;
  t221_n68: return -0.05437741428613663;
  t221_n69: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n75;
  t221_n70: if (E.getNumReferences() >= 3273850880 /*163.0*/) goto t221_n72;
  t221_n71: return 0.10757913440465927;
  t221_n72: if (E.getNumReferences() >= 3289161728 /*562.5*/) goto t221_n74;
  t221_n73: return -0.12365040928125381;
  t221_n74: return 0.108636274933815;
  t221_n75: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n79;
  t221_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t221_n78;
  t221_n77: return -0.7547285556793213;
  t221_n78: return 0.050751376897096634;
  t221_n79: return 0.12309613078832626;
  t221_n80: if (E.getNumReferences() >= 3282042880 /*320.0*/) goto t221_n82;
  t221_n81: return -0.20658378303050995;
  t221_n82: if (E.getNumReferences() >= 3285696512 /*431.5*/) goto t221_n84;
  t221_n83: return 0.1291450560092926;
  t221_n84: return -0.3657907545566559;
  t221_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t221_n147;
  t221_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t221_n88;
  t221_n87: return -0.06839060038328171;
  t221_n88: if (E.getNumReferences() >= 3263168512 /*64.0*/) goto t221_n90;
  t221_n89: return 0.09482893347740173;
  t221_n90: if (E.getNumReferences() >= 3302178816 /*1690.0*/) goto t221_n118;
  t221_n91: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t221_n103;
  t221_n92: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t221_n94;
  t221_n93: return 0.013703142292797565;
  t221_n94: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t221_n96;
  t221_n95: return 0.10092336684465408;
  t221_n96: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n98;
  t221_n97: return 0.04548928514122963;
  t221_n98: if (E.getNumReferences() >= 3272572928 /*143.5*/) goto t221_n102;
  t221_n99: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t221_n101;
  t221_n100: return 0.1012154147028923;
  t221_n101: return 0.08982017636299133;
  t221_n102: return 0.20592327415943146;
  t221_n103: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t221_n115;
  t221_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n112;
  t221_n105: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n111;
  t221_n106: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t221_n110;
  t221_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t221_n109;
  t221_n108: return -0.7251617312431335;
  t221_n109: return -0.2774731516838074;
  t221_n110: return -0.15754912793636322;
  t221_n111: return 0.01595480367541313;
  t221_n112: if (E.getNumReferences() >= 3295076352 /*923.5*/) goto t221_n114;
  t221_n113: return 0.03278085216879845;
  t221_n114: return -0.30949169397354126;
  t221_n115: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t221_n117;
  t221_n116: return -0.04726943373680115;
  t221_n117: return 0.06483691930770874;
  t221_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n132;
  t221_n119: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t221_n131;
  t221_n120: if (E.getNumReferences() >= 3337059584 /*29630.5*/) goto t221_n130;
  t221_n121: if (E.getNumReferences() >= 3317206016 /*5905.5*/) goto t221_n129;
  t221_n122: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t221_n126;
  t221_n123: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t221_n125;
  t221_n124: return 0.08031724393367767;
  t221_n125: return 0.10859410464763641;
  t221_n126: if (E.getNumReferences() >= 3309963264 /*3232.5*/) goto t221_n128;
  t221_n127: return -0.6920813322067261;
  t221_n128: return 0.13977959752082825;
  t221_n129: return -0.3142884075641632;
  t221_n130: return 0.10789406299591064;
  t221_n131: return 0.03991551697254181;
  t221_n132: if (E.getNumReferences() >= 3305592832 /*2165.5*/) goto t221_n136;
  t221_n133: if (E.getNumReferences() >= 3304538112 /*1978.0*/) goto t221_n135;
  t221_n134: return 0.050108570605516434;
  t221_n135: return 0.09601341933012009;
  t221_n136: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t221_n138;
  t221_n137: return 0.018279774114489555;
  t221_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n144;
  t221_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n141;
  t221_n140: return -0.19201722741127014;
  t221_n141: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t221_n143;
  t221_n142: return 0.0034943840000778437;
  t221_n143: return 0.11760672926902771;
  t221_n144: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t221_n146;
  t221_n145: return 0.10222864896059036;
  t221_n146: return -0.054575107991695404;
  t221_n147: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t221_n149;
  t221_n148: return -0.08667731285095215;
  t221_n149: return 0.01557349693030119;
  t221_n150: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t221_n242;
  t221_n151: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t221_n185;
  t221_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t221_n184;
  t221_n153: if (E.getNumReferences() >= 3375821112 /*749331.5*/) goto t221_n183;
  t221_n154: if (E.getNumReferences() >= 3369273984 /*432212.0*/) goto t221_n160;
  t221_n155: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t221_n157;
  t221_n156: return -0.027318241074681282;
  t221_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t221_n159;
  t221_n158: return 0.038358256220817566;
  t221_n159: return 0.10150964558124542;
  t221_n160: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n174;
  t221_n161: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t221_n165;
  t221_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t221_n164;
  t221_n163: return -0.17183853685855865;
  t221_n164: return 0.06691091507673264;
  t221_n165: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t221_n167;
  t221_n166: return -0.14997825026512146;
  t221_n167: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n169;
  t221_n168: return 0.04746823012828827;
  t221_n169: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t221_n173;
  t221_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t221_n172;
  t221_n171: return -2.564284563064575;
  t221_n172: return -0.4540286958217621;
  t221_n173: return -0.004124297294765711;
  t221_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n178;
  t221_n175: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t221_n177;
  t221_n176: return -0.15870875120162964;
  t221_n177: return 0.06601214408874512;
  t221_n178: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t221_n182;
  t221_n179: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t221_n181;
  t221_n180: return 0.10181920230388641;
  t221_n181: return 0.08925972133874893;
  t221_n182: return 0.06354673206806183;
  t221_n183: return 0.0057678367011249065;
  t221_n184: return -0.020403288304805756;
  t221_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t221_n187;
  t221_n186: return 0.0010508231353014708;
  t221_n187: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t221_n193;
  t221_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t221_n190;
  t221_n189: return -0.36607253551483154;
  t221_n190: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n192;
  t221_n191: return 0.06571311503648758;
  t221_n192: return 0.09119603782892227;
  t221_n193: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t221_n211;
  t221_n194: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t221_n196;
  t221_n195: return -0.016552133485674858;
  t221_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t221_n202;
  t221_n197: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t221_n199;
  t221_n198: return -0.04966044798493385;
  t221_n199: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t221_n201;
  t221_n200: return 0.17366145551204681;
  t221_n201: return 0.13102905452251434;
  t221_n202: if (E.getNumReferences() >= 3275489280 /*188.0*/) goto t221_n210;
  t221_n203: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t221_n207;
  t221_n204: if (E.getNumReferences() >= 3264086016 /*71.0*/) goto t221_n206;
  t221_n205: return 0.15517650544643402;
  t221_n206: return -0.273497998714447;
  t221_n207: if (E.getNumReferences() >= 3271819264 /*132.0*/) goto t221_n209;
  t221_n208: return 0.12977434694766998;
  t221_n209: return 0.11834187060594559;
  t221_n210: return -0.30568575859069824;
  t221_n211: if (E.getNumReferences() >= 3325700096 /*11914.0*/) goto t221_n223;
  t221_n212: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t221_n214;
  t221_n213: return -0.012666957452893257;
  t221_n214: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t221_n222;
  t221_n215: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t221_n217;
  t221_n216: return -0.21114756166934967;
  t221_n217: if (E.getNumReferences() >= 3277160448 /*213.5*/) goto t221_n219;
  t221_n218: return -0.19365918636322021;
  t221_n219: if (E.getNumReferences() >= 3287154688 /*476.0*/) goto t221_n221;
  t221_n220: return 0.13436463475227356;
  t221_n221: return 0.07637438178062439;
  t221_n222: return 0.03267310932278633;
  t221_n223: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t221_n241;
  t221_n224: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t221_n236;
  t221_n225: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n227;
  t221_n226: return 0.07789953798055649;
  t221_n227: if (E.getNumReferences() >= 3326541312 /*12735.5*/) goto t221_n229;
  t221_n228: return -0.11932701617479324;
  t221_n229: if (E.getNumReferences() >= 3326945792 /*13130.5*/) goto t221_n233;
  t221_n230: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t221_n232;
  t221_n231: return 0.1052161231637001;
  t221_n232: return 0.08220920711755753;
  t221_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t221_n235;
  t221_n234: return -0.7856515049934387;
  t221_n235: return 0.09613945335149765;
  t221_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t221_n238;
  t221_n237: return 0.8039295673370361;
  t221_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t221_n240;
  t221_n239: return 0.11722541600465775;
  t221_n240: return 0.010692157782614231;
  t221_n241: return 0.020804692059755325;
  t221_n242: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t221_n244;
  t221_n243: return -0.0072811977006495;
  t221_n244: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t221_n252;
  t221_n245: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t221_n251;
  t221_n246: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t221_n250;
  t221_n247: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t221_n249;
  t221_n248: return -1.6343845129013062;
  t221_n249: return 0.11205210536718369;
  t221_n250: return 0.11772152781486511;
  t221_n251: return 0.036850299686193466;
  t221_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t221_n254;
  t221_n253: return -0.020458951592445374;
  t221_n254: return 0.04273314028978348;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree222(const Example& E) {
  t222_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t222_n2;
  t222_n1: return -0.0009913243120536208;
  t222_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n254;
  t222_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t222_n41;
  t222_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t222_n12;
  t222_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n9;
  t222_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n8;
  t222_n7: return 0.10024742782115936;
  t222_n8: return -0.032472163438797;
  t222_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t222_n11;
  t222_n10: return -0.12431074678897858;
  t222_n11: return -0.10010270029306412;
  t222_n12: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t222_n22;
  t222_n13: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t222_n21;
  t222_n14: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n20;
  t222_n15: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n19;
  t222_n16: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t222_n18;
  t222_n17: return 0.10220754891633987;
  t222_n18: return 0.006657186429947615;
  t222_n19: return 0.006973198149353266;
  t222_n20: return -0.015567269176244736;
  t222_n21: return -0.34291374683380127;
  t222_n22: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t222_n40;
  t222_n23: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t222_n29;
  t222_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t222_n26;
  t222_n25: return 0.09465155750513077;
  t222_n26: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t222_n28;
  t222_n27: return 0.08048123866319656;
  t222_n28: return -0.3783389627933502;
  t222_n29: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t222_n31;
  t222_n30: return -0.017429599538445473;
  t222_n31: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t222_n35;
  t222_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n34;
  t222_n33: return 0.11538608372211456;
  t222_n34: return 0.10158223658800125;
  t222_n35: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n39;
  t222_n36: if (E.getNumReferences() >= 3348209792 /*74561.0*/) goto t222_n38;
  t222_n37: return 0.07339314371347427;
  t222_n38: return 0.02099578268826008;
  t222_n39: return 0.02515452541410923;
  t222_n40: return 0.10749462246894836;
  t222_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t222_n213;
  t222_n42: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t222_n212;
  t222_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t222_n151;
  t222_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n52;
  t222_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t222_n49;
  t222_n46: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t222_n48;
  t222_n47: return -0.044457800686359406;
  t222_n48: return -0.014712007716298103;
  t222_n49: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n51;
  t222_n50: return -0.026271454989910126;
  t222_n51: return 0.0012410692870616913;
  t222_n52: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t222_n148;
  t222_n53: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t222_n121;
  t222_n54: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t222_n112;
  t222_n55: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t222_n89;
  t222_n56: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t222_n66;
  t222_n57: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t222_n65;
  t222_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n60;
  t222_n59: return -0.022060833871364594;
  t222_n60: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t222_n62;
  t222_n61: return 0.02892441488802433;
  t222_n62: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n64;
  t222_n63: return -0.7602447867393494;
  t222_n64: return 0.023381253704428673;
  t222_n65: return 0.039736926555633545;
  t222_n66: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t222_n88;
  t222_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n75;
  t222_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t222_n70;
  t222_n69: return -0.1826210469007492;
  t222_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t222_n72;
  t222_n71: return 0.0416053831577301;
  t222_n72: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t222_n74;
  t222_n73: return -0.07995171844959259;
  t222_n74: return 0.10966924577951431;
  t222_n75: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n77;
  t222_n76: return -0.09493739902973175;
  t222_n77: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t222_n85;
  t222_n78: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t222_n84;
  t222_n79: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t222_n81;
  t222_n80: return 0.002782676136121154;
  t222_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t222_n83;
  t222_n82: return 0.06502211093902588;
  t222_n83: return 0.11392252147197723;
  t222_n84: return -0.05015985667705536;
  t222_n85: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t222_n87;
  t222_n86: return 0.08817116916179657;
  t222_n87: return -0.10461770743131638;
  t222_n88: return -0.16410866379737854;
  t222_n89: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n103;
  t222_n90: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t222_n102;
  t222_n91: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t222_n99;
  t222_n92: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n98;
  t222_n93: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t222_n95;
  t222_n94: return -1.3377625942230225;
  t222_n95: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t222_n97;
  t222_n96: return -0.052907269448041916;
  t222_n97: return -0.9543269872665405;
  t222_n98: return -0.020119424909353256;
  t222_n99: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t222_n101;
  t222_n100: return -0.671301007270813;
  t222_n101: return 0.018250806257128716;
  t222_n102: return -0.15926794707775116;
  t222_n103: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t222_n105;
  t222_n104: return -0.04135599359869957;
  t222_n105: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t222_n111;
  t222_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t222_n108;
  t222_n107: return -0.023091496899724007;
  t222_n108: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n110;
  t222_n109: return 0.09556233137845993;
  t222_n110: return 0.08834864944219589;
  t222_n111: return -0.14984093606472015;
  t222_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n114;
  t222_n113: return -0.04585503041744232;
  t222_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n120;
  t222_n115: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n117;
  t222_n116: return 0.03300366550683975;
  t222_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t222_n119;
  t222_n118: return 0.045768097043037415;
  t222_n119: return 0.10690542310476303;
  t222_n120: return -0.02067176252603531;
  t222_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t222_n147;
  t222_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t222_n146;
  t222_n123: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t222_n133;
  t222_n124: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n132;
  t222_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n131;
  t222_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n128;
  t222_n127: return 0.03216751664876938;
  t222_n128: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t222_n130;
  t222_n129: return 0.06733831763267517;
  t222_n130: return -0.11834114789962769;
  t222_n131: return -0.13013607263565063;
  t222_n132: return -0.049398425966501236;
  t222_n133: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t222_n145;
  t222_n134: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t222_n140;
  t222_n135: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n139;
  t222_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n138;
  t222_n137: return 0.09772950410842896;
  t222_n138: return -0.07396718114614487;
  t222_n139: return -0.02927916683256626;
  t222_n140: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t222_n142;
  t222_n141: return -0.22054894268512726;
  t222_n142: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t222_n144;
  t222_n143: return 0.09579051285982132;
  t222_n144: return 0.032565437257289886;
  t222_n145: return -0.0028690476901829243;
  t222_n146: return -0.012289895676076412;
  t222_n147: return 0.016243116930127144;
  t222_n148: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n150;
  t222_n149: return -0.3718186616897583;
  t222_n150: return -0.06361626833677292;
  t222_n151: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t222_n165;
  t222_n152: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t222_n154;
  t222_n153: return -0.01601114124059677;
  t222_n154: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t222_n164;
  t222_n155: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t222_n157;
  t222_n156: return 0.011600990779697895;
  t222_n157: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t222_n161;
  t222_n158: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n160;
  t222_n159: return -0.09951991587877274;
  t222_n160: return -0.037028249353170395;
  t222_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n163;
  t222_n162: return 0.06646394729614258;
  t222_n163: return -0.0017417800845578313;
  t222_n164: return 0.10244596749544144;
  t222_n165: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t222_n211;
  t222_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t222_n188;
  t222_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t222_n181;
  t222_n168: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t222_n170;
  t222_n169: return -0.0425318107008934;
  t222_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n174;
  t222_n171: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t222_n173;
  t222_n172: return 0.08825137466192245;
  t222_n173: return -0.21864619851112366;
  t222_n174: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n180;
  t222_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n179;
  t222_n176: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t222_n178;
  t222_n177: return 0.12043821066617966;
  t222_n178: return -0.10029661655426025;
  t222_n179: return -0.12759210169315338;
  t222_n180: return -0.18595321476459503;
  t222_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n183;
  t222_n182: return -0.14385314285755157;
  t222_n183: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t222_n187;
  t222_n184: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t222_n186;
  t222_n185: return -0.14611020684242249;
  t222_n186: return 0.08829008042812347;
  t222_n187: return -0.03846360370516777;
  t222_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n202;
  t222_n189: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t222_n201;
  t222_n190: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n198;
  t222_n191: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t222_n197;
  t222_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n196;
  t222_n193: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t222_n195;
  t222_n194: return 0.13226456940174103;
  t222_n195: return -0.24932228028774261;
  t222_n196: return 0.12888680398464203;
  t222_n197: return -0.11093797534704208;
  t222_n198: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t222_n200;
  t222_n199: return 0.13539353013038635;
  t222_n200: return 0.16154596209526062;
  t222_n201: return 0.04740780591964722;
  t222_n202: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t222_n204;
  t222_n203: return -0.03813396021723747;
  t222_n204: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t222_n206;
  t222_n205: return 0.014889082871377468;
  t222_n206: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t222_n208;
  t222_n207: return 0.05886504799127579;
  t222_n208: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n210;
  t222_n209: return 0.17019899189472198;
  t222_n210: return 0.10446176677942276;
  t222_n211: return 0.007939757779240608;
  t222_n212: return 0.0036925182212144136;
  t222_n213: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t222_n247;
  t222_n214: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t222_n236;
  t222_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t222_n217;
  t222_n216: return -0.06384909152984619;
  t222_n217: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t222_n229;
  t222_n218: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t222_n226;
  t222_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n221;
  t222_n220: return 0.01935068890452385;
  t222_n221: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t222_n225;
  t222_n222: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t222_n224;
  t222_n223: return 0.10760246217250824;
  t222_n224: return 0.018051689490675926;
  t222_n225: return -0.01595795527100563;
  t222_n226: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t222_n228;
  t222_n227: return -0.03193579614162445;
  t222_n228: return 0.04729814454913139;
  t222_n229: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t222_n235;
  t222_n230: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t222_n232;
  t222_n231: return 0.011933735571801662;
  t222_n232: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t222_n234;
  t222_n233: return 0.21887102723121643;
  t222_n234: return 0.11071616411209106;
  t222_n235: return -0.6168844699859619;
  t222_n236: if (E.getNumReferences() >= 3367470384 /*375849.5*/) goto t222_n238;
  t222_n237: return 0.0026577410753816366;
  t222_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t222_n240;
  t222_n239: return 0.08911927789449692;
  t222_n240: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t222_n244;
  t222_n241: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t222_n243;
  t222_n242: return 0.09057794511318207;
  t222_n243: return -0.28543782234191895;
  t222_n244: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t222_n246;
  t222_n245: return 0.09310455620288849;
  t222_n246: return 0.0649876669049263;
  t222_n247: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t222_n253;
  t222_n248: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t222_n252;
  t222_n249: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t222_n251;
  t222_n250: return 0.03159825876355171;
  t222_n251: return -0.09844845533370972;
  t222_n252: return 0.0008349312702193856;
  t222_n253: return 0.02353634685277939;
  t222_n254: return 0.002825578209012747;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree223(const Example& E) {
  t223_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t223_n2;
  t223_n1: return -0.00030225960654206574;
  t223_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t223_n24;
  t223_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t223_n9;
  t223_n4: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t223_n6;
  t223_n5: return -0.08881086856126785;
  t223_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t223_n8;
  t223_n7: return -0.1959427446126938;
  t223_n8: return 0.0942753478884697;
  t223_n9: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t223_n23;
  t223_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t223_n14;
  t223_n11: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t223_n13;
  t223_n12: return -0.0689210593700409;
  t223_n13: return 0.10726407915353775;
  t223_n14: if (E.getNumReferences() >= 3314636800 /*4651.0*/) goto t223_n16;
  t223_n15: return -0.10972477495670319;
  t223_n16: if (E.getNumReferences() >= 3329863680 /*15980.0*/) goto t223_n22;
  t223_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t223_n19;
  t223_n18: return 0.06889516115188599;
  t223_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t223_n21;
  t223_n20: return 0.11442457139492035;
  t223_n21: return 0.12357226759195328;
  t223_n22: return 0.06002621352672577;
  t223_n23: return 0.010425308719277382;
  t223_n24: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t223_n26;
  t223_n25: return -0.0005410931771621108;
  t223_n26: if (E.getNumReferences() >= 3311265792 /*3550.5*/) goto t223_n94;
  t223_n27: if (E.getNumReferences() >= 3309664256 /*3159.5*/) goto t223_n65;
  t223_n28: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t223_n62;
  t223_n29: if (E.getNumReferences() >= 3306835968 /*2469.0*/) goto t223_n31;
  t223_n30: return 0.0955280140042305;
  t223_n31: if (E.getNumReferences() >= 3309590528 /*3141.5*/) goto t223_n61;
  t223_n32: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t223_n34;
  t223_n33: return -0.17611229419708252;
  t223_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n60;
  t223_n35: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t223_n55;
  t223_n36: if (E.getNumReferences() >= 3308998656 /*2997.0*/) goto t223_n50;
  t223_n37: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t223_n41;
  t223_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t223_n40;
  t223_n39: return -0.37194597721099854;
  t223_n40: return 0.001504627987742424;
  t223_n41: if (E.getNumReferences() >= 3307941888 /*2739.0*/) goto t223_n47;
  t223_n42: if (E.getNumReferences() >= 3307663360 /*2671.0*/) goto t223_n46;
  t223_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t223_n45;
  t223_n44: return -0.03596928343176842;
  t223_n45: return 0.11492031812667847;
  t223_n46: return 0.12995092570781708;
  t223_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t223_n49;
  t223_n48: return -0.1335853934288025;
  t223_n49: return 0.07902020961046219;
  t223_n50: if (E.getNumReferences() >= 3309209600 /*3048.5*/) goto t223_n52;
  t223_n51: return 0.11678127199411392;
  t223_n52: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n54;
  t223_n53: return -0.07342595607042313;
  t223_n54: return 0.11602914333343506;
  t223_n55: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n59;
  t223_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t223_n58;
  t223_n57: return 0.035105083137750626;
  t223_n58: return 0.11791567504405975;
  t223_n59: return -0.13647301495075226;
  t223_n60: return -0.0509699322283268;
  t223_n61: return -0.2636476755142212;
  t223_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t223_n64;
  t223_n63: return 0.050119418650865555;
  t223_n64: return 0.10243455320596695;
  t223_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t223_n91;
  t223_n66: if (E.getNumReferences() >= 3309780992 /*3188.0*/) goto t223_n70;
  t223_n67: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t223_n69;
  t223_n68: return 0.12744170427322388;
  t223_n69: return 0.17016731202602386;
  t223_n70: if (E.getNumReferences() >= 3311222784 /*3540.0*/) goto t223_n90;
  t223_n71: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n83;
  t223_n72: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t223_n74;
  t223_n73: return -0.1631678342819214;
  t223_n74: if (E.getNumReferences() >= 3311050752 /*3498.0*/) goto t223_n82;
  t223_n75: if (E.getNumReferences() >= 3310497792 /*3363.0*/) goto t223_n81;
  t223_n76: if (E.getNumReferences() >= 3310071808 /*3259.0*/) goto t223_n78;
  t223_n77: return 0.01882539689540863;
  t223_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n80;
  t223_n79: return 0.05561196431517601;
  t223_n80: return 0.13397717475891113;
  t223_n81: return -0.05219866335391998;
  t223_n82: return 0.11910708993673325;
  t223_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t223_n87;
  t223_n84: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n86;
  t223_n85: return 0.1029561385512352;
  t223_n86: return 0.07862360775470734;
  t223_n87: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t223_n89;
  t223_n88: return -0.05364382639527321;
  t223_n89: return 0.12241631001234055;
  t223_n90: return 0.1295752078294754;
  t223_n91: if (E.getNumReferences() >= 3310143488 /*3276.5*/) goto t223_n93;
  t223_n92: return 0.10899953544139862;
  t223_n93: return -0.04017873480916023;
  t223_n94: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t223_n150;
  t223_n95: if (E.getNumReferences() >= 3315609600 /*5126.0*/) goto t223_n101;
  t223_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion))) goto t223_n98;
  t223_n97: return -0.06706073135137558;
  t223_n98: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n100;
  t223_n99: return -0.1309879869222641;
  t223_n100: return 0.10625500231981277;
  t223_n101: if (E.getNumReferences() >= 3319521280 /*7036.0*/) goto t223_n127;
  t223_n102: if (E.getNumReferences() >= 3319400448 /*6977.0*/) goto t223_n126;
  t223_n103: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t223_n123;
  t223_n104: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t223_n112;
  t223_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t223_n111;
  t223_n106: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t223_n108;
  t223_n107: return -0.1243208572268486;
  t223_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n110;
  t223_n109: return -0.13642992079257965;
  t223_n110: return 0.10642664134502411;
  t223_n111: return 0.10574585944414139;
  t223_n112: if (E.getNumReferences() >= 3318799360 /*6683.5*/) goto t223_n122;
  t223_n113: if (E.getNumReferences() >= 3318719488 /*6644.5*/) goto t223_n121;
  t223_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t223_n118;
  t223_n115: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t223_n117;
  t223_n116: return 0.12274851649999619;
  t223_n117: return 0.030897868797183037;
  t223_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n120;
  t223_n119: return 0.14743511378765106;
  t223_n120: return -0.052159152925014496;
  t223_n121: return 0.11091358214616776;
  t223_n122: return 0.008490953594446182;
  t223_n123: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t223_n125;
  t223_n124: return -0.13351579010486603;
  t223_n125: return 0.04073944687843323;
  t223_n126: return 0.11713580042123795;
  t223_n127: if (E.getNumReferences() >= 3320465408 /*7497.0*/) goto t223_n129;
  t223_n128: return -0.12094520777463913;
  t223_n129: if (E.getNumReferences() >= 3322556416 /*8844.0*/) goto t223_n149;
  t223_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t223_n144;
  t223_n131: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t223_n139;
  t223_n132: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t223_n134;
  t223_n133: return -0.016996344551444054;
  t223_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t223_n136;
  t223_n135: return -0.10727773606777191;
  t223_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t223_n138;
  t223_n137: return 0.13132824003696442;
  t223_n138: return -0.27782392501831055;
  t223_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n141;
  t223_n140: return 0.030611377209424973;
  t223_n141: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t223_n143;
  t223_n142: return 0.11228463053703308;
  t223_n143: return 0.09314531832933426;
  t223_n144: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t223_n146;
  t223_n145: return 0.07088711112737656;
  t223_n146: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t223_n148;
  t223_n147: return 0.11003460735082626;
  t223_n148: return 0.14348922669887543;
  t223_n149: return 0.006660331040620804;
  t223_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t223_n220;
  t223_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t223_n169;
  t223_n152: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t223_n156;
  t223_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t223_n155;
  t223_n154: return 0.01690451055765152;
  t223_n155: return 0.09941917657852173;
  t223_n156: if (E.getNumReferences() >= 3338411008 /*32270.0*/) goto t223_n166;
  t223_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t223_n165;
  t223_n158: if (E.getNumReferences() >= 3334364160 /*24366.0*/) goto t223_n160;
  t223_n159: return 0.005417082458734512;
  t223_n160: if (E.getNumReferences() >= 3334486272 /*24604.5*/) goto t223_n164;
  t223_n161: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t223_n163;
  t223_n162: return -0.21156924962997437;
  t223_n163: return -1.244766354560852;
  t223_n164: return -0.058898571878671646;
  t223_n165: return -0.3027057349681854;
  t223_n166: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t223_n168;
  t223_n167: return 0.07982542365789413;
  t223_n168: return 0.015450295060873032;
  t223_n169: if (E.getNumReferences() >= 3330418688 /*16660.0*/) goto t223_n207;
  t223_n170: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t223_n204;
  t223_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t223_n177;
  t223_n172: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n176;
  t223_n173: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t223_n175;
  t223_n174: return 0.02882930263876915;
  t223_n175: return 0.10187544673681259;
  t223_n176: return -0.06716786324977875;
  t223_n177: if (E.getNumReferences() >= 3326988288 /*13172.0*/) goto t223_n189;
  t223_n178: if (E.getNumReferences() >= 3322808320 /*9090.0*/) goto t223_n188;
  t223_n179: if (E.getNumReferences() >= 3319662592 /*7105.0*/) goto t223_n183;
  t223_n180: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t223_n182;
  t223_n181: return 0.10662314295768738;
  t223_n182: return 0.01913699321448803;
  t223_n183: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t223_n187;
  t223_n184: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t223_n186;
  t223_n185: return 0.07534017413854599;
  t223_n186: return 0.12344542890787125;
  t223_n187: return -0.02781509980559349;
  t223_n188: return -0.06361326575279236;
  t223_n189: if (E.getNumReferences() >= 3328450048 /*14599.5*/) goto t223_n193;
  t223_n190: if (E.getNumReferences() >= 3328288256 /*14441.5*/) goto t223_n192;
  t223_n191: return 0.10256063938140869;
  t223_n192: return 0.111517995595932;
  t223_n193: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t223_n199;
  t223_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n198;
  t223_n195: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n197;
  t223_n196: return 0.08950023353099823;
  t223_n197: return 0.028373733162879944;
  t223_n198: return -0.039194460958242416;
  t223_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n203;
  t223_n200: if (E.getNumReferences() >= 3329443328 /*15569.5*/) goto t223_n202;
  t223_n201: return 0.0773523598909378;
  t223_n202: return 0.11969128251075745;
  t223_n203: return -0.025570955127477646;
  t223_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t223_n206;
  t223_n205: return -0.2741762697696686;
  t223_n206: return 0.08904803544282913;
  t223_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t223_n219;
  t223_n208: if (E.getNumReferences() >= 3347567040 /*69539.5*/) goto t223_n218;
  t223_n209: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t223_n217;
  t223_n210: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t223_n214;
  t223_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t223_n213;
  t223_n212: return -0.21973657608032227;
  t223_n213: return -0.00835697166621685;
  t223_n214: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t223_n216;
  t223_n215: return 0.04417629539966583;
  t223_n216: return -0.8623164296150208;
  t223_n217: return 0.007995772175490856;
  t223_n218: return 0.0412602424621582;
  t223_n219: return 0.04690919071435928;
  t223_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t223_n226;
  t223_n221: if (E.getNumReferences() >= 3317711872 /*6152.5*/) goto t223_n223;
  t223_n222: return 0.11243002861738205;
  t223_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t223_n225;
  t223_n224: return -0.04909931868314743;
  t223_n225: return 0.0642022117972374;
  t223_n226: if (E.getNumReferences() >= 3365715136 /*320998.0*/) goto t223_n248;
  t223_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t223_n243;
  t223_n228: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t223_n230;
  t223_n229: return -0.41158854961395264;
  t223_n230: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n236;
  t223_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t223_n233;
  t223_n232: return 0.045621804893016815;
  t223_n233: if (E.getNumReferences() >= 3339768960 /*37076.5*/) goto t223_n235;
  t223_n234: return 0.10890340059995651;
  t223_n235: return 0.04154248163104057;
  t223_n236: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n238;
  t223_n237: return -0.1486285775899887;
  t223_n238: if (E.getNumReferences() >= 3328615936 /*14761.5*/) goto t223_n240;
  t223_n239: return -0.10855929553508759;
  t223_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t223_n242;
  t223_n241: return 0.07745000720024109;
  t223_n242: return 0.10014621168375015;
  t223_n243: if (E.getNumReferences() >= 3321041920 /*7778.5*/) goto t223_n247;
  t223_n244: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t223_n246;
  t223_n245: return 0.08618320524692535;
  t223_n246: return 0.10713700205087662;
  t223_n247: return 0.016089236363768578;
  t223_n248: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t223_n250;
  t223_n249: return 0.10637218505144119;
  t223_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t223_n254;
  t223_n251: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t223_n253;
  t223_n252: return 0.09013295918703079;
  t223_n253: return 0.07666965574026108;
  t223_n254: return -0.037875182926654816;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree224(const Example& E) {
  t224_n0: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t224_n254;
  t224_n1: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t224_n3;
  t224_n2: return 0.002090038964524865;
  t224_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t224_n49;
  t224_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t224_n6;
  t224_n5: return 0.007970655336976051;
  t224_n6: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n48;
  t224_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t224_n41;
  t224_n8: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n28;
  t224_n9: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t224_n15;
  t224_n10: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n12;
  t224_n11: return -0.009624226950109005;
  t224_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n14;
  t224_n13: return 0.11904498934745789;
  t224_n14: return -0.05007816106081009;
  t224_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t224_n17;
  t224_n16: return -0.12307945638895035;
  t224_n17: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t224_n27;
  t224_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n22;
  t224_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t224_n21;
  t224_n20: return -0.14290349185466766;
  t224_n21: return 0.4916507303714752;
  t224_n22: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t224_n26;
  t224_n23: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n25;
  t224_n24: return 0.0731588825583458;
  t224_n25: return 0.1060326024889946;
  t224_n26: return -0.10156445950269699;
  t224_n27: return 0.11653025448322296;
  t224_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t224_n38;
  t224_n29: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t224_n35;
  t224_n30: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t224_n34;
  t224_n31: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t224_n33;
  t224_n32: return -0.31851717829704285;
  t224_n33: return 0.6899611353874207;
  t224_n34: return -0.2799776792526245;
  t224_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n37;
  t224_n36: return -1.4092622995376587;
  t224_n37: return 0.10753193497657776;
  t224_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n40;
  t224_n39: return 0.0766822025179863;
  t224_n40: return 0.12125874310731888;
  t224_n41: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n45;
  t224_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t224_n44;
  t224_n43: return 0.118426114320755;
  t224_n44: return -0.10801494121551514;
  t224_n45: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n47;
  t224_n46: return 0.006017992272973061;
  t224_n47: return 0.11493261903524399;
  t224_n48: return -0.07552118599414825;
  t224_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t224_n249;
  t224_n50: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t224_n202;
  t224_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n115;
  t224_n52: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t224_n86;
  t224_n53: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n55;
  t224_n54: return 0.01360639464110136;
  t224_n55: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t224_n59;
  t224_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t224_n58;
  t224_n57: return 0.04151182994246483;
  t224_n58: return -0.05344850942492485;
  t224_n59: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t224_n85;
  t224_n60: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t224_n68;
  t224_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t224_n63;
  t224_n62: return 0.055362243205308914;
  t224_n63: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t224_n65;
  t224_n64: return 0.03326638042926788;
  t224_n65: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t224_n67;
  t224_n66: return 0.12040217220783234;
  t224_n67: return -0.12194763869047165;
  t224_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t224_n80;
  t224_n69: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t224_n77;
  t224_n70: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t224_n72;
  t224_n71: return 0.06697706878185272;
  t224_n72: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n74;
  t224_n73: return 0.05167331174015999;
  t224_n74: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n76;
  t224_n75: return 0.1317444145679474;
  t224_n76: return -0.12030099332332611;
  t224_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n79;
  t224_n78: return 0.04908344894647598;
  t224_n79: return 0.1296328604221344;
  t224_n80: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t224_n82;
  t224_n81: return 0.12855902314186096;
  t224_n82: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n84;
  t224_n83: return 0.1731124371290207;
  t224_n84: return 0.13055290281772614;
  t224_n85: return 0.0034022785257548094;
  t224_n86: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t224_n94;
  t224_n87: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t224_n93;
  t224_n88: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t224_n92;
  t224_n89: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t224_n91;
  t224_n90: return -0.23700694739818573;
  t224_n91: return 0.1081915944814682;
  t224_n92: return 0.013142767362296581;
  t224_n93: return 0.12475356459617615;
  t224_n94: if (E.getNumReferences() >= 3282436096 /*332.0*/) goto t224_n98;
  t224_n95: if (E.getNumReferences() >= 3282223104 /*325.5*/) goto t224_n97;
  t224_n96: return 0.05066218599677086;
  t224_n97: return 0.10012137144804001;
  t224_n98: if (E.getNumReferences() >= 3311534080 /*3616.0*/) goto t224_n104;
  t224_n99: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t224_n101;
  t224_n100: return -0.041479095816612244;
  t224_n101: if (E.getNumReferences() >= 3288514560 /*523.0*/) goto t224_n103;
  t224_n102: return 0.0839371457695961;
  t224_n103: return -0.046843502670526505;
  t224_n104: if (E.getNumReferences() >= 3313753088 /*4219.5*/) goto t224_n110;
  t224_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t224_n107;
  t224_n106: return -0.10076704621315002;
  t224_n107: if (E.getNumReferences() >= 3313506304 /*4099.0*/) goto t224_n109;
  t224_n108: return 0.10869736969470978;
  t224_n109: return 0.1146240159869194;
  t224_n110: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t224_n112;
  t224_n111: return 0.06858779489994049;
  t224_n112: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t224_n114;
  t224_n113: return 0.06768777966499329;
  t224_n114: return -0.5822276473045349;
  t224_n115: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t224_n193;
  t224_n116: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t224_n164;
  t224_n117: if (E.getNumReferences() >= 3256745984 /*39.5*/) goto t224_n153;
  t224_n118: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t224_n148;
  t224_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n129;
  t224_n120: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t224_n126;
  t224_n121: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t224_n125;
  t224_n122: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t224_n124;
  t224_n123: return -0.07862704247236252;
  t224_n124: return 0.020481903105974197;
  t224_n125: return -0.032830026000738144;
  t224_n126: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t224_n128;
  t224_n127: return -0.046723347157239914;
  t224_n128: return 0.10221507400274277;
  t224_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t224_n143;
  t224_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t224_n132;
  t224_n131: return -0.11155829578638077;
  t224_n132: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t224_n142;
  t224_n133: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t224_n135;
  t224_n134: return 0.028268828988075256;
  t224_n135: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n139;
  t224_n136: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t224_n138;
  t224_n137: return -0.05974140018224716;
  t224_n138: return 0.11140148341655731;
  t224_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t224_n141;
  t224_n140: return 0.12167350947856903;
  t224_n141: return 0.11712241172790527;
  t224_n142: return -0.024723181501030922;
  t224_n143: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t224_n147;
  t224_n144: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t224_n146;
  t224_n145: return 0.15960706770420074;
  t224_n146: return -0.10416930168867111;
  t224_n147: return -0.10023993253707886;
  t224_n148: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t224_n152;
  t224_n149: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t224_n151;
  t224_n150: return 0.04162727668881416;
  t224_n151: return 0.11127671599388123;
  t224_n152: return 0.4157874584197998;
  t224_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t224_n155;
  t224_n154: return -0.2628426253795624;
  t224_n155: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t224_n157;
  t224_n156: return -0.08329572528600693;
  t224_n157: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t224_n161;
  t224_n158: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t224_n160;
  t224_n159: return 0.0402182899415493;
  t224_n160: return -0.530044436454773;
  t224_n161: if (E.getNumReferences() >= 3284140032 /*384.0*/) goto t224_n163;
  t224_n162: return -0.12468789517879486;
  t224_n163: return -1.0637089014053345;
  t224_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t224_n166;
  t224_n165: return -0.1405564248561859;
  t224_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t224_n168;
  t224_n167: return 0.03361406922340393;
  t224_n168: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t224_n188;
  t224_n169: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t224_n171;
  t224_n170: return -0.011552898213267326;
  t224_n171: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t224_n187;
  t224_n172: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t224_n180;
  t224_n173: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t224_n179;
  t224_n174: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n178;
  t224_n175: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t224_n177;
  t224_n176: return 0.3902466595172882;
  t224_n177: return 0.12858246266841888;
  t224_n178: return -0.4032265841960907;
  t224_n179: return -0.19712156057357788;
  t224_n180: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t224_n184;
  t224_n181: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t224_n183;
  t224_n182: return -0.27597206830978394;
  t224_n183: return 0.12999580800533295;
  t224_n184: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n186;
  t224_n185: return 0.10880408436059952;
  t224_n186: return 0.1390291303396225;
  t224_n187: return -0.029175005853176117;
  t224_n188: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t224_n192;
  t224_n189: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t224_n191;
  t224_n190: return 0.028126342222094536;
  t224_n191: return 0.14137108623981476;
  t224_n192: return 0.10706236958503723;
  t224_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t224_n201;
  t224_n194: if (E.getNumReferences() >= 3292766208 /*782.5*/) goto t224_n200;
  t224_n195: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t224_n197;
  t224_n196: return -0.12851545214653015;
  t224_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n199;
  t224_n198: return -0.9177517294883728;
  t224_n199: return -0.012503090314567089;
  t224_n200: return -0.04234965145587921;
  t224_n201: return 0.08284295350313187;
  t224_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t224_n240;
  t224_n203: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t224_n211;
  t224_n204: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t224_n206;
  t224_n205: return -0.022888561710715294;
  t224_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n208;
  t224_n207: return 0.04268068075180054;
  t224_n208: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t224_n210;
  t224_n209: return 0.11648062616586685;
  t224_n210: return 0.05122195929288864;
  t224_n211: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t224_n213;
  t224_n212: return 0.007408101111650467;
  t224_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t224_n219;
  t224_n214: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t224_n218;
  t224_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t224_n217;
  t224_n216: return -0.08174259960651398;
  t224_n217: return 0.10520272701978683;
  t224_n218: return 0.027344726026058197;
  t224_n219: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n233;
  t224_n220: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t224_n228;
  t224_n221: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n227;
  t224_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n226;
  t224_n223: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t224_n225;
  t224_n224: return -0.4720199704170227;
  t224_n225: return 0.01656191051006317;
  t224_n226: return 0.08790045976638794;
  t224_n227: return 0.10284260660409927;
  t224_n228: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t224_n232;
  t224_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t224_n231;
  t224_n230: return 0.11345087736845016;
  t224_n231: return -0.10090146958827972;
  t224_n232: return 0.07714098691940308;
  t224_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t224_n239;
  t224_n234: if (E.getFilterLength() >= 3242721280 /*12.5*/) goto t224_n238;
  t224_n235: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t224_n237;
  t224_n236: return -0.10079355537891388;
  t224_n237: return 0.1393755078315735;
  t224_n238: return 0.09350764006376266;
  t224_n239: return 0.1080460399389267;
  t224_n240: if (E.getSymbolScopeDistance() >= 3242196992 /*12.0*/) goto t224_n242;
  t224_n241: return 0.05204559490084648;
  t224_n242: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t224_n246;
  t224_n243: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t224_n245;
  t224_n244: return 0.13454116880893707;
  t224_n245: return -0.036885373294353485;
  t224_n246: if (E.getNumReferences() >= 3261595648 /*58.0*/) goto t224_n248;
  t224_n247: return -0.06509009748697281;
  t224_n248: return 0.10308516025543213;
  t224_n249: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t224_n251;
  t224_n250: return -0.07751334458589554;
  t224_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t224_n253;
  t224_n252: return -0.34576794505119324;
  t224_n253: return 0.0026608342304825783;
  t224_n254: return -0.0006344494759105146;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree225(const Example& E) {
  t225_n0: if (E.getNumReferences() >= 3306797056 /*2459.5*/) goto t225_n2;
  t225_n1: return -0.0003128302050754428;
  t225_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t225_n4;
  t225_n3: return 0.009970094077289104;
  t225_n4: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t225_n6;
  t225_n5: return -0.0010643479181453586;
  t225_n6: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t225_n252;
  t225_n7: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t225_n183;
  t225_n8: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t225_n156;
  t225_n9: if (E.getNumReferences() >= 3318231040 /*6406.0*/) goto t225_n27;
  t225_n10: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t225_n20;
  t225_n11: if (E.getNumReferences() >= 3306874880 /*2478.5*/) goto t225_n19;
  t225_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t225_n14;
  t225_n13: return 0.047852881252765656;
  t225_n14: if (E.getNumReferences() >= 3306842112 /*2470.5*/) goto t225_n16;
  t225_n15: return 0.10095170885324478;
  t225_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t225_n18;
  t225_n17: return -0.2895142734050751;
  t225_n18: return 0.41574493050575256;
  t225_n19: return 0.005380767397582531;
  t225_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t225_n24;
  t225_n21: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t225_n23;
  t225_n22: return 0.10433246195316315;
  t225_n23: return 0.027285929769277573;
  t225_n24: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t225_n26;
  t225_n25: return 0.11709584295749664;
  t225_n26: return 0.07099901884794235;
  t225_n27: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t225_n61;
  t225_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t225_n36;
  t225_n29: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t225_n33;
  t225_n30: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t225_n32;
  t225_n31: return 0.10732364654541016;
  t225_n32: return -0.012454461306333542;
  t225_n33: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t225_n35;
  t225_n34: return 0.005057146772742271;
  t225_n35: return 0.24568337202072144;
  t225_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t225_n46;
  t225_n37: if (E.getNumReferences() >= 3318706176 /*6638.0*/) goto t225_n45;
  t225_n38: if (E.getNumReferences() >= 3318537216 /*6555.5*/) goto t225_n44;
  t225_n39: if (E.getNumReferences() >= 3318477824 /*6526.5*/) goto t225_n43;
  t225_n40: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t225_n42;
  t225_n41: return 0.250222772359848;
  t225_n42: return 0.13217505812644958;
  t225_n43: return 0.13140086829662323;
  t225_n44: return -0.454751193523407;
  t225_n45: return 0.11255329847335815;
  t225_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n54;
  t225_n47: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t225_n49;
  t225_n48: return 0.22767598927021027;
  t225_n49: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t225_n51;
  t225_n50: return -0.009186173789203167;
  t225_n51: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n53;
  t225_n52: return 0.11637281626462936;
  t225_n53: return 0.05535529553890228;
  t225_n54: if (E.getNumReferences() >= 3318714368 /*6642.0*/) goto t225_n60;
  t225_n55: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n57;
  t225_n56: return -0.11213743686676025;
  t225_n57: if (E.getNumReferences() >= 3318256640 /*6418.5*/) goto t225_n59;
  t225_n58: return 0.1315479725599289;
  t225_n59: return 0.09280383586883545;
  t225_n60: return 0.13891412317752838;
  t225_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t225_n63;
  t225_n62: return 0.008378828875720501;
  t225_n63: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t225_n77;
  t225_n64: if (E.getNumReferences() >= 3320185856 /*7360.5*/) goto t225_n72;
  t225_n65: if (E.getNumReferences() >= 3319960576 /*7250.5*/) goto t225_n71;
  t225_n66: if (E.getNumReferences() >= 3319654400 /*7101.0*/) goto t225_n68;
  t225_n67: return -0.016371307894587517;
  t225_n68: if (E.getNumReferences() >= 3319692288 /*7119.5*/) goto t225_n70;
  t225_n69: return 0.11892156302928925;
  t225_n70: return 0.045820266008377075;
  t225_n71: return 0.11863864213228226;
  t225_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t225_n74;
  t225_n73: return -0.004869378171861172;
  t225_n74: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t225_n76;
  t225_n75: return 0.10891716182231903;
  t225_n76: return 0.06980974227190018;
  t225_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t225_n89;
  t225_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t225_n80;
  t225_n79: return -0.017114335671067238;
  t225_n80: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t225_n88;
  t225_n81: if (E.getNumReferences() >= 3327006208 /*13189.5*/) goto t225_n83;
  t225_n82: return 0.09628321975469589;
  t225_n83: if (E.getNumReferences() >= 3327691264 /*13858.5*/) goto t225_n85;
  t225_n84: return 0.11125697195529938;
  t225_n85: if (E.getNumReferences() >= 3331214336 /*18214.0*/) goto t225_n87;
  t225_n86: return -0.10845309495925903;
  t225_n87: return 0.13731348514556885;
  t225_n88: return 0.0380374975502491;
  t225_n89: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t225_n95;
  t225_n90: if (E.getNumReferences() >= 3330558208 /*16932.5*/) goto t225_n92;
  t225_n91: return -0.01604125089943409;
  t225_n92: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n94;
  t225_n93: return 0.12386365979909897;
  t225_n94: return -0.10821074992418289;
  t225_n95: if (E.getNumReferences() >= 3324665856 /*10904.0*/) goto t225_n151;
  t225_n96: if (E.getNumReferences() >= 3324199424 /*10448.5*/) goto t225_n140;
  t225_n97: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t225_n117;
  t225_n98: if (E.getNumReferences() >= 3323001856 /*9279.0*/) goto t225_n116;
  t225_n99: if (E.getNumReferences() >= 3321178112 /*7845.0*/) goto t225_n101;
  t225_n100: return -0.00821286253631115;
  t225_n101: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n105;
  t225_n102: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t225_n104;
  t225_n103: return 0.05483260005712509;
  t225_n104: return 0.11395349353551865;
  t225_n105: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t225_n109;
  t225_n106: if (E.getNumReferences() >= 3321991168 /*8292.0*/) goto t225_n108;
  t225_n107: return 0.11436206847429276;
  t225_n108: return -0.021011311560869217;
  t225_n109: if (E.getNumReferences() >= 3322122752 /*8420.5*/) goto t225_n111;
  t225_n110: return -0.16106219589710236;
  t225_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t225_n113;
  t225_n112: return -0.11745794117450714;
  t225_n113: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t225_n115;
  t225_n114: return 0.11643092334270477;
  t225_n115: return 0.09625356644392014;
  t225_n116: return -0.13841097056865692;
  t225_n117: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t225_n131;
  t225_n118: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n120;
  t225_n119: return -0.04185833781957626;
  t225_n120: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t225_n122;
  t225_n121: return -0.02782095968723297;
  t225_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n126;
  t225_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t225_n125;
  t225_n124: return 0.09778451174497604;
  t225_n125: return 0.0820426344871521;
  t225_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n130;
  t225_n127: if (E.getNumReferences() >= 3321930240 /*8232.5*/) goto t225_n129;
  t225_n128: return 0.1148296594619751;
  t225_n129: return -0.16420969367027283;
  t225_n130: return 0.22774703800678253;
  t225_n131: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t225_n137;
  t225_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n134;
  t225_n133: return 0.06030729040503502;
  t225_n134: if (E.getNumReferences() >= 3320613888 /*7569.5*/) goto t225_n136;
  t225_n135: return 0.119156114757061;
  t225_n136: return 0.13378971815109253;
  t225_n137: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t225_n139;
  t225_n138: return 0.03995857387781143;
  t225_n139: return 0.10314061492681503;
  t225_n140: if (E.getNumReferences() >= 3324570112 /*10810.5*/) goto t225_n150;
  t225_n141: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t225_n149;
  t225_n142: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t225_n144;
  t225_n143: return -0.1168680191040039;
  t225_n144: if (E.getNumReferences() >= 3324409856 /*10654.0*/) goto t225_n148;
  t225_n145: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t225_n147;
  t225_n146: return 0.11614633351564407;
  t225_n147: return 0.0989418551325798;
  t225_n148: return -0.10555911064147949;
  t225_n149: return 0.09890850633382797;
  t225_n150: return 0.11663348227739334;
  t225_n151: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t225_n153;
  t225_n152: return -0.008974677883088589;
  t225_n153: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t225_n155;
  t225_n154: return 0.08475401997566223;
  t225_n155: return -0.07222270965576172;
  t225_n156: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t225_n176;
  t225_n157: if (E.getNumReferences() >= 3318137856 /*6360.5*/) goto t225_n161;
  t225_n158: if (E.getNumReferences() >= 3317563392 /*6080.0*/) goto t225_n160;
  t225_n159: return 0.01039116270840168;
  t225_n160: return -0.5080410838127136;
  t225_n161: if (E.getNumReferences() >= 3318199296 /*6390.5*/) goto t225_n167;
  t225_n162: if (E.getNumReferences() >= 3318195200 /*6388.5*/) goto t225_n164;
  t225_n163: return 0.040026016533374786;
  t225_n164: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n166;
  t225_n165: return 0.10378746688365936;
  t225_n166: return 0.11416418850421906;
  t225_n167: if (E.getNumReferences() >= 3321964544 /*8266.0*/) goto t225_n169;
  t225_n168: return 0.005507347639650106;
  t225_n169: if (E.getNumReferences() >= 3322966016 /*9244.0*/) goto t225_n175;
  t225_n170: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n172;
  t225_n171: return 0.09480433166027069;
  t225_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t225_n174;
  t225_n173: return 0.10718460381031036;
  t225_n174: return 0.0951366201043129;
  t225_n175: return 0.038687098771333694;
  t225_n176: if (E.getNumReferences() >= 3314617344 /*4641.5*/) goto t225_n182;
  t225_n177: if (E.getNumReferences() >= 3312302080 /*3803.5*/) goto t225_n181;
  t225_n178: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n180;
  t225_n179: return 0.08665508031845093;
  t225_n180: return -0.5897219777107239;
  t225_n181: return 0.10663345456123352;
  t225_n182: return 0.03500879555940628;
  t225_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace))) goto t225_n239;
  t225_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t225_n186;
  t225_n185: return -0.06521189212799072;
  t225_n186: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t225_n192;
  t225_n187: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t225_n191;
  t225_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t225_n190;
  t225_n189: return 0.14807188510894775;
  t225_n190: return 0.11428626626729965;
  t225_n191: return -0.06366360932588577;
  t225_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t225_n194;
  t225_n193: return -0.08275913447141647;
  t225_n194: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t225_n238;
  t225_n195: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t225_n221;
  t225_n196: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t225_n216;
  t225_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t225_n199;
  t225_n198: return 0.021025976166129112;
  t225_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n209;
  t225_n200: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t225_n202;
  t225_n201: return 0.10768400132656097;
  t225_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t225_n204;
  t225_n203: return 0.0406438447535038;
  t225_n204: if (E.getNumReferences() >= 3332674048 /*21065.0*/) goto t225_n206;
  t225_n205: return -0.26403915882110596;
  t225_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n208;
  t225_n207: return -0.12938638031482697;
  t225_n208: return 0.1251102089881897;
  t225_n209: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t225_n211;
  t225_n210: return -0.003643566742539406;
  t225_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n213;
  t225_n212: return -0.16294331848621368;
  t225_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t225_n215;
  t225_n214: return 0.07668208330869675;
  t225_n215: return -0.11286569386720657;
  t225_n216: if (E.getNumReferences() >= 3332022528 /*19792.5*/) goto t225_n220;
  t225_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t225_n219;
  t225_n218: return -0.07339909672737122;
  t225_n219: return 0.11608508974313736;
  t225_n220: return 0.013748367317020893;
  t225_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n231;
  t225_n222: if (E.getNumReferences() >= 3332378112 /*20487.0*/) goto t225_n224;
  t225_n223: return 0.06931395828723907;
  t225_n224: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t225_n228;
  t225_n225: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t225_n227;
  t225_n226: return -0.06272171437740326;
  t225_n227: return 0.11524982005357742;
  t225_n228: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t225_n230;
  t225_n229: return -0.11932200938463211;
  t225_n230: return 0.10788322240114212;
  t225_n231: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t225_n233;
  t225_n232: return -0.16366365551948547;
  t225_n233: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t225_n237;
  t225_n234: if (E.getNumReferences() >= 3332209408 /*20157.5*/) goto t225_n236;
  t225_n235: return 0.07750340551137924;
  t225_n236: return 0.13266776502132416;
  t225_n237: return 0.04152444377541542;
  t225_n238: return 0.11445538699626923;
  t225_n239: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t225_n241;
  t225_n240: return -0.10201117396354675;
  t225_n241: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t225_n251;
  t225_n242: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t225_n246;
  t225_n243: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t225_n245;
  t225_n244: return 0.08496444672346115;
  t225_n245: return -0.09028788655996323;
  t225_n246: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t225_n248;
  t225_n247: return 0.10916098952293396;
  t225_n248: if (E.getNumReferences() >= 3332746752 /*21207.0*/) goto t225_n250;
  t225_n249: return 0.14964279532432556;
  t225_n250: return -1.0192757844924927;
  t225_n251: return 0.09194037318229675;
  t225_n252: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t225_n254;
  t225_n253: return -0.008205424062907696;
  t225_n254: return 0.02984604984521866;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree226(const Example& E) {
  t226_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t226_n2;
  t226_n1: return -0.00017533040954731405;
  t226_n2: if (E.getNumReferences() >= 3341797376 /*45000.0*/) goto t226_n12;
  t226_n3: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n5;
  t226_n4: return 0.06059421971440315;
  t226_n5: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t226_n7;
  t226_n6: return 0.12014567106962204;
  t226_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n9;
  t226_n8: return -0.11768745630979538;
  t226_n9: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t226_n11;
  t226_n10: return 0.10627882927656174;
  t226_n11: return 0.07569621503353119;
  t226_n12: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t226_n14;
  t226_n13: return -0.050893932580947876;
  t226_n14: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t226_n126;
  t226_n15: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t226_n99;
  t226_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n50;
  t226_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t226_n33;
  t226_n18: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t226_n32;
  t226_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n21;
  t226_n20: return -0.15028971433639526;
  t226_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n31;
  t226_n22: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t226_n26;
  t226_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t226_n25;
  t226_n24: return -0.12919187545776367;
  t226_n25: return 0.13873206079006195;
  t226_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t226_n30;
  t226_n27: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n29;
  t226_n28: return 0.02632182091474533;
  t226_n29: return 0.10428933799266815;
  t226_n30: return 0.12050057202577591;
  t226_n31: return 0.09592633694410324;
  t226_n32: return -0.02437111921608448;
  t226_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n35;
  t226_n34: return -0.1057472825050354;
  t226_n35: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t226_n37;
  t226_n36: return 0.04941555857658386;
  t226_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n39;
  t226_n38: return 0.07102930545806885;
  t226_n39: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t226_n41;
  t226_n40: return 0.028677286580204964;
  t226_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n47;
  t226_n42: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t226_n44;
  t226_n43: return 0.3009549081325531;
  t226_n44: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t226_n46;
  t226_n45: return 0.1140109971165657;
  t226_n46: return 0.05849257856607437;
  t226_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n49;
  t226_n48: return 0.1096707284450531;
  t226_n49: return 0.06340867280960083;
  t226_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t226_n62;
  t226_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t226_n53;
  t226_n52: return -0.11093426495790482;
  t226_n53: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t226_n55;
  t226_n54: return -0.13194440305233002;
  t226_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n59;
  t226_n56: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t226_n58;
  t226_n57: return 1.5101317167282104;
  t226_n58: return 0.1548532098531723;
  t226_n59: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n61;
  t226_n60: return 0.10808151215314865;
  t226_n61: return 0.08787643164396286;
  t226_n62: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t226_n98;
  t226_n63: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t226_n77;
  t226_n64: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t226_n66;
  t226_n65: return 0.10410407930612564;
  t226_n66: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t226_n68;
  t226_n67: return -0.1627863496541977;
  t226_n68: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t226_n74;
  t226_n69: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t226_n73;
  t226_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n72;
  t226_n71: return 0.07127110660076141;
  t226_n72: return 0.05435521900653839;
  t226_n73: return 0.06591964513063431;
  t226_n74: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n76;
  t226_n75: return 0.012570698745548725;
  t226_n76: return 0.11143455654382706;
  t226_n77: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n79;
  t226_n78: return 0.1866176575422287;
  t226_n79: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t226_n81;
  t226_n80: return -0.25499263405799866;
  t226_n81: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t226_n95;
  t226_n82: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t226_n90;
  t226_n83: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n85;
  t226_n84: return 0.17246246337890625;
  t226_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t226_n87;
  t226_n86: return -0.05174802616238594;
  t226_n87: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t226_n89;
  t226_n88: return 0.12429917603731155;
  t226_n89: return 0.11589598655700684;
  t226_n90: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n94;
  t226_n91: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n93;
  t226_n92: return 0.11649461090564728;
  t226_n93: return 0.11884228140115738;
  t226_n94: return -0.12954485416412354;
  t226_n95: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n97;
  t226_n96: return 0.08096186816692352;
  t226_n97: return 0.1446511447429657;
  t226_n98: return 0.007526626344770193;
  t226_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t226_n111;
  t226_n100: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t226_n110;
  t226_n101: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n109;
  t226_n102: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n104;
  t226_n103: return 0.19348646700382233;
  t226_n104: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t226_n106;
  t226_n105: return 0.2574588656425476;
  t226_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n108;
  t226_n107: return 0.13187924027442932;
  t226_n108: return 0.07128043472766876;
  t226_n109: return -0.11533404141664505;
  t226_n110: return -0.1314399540424347;
  t226_n111: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t226_n117;
  t226_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n114;
  t226_n113: return -0.10565377026796341;
  t226_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n116;
  t226_n115: return 0.15660344064235687;
  t226_n116: return -0.0691312626004219;
  t226_n117: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n123;
  t226_n118: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n122;
  t226_n119: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n121;
  t226_n120: return 0.24964866042137146;
  t226_n121: return -0.21387779712677002;
  t226_n122: return 0.14104215800762177;
  t226_n123: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n125;
  t226_n124: return -0.135724738240242;
  t226_n125: return 0.10104583203792572;
  t226_n126: if (E.getNumReferences() >= 3349802816 /*87006.5*/) goto t226_n254;
  t226_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n215;
  t226_n128: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t226_n132;
  t226_n129: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t226_n131;
  t226_n130: return -0.021687597036361694;
  t226_n131: return -0.09556388109922409;
  t226_n132: if (E.getNumReferences() >= 3349481088 /*84493.0*/) goto t226_n204;
  t226_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n141;
  t226_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t226_n136;
  t226_n135: return -0.07286463677883148;
  t226_n136: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t226_n140;
  t226_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t226_n139;
  t226_n138: return -0.2354000210762024;
  t226_n139: return 0.08816909790039062;
  t226_n140: return -0.25773242115974426;
  t226_n141: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t226_n155;
  t226_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t226_n152;
  t226_n143: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t226_n151;
  t226_n144: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n150;
  t226_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n147;
  t226_n146: return 0.03822246566414833;
  t226_n147: if (E.getNumReferences() >= 3346276992 /*62498.5*/) goto t226_n149;
  t226_n148: return 0.11577289551496506;
  t226_n149: return 0.06273055076599121;
  t226_n150: return 0.10734102874994278;
  t226_n151: return -0.01601097360253334;
  t226_n152: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n154;
  t226_n153: return 0.10322726517915726;
  t226_n154: return -0.37292933464050293;
  t226_n155: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t226_n189;
  t226_n156: if (E.getNumReferences() >= 3348338496 /*75566.5*/) goto t226_n186;
  t226_n157: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n167;
  t226_n158: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t226_n160;
  t226_n159: return 0.00546486908569932;
  t226_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t226_n162;
  t226_n161: return -0.5416139364242554;
  t226_n162: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t226_n164;
  t226_n163: return 0.03691907227039337;
  t226_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t226_n166;
  t226_n165: return 0.09695029258728027;
  t226_n166: return 0.126206636428833;
  t226_n167: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t226_n185;
  t226_n168: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t226_n174;
  t226_n169: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t226_n171;
  t226_n170: return -0.02581111341714859;
  t226_n171: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n173;
  t226_n172: return -0.08101769536733627;
  t226_n173: return 0.07461884617805481;
  t226_n174: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n184;
  t226_n175: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t226_n183;
  t226_n176: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n178;
  t226_n177: return 0.021471839398145676;
  t226_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t226_n182;
  t226_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t226_n181;
  t226_n180: return -0.5624719262123108;
  t226_n181: return -0.1072666347026825;
  t226_n182: return 0.00288037839345634;
  t226_n183: return 0.0036030018236488104;
  t226_n184: return -0.026244422420859337;
  t226_n185: return 0.07977208495140076;
  t226_n186: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n188;
  t226_n187: return 0.0744422972202301;
  t226_n188: return 0.0015545382630079985;
  t226_n189: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t226_n199;
  t226_n190: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n198;
  t226_n191: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n193;
  t226_n192: return -0.19075259566307068;
  t226_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t226_n197;
  t226_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t226_n196;
  t226_n195: return 0.03950215503573418;
  t226_n196: return 0.11681276559829712;
  t226_n197: return 0.16383150219917297;
  t226_n198: return 0.08784643560647964;
  t226_n199: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n201;
  t226_n200: return 0.04278680682182312;
  t226_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t226_n203;
  t226_n202: return -1.1174371242523193;
  t226_n203: return -0.017228977754712105;
  t226_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t226_n214;
  t226_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t226_n213;
  t226_n206: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n212;
  t226_n207: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t226_n211;
  t226_n208: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t226_n210;
  t226_n209: return 0.08030099421739578;
  t226_n210: return -0.1909065693616867;
  t226_n211: return 0.1061973050236702;
  t226_n212: return -0.11897441744804382;
  t226_n213: return -0.14962415397167206;
  t226_n214: return -0.012308821082115173;
  t226_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t226_n217;
  t226_n216: return -0.046996843069791794;
  t226_n217: if (E.getNumReferences() >= 3348219712 /*74638.5*/) goto t226_n235;
  t226_n218: if (E.getNumReferences() >= 3345444992 /*59248.5*/) goto t226_n234;
  t226_n219: if (E.getNumReferences() >= 3345041664 /*57673.0*/) goto t226_n229;
  t226_n220: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t226_n228;
  t226_n221: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t226_n227;
  t226_n222: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n226;
  t226_n223: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n225;
  t226_n224: return -0.32709574699401855;
  t226_n225: return 0.10479336977005005;
  t226_n226: return 0.10867258906364441;
  t226_n227: return -0.009298094548285007;
  t226_n228: return -0.12151088565587997;
  t226_n229: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t226_n233;
  t226_n230: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t226_n232;
  t226_n231: return 0.1438698023557663;
  t226_n232: return 0.11511214822530746;
  t226_n233: return 0.16756704449653625;
  t226_n234: return -0.07709601521492004;
  t226_n235: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t226_n237;
  t226_n236: return -0.1924077421426773;
  t226_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t226_n245;
  t226_n238: if (E.getNumReferences() >= 3348571392 /*77386.0*/) goto t226_n240;
  t226_n239: return 0.06713894009590149;
  t226_n240: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n244;
  t226_n241: if (E.getNumReferences() >= 3349106816 /*81569.0*/) goto t226_n243;
  t226_n242: return 0.1149369329214096;
  t226_n243: return -0.13899670541286469;
  t226_n244: return 0.03760049492120743;
  t226_n245: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t226_n247;
  t226_n246: return 0.09792877733707428;
  t226_n247: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t226_n249;
  t226_n248: return -0.1266481876373291;
  t226_n249: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t226_n253;
  t226_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t226_n252;
  t226_n251: return 0.08630716055631638;
  t226_n252: return 0.06802322715520859;
  t226_n253: return -0.08548428863286972;
  t226_n254: return 0.005633901804685593;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree227(const Example& E) {
  t227_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t227_n2;
  t227_n1: return -0.0001784097112249583;
  t227_n2: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t227_n172;
  t227_n3: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t227_n143;
  t227_n4: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t227_n66;
  t227_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t227_n45;
  t227_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other))) goto t227_n8;
  t227_n7: return -0.029774783179163933;
  t227_n8: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t227_n14;
  t227_n9: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t227_n11;
  t227_n10: return -0.015342934057116508;
  t227_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n13;
  t227_n12: return 0.11169496178627014;
  t227_n13: return 0.09434407204389572;
  t227_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t227_n16;
  t227_n15: return -0.11290477961301804;
  t227_n16: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t227_n36;
  t227_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t227_n21;
  t227_n18: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n20;
  t227_n19: return -0.1636817902326584;
  t227_n20: return -0.5483795404434204;
  t227_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n25;
  t227_n22: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t227_n24;
  t227_n23: return -0.0018304219702258706;
  t227_n24: return 0.18900862336158752;
  t227_n25: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t227_n35;
  t227_n26: if (E.getNumReferences() >= 3342302208 /*46972.0*/) goto t227_n32;
  t227_n27: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t227_n29;
  t227_n28: return -0.11489814519882202;
  t227_n29: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n31;
  t227_n30: return 0.15102164447307587;
  t227_n31: return 0.054211776703596115;
  t227_n32: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n34;
  t227_n33: return -0.23720631003379822;
  t227_n34: return 0.07654022425413132;
  t227_n35: return 0.10101586580276489;
  t227_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t227_n38;
  t227_n37: return -0.2061801254749298;
  t227_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n44;
  t227_n39: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t227_n43;
  t227_n40: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t227_n42;
  t227_n41: return 0.2272113412618637;
  t227_n42: return 0.12145405262708664;
  t227_n43: return -0.11287268251180649;
  t227_n44: return 0.013823915272951126;
  t227_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t227_n47;
  t227_n46: return -0.10238359868526459;
  t227_n47: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n49;
  t227_n48: return 0.04485302045941353;
  t227_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t227_n53;
  t227_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n52;
  t227_n51: return 0.06705784797668457;
  t227_n52: return 0.025912538170814514;
  t227_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n59;
  t227_n54: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t227_n56;
  t227_n55: return 0.21769873797893524;
  t227_n56: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t227_n58;
  t227_n57: return 0.11280345171689987;
  t227_n58: return 0.054599594324827194;
  t227_n59: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n61;
  t227_n60: return 0.10874810814857483;
  t227_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t227_n63;
  t227_n62: return -0.028749313205480576;
  t227_n63: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t227_n65;
  t227_n64: return 0.12192407995462418;
  t227_n65: return -0.4735482633113861;
  t227_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t227_n78;
  t227_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t227_n69;
  t227_n68: return -0.11195701360702515;
  t227_n69: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t227_n71;
  t227_n70: return -0.13795490562915802;
  t227_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n75;
  t227_n72: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t227_n74;
  t227_n73: return 0.46745210886001587;
  t227_n74: return 0.1373944729566574;
  t227_n75: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n77;
  t227_n76: return 0.10799949616193771;
  t227_n77: return 0.08593820780515671;
  t227_n78: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t227_n120;
  t227_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n97;
  t227_n80: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t227_n96;
  t227_n81: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t227_n83;
  t227_n82: return 0.10378964245319366;
  t227_n83: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t227_n85;
  t227_n84: return -0.16091430187225342;
  t227_n85: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n89;
  t227_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n88;
  t227_n87: return 0.06278721988201141;
  t227_n88: return 0.00185683136805892;
  t227_n89: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n95;
  t227_n90: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t227_n94;
  t227_n91: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t227_n93;
  t227_n92: return 0.05911604315042496;
  t227_n93: return 0.1847732812166214;
  t227_n94: return 0.04381415247917175;
  t227_n95: return 0.08111384510993958;
  t227_n96: return 0.148252934217453;
  t227_n97: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t227_n119;
  t227_n98: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t227_n112;
  t227_n99: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t227_n111;
  t227_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t227_n102;
  t227_n101: return 0.07166149467229843;
  t227_n102: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n104;
  t227_n103: return 0.15227964520454407;
  t227_n104: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t227_n106;
  t227_n105: return -0.04703279957175255;
  t227_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t227_n110;
  t227_n107: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t227_n109;
  t227_n108: return 0.09330936521291733;
  t227_n109: return 0.15537357330322266;
  t227_n110: return 0.10828143358230591;
  t227_n111: return 0.07008079439401627;
  t227_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n118;
  t227_n113: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t227_n115;
  t227_n114: return 0.09506946057081223;
  t227_n115: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t227_n117;
  t227_n116: return 0.11674322187900543;
  t227_n117: return 0.11245232820510864;
  t227_n118: return 0.024940049275755882;
  t227_n119: return 0.0989314392209053;
  t227_n120: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t227_n132;
  t227_n121: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n125;
  t227_n122: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t227_n124;
  t227_n123: return 0.07233064621686935;
  t227_n124: return 1.9874733686447144;
  t227_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t227_n127;
  t227_n126: return 0.10433872044086456;
  t227_n127: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n131;
  t227_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n130;
  t227_n129: return 0.10722541064023972;
  t227_n130: return 0.10660528391599655;
  t227_n131: return 0.1402774304151535;
  t227_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n134;
  t227_n133: return -0.002822215436026454;
  t227_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n136;
  t227_n135: return -0.17707262933254242;
  t227_n136: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n142;
  t227_n137: if (E.getNumReferences() >= 3343393536 /*51235.0*/) goto t227_n139;
  t227_n138: return -0.1288444548845291;
  t227_n139: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t227_n141;
  t227_n140: return 0.14037805795669556;
  t227_n141: return 0.07649464160203934;
  t227_n142: return -0.2525664269924164;
  t227_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t227_n153;
  t227_n144: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t227_n152;
  t227_n145: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t227_n151;
  t227_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n148;
  t227_n147: return 0.14960524439811707;
  t227_n148: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t227_n150;
  t227_n149: return 0.10312923789024353;
  t227_n150: return 0.15892864763736725;
  t227_n151: return -0.11157489567995071;
  t227_n152: return -0.12919940054416656;
  t227_n153: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t227_n159;
  t227_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n156;
  t227_n155: return -0.10491697490215302;
  t227_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t227_n158;
  t227_n157: return 0.15015733242034912;
  t227_n158: return -0.06328748166561127;
  t227_n159: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n167;
  t227_n160: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t227_n166;
  t227_n161: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t227_n165;
  t227_n162: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t227_n164;
  t227_n163: return 4.051187515258789;
  t227_n164: return 0.3740459382534027;
  t227_n165: return 0.14990685880184174;
  t227_n166: return 0.05147432163357735;
  t227_n167: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t227_n169;
  t227_n168: return 0.0979628637433052;
  t227_n169: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n171;
  t227_n170: return 0.129465714097023;
  t227_n171: return 0.07955066859722137;
  t227_n172: if (E.getNumReferences() >= 3344974336 /*57410.0*/) goto t227_n174;
  t227_n173: return -0.05105435475707054;
  t227_n174: if (E.getNumReferences() >= 3345974912 /*61318.5*/) goto t227_n236;
  t227_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t227_n225;
  t227_n176: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t227_n184;
  t227_n177: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t227_n181;
  t227_n178: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t227_n180;
  t227_n179: return -0.020680787041783333;
  t227_n180: return 0.13546112179756165;
  t227_n181: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t227_n183;
  t227_n182: return 0.03925266116857529;
  t227_n183: return 0.11682417243719101;
  t227_n184: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t227_n208;
  t227_n185: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t227_n197;
  t227_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n190;
  t227_n187: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n189;
  t227_n188: return 0.07963547855615616;
  t227_n189: return -0.7520674467086792;
  t227_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t227_n196;
  t227_n191: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t227_n195;
  t227_n192: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t227_n194;
  t227_n193: return 0.09329473227262497;
  t227_n194: return 0.10875410586595535;
  t227_n195: return -0.01898382045328617;
  t227_n196: return 0.0868106260895729;
  t227_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t227_n199;
  t227_n198: return -0.19386409223079681;
  t227_n199: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n207;
  t227_n200: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t227_n202;
  t227_n201: return -0.10748142749071121;
  t227_n202: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t227_n206;
  t227_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t227_n205;
  t227_n204: return 0.13354001939296722;
  t227_n205: return -0.100342757999897;
  t227_n206: return 0.12761887907981873;
  t227_n207: return 0.039038367569446564;
  t227_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t227_n224;
  t227_n209: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t227_n223;
  t227_n210: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t227_n214;
  t227_n211: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t227_n213;
  t227_n212: return 0.0568409338593483;
  t227_n213: return -6.986021995544434;
  t227_n214: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t227_n218;
  t227_n215: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t227_n217;
  t227_n216: return 0.07182060927152634;
  t227_n217: return -0.7764049768447876;
  t227_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t227_n220;
  t227_n219: return 0.0847851112484932;
  t227_n220: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n222;
  t227_n221: return 0.12761607766151428;
  t227_n222: return 0.08718075603246689;
  t227_n223: return -0.008372673764824867;
  t227_n224: return 0.11229343712329865;
  t227_n225: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t227_n229;
  t227_n226: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t227_n228;
  t227_n227: return 0.020786816254258156;
  t227_n228: return -1.5353137254714966;
  t227_n229: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t227_n231;
  t227_n230: return 0.14593325555324554;
  t227_n231: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t227_n233;
  t227_n232: return 0.12205076217651367;
  t227_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n235;
  t227_n234: return 0.10971347242593765;
  t227_n235: return 0.11538337916135788;
  t227_n236: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t227_n254;
  t227_n237: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t227_n245;
  t227_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n240;
  t227_n239: return -0.03432999923825264;
  t227_n240: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t227_n242;
  t227_n241: return -0.032425541430711746;
  t227_n242: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t227_n244;
  t227_n243: return 0.06431389600038528;
  t227_n244: return 0.08524066209793091;
  t227_n245: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t227_n247;
  t227_n246: return -0.1388789713382721;
  t227_n247: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t227_n249;
  t227_n248: return -0.10999248176813126;
  t227_n249: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t227_n251;
  t227_n250: return 0.08361630141735077;
  t227_n251: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t227_n253;
  t227_n252: return 0.11745379865169525;
  t227_n253: return 0.08703722059726715;
  t227_n254: return 0.004652010276913643;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree228(const Example& E) {
  t228_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t228_n130;
  t228_n1: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t228_n3;
  t228_n2: return -0.0020938694942742586;
  t228_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t228_n5;
  t228_n4: return -0.0007171322358772159;
  t228_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t228_n119;
  t228_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t228_n32;
  t228_n7: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t228_n31;
  t228_n8: if (E.getNumReferences() >= 3264217088 /*72.0*/) goto t228_n10;
  t228_n9: return -0.053366903215646744;
  t228_n10: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t228_n20;
  t228_n11: if (E.getNumReferences() >= 3306246144 /*2325.0*/) goto t228_n19;
  t228_n12: if (E.getNumReferences() >= 3284074496 /*382.0*/) goto t228_n18;
  t228_n13: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t228_n17;
  t228_n14: if (E.getNumReferences() >= 3273097216 /*151.5*/) goto t228_n16;
  t228_n15: return 0.0661940947175026;
  t228_n16: return -0.31901994347572327;
  t228_n17: return 0.10841409116983414;
  t228_n18: return 0.0960458517074585;
  t228_n19: return -0.0951065719127655;
  t228_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n22;
  t228_n21: return -0.8604269623756409;
  t228_n22: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n26;
  t228_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n25;
  t228_n24: return -0.10725698620080948;
  t228_n25: return 0.03476792946457863;
  t228_n26: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t228_n28;
  t228_n27: return -0.003748284885659814;
  t228_n28: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t228_n30;
  t228_n29: return 0.10614235699176788;
  t228_n30: return 0.06699591130018234;
  t228_n31: return 0.11399231851100922;
  t228_n32: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t228_n82;
  t228_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n61;
  t228_n34: if (E.getNumReferences() >= 3276636160 /*205.5*/) goto t228_n48;
  t228_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n41;
  t228_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t228_n38;
  t228_n37: return -0.021366465836763382;
  t228_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n40;
  t228_n39: return -0.10288263112306595;
  t228_n40: return -0.035160914063453674;
  t228_n41: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t228_n47;
  t228_n42: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t228_n46;
  t228_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t228_n45;
  t228_n44: return 0.06899964809417725;
  t228_n45: return 0.12699712812900543;
  t228_n46: return -0.005988071672618389;
  t228_n47: return -0.025860577821731567;
  t228_n48: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t228_n50;
  t228_n49: return -0.038596611469984055;
  t228_n50: if (E.getNumReferences() >= 3285532672 /*426.5*/) goto t228_n60;
  t228_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t228_n55;
  t228_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n54;
  t228_n53: return -0.4010354280471802;
  t228_n54: return 0.0786970779299736;
  t228_n55: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n59;
  t228_n56: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t228_n58;
  t228_n57: return 0.10312933474779129;
  t228_n58: return -0.079692043364048;
  t228_n59: return 0.07326837629079819;
  t228_n60: return 0.024279223755002022;
  t228_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t228_n63;
  t228_n62: return -0.019442081451416016;
  t228_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n65;
  t228_n64: return 0.02636006474494934;
  t228_n65: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t228_n67;
  t228_n66: return -0.01274182554334402;
  t228_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n69;
  t228_n68: return 0.020495561882853508;
  t228_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n71;
  t228_n70: return 0.0656266063451767;
  t228_n71: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t228_n75;
  t228_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t228_n74;
  t228_n73: return -0.10931634902954102;
  t228_n74: return -0.0007593804621137679;
  t228_n75: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t228_n77;
  t228_n76: return 0.024430034682154655;
  t228_n77: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t228_n79;
  t228_n78: return 0.13949540257453918;
  t228_n79: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t228_n81;
  t228_n80: return 0.025244319811463356;
  t228_n81: return 0.11736910045146942;
  t228_n82: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t228_n118;
  t228_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n105;
  t228_n84: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t228_n94;
  t228_n85: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t228_n87;
  t228_n86: return -0.051212914288043976;
  t228_n87: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t228_n89;
  t228_n88: return 0.10188090056180954;
  t228_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n93;
  t228_n90: if (E.getNumReferences() >= 3308521472 /*2880.5*/) goto t228_n92;
  t228_n91: return 0.08346503227949142;
  t228_n92: return -0.042001236230134964;
  t228_n93: return 0.011603347025811672;
  t228_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t228_n98;
  t228_n95: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n97;
  t228_n96: return -0.0711580440402031;
  t228_n97: return 0.14415332674980164;
  t228_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n104;
  t228_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n101;
  t228_n100: return -0.10337429493665695;
  t228_n101: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n103;
  t228_n102: return 0.09964624047279358;
  t228_n103: return 0.0034490376710891724;
  t228_n104: return -0.21291767060756683;
  t228_n105: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t228_n115;
  t228_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n114;
  t228_n107: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t228_n109;
  t228_n108: return -0.0037963639479130507;
  t228_n109: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t228_n111;
  t228_n110: return 0.04983769357204437;
  t228_n111: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t228_n113;
  t228_n112: return -0.1556587517261505;
  t228_n113: return 0.14768265187740326;
  t228_n114: return 0.038851380348205566;
  t228_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t228_n117;
  t228_n116: return 0.128191739320755;
  t228_n117: return 0.1114841029047966;
  t228_n118: return 0.004106199834495783;
  t228_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t228_n121;
  t228_n120: return 0.0078915199264884;
  t228_n121: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t228_n129;
  t228_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n128;
  t228_n123: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t228_n127;
  t228_n124: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t228_n126;
  t228_n125: return 0.08508305996656418;
  t228_n126: return 0.062032002955675125;
  t228_n127: return 0.08882758021354675;
  t228_n128: return 0.05806632712483406;
  t228_n129: return -0.03390425816178322;
  t228_n130: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t228_n254;
  t228_n131: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t228_n227;
  t228_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n176;
  t228_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor))) goto t228_n171;
  t228_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t228_n136;
  t228_n135: return -0.025350017473101616;
  t228_n136: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t228_n138;
  t228_n137: return -0.10232371091842651;
  t228_n138: if (E.getNumReferences() >= 3342077440 /*46094.0*/) goto t228_n150;
  t228_n139: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t228_n147;
  t228_n140: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n142;
  t228_n141: return -0.20336401462554932;
  t228_n142: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t228_n144;
  t228_n143: return -0.04223497584462166;
  t228_n144: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t228_n146;
  t228_n145: return 0.0901193767786026;
  t228_n146: return 0.07141455262899399;
  t228_n147: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n149;
  t228_n148: return 0.1084149181842804;
  t228_n149: return 0.0926065444946289;
  t228_n150: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t228_n164;
  t228_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t228_n153;
  t228_n152: return -0.1913919299840927;
  t228_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n155;
  t228_n154: return 0.035481639206409454;
  t228_n155: if (E.getNumReferences() >= 3343039104 /*49850.5*/) goto t228_n163;
  t228_n156: if (E.getNumReferences() >= 3342302208 /*46972.0*/) goto t228_n162;
  t228_n157: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t228_n159;
  t228_n158: return -0.10423970222473145;
  t228_n159: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n161;
  t228_n160: return 0.13150231540203094;
  t228_n161: return 0.050808098167181015;
  t228_n162: return -0.03774164989590645;
  t228_n163: return 0.0987117812037468;
  t228_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t228_n166;
  t228_n165: return -0.19768323004245758;
  t228_n166: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n170;
  t228_n167: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t228_n169;
  t228_n168: return 0.11745845526456833;
  t228_n169: return -0.11156768351793289;
  t228_n170: return 0.01861785352230072;
  t228_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t228_n173;
  t228_n172: return -0.09923283755779266;
  t228_n173: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n175;
  t228_n174: return 0.040841713547706604;
  t228_n175: return 0.08992621302604675;
  t228_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t228_n188;
  t228_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t228_n179;
  t228_n178: return -0.10467901080846786;
  t228_n179: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t228_n181;
  t228_n180: return -0.13102716207504272;
  t228_n181: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t228_n185;
  t228_n182: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t228_n184;
  t228_n183: return 0.3700982928276062;
  t228_n184: return 0.13577619194984436;
  t228_n185: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n187;
  t228_n186: return 0.10788735747337341;
  t228_n187: return 0.08367250114679337;
  t228_n188: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t228_n206;
  t228_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n203;
  t228_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t228_n192;
  t228_n191: return 0.1190202385187149;
  t228_n192: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t228_n194;
  t228_n193: return 0.10676082968711853;
  t228_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n198;
  t228_n195: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n197;
  t228_n196: return 0.06294160336256027;
  t228_n197: return 0.0016451382543891668;
  t228_n198: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t228_n202;
  t228_n199: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t228_n201;
  t228_n200: return 0.06399407237768173;
  t228_n201: return 0.035152729600667953;
  t228_n202: return 0.07118792086839676;
  t228_n203: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t228_n205;
  t228_n204: return -0.23192457854747772;
  t228_n205: return 0.10371602326631546;
  t228_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t228_n218;
  t228_n207: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t228_n217;
  t228_n208: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n212;
  t228_n209: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t228_n211;
  t228_n210: return 0.062303245067596436;
  t228_n211: return 0.32017946243286133;
  t228_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t228_n214;
  t228_n213: return 0.10394002497196198;
  t228_n214: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n216;
  t228_n215: return 0.1046372577548027;
  t228_n216: return 0.13882383704185486;
  t228_n217: return -0.0045111277140676975;
  t228_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t228_n220;
  t228_n219: return -0.174350768327713;
  t228_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n226;
  t228_n221: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t228_n223;
  t228_n222: return -0.1012093722820282;
  t228_n223: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t228_n225;
  t228_n224: return 0.11997708678245544;
  t228_n225: return 0.07229796051979065;
  t228_n226: return -0.2868068218231201;
  t228_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t228_n237;
  t228_n228: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t228_n236;
  t228_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t228_n235;
  t228_n230: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n232;
  t228_n231: return 0.10028702765703201;
  t228_n232: if (E.getFileProximityDistance() >= 3248488448 /*20.0*/) goto t228_n234;
  t228_n233: return 0.09360408782958984;
  t228_n234: return 0.1505088210105896;
  t228_n235: return -0.1109347864985466;
  t228_n236: return -0.12931962311267853;
  t228_n237: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t228_n247;
  t228_n238: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t228_n240;
  t228_n239: return -0.10461778193712234;
  t228_n240: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t228_n246;
  t228_n241: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t228_n243;
  t228_n242: return 0.0755339190363884;
  t228_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t228_n245;
  t228_n244: return 0.28811630606651306;
  t228_n245: return 0.14119671285152435;
  t228_n246: return 0.04623691737651825;
  t228_n247: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t228_n249;
  t228_n248: return 0.11300083994865417;
  t228_n249: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t228_n251;
  t228_n250: return 0.08564302325248718;
  t228_n251: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t228_n253;
  t228_n252: return 0.1237017810344696;
  t228_n253: return 0.07707984745502472;
  t228_n254: return 0.0025088773109018803;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree229(const Example& E) {
  t229_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t229_n106;
  t229_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t229_n105;
  t229_n2: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t229_n102;
  t229_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n101;
  t229_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t229_n84;
  t229_n5: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t229_n7;
  t229_n6: return -0.008827724494040012;
  t229_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t229_n9;
  t229_n8: return -0.08257732540369034;
  t229_n9: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t229_n67;
  t229_n10: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t229_n62;
  t229_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n41;
  t229_n12: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n16;
  t229_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n15;
  t229_n14: return -0.2549056112766266;
  t229_n15: return -0.013391693122684956;
  t229_n16: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t229_n34;
  t229_n17: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t229_n19;
  t229_n18: return 0.008759884163737297;
  t229_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t229_n31;
  t229_n20: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t229_n28;
  t229_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n25;
  t229_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n24;
  t229_n23: return -0.009353257715702057;
  t229_n24: return -0.13552676141262054;
  t229_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t229_n27;
  t229_n26: return -0.04347705841064453;
  t229_n27: return 0.07215309143066406;
  t229_n28: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t229_n30;
  t229_n29: return -0.01510439533740282;
  t229_n30: return 0.04290100932121277;
  t229_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n33;
  t229_n32: return -0.014916523359715939;
  t229_n33: return -0.11166251450777054;
  t229_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t229_n36;
  t229_n35: return 0.016338763758540154;
  t229_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t229_n38;
  t229_n37: return 0.05040108785033226;
  t229_n38: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t229_n40;
  t229_n39: return 0.10452084988355637;
  t229_n40: return 0.07791754603385925;
  t229_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n43;
  t229_n42: return -0.059991154819726944;
  t229_n43: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t229_n53;
  t229_n44: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t229_n52;
  t229_n45: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t229_n51;
  t229_n46: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t229_n48;
  t229_n47: return -0.2989765405654907;
  t229_n48: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t229_n50;
  t229_n49: return 0.10537619888782501;
  t229_n50: return 0.03177500516176224;
  t229_n51: return 0.10094273835420609;
  t229_n52: return 0.09336747974157333;
  t229_n53: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t229_n59;
  t229_n54: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t229_n56;
  t229_n55: return -0.2969943881034851;
  t229_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t229_n58;
  t229_n57: return 0.04137731343507767;
  t229_n58: return 0.10170945525169373;
  t229_n59: if (E.getNumReferences() >= 3221225472 /*2.0*/) goto t229_n61;
  t229_n60: return 0.0730644017457962;
  t229_n61: return -0.21666662395000458;
  t229_n62: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n66;
  t229_n63: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t229_n65;
  t229_n64: return 0.07628054916858673;
  t229_n65: return 0.10125155001878738;
  t229_n66: return -0.0033702098298817873;
  t229_n67: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t229_n77;
  t229_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n72;
  t229_n69: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n71;
  t229_n70: return 0.10771392285823822;
  t229_n71: return 0.054296303540468216;
  t229_n72: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t229_n74;
  t229_n73: return -0.07144612818956375;
  t229_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t229_n76;
  t229_n75: return 0.015265372581779957;
  t229_n76: return 0.099054254591465;
  t229_n77: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t229_n81;
  t229_n78: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n80;
  t229_n79: return -0.1963401734828949;
  t229_n80: return 0.05990159884095192;
  t229_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n83;
  t229_n82: return -0.8378230929374695;
  t229_n83: return 0.01191626861691475;
  t229_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n86;
  t229_n85: return -0.025161609053611755;
  t229_n86: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t229_n100;
  t229_n87: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n99;
  t229_n88: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t229_n98;
  t229_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t229_n97;
  t229_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n96;
  t229_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t229_n95;
  t229_n92: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t229_n94;
  t229_n93: return 0.11072346568107605;
  t229_n94: return 0.05482763424515724;
  t229_n95: return 0.05376245453953743;
  t229_n96: return 0.05075547844171524;
  t229_n97: return 0.06831411272287369;
  t229_n98: return 0.04491439834237099;
  t229_n99: return 0.03189212828874588;
  t229_n100: return 0.026526866480708122;
  t229_n101: return 0.002963850973173976;
  t229_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t229_n104;
  t229_n103: return 0.00531742861494422;
  t229_n104: return 0.018470117822289467;
  t229_n105: return -0.0009065884514711797;
  t229_n106: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t229_n254;
  t229_n107: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t229_n221;
  t229_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t229_n130;
  t229_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t229_n111;
  t229_n110: return -0.06392844021320343;
  t229_n111: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n113;
  t229_n112: return -0.0039760032668709755;
  t229_n113: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t229_n125;
  t229_n114: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t229_n120;
  t229_n115: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n117;
  t229_n116: return 0.11529373377561569;
  t229_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n119;
  t229_n118: return 0.10106601566076279;
  t229_n119: return 0.05986829102039337;
  t229_n120: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n124;
  t229_n121: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n123;
  t229_n122: return -0.21535570919513702;
  t229_n123: return 0.09318668395280838;
  t229_n124: return 0.13839493691921234;
  t229_n125: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t229_n129;
  t229_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t229_n128;
  t229_n127: return -0.1355830878019333;
  t229_n128: return 0.08163640648126602;
  t229_n129: return -0.14924325048923492;
  t229_n130: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t229_n220;
  t229_n131: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t229_n197;
  t229_n132: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t229_n196;
  t229_n133: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n183;
  t229_n134: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t229_n142;
  t229_n135: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n137;
  t229_n136: return 0.01572791486978531;
  t229_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n139;
  t229_n138: return -0.21939319372177124;
  t229_n139: if (E.getNumReferences() >= 3341955584 /*45618.0*/) goto t229_n141;
  t229_n140: return 0.06294083595275879;
  t229_n141: return -0.28125059604644775;
  t229_n142: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t229_n152;
  t229_n143: if (E.getNumReferences() >= 3342524672 /*47841.0*/) goto t229_n145;
  t229_n144: return -0.028411677107214928;
  t229_n145: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t229_n147;
  t229_n146: return 0.015040401369333267;
  t229_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n151;
  t229_n148: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t229_n150;
  t229_n149: return 0.09776361286640167;
  t229_n150: return -0.11542519927024841;
  t229_n151: return 0.029418662190437317;
  t229_n152: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t229_n164;
  t229_n153: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t229_n157;
  t229_n154: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n156;
  t229_n155: return 0.10221483558416367;
  t229_n156: return 0.0931411013007164;
  t229_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n159;
  t229_n158: return -0.059975601732730865;
  t229_n159: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t229_n161;
  t229_n160: return -0.022603441029787064;
  t229_n161: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n163;
  t229_n162: return 0.07658649235963821;
  t229_n163: return -0.10148660838603973;
  t229_n164: if (E.getNumReferences() >= 3342302208 /*46972.0*/) goto t229_n182;
  t229_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n167;
  t229_n166: return -0.17286764085292816;
  t229_n167: if (E.getNumReferences() >= 3341955328 /*45617.0*/) goto t229_n173;
  t229_n168: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n170;
  t229_n169: return -0.15896688401699066;
  t229_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n172;
  t229_n171: return 0.08780355006456375;
  t229_n172: return 0.0678257867693901;
  t229_n173: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t229_n179;
  t229_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n176;
  t229_n175: return 0.1121138408780098;
  t229_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n178;
  t229_n177: return -0.022557176649570465;
  t229_n178: return 0.3873385190963745;
  t229_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n181;
  t229_n180: return -0.2629566788673401;
  t229_n181: return 0.09830786287784576;
  t229_n182: return -0.2388119399547577;
  t229_n183: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t229_n185;
  t229_n184: return 0.02421341836452484;
  t229_n185: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t229_n195;
  t229_n186: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t229_n194;
  t229_n187: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t229_n193;
  t229_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n190;
  t229_n189: return -0.10094743967056274;
  t229_n190: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t229_n192;
  t229_n191: return 0.06547456234693527;
  t229_n192: return 0.05186571180820465;
  t229_n193: return 0.03313888609409332;
  t229_n194: return -0.011272563599050045;
  t229_n195: return 0.1049414649605751;
  t229_n196: return -0.031858544796705246;
  t229_n197: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t229_n217;
  t229_n198: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t229_n202;
  t229_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t229_n201;
  t229_n200: return -0.11555061489343643;
  t229_n201: return 0.09685681015253067;
  t229_n202: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n210;
  t229_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n209;
  t229_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t229_n208;
  t229_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t229_n207;
  t229_n206: return -0.11820590496063232;
  t229_n207: return 0.1142498180270195;
  t229_n208: return -0.11047748476266861;
  t229_n209: return 0.004301621578633785;
  t229_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n214;
  t229_n211: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t229_n213;
  t229_n212: return 0.2612631618976593;
  t229_n213: return 0.13209940493106842;
  t229_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t229_n216;
  t229_n215: return 0.1096639558672905;
  t229_n216: return 0.08151865005493164;
  t229_n217: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t229_n219;
  t229_n218: return 0.14829295873641968;
  t229_n219: return 0.10006517171859741;
  t229_n220: return -0.11246698349714279;
  t229_n221: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t229_n227;
  t229_n222: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t229_n224;
  t229_n223: return 0.04845018312335014;
  t229_n224: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t229_n226;
  t229_n225: return -0.2684631943702698;
  t229_n226: return 0.10913858562707901;
  t229_n227: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t229_n237;
  t229_n228: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n236;
  t229_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t229_n231;
  t229_n230: return -0.10174600780010223;
  t229_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t229_n233;
  t229_n232: return 0.09252933412790298;
  t229_n233: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t229_n235;
  t229_n234: return 0.11351688951253891;
  t229_n235: return 0.10893280804157257;
  t229_n236: return -0.031243404373526573;
  t229_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t229_n243;
  t229_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t229_n240;
  t229_n239: return -0.12071814388036728;
  t229_n240: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t229_n242;
  t229_n241: return 0.06616829335689545;
  t229_n242: return 0.0844583660364151;
  t229_n243: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t229_n247;
  t229_n244: if (E.getNumReferences() >= 3344048512 /*53793.5*/) goto t229_n246;
  t229_n245: return 0.08607526868581772;
  t229_n246: return -0.23334987461566925;
  t229_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t229_n253;
  t229_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t229_n252;
  t229_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t229_n251;
  t229_n250: return 0.1165936216711998;
  t229_n251: return 0.15906639397144318;
  t229_n252: return 0.11228322237730026;
  t229_n253: return 0.04937702789902687;
  t229_n254: return 0.0024762488901615143;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree230(const Example& E) {
  t230_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t230_n176;
  t230_n1: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t230_n3;
  t230_n2: return -0.002080228878185153;
  t230_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t230_n5;
  t230_n4: return -0.0006614733138121665;
  t230_n5: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t230_n119;
  t230_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t230_n8;
  t230_n7: return -0.02552991919219494;
  t230_n8: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t230_n10;
  t230_n9: return 0.003411918645724654;
  t230_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n38;
  t230_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n29;
  t230_n12: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t230_n28;
  t230_n13: if (E.getNumReferences() >= 3280109568 /*261.0*/) goto t230_n25;
  t230_n14: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t230_n24;
  t230_n15: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t230_n21;
  t230_n16: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t230_n18;
  t230_n17: return 0.06678686290979385;
  t230_n18: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t230_n20;
  t230_n19: return 0.09529092162847519;
  t230_n20: return -0.11169867217540741;
  t230_n21: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t230_n23;
  t230_n22: return 0.10431835800409317;
  t230_n23: return -0.04054215922951698;
  t230_n24: return -0.2909981608390808;
  t230_n25: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t230_n27;
  t230_n26: return 0.1093577966094017;
  t230_n27: return 0.050016868859529495;
  t230_n28: return 0.002829896751791239;
  t230_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t230_n31;
  t230_n30: return -0.020748674869537354;
  t230_n31: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t230_n33;
  t230_n32: return -0.019679885357618332;
  t230_n33: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t230_n37;
  t230_n34: if (E.getNumReferences() >= 3285794816 /*434.5*/) goto t230_n36;
  t230_n35: return 0.1067177951335907;
  t230_n36: return 0.061771273612976074;
  t230_n37: return 0.048770472407341;
  t230_n38: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t230_n96;
  t230_n39: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t230_n51;
  t230_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t230_n42;
  t230_n41: return -0.01506817527115345;
  t230_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t230_n48;
  t230_n43: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t230_n45;
  t230_n44: return 0.13086001574993134;
  t230_n45: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n47;
  t230_n46: return 0.04110679030418396;
  t230_n47: return 0.10198889672756195;
  t230_n48: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t230_n50;
  t230_n49: return -0.0007285083411261439;
  t230_n50: return 0.12179415673017502;
  t230_n51: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t230_n91;
  t230_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t230_n82;
  t230_n53: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t230_n81;
  t230_n54: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t230_n60;
  t230_n55: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n59;
  t230_n56: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t230_n58;
  t230_n57: return 0.12562507390975952;
  t230_n58: return -0.11342611908912659;
  t230_n59: return 0.051991090178489685;
  t230_n60: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t230_n62;
  t230_n61: return -0.006567520089447498;
  t230_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t230_n74;
  t230_n63: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t230_n73;
  t230_n64: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t230_n66;
  t230_n65: return 0.042430102825164795;
  t230_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t230_n68;
  t230_n67: return 0.042333655059337616;
  t230_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n72;
  t230_n69: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t230_n71;
  t230_n70: return 0.10877928137779236;
  t230_n71: return 0.11058933287858963;
  t230_n72: return -0.11308007687330246;
  t230_n73: return 0.03411908447742462;
  t230_n74: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t230_n78;
  t230_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n77;
  t230_n76: return -0.07554042339324951;
  t230_n77: return 0.11842668801546097;
  t230_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t230_n80;
  t230_n79: return 0.028000421822071075;
  t230_n80: return 0.11909658461809158;
  t230_n81: return -0.09875456988811493;
  t230_n82: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t230_n84;
  t230_n83: return 0.01458948478102684;
  t230_n84: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t230_n86;
  t230_n85: return 0.02567414380609989;
  t230_n86: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n88;
  t230_n87: return 0.029060887172818184;
  t230_n88: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t230_n90;
  t230_n89: return 0.11559586971998215;
  t230_n90: return 0.1029600277543068;
  t230_n91: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t230_n95;
  t230_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n94;
  t230_n93: return 0.1015944555401802;
  t230_n94: return -0.01633737049996853;
  t230_n95: return -0.015297935344278812;
  t230_n96: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t230_n118;
  t230_n97: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t230_n111;
  t230_n98: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t230_n104;
  t230_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t230_n101;
  t230_n100: return 0.06420346349477768;
  t230_n101: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t230_n103;
  t230_n102: return -0.336605966091156;
  t230_n103: return 0.11886945366859436;
  t230_n104: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n110;
  t230_n105: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n109;
  t230_n106: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t230_n108;
  t230_n107: return 0.09681470692157745;
  t230_n108: return -0.12330363690853119;
  t230_n109: return -0.1304665356874466;
  t230_n110: return -0.0027551574166864157;
  t230_n111: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t230_n117;
  t230_n112: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t230_n114;
  t230_n113: return -0.024479741230607033;
  t230_n114: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t230_n116;
  t230_n115: return 0.15297438204288483;
  t230_n116: return 0.03553083911538124;
  t230_n117: return -0.21458065509796143;
  t230_n118: return 0.018479792401194572;
  t230_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t230_n169;
  t230_n120: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t230_n154;
  t230_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t230_n153;
  t230_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n130;
  t230_n123: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t230_n125;
  t230_n124: return -0.013301610015332699;
  t230_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n127;
  t230_n126: return -0.06416908651590347;
  t230_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n129;
  t230_n128: return 0.014945494942367077;
  t230_n129: return 0.08946972340345383;
  t230_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t230_n140;
  t230_n131: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n135;
  t230_n132: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n134;
  t230_n133: return -0.4405210614204407;
  t230_n134: return -0.02707890421152115;
  t230_n135: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t230_n137;
  t230_n136: return 0.006203519646078348;
  t230_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t230_n139;
  t230_n138: return 0.08000630140304565;
  t230_n139: return -0.10836916416883469;
  t230_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n152;
  t230_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n147;
  t230_n142: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t230_n146;
  t230_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t230_n145;
  t230_n144: return -0.03425687551498413;
  t230_n145: return 0.040111470967531204;
  t230_n146: return 0.016644541174173355;
  t230_n147: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n151;
  t230_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t230_n150;
  t230_n149: return 0.04714867100119591;
  t230_n150: return 0.07195115834474564;
  t230_n151: return -0.010537962429225445;
  t230_n152: return 0.020172150805592537;
  t230_n153: return 0.019728554412722588;
  t230_n154: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t230_n162;
  t230_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n161;
  t230_n156: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n158;
  t230_n157: return 0.0024275665637105703;
  t230_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t230_n160;
  t230_n159: return -0.15115578472614288;
  t230_n160: return 0.11574782431125641;
  t230_n161: return 0.05199561268091202;
  t230_n162: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n168;
  t230_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n165;
  t230_n164: return -0.015063953585922718;
  t230_n165: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t230_n167;
  t230_n166: return -0.016451891511678696;
  t230_n167: return -0.08468936383724213;
  t230_n168: return 0.01888909935951233;
  t230_n169: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t230_n175;
  t230_n170: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t230_n174;
  t230_n171: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t230_n173;
  t230_n172: return 0.0785905197262764;
  t230_n173: return 0.05003878474235535;
  t230_n174: return 0.05226927250623703;
  t230_n175: return -0.030620109289884567;
  t230_n176: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t230_n254;
  t230_n177: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t230_n225;
  t230_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n196;
  t230_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t230_n181;
  t230_n180: return -0.0560782290995121;
  t230_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n183;
  t230_n182: return -0.003234793432056904;
  t230_n183: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t230_n191;
  t230_n184: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t230_n190;
  t230_n185: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n187;
  t230_n186: return 0.11469823867082596;
  t230_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n189;
  t230_n188: return 0.09894530475139618;
  t230_n189: return 0.053832877427339554;
  t230_n190: return 0.09909836947917938;
  t230_n191: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t230_n195;
  t230_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t230_n194;
  t230_n193: return -0.12911589443683624;
  t230_n194: return 0.0757497251033783;
  t230_n195: return -0.13953116536140442;
  t230_n196: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t230_n224;
  t230_n197: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t230_n201;
  t230_n198: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t230_n200;
  t230_n199: return 0.031612787395715714;
  t230_n200: return -0.02796274796128273;
  t230_n201: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t230_n221;
  t230_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t230_n212;
  t230_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t230_n207;
  t230_n204: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t230_n206;
  t230_n205: return -0.10218559950590134;
  t230_n206: return 0.09472520649433136;
  t230_n207: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n211;
  t230_n208: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t230_n210;
  t230_n209: return 0.11006833612918854;
  t230_n210: return -0.10933378338813782;
  t230_n211: return 0.017741011455655098;
  t230_n212: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n214;
  t230_n213: return -0.26286348700523376;
  t230_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n218;
  t230_n215: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t230_n217;
  t230_n216: return 0.12425052374601364;
  t230_n217: return 0.1295604705810547;
  t230_n218: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t230_n220;
  t230_n219: return 0.1098533496260643;
  t230_n220: return 0.07893981039524078;
  t230_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t230_n223;
  t230_n222: return 0.14473600685596466;
  t230_n223: return 0.1000591292977333;
  t230_n224: return -0.11130452156066895;
  t230_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t230_n231;
  t230_n226: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t230_n228;
  t230_n227: return 0.050039779394865036;
  t230_n228: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t230_n230;
  t230_n229: return -0.22446170449256897;
  t230_n230: return 0.10837358981370926;
  t230_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t230_n245;
  t230_n232: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t230_n242;
  t230_n233: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n241;
  t230_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t230_n236;
  t230_n235: return -0.10133535414934158;
  t230_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t230_n238;
  t230_n237: return 0.0909932404756546;
  t230_n238: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t230_n240;
  t230_n239: return 0.11197250336408615;
  t230_n240: return 0.1070016399025917;
  t230_n241: return -0.02104800008237362;
  t230_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t230_n244;
  t230_n243: return -0.09993122518062592;
  t230_n244: return 0.0606209971010685;
  t230_n245: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t230_n247;
  t230_n246: return -0.051896460354328156;
  t230_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t230_n253;
  t230_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t230_n252;
  t230_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t230_n251;
  t230_n250: return 0.1129627525806427;
  t230_n251: return 0.1253780871629715;
  t230_n252: return 0.10646212100982666;
  t230_n253: return 0.04699995741248131;
  t230_n254: return 0.0021298343781381845;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree231(const Example& E) {
  t231_n0: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t231_n130;
  t231_n1: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t231_n77;
  t231_n2: if (E.getNumReferences() >= 3338822784 /*33380.5*/) goto t231_n30;
  t231_n3: if (E.getNumReferences() >= 3338797696 /*33282.5*/) goto t231_n29;
  t231_n4: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n28;
  t231_n5: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t231_n7;
  t231_n6: return 0.0009012313676066697;
  t231_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t231_n9;
  t231_n8: return 0.00619508558884263;
  t231_n9: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t231_n27;
  t231_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n26;
  t231_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t231_n13;
  t231_n12: return 0.028381306678056717;
  t231_n13: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t231_n19;
  t231_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n16;
  t231_n15: return 0.02179938741028309;
  t231_n16: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t231_n18;
  t231_n17: return -0.14775879681110382;
  t231_n18: return 0.04747464507818222;
  t231_n19: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t231_n21;
  t231_n20: return 0.03860820084810257;
  t231_n21: if (E.getNumReferences() >= 3309017088 /*3001.5*/) goto t231_n23;
  t231_n22: return -0.03336794674396515;
  t231_n23: if (E.getNumReferences() >= 3310295040 /*3313.5*/) goto t231_n25;
  t231_n24: return 0.12298686802387238;
  t231_n25: return 0.002288965741172433;
  t231_n26: return 0.003734458237886429;
  t231_n27: return -0.030162999406456947;
  t231_n28: return -0.0008571849321015179;
  t231_n29: return -0.17032289505004883;
  t231_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n36;
  t231_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n33;
  t231_n32: return 0.01931159198284149;
  t231_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t231_n35;
  t231_n34: return 0.052454959601163864;
  t231_n35: return 0.1021847203373909;
  t231_n36: if (E.getNumReferences() >= 3338855552 /*33508.5*/) goto t231_n46;
  t231_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t231_n39;
  t231_n38: return 0.09463291615247726;
  t231_n39: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n41;
  t231_n40: return 0.09625700861215591;
  t231_n41: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t231_n43;
  t231_n42: return 0.12045193463563919;
  t231_n43: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t231_n45;
  t231_n44: return 0.11038696020841599;
  t231_n45: return -0.011528143659234047;
  t231_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t231_n66;
  t231_n47: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n49;
  t231_n48: return -0.1911729872226715;
  t231_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n63;
  t231_n50: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n54;
  t231_n51: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t231_n53;
  t231_n52: return -0.10786619037389755;
  t231_n53: return 0.11895690858364105;
  t231_n54: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n58;
  t231_n55: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t231_n57;
  t231_n56: return 0.11791300773620605;
  t231_n57: return -0.01977074146270752;
  t231_n58: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t231_n60;
  t231_n59: return 0.04230313003063202;
  t231_n60: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t231_n62;
  t231_n61: return 0.13733558356761932;
  t231_n62: return 0.08747958391904831;
  t231_n63: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n65;
  t231_n64: return 0.1361626535654068;
  t231_n65: return 0.07634949684143066;
  t231_n66: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t231_n72;
  t231_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n71;
  t231_n68: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t231_n70;
  t231_n69: return 0.17244696617126465;
  t231_n70: return 0.16950000822544098;
  t231_n71: return 0.1448960155248642;
  t231_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n76;
  t231_n73: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n75;
  t231_n74: return -0.10808490961790085;
  t231_n75: return 0.10921952873468399;
  t231_n76: return 0.1279817670583725;
  t231_n77: if (E.getNumReferences() >= 3339031168 /*34194.5*/) goto t231_n79;
  t231_n78: return -0.20501375198364258;
  t231_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t231_n129;
  t231_n80: if (E.getNumReferences() >= 3341597824 /*44220.5*/) goto t231_n106;
  t231_n81: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t231_n83;
  t231_n82: return -0.0065123094245791435;
  t231_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t231_n95;
  t231_n84: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t231_n90;
  t231_n85: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n89;
  t231_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t231_n88;
  t231_n87: return 0.029904965311288834;
  t231_n88: return 0.08755147457122803;
  t231_n89: return 0.11236118525266647;
  t231_n90: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n94;
  t231_n91: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t231_n93;
  t231_n92: return -16.69675636291504;
  t231_n93: return 0.1014537587761879;
  t231_n94: return -0.028648225590586662;
  t231_n95: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t231_n103;
  t231_n96: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n102;
  t231_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t231_n99;
  t231_n98: return 0.09570889919996262;
  t231_n99: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t231_n101;
  t231_n100: return 0.11410635709762573;
  t231_n101: return 0.12256407737731934;
  t231_n102: return 0.07548188418149948;
  t231_n103: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t231_n105;
  t231_n104: return -0.3149472177028656;
  t231_n105: return 0.11245398223400116;
  t231_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n114;
  t231_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n109;
  t231_n108: return -0.07760737836360931;
  t231_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n113;
  t231_n110: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t231_n112;
  t231_n111: return 0.09866248816251755;
  t231_n112: return -0.37009701132774353;
  t231_n113: return -0.2355956733226776;
  t231_n114: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t231_n120;
  t231_n115: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n119;
  t231_n116: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t231_n118;
  t231_n117: return -0.2086666226387024;
  t231_n118: return 0.12299884110689163;
  t231_n119: return -0.03942803293466568;
  t231_n120: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t231_n126;
  t231_n121: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n125;
  t231_n122: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n124;
  t231_n123: return 0.11385894566774368;
  t231_n124: return -0.08613656461238861;
  t231_n125: return -0.03727278485894203;
  t231_n126: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t231_n128;
  t231_n127: return -0.20136815309524536;
  t231_n128: return 0.10896818339824677;
  t231_n129: return -0.09057972580194473;
  t231_n130: if (E.getNumReferences() >= 3344543232 /*55726.0*/) goto t231_n254;
  t231_n131: if (E.getNumReferences() >= 3343638400 /*52191.5*/) goto t231_n179;
  t231_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t231_n152;
  t231_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t231_n137;
  t231_n134: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t231_n136;
  t231_n135: return -0.06059994176030159;
  t231_n136: return -0.21353879570960999;
  t231_n137: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n139;
  t231_n138: return -0.0027919779531657696;
  t231_n139: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t231_n147;
  t231_n140: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t231_n146;
  t231_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n143;
  t231_n142: return 0.11334946751594543;
  t231_n143: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n145;
  t231_n144: return 0.09661832451820374;
  t231_n145: return 0.05052567645907402;
  t231_n146: return 0.0961642637848854;
  t231_n147: if (E.getNumReferences() >= 3342690432 /*48488.5*/) goto t231_n151;
  t231_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t231_n150;
  t231_n149: return -0.13412067294120789;
  t231_n150: return 0.06790827959775925;
  t231_n151: return -0.13605047762393951;
  t231_n152: if (E.getNumReferences() >= 3343486720 /*51599.0*/) goto t231_n178;
  t231_n153: if (E.getNumReferences() >= 3343221504 /*50563.0*/) goto t231_n155;
  t231_n154: return 0.0222114697098732;
  t231_n155: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t231_n175;
  t231_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t231_n166;
  t231_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t231_n161;
  t231_n158: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n160;
  t231_n159: return -0.10896036028862;
  t231_n160: return 0.09264113754034042;
  t231_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n165;
  t231_n162: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t231_n164;
  t231_n163: return 0.1068584993481636;
  t231_n164: return -0.10839614272117615;
  t231_n165: return 0.008075808174908161;
  t231_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n168;
  t231_n167: return -0.24044907093048096;
  t231_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n172;
  t231_n169: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t231_n171;
  t231_n170: return 0.1219019815325737;
  t231_n171: return 0.12660382688045502;
  t231_n172: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t231_n174;
  t231_n173: return 0.10994135588407516;
  t231_n174: return 0.07584599405527115;
  t231_n175: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t231_n177;
  t231_n176: return 0.13801875710487366;
  t231_n177: return 0.10005316138267517;
  t231_n178: return -0.11054067313671112;
  t231_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t231_n227;
  t231_n180: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t231_n224;
  t231_n181: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n183;
  t231_n182: return -0.11090686172246933;
  t231_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t231_n217;
  t231_n184: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n186;
  t231_n185: return 0.0014131860807538033;
  t231_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t231_n210;
  t231_n187: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t231_n189;
  t231_n188: return 1.5974023342132568;
  t231_n189: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t231_n203;
  t231_n190: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t231_n194;
  t231_n191: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t231_n193;
  t231_n192: return 0.12295616418123245;
  t231_n193: return -0.15749847888946533;
  t231_n194: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t231_n200;
  t231_n195: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t231_n199;
  t231_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t231_n198;
  t231_n197: return 0.11173875629901886;
  t231_n198: return 0.08985140919685364;
  t231_n199: return 0.012673157267272472;
  t231_n200: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t231_n202;
  t231_n201: return -0.19257064163684845;
  t231_n202: return 0.10517048835754395;
  t231_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t231_n205;
  t231_n204: return 0.05812850967049599;
  t231_n205: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t231_n209;
  t231_n206: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t231_n208;
  t231_n207: return -0.13885675370693207;
  t231_n208: return 0.1257636547088623;
  t231_n209: return -0.1169593334197998;
  t231_n210: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t231_n212;
  t231_n211: return -0.03505382314324379;
  t231_n212: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t231_n214;
  t231_n213: return 0.10101723670959473;
  t231_n214: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t231_n216;
  t231_n215: return 0.11903303116559982;
  t231_n216: return -0.05713518708944321;
  t231_n217: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t231_n219;
  t231_n218: return -0.10716363787651062;
  t231_n219: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t231_n223;
  t231_n220: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t231_n222;
  t231_n221: return 0.09887635707855225;
  t231_n222: return 0.10894297063350677;
  t231_n223: return 0.02390589751303196;
  t231_n224: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t231_n226;
  t231_n225: return -0.1805730015039444;
  t231_n226: return 0.10760954767465591;
  t231_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t231_n245;
  t231_n228: if (E.getNumReferences() >= 3343818112 /*52893.5*/) goto t231_n238;
  t231_n229: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n237;
  t231_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n232;
  t231_n231: return -0.10120993107557297;
  t231_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t231_n234;
  t231_n233: return 0.08895883709192276;
  t231_n234: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t231_n236;
  t231_n235: return 0.10963042825460434;
  t231_n236: return 0.10501892864704132;
  t231_n237: return -0.019083362072706223;
  t231_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t231_n244;
  t231_n239: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t231_n243;
  t231_n240: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t231_n242;
  t231_n241: return 0.19672761857509613;
  t231_n242: return 0.053110040724277496;
  t231_n243: return -0.02231592684984207;
  t231_n244: return 0.07625479251146317;
  t231_n245: if (E.getNumReferences() >= 3344481024 /*55483.0*/) goto t231_n247;
  t231_n246: return -0.04719622805714607;
  t231_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t231_n253;
  t231_n248: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t231_n252;
  t231_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t231_n251;
  t231_n250: return 0.1097479909658432;
  t231_n251: return 0.12170543521642685;
  t231_n252: return 0.10350647568702698;
  t231_n253: return 0.03925583139061928;
  t231_n254: return 0.002021051710471511;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree232(const Example& E) {
  t232_n0: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t232_n2;
  t232_n1: return -0.0002175923145841807;
  t232_n2: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t232_n68;
  t232_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t232_n13;
  t232_n4: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n6;
  t232_n5: return 0.013351277448236942;
  t232_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t232_n12;
  t232_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t232_n9;
  t232_n8: return -0.10576687008142471;
  t232_n9: if (E.getNumReferences() >= 3332800000 /*21311.0*/) goto t232_n11;
  t232_n10: return -0.527614951133728;
  t232_n11: return 0.10669150203466415;
  t232_n12: return 0.03513042628765106;
  t232_n13: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t232_n67;
  t232_n14: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t232_n58;
  t232_n15: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t232_n37;
  t232_n16: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t232_n28;
  t232_n17: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t232_n19;
  t232_n18: return 0.04416775330901146;
  t232_n19: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n27;
  t232_n20: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t232_n22;
  t232_n21: return -0.19285982847213745;
  t232_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n26;
  t232_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t232_n25;
  t232_n24: return 0.11460813134908676;
  t232_n25: return 0.21841853857040405;
  t232_n26: return -0.003321316558867693;
  t232_n27: return 0.1014443039894104;
  t232_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n36;
  t232_n29: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t232_n31;
  t232_n30: return -0.2223345935344696;
  t232_n31: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t232_n35;
  t232_n32: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n34;
  t232_n33: return 0.10391656309366226;
  t232_n34: return 0.11046796292066574;
  t232_n35: return 0.10151181370019913;
  t232_n36: return 0.017036404460668564;
  t232_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n39;
  t232_n38: return -0.08534416556358337;
  t232_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n49;
  t232_n40: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n48;
  t232_n41: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t232_n43;
  t232_n42: return -0.07203520089387894;
  t232_n43: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t232_n45;
  t232_n44: return -0.3233402967453003;
  t232_n45: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t232_n47;
  t232_n46: return 0.039011433720588684;
  t232_n47: return 0.1364465206861496;
  t232_n48: return -0.3571794331073761;
  t232_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t232_n55;
  t232_n50: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t232_n52;
  t232_n51: return 0.0522361695766449;
  t232_n52: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t232_n54;
  t232_n53: return 0.11752546578645706;
  t232_n54: return 0.03923153132200241;
  t232_n55: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t232_n57;
  t232_n56: return 0.11188330501317978;
  t232_n57: return 0.10663135349750519;
  t232_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n60;
  t232_n59: return 0.1768517643213272;
  t232_n60: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n64;
  t232_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t232_n63;
  t232_n62: return -0.2021108716726303;
  t232_n63: return 0.15252265334129333;
  t232_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t232_n66;
  t232_n65: return 0.12759356200695038;
  t232_n66: return 0.09905426949262619;
  t232_n67: return 0.022088568657636642;
  t232_n68: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t232_n156;
  t232_n69: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t232_n109;
  t232_n70: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t232_n72;
  t232_n71: return -0.01908307895064354;
  t232_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n80;
  t232_n73: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t232_n79;
  t232_n74: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t232_n76;
  t232_n75: return -0.20799237489700317;
  t232_n76: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t232_n78;
  t232_n77: return 0.16065415740013123;
  t232_n78: return -0.11513452231884003;
  t232_n79: return -0.050117213279008865;
  t232_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n82;
  t232_n81: return -0.2065330296754837;
  t232_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t232_n84;
  t232_n83: return -0.005014016292989254;
  t232_n84: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t232_n100;
  t232_n85: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t232_n87;
  t232_n86: return 0.10986679792404175;
  t232_n87: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t232_n99;
  t232_n88: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t232_n98;
  t232_n89: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t232_n93;
  t232_n90: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t232_n92;
  t232_n91: return 0.04881748929619789;
  t232_n92: return 0.09828509390354156;
  t232_n93: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t232_n95;
  t232_n94: return 0.08941129595041275;
  t232_n95: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t232_n97;
  t232_n96: return -0.126066192984581;
  t232_n97: return 0.09164924919605255;
  t232_n98: return -0.5337142944335938;
  t232_n99: return -0.4070860743522644;
  t232_n100: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t232_n102;
  t232_n101: return -0.025112923234701157;
  t232_n102: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t232_n106;
  t232_n103: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t232_n105;
  t232_n104: return 0.07353940606117249;
  t232_n105: return 0.09080211073160172;
  t232_n106: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t232_n108;
  t232_n107: return 0.08144137263298035;
  t232_n108: return -0.42888325452804565;
  t232_n109: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t232_n153;
  t232_n110: if (E.getNumReferences() >= 3338024448 /*31515.0*/) goto t232_n148;
  t232_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n127;
  t232_n112: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t232_n118;
  t232_n113: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t232_n115;
  t232_n114: return 0.10419655591249466;
  t232_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t232_n117;
  t232_n116: return -0.029604805633425713;
  t232_n117: return 0.1069948598742485;
  t232_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t232_n126;
  t232_n119: if (E.getNumReferences() >= 3336972544 /*29460.5*/) goto t232_n123;
  t232_n120: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t232_n122;
  t232_n121: return -0.5102341771125793;
  t232_n122: return -0.3265434205532074;
  t232_n123: if (E.getNumReferences() >= 3337362176 /*30221.5*/) goto t232_n125;
  t232_n124: return 0.07568149268627167;
  t232_n125: return -0.17462517321109772;
  t232_n126: return -0.05886850878596306;
  t232_n127: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t232_n129;
  t232_n128: return -0.10588689893484116;
  t232_n129: if (E.getNumReferences() >= 3334778368 /*25175.0*/) goto t232_n131;
  t232_n130: return -0.04704712703824043;
  t232_n131: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t232_n135;
  t232_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t232_n134;
  t232_n133: return 0.05607692897319794;
  t232_n134: return 0.24042171239852905;
  t232_n135: if (E.getNumReferences() >= 3336787456 /*29099.0*/) goto t232_n145;
  t232_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t232_n138;
  t232_n137: return -0.018560878932476044;
  t232_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n140;
  t232_n139: return -0.02819335088133812;
  t232_n140: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t232_n144;
  t232_n141: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t232_n143;
  t232_n142: return 0.09885057806968689;
  t232_n143: return -0.1454131156206131;
  t232_n144: return 0.10690402239561081;
  t232_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t232_n147;
  t232_n146: return 0.06556006520986557;
  t232_n147: return 0.10866563022136688;
  t232_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t232_n150;
  t232_n149: return -0.3831841051578522;
  t232_n150: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t232_n152;
  t232_n151: return 0.06590266525745392;
  t232_n152: return 0.10224578529596329;
  t232_n153: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t232_n155;
  t232_n154: return 0.06898240000009537;
  t232_n155: return -0.13598299026489258;
  t232_n156: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t232_n158;
  t232_n157: return -0.021570244804024696;
  t232_n158: if (E.getNumReferences() >= 3362537216 /*241916.0*/) goto t232_n254;
  t232_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t232_n193;
  t232_n160: if (E.getNumReferences() >= 3360146624 /*204563.0*/) goto t232_n162;
  t232_n161: return 0.00762323709204793;
  t232_n162: if (E.getNumReferences() >= 3360215360 /*205637.0*/) goto t232_n172;
  t232_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t232_n167;
  t232_n164: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t232_n166;
  t232_n165: return 0.014726178720593452;
  t232_n166: return 0.05899772047996521;
  t232_n167: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t232_n169;
  t232_n168: return 0.028113756328821182;
  t232_n169: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n171;
  t232_n170: return 0.059232816100120544;
  t232_n171: return 0.04861968755722046;
  t232_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t232_n174;
  t232_n173: return -0.004770119208842516;
  t232_n174: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t232_n188;
  t232_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n177;
  t232_n176: return 0.05562581866979599;
  t232_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t232_n187;
  t232_n178: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n186;
  t232_n179: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n183;
  t232_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t232_n182;
  t232_n181: return 0.06051088124513626;
  t232_n182: return 0.08405157178640366;
  t232_n183: if (E.getNumReferences() >= 3362012384 /*233715.5*/) goto t232_n185;
  t232_n184: return 0.11275716125965118;
  t232_n185: return -0.41546744108200073;
  t232_n186: return 0.009930022992193699;
  t232_n187: return 0.024009421467781067;
  t232_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t232_n190;
  t232_n189: return 0.04968545213341713;
  t232_n190: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t232_n192;
  t232_n191: return 0.1029479131102562;
  t232_n192: return 0.10123127698898315;
  t232_n193: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t232_n195;
  t232_n194: return -0.041376274079084396;
  t232_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t232_n235;
  t232_n196: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t232_n218;
  t232_n197: if (E.getNumReferences() >= 3340138112 /*38518.5*/) goto t232_n199;
  t232_n198: return -0.04374891519546509;
  t232_n199: if (E.getNumReferences() >= 3340748416 /*40902.5*/) goto t232_n203;
  t232_n200: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t232_n202;
  t232_n201: return -0.10479623824357986;
  t232_n202: return 0.5461077690124512;
  t232_n203: if (E.getNumReferences() >= 3355687776 /*134893.5*/) goto t232_n217;
  t232_n204: if (E.getNumReferences() >= 3354956672 /*127271.0*/) goto t232_n212;
  t232_n205: if (E.getNumReferences() >= 3351450688 /*99880.5*/) goto t232_n211;
  t232_n206: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t232_n208;
  t232_n207: return 0.04564337804913521;
  t232_n208: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t232_n210;
  t232_n209: return 0.2094457596540451;
  t232_n210: return 0.10663723945617676;
  t232_n211: return -0.1394236832857132;
  t232_n212: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t232_n216;
  t232_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n215;
  t232_n214: return -0.11440254002809525;
  t232_n215: return 0.13331559300422668;
  t232_n216: return -0.13223040103912354;
  t232_n217: return -0.10879696160554886;
  t232_n218: if (E.getNumReferences() >= 3359831936 /*199646.0*/) goto t232_n222;
  t232_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t232_n221;
  t232_n220: return 0.09925760328769684;
  t232_n221: return 0.05555868521332741;
  t232_n222: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t232_n228;
  t232_n223: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t232_n225;
  t232_n224: return -0.14578159153461456;
  t232_n225: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t232_n227;
  t232_n226: return -0.12822267413139343;
  t232_n227: return 0.09625118970870972;
  t232_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t232_n230;
  t232_n229: return -0.10124228894710541;
  t232_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n234;
  t232_n231: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t232_n233;
  t232_n232: return 0.09607437998056412;
  t232_n233: return 0.040990691632032394;
  t232_n234: return -0.0339815728366375;
  t232_n235: if (E.getNumReferences() >= 3338881664 /*33610.5*/) goto t232_n245;
  t232_n236: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t232_n244;
  t232_n237: if (E.getNumReferences() >= 3338765056 /*33155.0*/) goto t232_n239;
  t232_n238: return -0.7941709756851196;
  t232_n239: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t232_n241;
  t232_n240: return 0.11719724535942078;
  t232_n241: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t232_n243;
  t232_n242: return 0.06299874931573868;
  t232_n243: return 0.1077769547700882;
  t232_n244: return 0.12481680512428284;
  t232_n245: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t232_n251;
  t232_n246: if (E.getNumReferences() >= 3340945792 /*41673.5*/) goto t232_n248;
  t232_n247: return -0.1479800045490265;
  t232_n248: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t232_n250;
  t232_n249: return -0.00164173380471766;
  t232_n250: return -0.09719032794237137;
  t232_n251: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t232_n253;
  t232_n252: return 0.02928837575018406;
  t232_n253: return 0.07410646975040436;
  t232_n254: return -0.0045210616663098335;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree233(const Example& E) {
  t233_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t233_n144;
  t233_n1: if (E.getNumReferences() >= 3331421184 /*18618.0*/) goto t233_n3;
  t233_n2: return -0.0005938521353527904;
  t233_n3: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t233_n85;
  t233_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t233_n12;
  t233_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n7;
  t233_n6: return 0.011752794496715069;
  t233_n7: if (E.getNumReferences() >= 3334111488 /*23872.5*/) goto t233_n9;
  t233_n8: return 0.02771328203380108;
  t233_n9: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t233_n11;
  t233_n10: return 0.04685702174901962;
  t233_n11: return 0.08852212876081467;
  t233_n12: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t233_n58;
  t233_n13: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t233_n49;
  t233_n14: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t233_n48;
  t233_n15: if (E.getNumReferences() >= 3332205568 /*20150.0*/) goto t233_n47;
  t233_n16: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t233_n18;
  t233_n17: return 0.03747617453336716;
  t233_n18: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t233_n28;
  t233_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n27;
  t233_n20: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t233_n22;
  t233_n21: return -0.2004418522119522;
  t233_n22: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t233_n26;
  t233_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n25;
  t233_n24: return 0.10354270786046982;
  t233_n25: return 0.1084311380982399;
  t233_n26: return 0.09928238391876221;
  t233_n27: return 0.007918983697891235;
  t233_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t233_n30;
  t233_n29: return -0.02434728667140007;
  t233_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n38;
  t233_n31: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t233_n33;
  t233_n32: return -0.06636527925729752;
  t233_n33: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t233_n35;
  t233_n34: return -0.01093908492475748;
  t233_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n37;
  t233_n36: return 0.11811843514442444;
  t233_n37: return -0.29938235878944397;
  t233_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t233_n44;
  t233_n39: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t233_n41;
  t233_n40: return 0.04895352944731712;
  t233_n41: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t233_n43;
  t233_n42: return 0.11669766902923584;
  t233_n43: return 0.03666568174958229;
  t233_n44: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t233_n46;
  t233_n45: return 0.10216780006885529;
  t233_n46: return 0.10581912845373154;
  t233_n47: return -0.1896388679742813;
  t233_n48: return 0.026960918679833412;
  t233_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t233_n51;
  t233_n50: return 0.15134292840957642;
  t233_n51: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n55;
  t233_n52: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t233_n54;
  t233_n53: return -0.206853985786438;
  t233_n54: return 0.14843876659870148;
  t233_n55: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t233_n57;
  t233_n56: return 0.12209930270910263;
  t233_n57: return 0.09689514338970184;
  t233_n58: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n84;
  t233_n59: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t233_n61;
  t233_n60: return 0.03237846493721008;
  t233_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n63;
  t233_n62: return -0.2664927542209625;
  t233_n63: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t233_n81;
  t233_n64: if (E.getNumReferences() >= 3333319168 /*22325.0*/) goto t233_n70;
  t233_n65: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t233_n67;
  t233_n66: return -0.07484520971775055;
  t233_n67: if (E.getNumReferences() >= 3332469248 /*20665.0*/) goto t233_n69;
  t233_n68: return 0.25090736150741577;
  t233_n69: return -0.8357316255569458;
  t233_n70: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n78;
  t233_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n73;
  t233_n72: return -0.10504280030727386;
  t233_n73: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t233_n77;
  t233_n74: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t233_n76;
  t233_n75: return 0.14008572697639465;
  t233_n76: return 0.08525371551513672;
  t233_n77: return -0.010825074277818203;
  t233_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n80;
  t233_n79: return 0.0858515202999115;
  t233_n80: return -0.3088398277759552;
  t233_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n83;
  t233_n82: return 0.137326180934906;
  t233_n83: return 0.06173580884933472;
  t233_n84: return 0.016018282622098923;
  t233_n85: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t233_n143;
  t233_n86: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t233_n88;
  t233_n87: return -0.017152998596429825;
  t233_n88: if (E.getNumReferences() >= 3338286080 /*32026.0*/) goto t233_n134;
  t233_n89: if (E.getNumReferences() >= 3338024448 /*31515.0*/) goto t233_n131;
  t233_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t233_n98;
  t233_n91: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t233_n97;
  t233_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n94;
  t233_n93: return -0.4919912815093994;
  t233_n94: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t233_n96;
  t233_n95: return 0.10837584733963013;
  t233_n96: return 0.04076884686946869;
  t233_n97: return -0.0767202377319336;
  t233_n98: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t233_n100;
  t233_n99: return -0.08820342272520065;
  t233_n100: if (E.getNumReferences() >= 3334778368 /*25175.0*/) goto t233_n102;
  t233_n101: return -0.033321984112262726;
  t233_n102: if (E.getNumReferences() >= 3334835456 /*25286.5*/) goto t233_n108;
  t233_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t233_n105;
  t233_n104: return -0.5333085060119629;
  t233_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t233_n107;
  t233_n106: return 0.09999001026153564;
  t233_n107: return 0.0028470128308981657;
  t233_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t233_n110;
  t233_n109: return 0.015066242776811123;
  t233_n110: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t233_n130;
  t233_n111: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t233_n129;
  t233_n112: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n118;
  t233_n113: if (E.getNumReferences() >= 3336242944 /*28035.5*/) goto t233_n115;
  t233_n114: return -0.18377794325351715;
  t233_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n117;
  t233_n116: return -0.24384310841560364;
  t233_n117: return 0.09930337220430374;
  t233_n118: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t233_n128;
  t233_n119: if (E.getNumReferences() >= 3334963456 /*25536.5*/) goto t233_n121;
  t233_n120: return -0.11101038753986359;
  t233_n121: if (E.getNumReferences() >= 3335557632 /*26697.0*/) goto t233_n123;
  t233_n122: return 0.1016603335738182;
  t233_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t233_n127;
  t233_n124: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t233_n126;
  t233_n125: return -0.0016548112034797668;
  t233_n126: return 0.09737895429134369;
  t233_n127: return 0.18110710382461548;
  t233_n128: return 0.03149963542819023;
  t233_n129: return -0.18441839516162872;
  t233_n130: return -0.029339905828237534;
  t233_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t233_n133;
  t233_n132: return -0.34630918502807617;
  t233_n133: return 0.06326786428689957;
  t233_n134: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t233_n136;
  t233_n135: return 0.06590069830417633;
  t233_n136: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t233_n142;
  t233_n137: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n141;
  t233_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n140;
  t233_n139: return -1.0510250329971313;
  t233_n140: return -0.19751206040382385;
  t233_n141: return -0.18893134593963623;
  t233_n142: return -0.019309530034661293;
  t233_n143: return 0.004704170394688845;
  t233_n144: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t233_n254;
  t233_n145: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t233_n251;
  t233_n146: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t233_n248;
  t233_n147: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t233_n169;
  t233_n148: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n150;
  t233_n149: return -0.38432809710502625;
  t233_n150: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t233_n164;
  t233_n151: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t233_n163;
  t233_n152: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t233_n162;
  t233_n153: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t233_n159;
  t233_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t233_n156;
  t233_n155: return -0.023091452196240425;
  t233_n156: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t233_n158;
  t233_n157: return 0.10671047121286392;
  t233_n158: return 0.1049206405878067;
  t233_n159: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t233_n161;
  t233_n160: return -0.2375057488679886;
  t233_n161: return 0.0636105090379715;
  t233_n162: return -0.2869742214679718;
  t233_n163: return -0.11038855463266373;
  t233_n164: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t233_n168;
  t233_n165: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t233_n167;
  t233_n166: return -0.03490452095866203;
  t233_n167: return -1.4856001138687134;
  t233_n168: return -0.02099059894680977;
  t233_n169: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t233_n175;
  t233_n170: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t233_n174;
  t233_n171: if (E.getNumReferences() >= 3322734080 /*9017.5*/) goto t233_n173;
  t233_n172: return 0.009365562349557877;
  t233_n173: return 0.10373110324144363;
  t233_n174: return -0.10950691252946854;
  t233_n175: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t233_n201;
  t233_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t233_n198;
  t233_n177: if (E.getNumReferences() >= 3327652864 /*13821.0*/) goto t233_n191;
  t233_n178: if (E.getNumReferences() >= 3327370240 /*13545.0*/) goto t233_n190;
  t233_n179: if (E.getNumReferences() >= 3325806080 /*12017.5*/) goto t233_n183;
  t233_n180: if (E.getNumReferences() >= 3325388288 /*11609.5*/) goto t233_n182;
  t233_n181: return 0.07316327840089798;
  t233_n182: return -0.32573115825653076;
  t233_n183: if (E.getNumReferences() >= 3326233600 /*12435.0*/) goto t233_n185;
  t233_n184: return 0.07404986768960953;
  t233_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n187;
  t233_n186: return -0.18325573205947876;
  t233_n187: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t233_n189;
  t233_n188: return 0.13260243833065033;
  t233_n189: return -0.22246991097927094;
  t233_n190: return -0.1369585543870926;
  t233_n191: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n195;
  t233_n192: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n194;
  t233_n193: return 0.07560700178146362;
  t233_n194: return 0.0010590020101517439;
  t233_n195: if (E.getNumReferences() >= 3329677312 /*15798.0*/) goto t233_n197;
  t233_n196: return 0.0920475497841835;
  t233_n197: return -0.10364165157079697;
  t233_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t233_n200;
  t233_n199: return 0.10492227971553802;
  t233_n200: return -0.37957435846328735;
  t233_n201: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t233_n205;
  t233_n202: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t233_n204;
  t233_n203: return -1.0983994007110596;
  t233_n204: return -0.05572151020169258;
  t233_n205: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t233_n223;
  t233_n206: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t233_n220;
  t233_n207: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t233_n217;
  t233_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n216;
  t233_n209: if (E.getNumReferences() >= 3331214848 /*18215.0*/) goto t233_n211;
  t233_n210: return -0.11214805394411087;
  t233_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t233_n215;
  t233_n212: if (E.getNumReferences() >= 3333870080 /*23401.0*/) goto t233_n214;
  t233_n213: return -0.468962699174881;
  t233_n214: return 0.07854576408863068;
  t233_n215: return 0.09656433761119843;
  t233_n216: return -0.00789732951670885;
  t233_n217: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t233_n219;
  t233_n218: return 0.12265193462371826;
  t233_n219: return 0.10525072365999222;
  t233_n220: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t233_n222;
  t233_n221: return -0.012685306370258331;
  t233_n222: return 0.09189572185277939;
  t233_n223: if (E.getNumReferences() >= 3339407360 /*35664.0*/) goto t233_n239;
  t233_n224: if (E.getNumReferences() >= 3333245184 /*22180.5*/) goto t233_n232;
  t233_n225: if (E.getNumReferences() >= 3331678976 /*19121.5*/) goto t233_n227;
  t233_n226: return -0.049094121903181076;
  t233_n227: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n229;
  t233_n228: return -0.1760498434305191;
  t233_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t233_n231;
  t233_n230: return 0.12377896159887314;
  t233_n231: return 0.11554112285375595;
  t233_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n238;
  t233_n233: if (E.getNumReferences() >= 3334268416 /*24179.0*/) goto t233_n237;
  t233_n234: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t233_n236;
  t233_n235: return -1.450974941253662;
  t233_n236: return -0.48426318168640137;
  t233_n237: return -0.06355147808790207;
  t233_n238: return 0.01714138127863407;
  t233_n239: if (E.getNumReferences() >= 3340199168 /*38757.0*/) goto t233_n243;
  t233_n240: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t233_n242;
  t233_n241: return 0.08480694144964218;
  t233_n242: return -0.022976407781243324;
  t233_n243: if (E.getNumReferences() >= 3341699072 /*44616.0*/) goto t233_n245;
  t233_n244: return -0.7819960117340088;
  t233_n245: if (E.getNumReferences() >= 3342038016 /*45940.0*/) goto t233_n247;
  t233_n246: return 0.09866471588611603;
  t233_n247: return 0.011643914505839348;
  t233_n248: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t233_n250;
  t233_n249: return 0.15446262061595917;
  t233_n250: return -0.10897192358970642;
  t233_n251: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t233_n253;
  t233_n252: return -0.10347583144903183;
  t233_n253: return 0.006042052526026964;
  t233_n254: return -0.00027679899358190596;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree234(const Example& E) {
  t234_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t234_n2;
  t234_n1: return -0.0010641446569934487;
  t234_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n30;
  t234_n3: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t234_n19;
  t234_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t234_n12;
  t234_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n7;
  t234_n6: return -0.01111754309386015;
  t234_n7: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t234_n11;
  t234_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n10;
  t234_n9: return 0.06572400778532028;
  t234_n10: return 0.01166597381234169;
  t234_n11: return 0.0048749144189059734;
  t234_n12: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t234_n14;
  t234_n13: return -0.003200339851900935;
  t234_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n18;
  t234_n15: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n17;
  t234_n16: return 0.02646108902990818;
  t234_n17: return 0.04694633185863495;
  t234_n18: return -0.004244958516210318;
  t234_n19: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t234_n29;
  t234_n20: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t234_n26;
  t234_n21: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t234_n23;
  t234_n22: return 0.0037142287474125624;
  t234_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n25;
  t234_n24: return 0.09637418389320374;
  t234_n25: return 0.06635073572397232;
  t234_n26: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t234_n28;
  t234_n27: return -0.07227066904306412;
  t234_n28: return 0.039050620049238205;
  t234_n29: return -0.008722597733139992;
  t234_n30: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t234_n114;
  t234_n31: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n77;
  t234_n32: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t234_n76;
  t234_n33: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t234_n73;
  t234_n34: if (E.getNumReferences() >= 3263561728 /*67.0*/) goto t234_n60;
  t234_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n37;
  t234_n36: return -0.03231161832809448;
  t234_n37: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t234_n59;
  t234_n38: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t234_n48;
  t234_n39: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t234_n47;
  t234_n40: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t234_n44;
  t234_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n43;
  t234_n42: return -0.10541443526744843;
  t234_n43: return 0.03405708819627762;
  t234_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n46;
  t234_n45: return 0.08433831483125687;
  t234_n46: return -0.34463417530059814;
  t234_n47: return -0.2939301133155823;
  t234_n48: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t234_n52;
  t234_n49: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t234_n51;
  t234_n50: return 0.0909404307603836;
  t234_n51: return 0.11231893301010132;
  t234_n52: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t234_n54;
  t234_n53: return -0.02130432054400444;
  t234_n54: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t234_n58;
  t234_n55: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t234_n57;
  t234_n56: return 0.08969686180353165;
  t234_n57: return 0.11408265680074692;
  t234_n58: return 0.021061616018414497;
  t234_n59: return 0.1854536533355713;
  t234_n60: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t234_n62;
  t234_n61: return 0.11668667197227478;
  t234_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t234_n64;
  t234_n63: return -0.016515858471393585;
  t234_n64: if (E.getNumReferences() >= 3267493888 /*97.0*/) goto t234_n66;
  t234_n65: return 0.09830311685800552;
  t234_n66: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t234_n68;
  t234_n67: return -0.25196534395217896;
  t234_n68: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t234_n70;
  t234_n69: return 0.08201935887336731;
  t234_n70: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t234_n72;
  t234_n71: return -0.6481800079345703;
  t234_n72: return 0.10095661878585815;
  t234_n73: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t234_n75;
  t234_n74: return -0.06865804642438889;
  t234_n75: return -0.003042042488232255;
  t234_n76: return -0.04528150334954262;
  t234_n77: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t234_n107;
  t234_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t234_n80;
  t234_n79: return 0.0011337555479258299;
  t234_n80: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t234_n102;
  t234_n81: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t234_n91;
  t234_n82: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t234_n84;
  t234_n83: return 0.06308375298976898;
  t234_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n86;
  t234_n85: return 0.03440427407622337;
  t234_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n88;
  t234_n87: return 0.11465925723314285;
  t234_n88: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t234_n90;
  t234_n89: return 0.07990569621324539;
  t234_n90: return 0.11683782935142517;
  t234_n91: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n99;
  t234_n92: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t234_n96;
  t234_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t234_n95;
  t234_n94: return 0.006473137065768242;
  t234_n95: return 0.056696195155382156;
  t234_n96: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t234_n98;
  t234_n97: return -0.017287397757172585;
  t234_n98: return 0.036060530692338943;
  t234_n99: if (E.getNumReferences() >= 3366959872 /*359896.0*/) goto t234_n101;
  t234_n100: return 0.008931558579206467;
  t234_n101: return 0.1278890073299408;
  t234_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n104;
  t234_n103: return -0.08319851756095886;
  t234_n104: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t234_n106;
  t234_n105: return 0.008745432831346989;
  t234_n106: return 0.050278499722480774;
  t234_n107: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t234_n109;
  t234_n108: return -0.06901729851961136;
  t234_n109: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n113;
  t234_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t234_n112;
  t234_n111: return -0.13102243840694427;
  t234_n112: return 0.008894229307770729;
  t234_n113: return -0.03397110104560852;
  t234_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t234_n186;
  t234_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t234_n185;
  t234_n116: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t234_n158;
  t234_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t234_n119;
  t234_n118: return -0.01614421419799328;
  t234_n119: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t234_n149;
  t234_n120: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t234_n146;
  t234_n121: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t234_n143;
  t234_n122: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t234_n142;
  t234_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Type))) goto t234_n135;
  t234_n124: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t234_n128;
  t234_n125: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t234_n127;
  t234_n126: return -0.09395354241132736;
  t234_n127: return 0.019595304504036903;
  t234_n128: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t234_n134;
  t234_n129: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t234_n133;
  t234_n130: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t234_n132;
  t234_n131: return 0.05370555445551872;
  t234_n132: return 0.10285641252994537;
  t234_n133: return -0.18577730655670166;
  t234_n134: return -0.0008067915332503617;
  t234_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t234_n137;
  t234_n136: return 0.05234040319919586;
  t234_n137: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t234_n141;
  t234_n138: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t234_n140;
  t234_n139: return -0.02181210182607174;
  t234_n140: return 0.09930787980556488;
  t234_n141: return 0.12065129727125168;
  t234_n142: return 0.1258840411901474;
  t234_n143: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t234_n145;
  t234_n144: return 0.008208034560084343;
  t234_n145: return -0.10311874002218246;
  t234_n146: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t234_n148;
  t234_n147: return -0.024082016199827194;
  t234_n148: return -0.3095194697380066;
  t234_n149: if (E.getNumReferences() >= 3273752576 /*161.5*/) goto t234_n153;
  t234_n150: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t234_n152;
  t234_n151: return 0.10935230553150177;
  t234_n152: return -0.8407748937606812;
  t234_n153: if (E.getNumReferences() >= 3305666560 /*2183.5*/) goto t234_n155;
  t234_n154: return -0.04155762866139412;
  t234_n155: if (E.getNumReferences() >= 3313434624 /*4080.0*/) goto t234_n157;
  t234_n156: return 0.09822956472635269;
  t234_n157: return 0.04865462705492973;
  t234_n158: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t234_n168;
  t234_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n163;
  t234_n160: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t234_n162;
  t234_n161: return -0.02010677382349968;
  t234_n162: return -0.08062451332807541;
  t234_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t234_n165;
  t234_n164: return 0.005868602078408003;
  t234_n165: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t234_n167;
  t234_n166: return 0.1339205950498581;
  t234_n167: return 0.012874465435743332;
  t234_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t234_n184;
  t234_n169: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t234_n183;
  t234_n170: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t234_n172;
  t234_n171: return 0.011560493148863316;
  t234_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t234_n174;
  t234_n173: return -0.21194028854370117;
  t234_n174: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n180;
  t234_n175: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t234_n179;
  t234_n176: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t234_n178;
  t234_n177: return 0.0007044454687274992;
  t234_n178: return 0.11866720765829086;
  t234_n179: return 0.018499203026294708;
  t234_n180: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t234_n182;
  t234_n181: return 0.11911056190729141;
  t234_n182: return -0.1852056235074997;
  t234_n183: return -0.014004210010170937;
  t234_n184: return 0.031970374286174774;
  t234_n185: return 0.014202316291630268;
  t234_n186: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t234_n250;
  t234_n187: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t234_n241;
  t234_n188: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t234_n240;
  t234_n189: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t234_n207;
  t234_n190: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n204;
  t234_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t234_n197;
  t234_n192: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t234_n196;
  t234_n193: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t234_n195;
  t234_n194: return -0.07281878590583801;
  t234_n195: return 0.057040221989154816;
  t234_n196: return -0.11314134299755096;
  t234_n197: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t234_n199;
  t234_n198: return -0.24730738997459412;
  t234_n199: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t234_n203;
  t234_n200: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t234_n202;
  t234_n201: return -0.4125252962112427;
  t234_n202: return 0.1022844985127449;
  t234_n203: return -0.7334324717521667;
  t234_n204: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n206;
  t234_n205: return -0.05168270319700241;
  t234_n206: return 0.07568979263305664;
  t234_n207: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n237;
  t234_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t234_n230;
  t234_n209: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t234_n221;
  t234_n210: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t234_n212;
  t234_n211: return 0.0032323964405804873;
  t234_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t234_n214;
  t234_n213: return 0.01843658648431301;
  t234_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t234_n216;
  t234_n215: return -0.20223072171211243;
  t234_n216: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n220;
  t234_n217: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t234_n219;
  t234_n218: return 0.13318543136119843;
  t234_n219: return 0.22076627612113953;
  t234_n220: return 0.08705823123455048;
  t234_n221: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t234_n225;
  t234_n222: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t234_n224;
  t234_n223: return -0.024399301037192345;
  t234_n224: return -0.1980247050523758;
  t234_n225: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t234_n227;
  t234_n226: return -0.0841427892446518;
  t234_n227: if (E.getNumReferences() >= 3279290368 /*246.0*/) goto t234_n229;
  t234_n228: return 0.08472174406051636;
  t234_n229: return -0.018170202150940895;
  t234_n230: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t234_n232;
  t234_n231: return 0.008128178305923939;
  t234_n232: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t234_n234;
  t234_n233: return -0.011393863707780838;
  t234_n234: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t234_n236;
  t234_n235: return 0.10887526720762253;
  t234_n236: return -0.7164533734321594;
  t234_n237: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n239;
  t234_n238: return 0.023766275495290756;
  t234_n239: return -0.0022357471752911806;
  t234_n240: return 0.005250841844826937;
  t234_n241: if (E.getNumReferences() >= 3346171648 /*62087.0*/) goto t234_n249;
  t234_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t234_n248;
  t234_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n245;
  t234_n244: return -0.043395694345235825;
  t234_n245: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t234_n247;
  t234_n246: return 0.09269299358129501;
  t234_n247: return 0.04359079524874687;
  t234_n248: return 0.10569348931312561;
  t234_n249: return 0.012111459858715534;
  t234_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t234_n254;
  t234_n251: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t234_n253;
  t234_n252: return -0.04753834754228592;
  t234_n253: return 0.0026990517508238554;
  t234_n254: return -0.0028170200530439615;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree235(const Example& E) {
  t235_n0: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t235_n2;
  t235_n1: return -0.0016964878886938095;
  t235_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t235_n4;
  t235_n3: return -0.0004847196687478572;
  t235_n4: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t235_n246;
  t235_n5: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t235_n15;
  t235_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n12;
  t235_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n9;
  t235_n8: return -0.002193744294345379;
  t235_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n11;
  t235_n10: return -0.009936890564858913;
  t235_n11: return -0.002969286637380719;
  t235_n12: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t235_n14;
  t235_n13: return -0.005930924788117409;
  t235_n14: return 0.006817126180976629;
  t235_n15: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t235_n143;
  t235_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t235_n132;
  t235_n17: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t235_n85;
  t235_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t235_n44;
  t235_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t235_n23;
  t235_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n22;
  t235_n21: return -0.01780949905514717;
  t235_n22: return -0.03894011676311493;
  t235_n23: if (E.getNumReferences() >= 3279028224 /*242.0*/) goto t235_n35;
  t235_n24: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t235_n32;
  t235_n25: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t235_n29;
  t235_n26: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t235_n28;
  t235_n27: return 0.026560338214039803;
  t235_n28: return 0.09051056951284409;
  t235_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n31;
  t235_n30: return -2.0699143409729004;
  t235_n31: return -0.4000582993030548;
  t235_n32: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t235_n34;
  t235_n33: return -0.06546232104301453;
  t235_n34: return 0.01699988543987274;
  t235_n35: if (E.getNumReferences() >= 3292487680 /*765.5*/) goto t235_n41;
  t235_n36: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t235_n38;
  t235_n37: return 0.07030005007982254;
  t235_n38: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t235_n40;
  t235_n39: return 0.024904832243919373;
  t235_n40: return 0.12278055399656296;
  t235_n41: if (E.getNumReferences() >= 3293552640 /*830.5*/) goto t235_n43;
  t235_n42: return -0.7906782627105713;
  t235_n43: return 0.04775385186076164;
  t235_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t235_n66;
  t235_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n47;
  t235_n46: return -0.06871769577264786;
  t235_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t235_n55;
  t235_n48: if (E.getNumReferences() >= 3307462656 /*2622.0*/) goto t235_n50;
  t235_n49: return -0.029296724125742912;
  t235_n50: if (E.getNumReferences() >= 3312713728 /*3904.0*/) goto t235_n54;
  t235_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t235_n53;
  t235_n52: return 0.06635088473558426;
  t235_n53: return 0.11519208550453186;
  t235_n54: return 0.03867905214428902;
  t235_n55: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n65;
  t235_n56: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t235_n64;
  t235_n57: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t235_n63;
  t235_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n62;
  t235_n59: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t235_n61;
  t235_n60: return 0.06757719069719315;
  t235_n61: return 0.10275302082300186;
  t235_n62: return 0.09534895420074463;
  t235_n63: return 0.02615673653781414;
  t235_n64: return -0.2559110224246979;
  t235_n65: return -0.07736318558454514;
  t235_n66: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t235_n84;
  t235_n67: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t235_n71;
  t235_n68: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t235_n70;
  t235_n69: return 0.01858699321746826;
  t235_n70: return 0.11028186231851578;
  t235_n71: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t235_n75;
  t235_n72: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n74;
  t235_n73: return 0.116029292345047;
  t235_n74: return 0.09092079102993011;
  t235_n75: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t235_n77;
  t235_n76: return -0.012631651014089584;
  t235_n77: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t235_n81;
  t235_n78: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n80;
  t235_n79: return -1.2225909233093262;
  t235_n80: return 0.10112662613391876;
  t235_n81: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t235_n83;
  t235_n82: return -0.11805037409067154;
  t235_n83: return 0.07770910859107971;
  t235_n84: return 0.033351462334394455;
  t235_n85: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t235_n97;
  t235_n86: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n88;
  t235_n87: return 0.015576930716633797;
  t235_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n92;
  t235_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n91;
  t235_n90: return -0.3781226575374603;
  t235_n91: return -0.026370586827397346;
  t235_n92: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t235_n94;
  t235_n93: return -0.21431861817836761;
  t235_n94: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t235_n96;
  t235_n95: return -0.031907819211483;
  t235_n96: return 0.1623108983039856;
  t235_n97: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t235_n119;
  t235_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t235_n118;
  t235_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n101;
  t235_n100: return -0.0048116096295416355;
  t235_n101: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t235_n109;
  t235_n102: if (E.getNumReferences() >= 3367651744 /*381517.0*/) goto t235_n108;
  t235_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t235_n105;
  t235_n104: return -0.0036206713411957026;
  t235_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t235_n107;
  t235_n106: return 0.09483110904693604;
  t235_n107: return -0.11223690956830978;
  t235_n108: return -0.8855460286140442;
  t235_n109: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t235_n111;
  t235_n110: return -0.4161752760410309;
  t235_n111: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t235_n117;
  t235_n112: if (E.getNumReferences() >= 3367651744 /*381517.0*/) goto t235_n114;
  t235_n113: return 0.049457233399152756;
  t235_n114: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t235_n116;
  t235_n115: return -1.2128745317459106;
  t235_n116: return 0.05999613553285599;
  t235_n117: return -0.10053097456693649;
  t235_n118: return 0.02401733584702015;
  t235_n119: if (E.getNumReferences() >= 3362744896 /*245161.0*/) goto t235_n131;
  t235_n120: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t235_n122;
  t235_n121: return 0.07191532105207443;
  t235_n122: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n130;
  t235_n123: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t235_n129;
  t235_n124: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n126;
  t235_n125: return -0.1092785894870758;
  t235_n126: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n128;
  t235_n127: return 0.023328006267547607;
  t235_n128: return 0.08988340198993683;
  t235_n129: return 0.11167822778224945;
  t235_n130: return -0.7367027997970581;
  t235_n131: return -0.008574661798775196;
  t235_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n140;
  t235_n133: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n137;
  t235_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n136;
  t235_n135: return -0.032365262508392334;
  t235_n136: return 0.0722571611404419;
  t235_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n139;
  t235_n138: return -0.01386462152004242;
  t235_n139: return 0.05044139176607132;
  t235_n140: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n142;
  t235_n141: return -0.005197540856897831;
  t235_n142: return 0.01247369684278965;
  t235_n143: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t235_n203;
  t235_n144: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t235_n196;
  t235_n145: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t235_n151;
  t235_n146: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n148;
  t235_n147: return 0.0006042178720235825;
  t235_n148: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t235_n150;
  t235_n149: return -0.5456435084342957;
  t235_n150: return -0.2044491022825241;
  t235_n151: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t235_n195;
  t235_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t235_n176;
  t235_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t235_n175;
  t235_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t235_n170;
  t235_n155: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t235_n157;
  t235_n156: return -0.0013598862569779158;
  t235_n157: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t235_n169;
  t235_n158: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n162;
  t235_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n161;
  t235_n160: return 0.09541548043489456;
  t235_n161: return 0.11100815236568451;
  t235_n162: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t235_n164;
  t235_n163: return -0.14344114065170288;
  t235_n164: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t235_n168;
  t235_n165: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t235_n167;
  t235_n166: return 0.05894634127616882;
  t235_n167: return 0.11783327162265778;
  t235_n168: return -0.15004995465278625;
  t235_n169: return 0.022614311426877975;
  t235_n170: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t235_n174;
  t235_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n173;
  t235_n172: return -0.11638084053993225;
  t235_n173: return -0.04670265316963196;
  t235_n174: return 0.025480138137936592;
  t235_n175: return -0.035222165286540985;
  t235_n176: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t235_n186;
  t235_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n185;
  t235_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n182;
  t235_n179: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n181;
  t235_n180: return 0.003316278802230954;
  t235_n181: return -0.2719312906265259;
  t235_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t235_n184;
  t235_n183: return -0.35100609064102173;
  t235_n184: return 0.08525485545396805;
  t235_n185: return 0.04693758487701416;
  t235_n186: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t235_n188;
  t235_n187: return 0.11728863418102264;
  t235_n188: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t235_n192;
  t235_n189: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t235_n191;
  t235_n190: return -0.07390407472848892;
  t235_n191: return 0.11369853466749191;
  t235_n192: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n194;
  t235_n193: return 0.10565035790205002;
  t235_n194: return -0.3244180977344513;
  t235_n195: return -0.006096061319112778;
  t235_n196: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t235_n200;
  t235_n197: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t235_n199;
  t235_n198: return -0.050258032977581024;
  t235_n199: return 0.012700696475803852;
  t235_n200: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t235_n202;
  t235_n201: return -0.13074424862861633;
  t235_n202: return 0.1304989755153656;
  t235_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t235_n237;
  t235_n204: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t235_n232;
  t235_n205: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t235_n211;
  t235_n206: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t235_n208;
  t235_n207: return -0.101736880838871;
  t235_n208: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n210;
  t235_n209: return 0.10658983141183853;
  t235_n210: return 0.11326320469379425;
  t235_n211: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t235_n217;
  t235_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t235_n216;
  t235_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n215;
  t235_n214: return 0.030833356082439423;
  t235_n215: return 0.11488129198551178;
  t235_n216: return -0.023241402581334114;
  t235_n217: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t235_n223;
  t235_n218: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t235_n220;
  t235_n219: return 0.005372007377445698;
  t235_n220: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t235_n222;
  t235_n221: return 0.10426837205886841;
  t235_n222: return -0.24495472013950348;
  t235_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t235_n231;
  t235_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t235_n230;
  t235_n225: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t235_n229;
  t235_n226: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t235_n228;
  t235_n227: return 0.07457523047924042;
  t235_n228: return 0.12908215820789337;
  t235_n229: return 0.002747832564637065;
  t235_n230: return -0.12644465267658234;
  t235_n231: return 0.11676270514726639;
  t235_n232: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t235_n236;
  t235_n233: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t235_n235;
  t235_n234: return -0.0998569130897522;
  t235_n235: return 0.03600252419710159;
  t235_n236: return 0.016587238758802414;
  t235_n237: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t235_n243;
  t235_n238: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t235_n240;
  t235_n239: return 0.11754801124334335;
  t235_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t235_n242;
  t235_n241: return -0.8892221450805664;
  t235_n242: return 0.079160675406456;
  t235_n243: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t235_n245;
  t235_n244: return 0.04384787380695343;
  t235_n245: return -0.146385058760643;
  t235_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t235_n248;
  t235_n247: return 0.006987827364355326;
  t235_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t235_n254;
  t235_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t235_n253;
  t235_n250: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t235_n252;
  t235_n251: return 0.0807112380862236;
  t235_n252: return 0.0787934809923172;
  t235_n253: return 0.05605660751461983;
  t235_n254: return -0.014412764459848404;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree236(const Example& E) {
  t236_n0: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t236_n2;
  t236_n1: return -0.00022388073557522148;
  t236_n2: if (E.getNumReferences() >= 3334334464 /*24308.0*/) goto t236_n100;
  t236_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t236_n5;
  t236_n4: return 0.021413862705230713;
  t236_n5: if (E.getNumReferences() >= 3332305408 /*20345.0*/) goto t236_n69;
  t236_n6: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t236_n60;
  t236_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t236_n47;
  t236_n8: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t236_n38;
  t236_n9: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t236_n37;
  t236_n10: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t236_n36;
  t236_n11: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t236_n15;
  t236_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n14;
  t236_n13: return -0.002582325367256999;
  t236_n14: return 0.34548279643058777;
  t236_n15: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t236_n23;
  t236_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n22;
  t236_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n19;
  t236_n18: return -0.5432167053222656;
  t236_n19: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t236_n21;
  t236_n20: return 0.10651775449514389;
  t236_n21: return 0.09453095495700836;
  t236_n22: return 0.017146514728665352;
  t236_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t236_n27;
  t236_n24: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t236_n26;
  t236_n25: return -0.04771795868873596;
  t236_n26: return 0.14031246304512024;
  t236_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n29;
  t236_n28: return -0.04640482738614082;
  t236_n29: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n35;
  t236_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t236_n32;
  t236_n31: return 0.08718041330575943;
  t236_n32: if (E.getNumReferences() >= 3332040448 /*19827.5*/) goto t236_n34;
  t236_n33: return 0.11592978984117508;
  t236_n34: return 0.06074473634362221;
  t236_n35: return 0.10821636766195297;
  t236_n36: return -0.17309193313121796;
  t236_n37: return 0.02680112235248089;
  t236_n38: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t236_n40;
  t236_n39: return 0.10413626581430435;
  t236_n40: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t236_n46;
  t236_n41: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n43;
  t236_n42: return -0.0023156972602009773;
  t236_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t236_n45;
  t236_n44: return 0.088651642203331;
  t236_n45: return -0.17654521763324738;
  t236_n46: return -0.506714940071106;
  t236_n47: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n59;
  t236_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n58;
  t236_n49: if (E.getNumReferences() >= 3332129024 /*20000.5*/) goto t236_n55;
  t236_n50: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t236_n54;
  t236_n51: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n53;
  t236_n52: return 0.1117396429181099;
  t236_n53: return -0.07267118990421295;
  t236_n54: return -0.20418226718902588;
  t236_n55: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t236_n57;
  t236_n56: return 0.036639951169490814;
  t236_n57: return 0.12246359884738922;
  t236_n58: return -0.042684487998485565;
  t236_n59: return -0.2732391357421875;
  t236_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n62;
  t236_n61: return 0.1297493875026703;
  t236_n62: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n66;
  t236_n63: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t236_n65;
  t236_n64: return -0.1101173534989357;
  t236_n65: return 0.14461782574653625;
  t236_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n68;
  t236_n67: return 0.11980900913476944;
  t236_n68: return 0.09856479614973068;
  t236_n69: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t236_n91;
  t236_n70: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t236_n72;
  t236_n71: return 0.006605330388993025;
  t236_n72: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n84;
  t236_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t236_n81;
  t236_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n76;
  t236_n75: return 0.016445279121398926;
  t236_n76: if (E.getNumReferences() >= 3332378112 /*20487.0*/) goto t236_n80;
  t236_n77: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t236_n79;
  t236_n78: return -0.16835801303386688;
  t236_n79: return 0.284547358751297;
  t236_n80: return -0.6112586259841919;
  t236_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n83;
  t236_n82: return 0.13270632922649384;
  t236_n83: return 0.04944198951125145;
  t236_n84: if (E.getNumReferences() >= 3333643008 /*22957.5*/) goto t236_n86;
  t236_n85: return 0.019561665132641792;
  t236_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n88;
  t236_n87: return 0.09380579739809036;
  t236_n88: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n90;
  t236_n89: return 0.07525160163640976;
  t236_n90: return -0.14553745090961456;
  t236_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t236_n93;
  t236_n92: return -0.07841986417770386;
  t236_n93: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t236_n95;
  t236_n94: return 0.023071832954883575;
  t236_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t236_n99;
  t236_n96: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n98;
  t236_n97: return -0.00374954123981297;
  t236_n98: return 0.27745646238327026;
  t236_n99: return 0.09202833473682404;
  t236_n100: if (E.getNumReferences() >= 3334783232 /*25184.5*/) goto t236_n106;
  t236_n101: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t236_n103;
  t236_n102: return -0.09694735705852509;
  t236_n103: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t236_n105;
  t236_n104: return 0.12830929458141327;
  t236_n105: return -0.19025078415870667;
  t236_n106: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t236_n110;
  t236_n107: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t236_n109;
  t236_n108: return -0.010789294727146626;
  t236_n109: return 0.005378338973969221;
  t236_n110: if (E.getNumReferences() >= 3335643392 /*26864.5*/) goto t236_n136;
  t236_n111: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t236_n129;
  t236_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t236_n126;
  t236_n113: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t236_n123;
  t236_n114: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t236_n116;
  t236_n115: return 0.10743792355060577;
  t236_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n118;
  t236_n117: return -0.02725602686405182;
  t236_n118: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t236_n120;
  t236_n119: return 0.03168267011642456;
  t236_n120: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t236_n122;
  t236_n121: return 0.11634249985218048;
  t236_n122: return 0.1117578074336052;
  t236_n123: if (E.getNumReferences() >= 3335170304 /*25940.5*/) goto t236_n125;
  t236_n124: return 0.4724576473236084;
  t236_n125: return -0.18554921448230743;
  t236_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n128;
  t236_n127: return 0.14138925075531006;
  t236_n128: return -0.11328788101673126;
  t236_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t236_n131;
  t236_n130: return -0.36266660690307617;
  t236_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n135;
  t236_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n134;
  t236_n133: return -0.12431108206510544;
  t236_n134: return 0.10636324435472488;
  t236_n135: return 0.10796187072992325;
  t236_n136: if (E.getNumReferences() >= 3336316928 /*28180.0*/) goto t236_n152;
  t236_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t236_n149;
  t236_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n140;
  t236_n139: return -0.2971321642398834;
  t236_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t236_n142;
  t236_n141: return -0.5702822208404541;
  t236_n142: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t236_n148;
  t236_n143: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n147;
  t236_n144: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t236_n146;
  t236_n145: return 0.09031753242015839;
  t236_n146: return -0.6836487650871277;
  t236_n147: return 0.1034558042883873;
  t236_n148: return 0.0019719155970960855;
  t236_n149: if (E.getNumReferences() >= 3336061952 /*27682.0*/) goto t236_n151;
  t236_n150: return -0.4114331305027008;
  t236_n151: return 0.11514627188444138;
  t236_n152: if (E.getNumReferences() >= 3361426240 /*224557.0*/) goto t236_n216;
  t236_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t236_n203;
  t236_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n164;
  t236_n155: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t236_n157;
  t236_n156: return 0.016109244897961617;
  t236_n157: if (E.getNumReferences() >= 3351920320 /*103549.5*/) goto t236_n159;
  t236_n158: return -0.06612683832645416;
  t236_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n163;
  t236_n160: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n162;
  t236_n161: return 0.26597148180007935;
  t236_n162: return -0.10034690797328949;
  t236_n163: return -0.10120397806167603;
  t236_n164: if (E.getNumReferences() >= 3341622016 /*44315.0*/) goto t236_n202;
  t236_n165: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t236_n199;
  t236_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t236_n184;
  t236_n167: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t236_n171;
  t236_n168: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n170;
  t236_n169: return -0.036729276180267334;
  t236_n170: return 0.0578865148127079;
  t236_n171: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t236_n179;
  t236_n172: if (E.getNumReferences() >= 3338840960 /*33451.5*/) goto t236_n174;
  t236_n173: return 0.0008473021443933249;
  t236_n174: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n178;
  t236_n175: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n177;
  t236_n176: return 0.1790025681257248;
  t236_n177: return 0.06392008811235428;
  t236_n178: return 0.11109161376953125;
  t236_n179: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t236_n183;
  t236_n180: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t236_n182;
  t236_n181: return 0.09697183221578598;
  t236_n182: return 0.06412011384963989;
  t236_n183: return 0.044244568794965744;
  t236_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n188;
  t236_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n187;
  t236_n186: return 0.06347320973873138;
  t236_n187: return 0.10942717641592026;
  t236_n188: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t236_n198;
  t236_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n197;
  t236_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t236_n192;
  t236_n191: return -0.0019197211368009448;
  t236_n192: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t236_n194;
  t236_n193: return -0.021851247176527977;
  t236_n194: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t236_n196;
  t236_n195: return 0.11983220279216766;
  t236_n196: return 0.11114731431007385;
  t236_n197: return 0.1252603828907013;
  t236_n198: return 0.008456042967736721;
  t236_n199: if (E.getNumReferences() >= 3337280256 /*30061.5*/) goto t236_n201;
  t236_n200: return 0.06732653081417084;
  t236_n201: return -0.035623449832201004;
  t236_n202: return 0.005391511134803295;
  t236_n203: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t236_n213;
  t236_n204: if (E.getNumReferences() >= 3351111424 /*97230.0*/) goto t236_n210;
  t236_n205: if (E.getNumReferences() >= 3339744256 /*36980.0*/) goto t236_n209;
  t236_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n208;
  t236_n207: return 0.02651919424533844;
  t236_n208: return 0.09740544110536575;
  t236_n209: return -0.12483083456754684;
  t236_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t236_n212;
  t236_n211: return 0.0465371310710907;
  t236_n212: return 0.10390252619981766;
  t236_n213: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t236_n215;
  t236_n214: return 0.027522793039679527;
  t236_n215: return -0.48003441095352173;
  t236_n216: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t236_n246;
  t236_n217: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t236_n223;
  t236_n218: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t236_n222;
  t236_n219: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t236_n221;
  t236_n220: return -0.4869035482406616;
  t236_n221: return 0.01688479445874691;
  t236_n222: return -0.018568281084299088;
  t236_n223: if (E.getNumReferences() >= 3380813364 /*1074118.5*/) goto t236_n243;
  t236_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t236_n238;
  t236_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n237;
  t236_n226: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t236_n232;
  t236_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t236_n229;
  t236_n228: return -0.024015579372644424;
  t236_n229: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t236_n231;
  t236_n230: return 0.10758604109287262;
  t236_n231: return 0.0318157859146595;
  t236_n232: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t236_n236;
  t236_n233: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n235;
  t236_n234: return -0.22383418679237366;
  t236_n235: return -0.029082857072353363;
  t236_n236: return 0.04015248641371727;
  t236_n237: return 0.057412173599004745;
  t236_n238: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n240;
  t236_n239: return 0.07894423604011536;
  t236_n240: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t236_n242;
  t236_n241: return 0.07389459758996964;
  t236_n242: return -0.06094193458557129;
  t236_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t236_n245;
  t236_n244: return -0.008301163092255592;
  t236_n245: return 0.012517380528151989;
  t236_n246: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t236_n254;
  t236_n247: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t236_n253;
  t236_n248: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t236_n252;
  t236_n249: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t236_n251;
  t236_n250: return -0.12018615007400513;
  t236_n251: return 0.10033727437257767;
  t236_n252: return 0.040122270584106445;
  t236_n253: return 0.10911203175783157;
  t236_n254: return -0.19576920568943024;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree237(const Example& E) {
  t237_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t237_n84;
  t237_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n3;
  t237_n2: return -5.1435225032037124e-05;
  t237_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t237_n23;
  t237_n4: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t237_n22;
  t237_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t237_n19;
  t237_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t237_n8;
  t237_n7: return 0.03168753534555435;
  t237_n8: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t237_n18;
  t237_n9: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n13;
  t237_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t237_n12;
  t237_n11: return 0.12078577280044556;
  t237_n12: return 0.10580737888813019;
  t237_n13: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t237_n15;
  t237_n14: return 0.015372871421277523;
  t237_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t237_n17;
  t237_n16: return -0.04225775972008705;
  t237_n17: return 0.14001192152500153;
  t237_n18: return -0.042311061173677444;
  t237_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t237_n21;
  t237_n20: return -0.022824382409453392;
  t237_n21: return 0.011868756264448166;
  t237_n22: return -0.01520537305623293;
  t237_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t237_n25;
  t237_n24: return 0.0008434552000835538;
  t237_n25: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t237_n83;
  t237_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t237_n46;
  t237_n27: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t237_n29;
  t237_n28: return -0.005829721689224243;
  t237_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n31;
  t237_n30: return 0.0310814268887043;
  t237_n31: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t237_n37;
  t237_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag))) goto t237_n34;
  t237_n33: return 0.02742479369044304;
  t237_n34: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n36;
  t237_n35: return 0.06468179076910019;
  t237_n36: return -0.00680284108966589;
  t237_n37: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t237_n45;
  t237_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t237_n44;
  t237_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t237_n41;
  t237_n40: return 0.009207948110997677;
  t237_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n43;
  t237_n42: return 0.08514373749494553;
  t237_n43: return 0.10491642355918884;
  t237_n44: return 0.06753301620483398;
  t237_n45: return -0.0589970164000988;
  t237_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t237_n64;
  t237_n47: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n49;
  t237_n48: return 0.0623636320233345;
  t237_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t237_n63;
  t237_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n62;
  t237_n51: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t237_n61;
  t237_n52: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t237_n58;
  t237_n53: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n55;
  t237_n54: return 0.08653023838996887;
  t237_n55: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t237_n57;
  t237_n56: return 0.12377000600099564;
  t237_n57: return 0.08992923051118851;
  t237_n58: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n60;
  t237_n59: return 0.07436404377222061;
  t237_n60: return 0.11396299302577972;
  t237_n61: return -0.23711907863616943;
  t237_n62: return 0.07143474370241165;
  t237_n63: return 0.05342867970466614;
  t237_n64: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t237_n78;
  t237_n65: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t237_n73;
  t237_n66: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n68;
  t237_n67: return 0.014752237126231194;
  t237_n68: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t237_n72;
  t237_n69: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n71;
  t237_n70: return 0.14309346675872803;
  t237_n71: return 0.10952333360910416;
  t237_n72: return 0.07786242663860321;
  t237_n73: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n77;
  t237_n74: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t237_n76;
  t237_n75: return 0.12003489583730698;
  t237_n76: return 0.08183428645133972;
  t237_n77: return 0.04839726537466049;
  t237_n78: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t237_n80;
  t237_n79: return 0.023361900821328163;
  t237_n80: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n82;
  t237_n81: return 0.13361407816410065;
  t237_n82: return -0.11291475594043732;
  t237_n83: return -0.01508607342839241;
  t237_n84: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t237_n98;
  t237_n85: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t237_n97;
  t237_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t237_n96;
  t237_n87: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n89;
  t237_n88: return -0.0457756482064724;
  t237_n89: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n93;
  t237_n90: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n92;
  t237_n91: return -0.1184995099902153;
  t237_n92: return -0.566068708896637;
  t237_n93: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n95;
  t237_n94: return -0.08575249463319778;
  t237_n95: return -0.8836507797241211;
  t237_n96: return -0.07344246655702591;
  t237_n97: return -0.002713852096349001;
  t237_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t237_n100;
  t237_n99: return -0.03607690706849098;
  t237_n100: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t237_n252;
  t237_n101: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t237_n179;
  t237_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t237_n168;
  t237_n103: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t237_n163;
  t237_n104: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t237_n158;
  t237_n105: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t237_n111;
  t237_n106: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t237_n110;
  t237_n107: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t237_n109;
  t237_n108: return 0.03941700980067253;
  t237_n109: return 0.09876066446304321;
  t237_n110: return -0.09688885509967804;
  t237_n111: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t237_n115;
  t237_n112: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t237_n114;
  t237_n113: return -0.08850392699241638;
  t237_n114: return 0.11939424276351929;
  t237_n115: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n117;
  t237_n116: return -0.07308098673820496;
  t237_n117: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t237_n135;
  t237_n118: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t237_n128;
  t237_n119: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n127;
  t237_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t237_n126;
  t237_n121: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n125;
  t237_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t237_n124;
  t237_n123: return 0.10182283073663712;
  t237_n124: return -0.004314585123211145;
  t237_n125: return 0.11276565492153168;
  t237_n126: return -0.09061479568481445;
  t237_n127: return -0.11113514006137848;
  t237_n128: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n134;
  t237_n129: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t237_n131;
  t237_n130: return 0.13166847825050354;
  t237_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n133;
  t237_n132: return 0.12197785079479218;
  t237_n133: return -0.10657919198274612;
  t237_n134: return 0.13186943531036377;
  t237_n135: if (E.getNumReferences() >= 3254779904 /*32.0*/) goto t237_n137;
  t237_n136: return -0.16901233792304993;
  t237_n137: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t237_n143;
  t237_n138: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t237_n142;
  t237_n139: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t237_n141;
  t237_n140: return 0.10752992331981659;
  t237_n141: return -0.22814267873764038;
  t237_n142: return 0.11521207541227341;
  t237_n143: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n155;
  t237_n144: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n154;
  t237_n145: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n149;
  t237_n146: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n148;
  t237_n147: return 0.40778711438179016;
  t237_n148: return -0.1681545525789261;
  t237_n149: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t237_n151;
  t237_n150: return 0.05392639338970184;
  t237_n151: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n153;
  t237_n152: return 0.13264474272727966;
  t237_n153: return 0.09425998479127884;
  t237_n154: return -0.04256065934896469;
  t237_n155: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t237_n157;
  t237_n156: return -0.13712544739246368;
  t237_n157: return 0.09357529878616333;
  t237_n158: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t237_n162;
  t237_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t237_n161;
  t237_n160: return 0.040087759494781494;
  t237_n161: return 0.8495534658432007;
  t237_n162: return 0.11176493018865585;
  t237_n163: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t237_n167;
  t237_n164: if (E.getNumReferences() >= 3332634624 /*20988.0*/) goto t237_n166;
  t237_n165: return -0.11165913939476013;
  t237_n166: return 0.0665389820933342;
  t237_n167: return -0.07633604109287262;
  t237_n168: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t237_n170;
  t237_n169: return 0.002507341792806983;
  t237_n170: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n178;
  t237_n171: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t237_n173;
  t237_n172: return -0.10228735208511353;
  t237_n173: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t237_n177;
  t237_n174: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t237_n176;
  t237_n175: return 0.05970760062336922;
  t237_n176: return 0.09972960501909256;
  t237_n177: return 0.10642696171998978;
  t237_n178: return 0.02763502672314644;
  t237_n179: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t237_n205;
  t237_n180: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n198;
  t237_n181: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n183;
  t237_n182: return -0.010110598988831043;
  t237_n183: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t237_n193;
  t237_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t237_n192;
  t237_n185: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t237_n187;
  t237_n186: return -0.12259835749864578;
  t237_n187: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t237_n191;
  t237_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t237_n190;
  t237_n189: return 0.10751335322856903;
  t237_n190: return -0.11914780735969543;
  t237_n191: return -0.07859598100185394;
  t237_n192: return 0.12416515499353409;
  t237_n193: if (E.getNumReferences() >= 3333465344 /*22610.5*/) goto t237_n197;
  t237_n194: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n196;
  t237_n195: return -0.26804426312446594;
  t237_n196: return -0.27199122309684753;
  t237_n197: return -0.014667797833681107;
  t237_n198: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t237_n204;
  t237_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t237_n203;
  t237_n200: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t237_n202;
  t237_n201: return -0.7299579977989197;
  t237_n202: return 0.07285165786743164;
  t237_n203: return 0.11124583333730698;
  t237_n204: return 0.10308852046728134;
  t237_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t237_n245;
  t237_n206: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t237_n216;
  t237_n207: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t237_n209;
  t237_n208: return -0.10874655842781067;
  t237_n209: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t237_n215;
  t237_n210: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t237_n212;
  t237_n211: return 0.1144028976559639;
  t237_n212: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t237_n214;
  t237_n213: return -0.10437978059053421;
  t237_n214: return 0.09122985601425171;
  t237_n215: return -0.07614503055810928;
  t237_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t237_n218;
  t237_n217: return -0.023366471752524376;
  t237_n218: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t237_n224;
  t237_n219: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t237_n223;
  t237_n220: if (E.getSymbolScopeDistance() >= 3229614080 /*4.0*/) goto t237_n222;
  t237_n221: return 0.11945070326328278;
  t237_n222: return -0.15441149473190308;
  t237_n223: return 0.11582613736391068;
  t237_n224: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t237_n244;
  t237_n225: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t237_n237;
  t237_n226: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t237_n236;
  t237_n227: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t237_n229;
  t237_n228: return 0.05946531519293785;
  t237_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n235;
  t237_n230: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t237_n232;
  t237_n231: return 0.11844876408576965;
  t237_n232: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n234;
  t237_n233: return 0.10484350472688675;
  t237_n234: return 0.09156773239374161;
  t237_n235: return -0.299567848443985;
  t237_n236: return -0.19454243779182434;
  t237_n237: if (E.getNumReferences() >= 3265134592 /*79.0*/) goto t237_n243;
  t237_n238: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t237_n242;
  t237_n239: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t237_n241;
  t237_n240: return 0.06127196177840233;
  t237_n241: return 0.14615048468112946;
  t237_n242: return 0.09275482594966888;
  t237_n243: return 0.05977306887507439;
  t237_n244: return 0.003755465615540743;
  t237_n245: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t237_n251;
  t237_n246: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t237_n250;
  t237_n247: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t237_n249;
  t237_n248: return -0.019398318603634834;
  t237_n249: return 0.1077289804816246;
  t237_n250: return 0.12174779921770096;
  t237_n251: return 0.08868597447872162;
  t237_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t237_n254;
  t237_n253: return -0.04112422838807106;
  t237_n254: return 0.1400744467973709;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree238(const Example& E) {
  t238_n0: if (E.getNumReferences() >= 3306510336 /*2389.5*/) goto t238_n6;
  t238_n1: if (E.getNumReferences() >= 3306272768 /*2331.5*/) goto t238_n3;
  t238_n2: return -0.0002945251762866974;
  t238_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t238_n5;
  t238_n4: return -0.08431518822908401;
  t238_n5: return -0.1791301667690277;
  t238_n6: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t238_n12;
  t238_n7: if (E.getNumReferences() >= 3306528768 /*2394.0*/) goto t238_n11;
  t238_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t238_n10;
  t238_n9: return -0.10303020477294922;
  t238_n10: return 0.11028960347175598;
  t238_n11: return 0.009634477086365223;
  t238_n12: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t238_n14;
  t238_n13: return -0.0009304296690970659;
  t238_n14: if (E.getNumReferences() >= 3346195456 /*62180.0*/) goto t238_n212;
  t238_n15: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t238_n199;
  t238_n16: if (E.getNumReferences() >= 3346034176 /*61550.0*/) goto t238_n198;
  t238_n17: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t238_n25;
  t238_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t238_n20;
  t238_n19: return 0.04767290875315666;
  t238_n20: if (E.getNumReferences() >= 3321453568 /*7979.5*/) goto t238_n24;
  t238_n21: if (E.getNumReferences() >= 3317408768 /*6004.5*/) goto t238_n23;
  t238_n22: return 0.03863966464996338;
  t238_n23: return 0.12355863302946091;
  t238_n24: return 0.051193565130233765;
  t238_n25: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t238_n143;
  t238_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t238_n86;
  t238_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t238_n85;
  t238_n28: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t238_n66;
  t238_n29: if (E.getNumReferences() >= 3329498112 /*15623.0*/) goto t238_n31;
  t238_n30: return -0.08232881128787994;
  t238_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n33;
  t238_n32: return -0.03980744630098343;
  t238_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n61;
  t238_n34: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t238_n60;
  t238_n35: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n37;
  t238_n36: return -0.13966867327690125;
  t238_n37: if (E.getNumReferences() >= 3336769792 /*29064.5*/) goto t238_n49;
  t238_n38: if (E.getNumReferences() >= 3335832832 /*27234.5*/) goto t238_n48;
  t238_n39: if (E.getNumReferences() >= 3330932480 /*17663.5*/) goto t238_n47;
  t238_n40: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t238_n44;
  t238_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n43;
  t238_n42: return 0.1205008327960968;
  t238_n43: return -0.20741243660449982;
  t238_n44: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n46;
  t238_n45: return -0.15187089145183563;
  t238_n46: return 0.10174985229969025;
  t238_n47: return -0.19678078591823578;
  t238_n48: return 0.11677782982587814;
  t238_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t238_n51;
  t238_n50: return -0.03948301449418068;
  t238_n51: if (E.getNumReferences() >= 3340710656 /*40755.0*/) goto t238_n53;
  t238_n52: return 0.14153407514095306;
  t238_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n55;
  t238_n54: return -0.14702636003494263;
  t238_n55: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t238_n57;
  t238_n56: return 0.03492799773812294;
  t238_n57: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t238_n59;
  t238_n58: return 0.2563248872756958;
  t238_n59: return 0.1043776422739029;
  t238_n60: return -0.03371497243642807;
  t238_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n63;
  t238_n62: return -0.1891191005706787;
  t238_n63: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t238_n65;
  t238_n64: return -0.1303589791059494;
  t238_n65: return 0.09929847717285156;
  t238_n66: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t238_n76;
  t238_n67: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t238_n69;
  t238_n68: return -0.08115930110216141;
  t238_n69: if (E.getNumReferences() >= 3308478464 /*2870.0*/) goto t238_n75;
  t238_n70: if (E.getNumReferences() >= 3307792384 /*2702.5*/) goto t238_n72;
  t238_n71: return 0.1373133361339569;
  t238_n72: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t238_n74;
  t238_n73: return -0.10332739353179932;
  t238_n74: return 0.11881046742200851;
  t238_n75: return 0.02383965253829956;
  t238_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n78;
  t238_n77: return 0.010991232469677925;
  t238_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n82;
  t238_n79: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t238_n81;
  t238_n80: return -0.46058303117752075;
  t238_n81: return 0.10541371256113052;
  t238_n82: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t238_n84;
  t238_n83: return 0.1199665367603302;
  t238_n84: return 0.08058198541402817;
  t238_n85: return 0.05009876564145088;
  t238_n86: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t238_n140;
  t238_n87: if (E.getNumReferences() >= 3333043200 /*21786.0*/) goto t238_n129;
  t238_n88: if (E.getNumReferences() >= 3332993536 /*21689.0*/) goto t238_n126;
  t238_n89: if (E.getNumReferences() >= 3316685824 /*5651.5*/) goto t238_n91;
  t238_n90: return 0.006964432075619698;
  t238_n91: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t238_n93;
  t238_n92: return 0.006884814240038395;
  t238_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t238_n95;
  t238_n94: return 0.01812676340341568;
  t238_n95: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t238_n99;
  t238_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n98;
  t238_n97: return -0.0608956404030323;
  t238_n98: return 0.10811587423086166;
  t238_n99: if (E.getNumReferences() >= 3328404480 /*14555.0*/) goto t238_n123;
  t238_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t238_n102;
  t238_n101: return 0.019625768065452576;
  t238_n102: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t238_n106;
  t238_n103: if (E.getNumReferences() >= 3316792320 /*5703.5*/) goto t238_n105;
  t238_n104: return 0.12034271657466888;
  t238_n105: return 0.012675575911998749;
  t238_n106: if (E.getNumReferences() >= 3322110464 /*8408.5*/) goto t238_n108;
  t238_n107: return 0.04211173951625824;
  t238_n108: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t238_n116;
  t238_n109: if (E.getNumReferences() >= 3322621952 /*8908.0*/) goto t238_n113;
  t238_n110: if (E.getNumReferences() >= 3322180096 /*8476.5*/) goto t238_n112;
  t238_n111: return 0.10851346701383591;
  t238_n112: return 0.0101082194596529;
  t238_n113: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n115;
  t238_n114: return 0.11550536751747131;
  t238_n115: return -0.022607725113630295;
  t238_n116: if (E.getNumReferences() >= 3324676608 /*10914.5*/) goto t238_n122;
  t238_n117: if (E.getNumReferences() >= 3324197888 /*10447.0*/) goto t238_n119;
  t238_n118: return 0.06706180423498154;
  t238_n119: if (E.getNumReferences() >= 3324302336 /*10549.0*/) goto t238_n121;
  t238_n120: return 0.10797446966171265;
  t238_n121: return 0.09468881785869598;
  t238_n122: return 0.009508221410214901;
  t238_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t238_n125;
  t238_n124: return 0.047596462070941925;
  t238_n125: return 0.08549313247203827;
  t238_n126: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t238_n128;
  t238_n127: return 0.08053221553564072;
  t238_n128: return -0.055051546543836594;
  t238_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t238_n131;
  t238_n130: return -0.03670007362961769;
  t238_n131: if (E.getNumReferences() >= 3338548224 /*32538.0*/) goto t238_n133;
  t238_n132: return -0.015828508883714676;
  t238_n133: if (E.getNumReferences() >= 3338711808 /*32947.0*/) goto t238_n139;
  t238_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t238_n138;
  t238_n135: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t238_n137;
  t238_n136: return 0.10437315702438354;
  t238_n137: return 0.10284220427274704;
  t238_n138: return 0.09688892215490341;
  t238_n139: return 0.027469931170344353;
  t238_n140: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n142;
  t238_n141: return 0.12044437229633331;
  t238_n142: return 0.087065689265728;
  t238_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t238_n145;
  t238_n144: return 0.007267417386174202;
  t238_n145: if (E.getNumReferences() >= 3320657920 /*7591.0*/) goto t238_n157;
  t238_n146: if (E.getNumReferences() >= 3313014784 /*3977.5*/) goto t238_n154;
  t238_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel))) goto t238_n149;
  t238_n148: return 0.026871172711253166;
  t238_n149: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n153;
  t238_n150: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n152;
  t238_n151: return 0.11144774407148361;
  t238_n152: return -0.010710001923143864;
  t238_n153: return 0.10507358610630035;
  t238_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t238_n156;
  t238_n155: return -0.07340134680271149;
  t238_n156: return 0.039475612342357635;
  t238_n157: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t238_n197;
  t238_n158: if (E.getNumReferences() >= 3342715264 /*48585.5*/) goto t238_n190;
  t238_n159: if (E.getNumReferences() >= 3329272320 /*15402.5*/) goto t238_n189;
  t238_n160: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n176;
  t238_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t238_n169;
  t238_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n164;
  t238_n163: return -0.011288020759820938;
  t238_n164: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t238_n166;
  t238_n165: return -0.07570052146911621;
  t238_n166: if (E.getNumReferences() >= 3324484096 /*10726.5*/) goto t238_n168;
  t238_n167: return 0.11585585027933121;
  t238_n168: return 0.04190701246261597;
  t238_n169: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t238_n171;
  t238_n170: return 0.1209324300289154;
  t238_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t238_n173;
  t238_n172: return 0.102461077272892;
  t238_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t238_n175;
  t238_n174: return 0.05308203771710396;
  t238_n175: return 0.25214433670043945;
  t238_n176: if (E.getNumReferences() >= 3325046272 /*11275.5*/) goto t238_n182;
  t238_n177: if (E.getNumReferences() >= 3321261056 /*7885.5*/) goto t238_n179;
  t238_n178: return 0.08924742043018341;
  t238_n179: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t238_n181;
  t238_n180: return -0.32754138112068176;
  t238_n181: return 0.02115589566528797;
  t238_n182: if (E.getNumReferences() >= 3326581248 /*12774.5*/) goto t238_n186;
  t238_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t238_n185;
  t238_n184: return 0.1277487725019455;
  t238_n185: return 0.11960749328136444;
  t238_n186: if (E.getNumReferences() >= 3328893952 /*15033.0*/) goto t238_n188;
  t238_n187: return -0.00679310318082571;
  t238_n188: return 0.0878482311964035;
  t238_n189: return 0.029134346172213554;
  t238_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t238_n194;
  t238_n191: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t238_n193;
  t238_n192: return -0.15772350132465363;
  t238_n193: return 0.10596992075443268;
  t238_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n196;
  t238_n195: return 0.09858328104019165;
  t238_n196: return 0.09423080086708069;
  t238_n197: return -0.019318021833896637;
  t238_n198: return 0.08733847737312317;
  t238_n199: if (E.getNumReferences() >= 3306622976 /*2417.0*/) goto t238_n203;
  t238_n200: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n202;
  t238_n201: return 0.11277218163013458;
  t238_n202: return 0.04899050295352936;
  t238_n203: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t238_n205;
  t238_n204: return 0.020884785801172256;
  t238_n205: if (E.getNumReferences() >= 3314617344 /*4641.5*/) goto t238_n211;
  t238_n206: if (E.getNumReferences() >= 3312302080 /*3803.5*/) goto t238_n210;
  t238_n207: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n209;
  t238_n208: return 0.08541683852672577;
  t238_n209: return -0.5983622074127197;
  t238_n210: return 0.10659342259168625;
  t238_n211: return -0.04316575825214386;
  t238_n212: if (E.getNumReferences() >= 3348227392 /*74698.5*/) goto t238_n230;
  t238_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n217;
  t238_n214: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t238_n216;
  t238_n215: return -0.09732650220394135;
  t238_n216: return 0.021578503772616386;
  t238_n217: if (E.getNumReferences() >= 3348120000 /*73859.5*/) goto t238_n227;
  t238_n218: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t238_n220;
  t238_n219: return -0.0488477498292923;
  t238_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t238_n222;
  t238_n221: return -0.17026780545711517;
  t238_n222: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n226;
  t238_n223: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t238_n225;
  t238_n224: return 0.09425278007984161;
  t238_n225: return 0.04298793897032738;
  t238_n226: return 0.03146488592028618;
  t238_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n229;
  t238_n228: return 0.03603697195649147;
  t238_n229: return 0.10851415991783142;
  t238_n230: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t238_n252;
  t238_n231: if (E.getNumReferences() >= 3356105632 /*141422.5*/) goto t238_n249;
  t238_n232: if (E.getNumReferences() >= 3356017152 /*140040.0*/) goto t238_n240;
  t238_n233: if (E.getNumReferences() >= 3351031040 /*96602.0*/) goto t238_n237;
  t238_n234: if (E.getNumReferences() >= 3348960256 /*80424.0*/) goto t238_n236;
  t238_n235: return 0.04093145951628685;
  t238_n236: return -0.04027732461690903;
  t238_n237: if (E.getNumReferences() >= 3351221312 /*98088.5*/) goto t238_n239;
  t238_n238: return 0.09415601193904877;
  t238_n239: return 0.01046594325453043;
  t238_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t238_n242;
  t238_n241: return -0.04566184803843498;
  t238_n242: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t238_n246;
  t238_n243: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t238_n245;
  t238_n244: return 0.10166231542825699;
  t238_n245: return 0.1108425110578537;
  t238_n246: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t238_n248;
  t238_n247: return -0.48887914419174194;
  t238_n248: return 0.0955863893032074;
  t238_n249: if (E.getNumReferences() >= 3357792448 /*167779.0*/) goto t238_n251;
  t238_n250: return -0.2639353275299072;
  t238_n251: return -0.019048606976866722;
  t238_n252: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t238_n254;
  t238_n253: return -0.004719079937785864;
  t238_n254: return 0.03310784325003624;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree239(const Example& E) {
  t239_n0: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t239_n2;
  t239_n1: return -0.0016929218545556068;
  t239_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t239_n4;
  t239_n3: return -0.0004881874774582684;
  t239_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Expression))) goto t239_n28;
  t239_n5: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t239_n7;
  t239_n6: return -0.01806524582207203;
  t239_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t239_n9;
  t239_n8: return -0.00014090290642343462;
  t239_n9: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t239_n11;
  t239_n10: return 0.01219144370406866;
  t239_n11: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t239_n27;
  t239_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t239_n14;
  t239_n13: return -0.10924138873815536;
  t239_n14: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t239_n16;
  t239_n15: return 0.11810197681188583;
  t239_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n26;
  t239_n17: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t239_n25;
  t239_n18: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t239_n24;
  t239_n19: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t239_n21;
  t239_n20: return -0.04167279601097107;
  t239_n21: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t239_n23;
  t239_n22: return 0.09619231522083282;
  t239_n23: return 0.036379389464855194;
  t239_n24: return 0.09221871942281723;
  t239_n25: return 0.0014299002941697836;
  t239_n26: return -1.1435747146606445;
  t239_n27: return -0.002403068821877241;
  t239_n28: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t239_n238;
  t239_n29: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t239_n31;
  t239_n30: return 0.004531803075224161;
  t239_n31: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t239_n97;
  t239_n32: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t239_n72;
  t239_n33: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t239_n71;
  t239_n34: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t239_n64;
  t239_n35: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t239_n37;
  t239_n36: return 0.1041426807641983;
  t239_n37: if (E.getNumReferences() >= 3279962112 /*256.5*/) goto t239_n43;
  t239_n38: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n40;
  t239_n39: return -0.3251800835132599;
  t239_n40: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t239_n42;
  t239_n41: return 0.09853597730398178;
  t239_n42: return 0.03257157281041145;
  t239_n43: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t239_n45;
  t239_n44: return 0.11281442642211914;
  t239_n45: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t239_n63;
  t239_n46: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t239_n48;
  t239_n47: return -0.0037673565093427896;
  t239_n48: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t239_n62;
  t239_n49: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t239_n51;
  t239_n50: return 0.11357583105564117;
  t239_n51: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t239_n53;
  t239_n52: return -0.005594304762780666;
  t239_n53: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t239_n57;
  t239_n54: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n56;
  t239_n55: return 0.11156981438398361;
  t239_n56: return 0.06752243638038635;
  t239_n57: if (E.getNumReferences() >= 3292536832 /*768.5*/) goto t239_n59;
  t239_n58: return 0.11478089541196823;
  t239_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n61;
  t239_n60: return 0.026791831478476524;
  t239_n61: return 0.11933645606040955;
  t239_n62: return -0.044720470905303955;
  t239_n63: return -0.0823153406381607;
  t239_n64: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t239_n70;
  t239_n65: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t239_n67;
  t239_n66: return 0.0752767026424408;
  t239_n67: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t239_n69;
  t239_n68: return 0.09258256107568741;
  t239_n69: return -0.10782159119844437;
  t239_n70: return -0.3432041108608246;
  t239_n71: return 0.01070599164813757;
  t239_n72: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t239_n96;
  t239_n73: if (E.getNumReferences() >= 3302137856 /*1685.0*/) goto t239_n93;
  t239_n74: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t239_n88;
  t239_n75: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n87;
  t239_n76: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t239_n78;
  t239_n77: return -0.028283799067139626;
  t239_n78: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t239_n82;
  t239_n79: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t239_n81;
  t239_n80: return 0.1738157421350479;
  t239_n81: return -0.3618260324001312;
  t239_n82: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t239_n84;
  t239_n83: return -0.2822236120700836;
  t239_n84: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n86;
  t239_n85: return 0.16054287552833557;
  t239_n86: return 0.05542551353573799;
  t239_n87: return -0.22503572702407837;
  t239_n88: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t239_n90;
  t239_n89: return -0.3064989447593689;
  t239_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t239_n92;
  t239_n91: return -0.1170511320233345;
  t239_n92: return 0.0856415256857872;
  t239_n93: if (E.getNumReferences() >= 3306971136 /*2502.0*/) goto t239_n95;
  t239_n94: return 0.11686757951974869;
  t239_n95: return -0.010503273457288742;
  t239_n96: return 0.005814883857965469;
  t239_n97: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t239_n107;
  t239_n98: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n102;
  t239_n99: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n101;
  t239_n100: return 0.12200180441141129;
  t239_n101: return 0.01759653352200985;
  t239_n102: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t239_n104;
  t239_n103: return 0.07667386531829834;
  t239_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n106;
  t239_n105: return 0.13254275918006897;
  t239_n106: return 0.02206791564822197;
  t239_n107: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t239_n237;
  t239_n108: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t239_n222;
  t239_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n193;
  t239_n110: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t239_n112;
  t239_n111: return -0.02204040065407753;
  t239_n112: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n188;
  t239_n113: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t239_n167;
  t239_n114: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t239_n166;
  t239_n115: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t239_n135;
  t239_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n132;
  t239_n117: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t239_n129;
  t239_n118: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t239_n128;
  t239_n119: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n123;
  t239_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n122;
  t239_n121: return 0.07752551883459091;
  t239_n122: return -0.10316836088895798;
  t239_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n125;
  t239_n124: return 0.12264664471149445;
  t239_n125: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t239_n127;
  t239_n126: return 0.0903065875172615;
  t239_n127: return -0.42400479316711426;
  t239_n128: return 0.011571393348276615;
  t239_n129: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t239_n131;
  t239_n130: return 0.08862986415624619;
  t239_n131: return 0.10862839221954346;
  t239_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t239_n134;
  t239_n133: return -0.05265258252620697;
  t239_n134: return 1.0442376136779785;
  t239_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n147;
  t239_n136: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t239_n144;
  t239_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n139;
  t239_n138: return 0.05020782724022865;
  t239_n139: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t239_n143;
  t239_n140: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n142;
  t239_n141: return 0.09628400951623917;
  t239_n142: return 0.1076788604259491;
  t239_n143: return 0.10349985957145691;
  t239_n144: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n146;
  t239_n145: return -0.7363951206207275;
  t239_n146: return 0.05320395156741142;
  t239_n147: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t239_n151;
  t239_n148: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t239_n150;
  t239_n149: return 0.1061878651380539;
  t239_n150: return -0.012840408831834793;
  t239_n151: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t239_n153;
  t239_n152: return 0.00789994839578867;
  t239_n153: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t239_n157;
  t239_n154: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n156;
  t239_n155: return -0.2042015939950943;
  t239_n156: return 0.07538007944822311;
  t239_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t239_n165;
  t239_n158: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t239_n160;
  t239_n159: return -0.048874638974666595;
  t239_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n164;
  t239_n161: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t239_n163;
  t239_n162: return 0.13985179364681244;
  t239_n163: return 0.11195360124111176;
  t239_n164: return 0.04829764738678932;
  t239_n165: return 0.14802701771259308;
  t239_n166: return -0.10633137822151184;
  t239_n167: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t239_n169;
  t239_n168: return -0.11099422723054886;
  t239_n169: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t239_n171;
  t239_n170: return -0.23952151834964752;
  t239_n171: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n173;
  t239_n172: return -0.0318976454436779;
  t239_n173: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n179;
  t239_n174: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t239_n178;
  t239_n175: if (E.getNumReferences() >= 3239051264 /*9.0*/) goto t239_n177;
  t239_n176: return 0.09686847776174545;
  t239_n177: return -0.17608405649662018;
  t239_n178: return 0.09128738194704056;
  t239_n179: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t239_n181;
  t239_n180: return -0.10673452168703079;
  t239_n181: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t239_n183;
  t239_n182: return 0.11105432361364365;
  t239_n183: if (E.getNumReferences() >= 3247439872 /*18.0*/) goto t239_n187;
  t239_n184: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t239_n186;
  t239_n185: return -0.42080947756767273;
  t239_n186: return 0.10107319802045822;
  t239_n187: return 0.0758405402302742;
  t239_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t239_n190;
  t239_n189: return 0.1569335162639618;
  t239_n190: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t239_n192;
  t239_n191: return 0.07475024461746216;
  t239_n192: return -0.04409709572792053;
  t239_n193: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t239_n201;
  t239_n194: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t239_n196;
  t239_n195: return 0.10397030413150787;
  t239_n196: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t239_n198;
  t239_n197: return -0.04269061237573624;
  t239_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n200;
  t239_n199: return 0.10603206604719162;
  t239_n200: return 0.06843029707670212;
  t239_n201: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t239_n213;
  t239_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t239_n208;
  t239_n203: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n205;
  t239_n204: return -0.07808300852775574;
  t239_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n207;
  t239_n206: return -0.06554105877876282;
  t239_n207: return -0.17703987658023834;
  t239_n208: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t239_n210;
  t239_n209: return 0.017559364438056946;
  t239_n210: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t239_n212;
  t239_n211: return 0.11769122630357742;
  t239_n212: return 0.13367368280887604;
  t239_n213: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t239_n215;
  t239_n214: return -0.02192419022321701;
  t239_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n219;
  t239_n216: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t239_n218;
  t239_n217: return -0.07191582024097443;
  t239_n218: return 0.11885355412960052;
  t239_n219: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t239_n221;
  t239_n220: return 0.08755003660917282;
  t239_n221: return 0.03431760147213936;
  t239_n222: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t239_n228;
  t239_n223: if (E.getNumReferences() >= 3256483840 /*38.5*/) goto t239_n227;
  t239_n224: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n226;
  t239_n225: return 0.12480472773313522;
  t239_n226: return 0.023843908682465553;
  t239_n227: return 0.015225752256810665;
  t239_n228: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t239_n234;
  t239_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n231;
  t239_n230: return 0.028373975306749344;
  t239_n231: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t239_n233;
  t239_n232: return -0.09293878078460693;
  t239_n233: return 0.11094542592763901;
  t239_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t239_n236;
  t239_n235: return 0.016023149713873863;
  t239_n236: return 0.11992646753787994;
  t239_n237: return 0.006870684213936329;
  t239_n238: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t239_n254;
  t239_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t239_n243;
  t239_n240: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n242;
  t239_n241: return 0.019212966784834862;
  t239_n242: return -0.005429632030427456;
  t239_n243: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t239_n253;
  t239_n244: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t239_n252;
  t239_n245: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t239_n247;
  t239_n246: return 0.0713188573718071;
  t239_n247: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t239_n251;
  t239_n248: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t239_n250;
  t239_n249: return 0.08320864289999008;
  t239_n250: return 0.07129298895597458;
  t239_n251: return 0.039818815886974335;
  t239_n252: return 0.05954679474234581;
  t239_n253: return -0.030411247164011;
  t239_n254: return 0.12407396733760834;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree240(const Example& E) {
  t240_n0: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t240_n2;
  t240_n1: return -0.0004754458204843104;
  t240_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t240_n234;
  t240_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t240_n5;
  t240_n4: return -0.016822611913084984;
  t240_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t240_n11;
  t240_n6: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t240_n10;
  t240_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t240_n9;
  t240_n8: return -0.026837563142180443;
  t240_n9: return 0.03502151742577553;
  t240_n10: return 0.12367028743028641;
  t240_n11: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t240_n203;
  t240_n12: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t240_n128;
  t240_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t240_n33;
  t240_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t240_n22;
  t240_n15: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t240_n17;
  t240_n16: return -0.006280119530856609;
  t240_n17: if (E.getNumReferences() >= 3265265664 /*80.0*/) goto t240_n21;
  t240_n18: if (E.getNumReferences() >= 3262119936 /*60.0*/) goto t240_n20;
  t240_n19: return -0.4754709303379059;
  t240_n20: return 0.11628332734107971;
  t240_n21: return -0.023576488718390465;
  t240_n22: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t240_n32;
  t240_n23: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t240_n27;
  t240_n24: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t240_n26;
  t240_n25: return 0.09646379947662354;
  t240_n26: return 0.14275120198726654;
  t240_n27: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t240_n29;
  t240_n28: return -0.07836821675300598;
  t240_n29: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t240_n31;
  t240_n30: return 0.11629479378461838;
  t240_n31: return -0.20922642946243286;
  t240_n32: return 0.021024782210588455;
  t240_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t240_n35;
  t240_n34: return 0.03388875350356102;
  t240_n35: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t240_n123;
  t240_n36: if (E.getNumReferences() >= 3362084992 /*234850.0*/) goto t240_n122;
  t240_n37: if (E.getNumReferences() >= 3357822688 /*168251.5*/) goto t240_n121;
  t240_n38: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t240_n76;
  t240_n39: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n41;
  t240_n40: return 0.04785376042127609;
  t240_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t240_n69;
  t240_n42: if (E.getNumReferences() >= 3291308032 /*693.5*/) goto t240_n66;
  t240_n43: if (E.getNumReferences() >= 3280584704 /*275.5*/) goto t240_n65;
  t240_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t240_n46;
  t240_n45: return -0.12057238817214966;
  t240_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t240_n54;
  t240_n47: if (E.getNumReferences() >= 3277914112 /*225.0*/) goto t240_n53;
  t240_n48: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t240_n50;
  t240_n49: return 0.10285972058773041;
  t240_n50: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t240_n52;
  t240_n51: return 0.09576405584812164;
  t240_n52: return -0.27773338556289673;
  t240_n53: return 0.11043841391801834;
  t240_n54: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t240_n60;
  t240_n55: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t240_n59;
  t240_n56: if (E.getNumReferences() >= 3260416000 /*53.5*/) goto t240_n58;
  t240_n57: return -0.45596399903297424;
  t240_n58: return 0.11644545197486877;
  t240_n59: return -0.1160360649228096;
  t240_n60: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t240_n62;
  t240_n61: return 0.016826007515192032;
  t240_n62: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t240_n64;
  t240_n63: return 0.10202235728502274;
  t240_n64: return 0.04312444478273392;
  t240_n65: return -0.20312952995300293;
  t240_n66: if (E.getNumReferences() >= 3293487104 /*826.5*/) goto t240_n68;
  t240_n67: return 0.1007300615310669;
  t240_n68: return 0.02813171036541462;
  t240_n69: if (E.getNumReferences() >= 3269066752 /*109.0*/) goto t240_n73;
  t240_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n72;
  t240_n71: return 0.013891187496483326;
  t240_n72: return 0.0986388772726059;
  t240_n73: if (E.getNumReferences() >= 3272081408 /*136.0*/) goto t240_n75;
  t240_n74: return 0.12860652804374695;
  t240_n75: return -0.28182411193847656;
  t240_n76: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t240_n78;
  t240_n77: return 0.10147961229085922;
  t240_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t240_n116;
  t240_n79: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t240_n81;
  t240_n80: return -0.2383030205965042;
  t240_n81: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t240_n83;
  t240_n82: return 0.08572627604007721;
  t240_n83: if (E.getNumReferences() >= 3283517440 /*365.0*/) goto t240_n107;
  t240_n84: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t240_n92;
  t240_n85: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t240_n89;
  t240_n86: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t240_n88;
  t240_n87: return -0.4302809536457062;
  t240_n88: return 0.0822673812508583;
  t240_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n91;
  t240_n90: return -0.5599217414855957;
  t240_n91: return 0.052474021911621094;
  t240_n92: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t240_n94;
  t240_n93: return 0.11027955263853073;
  t240_n94: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t240_n106;
  t240_n95: if (E.getNumReferences() >= 3277783040 /*223.0*/) goto t240_n105;
  t240_n96: if (E.getNumReferences() >= 3273588736 /*159.0*/) goto t240_n100;
  t240_n97: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t240_n99;
  t240_n98: return -0.2743324041366577;
  t240_n99: return 0.08371678739786148;
  t240_n100: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t240_n102;
  t240_n101: return 0.09931459277868271;
  t240_n102: if (E.getNumReferences() >= 3276079104 /*197.0*/) goto t240_n104;
  t240_n103: return -0.3757486343383789;
  t240_n104: return 0.07312420010566711;
  t240_n105: return -0.1498406082391739;
  t240_n106: return 0.1041615679860115;
  t240_n107: if (E.getNumReferences() >= 3307436032 /*2615.5*/) goto t240_n109;
  t240_n108: return -0.1610880196094513;
  t240_n109: if (E.getNumReferences() >= 3315365888 /*5007.0*/) goto t240_n113;
  t240_n110: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t240_n112;
  t240_n111: return 0.08923061937093735;
  t240_n112: return 0.11913466453552246;
  t240_n113: if (E.getNumReferences() >= 3330320640 /*16468.5*/) goto t240_n115;
  t240_n114: return -0.8525256514549255;
  t240_n115: return 0.0012525112833827734;
  t240_n116: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t240_n118;
  t240_n117: return 0.10337620973587036;
  t240_n118: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t240_n120;
  t240_n119: return 0.08281085640192032;
  t240_n120: return -0.43004146218299866;
  t240_n121: return -0.3988597095012665;
  t240_n122: return 0.05107990652322769;
  t240_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n127;
  t240_n124: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t240_n126;
  t240_n125: return -0.11085085570812225;
  t240_n126: return 0.021015707403421402;
  t240_n127: return -0.021317118778824806;
  t240_n128: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t240_n130;
  t240_n129: return 0.017718298360705376;
  t240_n130: if (E.getNumReferences() >= 3331557888 /*18885.0*/) goto t240_n192;
  t240_n131: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t240_n143;
  t240_n132: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n142;
  t240_n133: if (E.getNumReferences() >= 3310508032 /*3365.5*/) goto t240_n141;
  t240_n134: if (E.getNumReferences() >= 3285663744 /*430.5*/) goto t240_n136;
  t240_n135: return -0.3967925012111664;
  t240_n136: if (E.getNumReferences() >= 3291455488 /*702.5*/) goto t240_n138;
  t240_n137: return 0.1056346446275711;
  t240_n138: if (E.getNumReferences() >= 3309215744 /*3050.0*/) goto t240_n140;
  t240_n139: return -0.3425101935863495;
  t240_n140: return 0.09051606804132462;
  t240_n141: return -0.7534515261650085;
  t240_n142: return -0.03908267244696617;
  t240_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t240_n179;
  t240_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t240_n176;
  t240_n145: if (E.getNumReferences() >= 3324132864 /*10383.5*/) goto t240_n175;
  t240_n146: if (E.getNumReferences() >= 3323790336 /*10049.0*/) goto t240_n174;
  t240_n147: if (E.getNumReferences() >= 3322210304 /*8506.0*/) goto t240_n173;
  t240_n148: if (E.getNumReferences() >= 3319786496 /*7165.5*/) goto t240_n170;
  t240_n149: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n151;
  t240_n150: return -0.02533995360136032;
  t240_n151: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t240_n169;
  t240_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n162;
  t240_n153: if (E.getNumReferences() >= 3281764352 /*311.5*/) goto t240_n155;
  t240_n154: return -0.2770109176635742;
  t240_n155: if (E.getNumReferences() >= 3294363648 /*880.0*/) goto t240_n157;
  t240_n156: return 0.10335253179073334;
  t240_n157: if (E.getNumReferences() >= 3301511168 /*1608.5*/) goto t240_n159;
  t240_n158: return -0.05996205285191536;
  t240_n159: if (E.getNumReferences() >= 3312558080 /*3866.0*/) goto t240_n161;
  t240_n160: return 0.10640125721693039;
  t240_n161: return -0.11487974226474762;
  t240_n162: if (E.getNumReferences() >= 3283369984 /*360.5*/) goto t240_n168;
  t240_n163: if (E.getNumReferences() >= 3281682432 /*309.0*/) goto t240_n167;
  t240_n164: if (E.getNumReferences() >= 3271950336 /*134.0*/) goto t240_n166;
  t240_n165: return 0.08097883313894272;
  t240_n166: return -0.3058198094367981;
  t240_n167: return 0.12463012337684631;
  t240_n168: return -0.07816372066736221;
  t240_n169: return -0.04142913967370987;
  t240_n170: if (E.getNumReferences() >= 3321036800 /*7776.0*/) goto t240_n172;
  t240_n171: return 0.11606843769550323;
  t240_n172: return -0.1188897043466568;
  t240_n173: return -0.30716222524642944;
  t240_n174: return 0.08669893443584442;
  t240_n175: return -0.09565165638923645;
  t240_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t240_n178;
  t240_n177: return 0.05893312767148018;
  t240_n178: return 0.10989690572023392;
  t240_n179: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t240_n191;
  t240_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n186;
  t240_n181: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t240_n185;
  t240_n182: if (E.getNumReferences() >= 3269197824 /*110.0*/) goto t240_n184;
  t240_n183: return -0.42099931836128235;
  t240_n184: return 0.09490638226270676;
  t240_n185: return -0.36597150564193726;
  t240_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n188;
  t240_n187: return 0.02067597024142742;
  t240_n188: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t240_n190;
  t240_n189: return -0.706843376159668;
  t240_n190: return -0.0604146271944046;
  t240_n191: return -0.02529534511268139;
  t240_n192: if (E.getNumReferences() >= 3332209408 /*20157.5*/) goto t240_n202;
  t240_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n201;
  t240_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t240_n200;
  t240_n195: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t240_n199;
  t240_n196: if (E.getNumReferences() >= 3331918592 /*19589.5*/) goto t240_n198;
  t240_n197: return 0.19412000477313995;
  t240_n198: return 0.013597289100289345;
  t240_n199: return 0.1126006543636322;
  t240_n200: return -0.06878284364938736;
  t240_n201: return -0.3329028785228729;
  t240_n202: return 0.00013901761849410832;
  t240_n203: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t240_n207;
  t240_n204: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t240_n206;
  t240_n205: return -0.021633341908454895;
  t240_n206: return 0.19809651374816895;
  t240_n207: if (E.getNumReferences() >= 3341718784 /*44693.0*/) goto t240_n209;
  t240_n208: return 0.006289023440331221;
  t240_n209: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t240_n233;
  t240_n210: if (E.getNumReferences() >= 3346296960 /*62576.5*/) goto t240_n220;
  t240_n211: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t240_n219;
  t240_n212: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t240_n216;
  t240_n213: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n215;
  t240_n214: return 0.08714669197797775;
  t240_n215: return 0.027704352512955666;
  t240_n216: if (E.getNumReferences() >= 3343032192 /*49823.5*/) goto t240_n218;
  t240_n217: return -0.30379414558410645;
  t240_n218: return 0.1191243901848793;
  t240_n219: return 0.06077314168214798;
  t240_n220: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t240_n228;
  t240_n221: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t240_n223;
  t240_n222: return -0.024538015946745872;
  t240_n223: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n227;
  t240_n224: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t240_n226;
  t240_n225: return -0.18491016328334808;
  t240_n226: return 0.09216825664043427;
  t240_n227: return 0.0049872430972754955;
  t240_n228: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t240_n232;
  t240_n229: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t240_n231;
  t240_n230: return 0.028698090463876724;
  t240_n231: return 0.08901993930339813;
  t240_n232: return 0.020085005089640617;
  t240_n233: return 0.010349598713219166;
  t240_n234: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t240_n236;
  t240_n235: return -0.0006645562825724483;
  t240_n236: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t240_n238;
  t240_n237: return 0.03328157588839531;
  t240_n238: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t240_n254;
  t240_n239: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t240_n243;
  t240_n240: if (E.getNumReferences() >= 3260153856 /*52.5*/) goto t240_n242;
  t240_n241: return -0.08701115101575851;
  t240_n242: return 0.1459837555885315;
  t240_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t240_n249;
  t240_n244: if (E.getNumReferences() >= 3288834048 /*542.5*/) goto t240_n246;
  t240_n245: return 0.06893644481897354;
  t240_n246: if (E.getNumReferences() >= 3305973760 /*2258.5*/) goto t240_n248;
  t240_n247: return 0.14952890574932098;
  t240_n248: return 0.11020484566688538;
  t240_n249: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t240_n251;
  t240_n250: return 0.003554086433723569;
  t240_n251: if (E.getNumReferences() >= 3315506176 /*5075.5*/) goto t240_n253;
  t240_n252: return 0.13049198687076569;
  t240_n253: return 0.10072603076696396;
  t240_n254: return 0.044840335845947266;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree241(const Example& E) {
  t241_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t241_n2;
  t241_n1: return -0.00031889279489405453;
  t241_n2: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t241_n254;
  t241_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t241_n23;
  t241_n4: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t241_n16;
  t241_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression))) goto t241_n7;
  t241_n6: return 0.0030734564643353224;
  t241_n7: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t241_n9;
  t241_n8: return 0.011034179478883743;
  t241_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n11;
  t241_n10: return 0.02268020249903202;
  t241_n11: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t241_n13;
  t241_n12: return 0.08460575342178345;
  t241_n13: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n15;
  t241_n14: return 0.11321432888507843;
  t241_n15: return 0.012118586339056492;
  t241_n16: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t241_n22;
  t241_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t241_n19;
  t241_n18: return 0.049503762274980545;
  t241_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n21;
  t241_n20: return 0.10452258586883545;
  t241_n21: return -0.23941659927368164;
  t241_n22: return 0.013390183448791504;
  t241_n23: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t241_n25;
  t241_n24: return 0.005121992435306311;
  t241_n25: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t241_n37;
  t241_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t241_n36;
  t241_n27: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t241_n35;
  t241_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n30;
  t241_n29: return -0.010323172435164452;
  t241_n30: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n34;
  t241_n31: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t241_n33;
  t241_n32: return -0.30521318316459656;
  t241_n33: return -0.0834137499332428;
  t241_n34: return -0.049566641449928284;
  t241_n35: return 0.09970404952764511;
  t241_n36: return -0.0060514602810144424;
  t241_n37: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t241_n169;
  t241_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t241_n164;
  t241_n39: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t241_n77;
  t241_n40: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t241_n60;
  t241_n41: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n59;
  t241_n42: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t241_n44;
  t241_n43: return -0.06306396424770355;
  t241_n44: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n48;
  t241_n45: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t241_n47;
  t241_n46: return 0.07520659267902374;
  t241_n47: return -0.03359297662973404;
  t241_n48: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n54;
  t241_n49: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t241_n53;
  t241_n50: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n52;
  t241_n51: return 0.03425564989447594;
  t241_n52: return -0.5554457902908325;
  t241_n53: return -0.43309375643730164;
  t241_n54: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t241_n56;
  t241_n55: return 0.01741253398358822;
  t241_n56: if (E.getNumReferences() >= 3250585600 /*24.0*/) goto t241_n58;
  t241_n57: return 0.11048698425292969;
  t241_n58: return 0.02742314152419567;
  t241_n59: return -0.12922370433807373;
  t241_n60: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t241_n76;
  t241_n61: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n71;
  t241_n62: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t241_n64;
  t241_n63: return -0.16172197461128235;
  t241_n64: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t241_n66;
  t241_n65: return 0.14386136829853058;
  t241_n66: if (E.getNumReferences() >= 3252158464 /*27.0*/) goto t241_n70;
  t241_n67: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t241_n69;
  t241_n68: return -0.12075906246900558;
  t241_n69: return 0.1023542508482933;
  t241_n70: return -0.11917737126350403;
  t241_n71: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n73;
  t241_n72: return 0.11289621889591217;
  t241_n73: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t241_n75;
  t241_n74: return -0.1231093779206276;
  t241_n75: return 0.07695458829402924;
  t241_n76: return 0.10074523836374283;
  t241_n77: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t241_n131;
  t241_n78: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t241_n112;
  t241_n79: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t241_n85;
  t241_n80: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t241_n84;
  t241_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n83;
  t241_n82: return -0.06691452860832214;
  t241_n83: return -0.005183847155421972;
  t241_n84: return 0.0830283984541893;
  t241_n85: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t241_n95;
  t241_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t241_n92;
  t241_n87: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t241_n91;
  t241_n88: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t241_n90;
  t241_n89: return -0.13518522679805756;
  t241_n90: return 0.10290350764989853;
  t241_n91: return 0.09870067983865738;
  t241_n92: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t241_n94;
  t241_n93: return 0.06434974074363708;
  t241_n94: return -0.37314674258232117;
  t241_n95: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n97;
  t241_n96: return -0.060244474560022354;
  t241_n97: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t241_n99;
  t241_n98: return -0.08180879056453705;
  t241_n99: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t241_n109;
  t241_n100: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t241_n104;
  t241_n101: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t241_n103;
  t241_n102: return 0.07510316371917725;
  t241_n103: return 0.11504116654396057;
  t241_n104: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t241_n108;
  t241_n105: if (E.getNumReferences() >= 3289014272 /*553.5*/) goto t241_n107;
  t241_n106: return 0.08797058463096619;
  t241_n107: return 0.04999915510416031;
  t241_n108: return 0.006032351870089769;
  t241_n109: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t241_n111;
  t241_n110: return 0.0746794044971466;
  t241_n111: return -0.4367775619029999;
  t241_n112: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n126;
  t241_n113: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t241_n115;
  t241_n114: return 0.005553332157433033;
  t241_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t241_n119;
  t241_n116: if (E.getNumReferences() >= 3325290496 /*11514.0*/) goto t241_n118;
  t241_n117: return -0.022771397605538368;
  t241_n118: return 0.07443307340145111;
  t241_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n123;
  t241_n120: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t241_n122;
  t241_n121: return 0.09269339591264725;
  t241_n122: return 0.04285329207777977;
  t241_n123: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t241_n125;
  t241_n124: return 0.03931164741516113;
  t241_n125: return 0.1271916627883911;
  t241_n126: if (E.getNumReferences() >= 3277357056 /*216.5*/) goto t241_n128;
  t241_n127: return -0.009314036928117275;
  t241_n128: if (E.getNumReferences() >= 3298672640 /*1262.0*/) goto t241_n130;
  t241_n129: return -0.6297067999839783;
  t241_n130: return -0.03177985921502113;
  t241_n131: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n139;
  t241_n132: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t241_n138;
  t241_n133: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t241_n137;
  t241_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t241_n136;
  t241_n135: return 0.46274012327194214;
  t241_n136: return 0.018629413098096848;
  t241_n137: return 0.12678535282611847;
  t241_n138: return 0.011360838077962399;
  t241_n139: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t241_n145;
  t241_n140: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t241_n142;
  t241_n141: return -0.05360225588083267;
  t241_n142: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t241_n144;
  t241_n143: return 0.09890687465667725;
  t241_n144: return 0.0696510598063469;
  t241_n145: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t241_n157;
  t241_n146: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t241_n156;
  t241_n147: if (E.getNumReferences() >= 3296755712 /*1028.0*/) goto t241_n153;
  t241_n148: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t241_n150;
  t241_n149: return 0.11691572517156601;
  t241_n150: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t241_n152;
  t241_n151: return -0.3818754553794861;
  t241_n152: return -0.03652709722518921;
  t241_n153: if (E.getNumReferences() >= 3342540544 /*47903.0*/) goto t241_n155;
  t241_n154: return 0.11752401292324066;
  t241_n155: return 0.06260769814252853;
  t241_n156: return 0.047910548746585846;
  t241_n157: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t241_n163;
  t241_n158: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t241_n162;
  t241_n159: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n161;
  t241_n160: return 0.11714202165603638;
  t241_n161: return 0.029578587040305138;
  t241_n162: return 0.045789819210767746;
  t241_n163: return -0.0377354621887207;
  t241_n164: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t241_n168;
  t241_n165: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t241_n167;
  t241_n166: return 0.10153556615114212;
  t241_n167: return 0.043062347918748856;
  t241_n168: return 0.21241040527820587;
  t241_n169: if (E.getNumReferences() >= 3269066752 /*109.0*/) goto t241_n225;
  t241_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t241_n178;
  t241_n171: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t241_n173;
  t241_n172: return -0.021858589723706245;
  t241_n173: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t241_n177;
  t241_n174: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t241_n176;
  t241_n175: return -0.1266472488641739;
  t241_n176: return 0.006181780248880386;
  t241_n177: return 0.05839533731341362;
  t241_n178: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t241_n200;
  t241_n179: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t241_n197;
  t241_n180: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t241_n192;
  t241_n181: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t241_n189;
  t241_n182: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t241_n188;
  t241_n183: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t241_n185;
  t241_n184: return -0.4096609652042389;
  t241_n185: if (E.getFileProximityDistance() >= 3238002688 /*8.0*/) goto t241_n187;
  t241_n186: return 0.3862212598323822;
  t241_n187: return -0.13556452095508575;
  t241_n188: return -0.014235349372029305;
  t241_n189: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t241_n191;
  t241_n190: return -0.1755097657442093;
  t241_n191: return 0.04348307475447655;
  t241_n192: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t241_n194;
  t241_n193: return 0.09416031837463379;
  t241_n194: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t241_n196;
  t241_n195: return 0.08012592047452927;
  t241_n196: return 0.014102858491241932;
  t241_n197: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t241_n199;
  t241_n198: return -0.8212521076202393;
  t241_n199: return -0.11076177656650543;
  t241_n200: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t241_n206;
  t241_n201: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t241_n205;
  t241_n202: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t241_n204;
  t241_n203: return 0.009225054644048214;
  t241_n204: return 0.13718000054359436;
  t241_n205: return -0.9921821355819702;
  t241_n206: if (E.getNumReferences() >= 3258974208 /*48.0*/) goto t241_n224;
  t241_n207: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t241_n223;
  t241_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t241_n220;
  t241_n209: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t241_n217;
  t241_n210: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t241_n212;
  t241_n211: return 0.08332151919603348;
  t241_n212: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t241_n214;
  t241_n213: return -0.04729318246245384;
  t241_n214: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t241_n216;
  t241_n215: return 0.042762573808431625;
  t241_n216: return 0.06317666918039322;
  t241_n217: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t241_n219;
  t241_n218: return -0.7822275757789612;
  t241_n219: return -0.017977511510252953;
  t241_n220: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t241_n222;
  t241_n221: return 0.10013934224843979;
  t241_n222: return 0.15096499025821686;
  t241_n223: return -0.02739504911005497;
  t241_n224: return 0.11015935987234116;
  t241_n225: if (E.getNumReferences() >= 3289784320 /*600.5*/) goto t241_n239;
  t241_n226: if (E.getNumReferences() >= 3287810048 /*496.0*/) goto t241_n236;
  t241_n227: if (E.getNumReferences() >= 3274014720 /*165.5*/) goto t241_n235;
  t241_n228: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t241_n230;
  t241_n229: return 0.12912246584892273;
  t241_n230: if (E.getNumReferences() >= 3272376320 /*140.5*/) goto t241_n232;
  t241_n231: return -0.060532547533512115;
  t241_n232: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t241_n234;
  t241_n233: return -0.2940422296524048;
  t241_n234: return 0.10365653783082962;
  t241_n235: return -0.012259368784725666;
  t241_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t241_n238;
  t241_n237: return 0.09645882248878479;
  t241_n238: return 0.09397386014461517;
  t241_n239: if (E.getNumReferences() >= 3305295872 /*2093.0*/) goto t241_n247;
  t241_n240: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t241_n246;
  t241_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t241_n245;
  t241_n242: if (E.getNumReferences() >= 3299385344 /*1349.0*/) goto t241_n244;
  t241_n243: return -0.48323705792427063;
  t241_n244: return -1.1121833324432373;
  t241_n245: return -0.0989876314997673;
  t241_n246: return 0.05183260887861252;
  t241_n247: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t241_n251;
  t241_n248: if (E.getNumReferences() >= 3306676224 /*2430.0*/) goto t241_n250;
  t241_n249: return 0.10444844514131546;
  t241_n250: return 0.09511885046958923;
  t241_n251: if (E.getNumReferences() >= 3325117440 /*11345.0*/) goto t241_n253;
  t241_n252: return -0.25829365849494934;
  t241_n253: return 0.07775874435901642;
  t241_n254: return -0.0003493283875286579;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree242(const Example& E) {
  t242_n0: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t242_n2;
  t242_n1: return -0.0004759879084303975;
  t242_n2: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t242_n180;
  t242_n3: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t242_n81;
  t242_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t242_n6;
  t242_n5: return 0.003826610976830125;
  t242_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t242_n74;
  t242_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n21;
  t242_n8: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t242_n20;
  t242_n9: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t242_n11;
  t242_n10: return 0.01226250734180212;
  t242_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t242_n13;
  t242_n12: return -0.10197734832763672;
  t242_n13: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n19;
  t242_n14: if (E.getNumReferences() >= 3275751424 /*192.0*/) goto t242_n18;
  t242_n15: if (E.getNumReferences() >= 3266641920 /*90.5*/) goto t242_n17;
  t242_n16: return 0.01774969883263111;
  t242_n17: return 0.10950680077075958;
  t242_n18: return -0.1168958768248558;
  t242_n19: return -0.3354310989379883;
  t242_n20: return -0.13776348531246185;
  t242_n21: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t242_n73;
  t242_n22: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t242_n56;
  t242_n23: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n25;
  t242_n24: return -0.08577151596546173;
  t242_n25: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t242_n35;
  t242_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t242_n32;
  t242_n27: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t242_n31;
  t242_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t242_n30;
  t242_n29: return -0.824708878993988;
  t242_n30: return -0.1876383125782013;
  t242_n31: return -0.010720578022301197;
  t242_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n34;
  t242_n33: return -0.2424316257238388;
  t242_n34: return 0.12780441343784332;
  t242_n35: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t242_n39;
  t242_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t242_n38;
  t242_n37: return 0.029840027913451195;
  t242_n38: return 0.11760036647319794;
  t242_n39: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t242_n41;
  t242_n40: return -0.04387642815709114;
  t242_n41: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t242_n47;
  t242_n42: if (E.getNumReferences() >= 3274178560 /*168.0*/) goto t242_n46;
  t242_n43: if (E.getNumReferences() >= 3273293824 /*154.5*/) goto t242_n45;
  t242_n44: return 0.0936851054430008;
  t242_n45: return 0.024105727672576904;
  t242_n46: return 0.11770384013652802;
  t242_n47: if (E.getNumReferences() >= 3275620352 /*190.0*/) goto t242_n49;
  t242_n48: return -0.6160053610801697;
  t242_n49: if (E.getNumReferences() >= 3275948032 /*195.0*/) goto t242_n51;
  t242_n50: return 0.09475556015968323;
  t242_n51: if (E.getNumReferences() >= 3278077952 /*227.5*/) goto t242_n53;
  t242_n52: return -0.2309671938419342;
  t242_n53: if (E.getNumReferences() >= 3280044032 /*259.0*/) goto t242_n55;
  t242_n54: return 0.10431579500436783;
  t242_n55: return 0.03978181630373001;
  t242_n56: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t242_n66;
  t242_n57: if (E.getNumReferences() >= 3266510848 /*89.5*/) goto t242_n61;
  t242_n58: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t242_n60;
  t242_n59: return 0.0027261136565357447;
  t242_n60: return 0.12948425114154816;
  t242_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n63;
  t242_n62: return -0.03820207715034485;
  t242_n63: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t242_n65;
  t242_n64: return 0.10605953633785248;
  t242_n65: return 0.0008893201593309641;
  t242_n66: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t242_n68;
  t242_n67: return 0.11801600456237793;
  t242_n68: if (E.getNumReferences() >= 3295485952 /*948.5*/) goto t242_n70;
  t242_n69: return -0.1886707842350006;
  t242_n70: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t242_n72;
  t242_n71: return 0.1041620597243309;
  t242_n72: return 0.110979825258255;
  t242_n73: return 0.014157609082758427;
  t242_n74: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t242_n76;
  t242_n75: return 0.029648326337337494;
  t242_n76: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t242_n78;
  t242_n77: return -0.20731233060359955;
  t242_n78: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t242_n80;
  t242_n79: return 0.13193732500076294;
  t242_n80: return -0.07842736691236496;
  t242_n81: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t242_n177;
  t242_n82: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t242_n84;
  t242_n83: return -0.007396592292934656;
  t242_n84: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t242_n86;
  t242_n85: return 0.016364455223083496;
  t242_n86: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t242_n138;
  t242_n87: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t242_n133;
  t242_n88: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t242_n94;
  t242_n89: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n93;
  t242_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t242_n92;
  t242_n91: return -0.12205569446086884;
  t242_n92: return 0.4533081352710724;
  t242_n93: return 0.1093655675649643;
  t242_n94: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t242_n116;
  t242_n95: if (E.getNumReferences() >= 3270967296 /*123.5*/) goto t242_n115;
  t242_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t242_n98;
  t242_n97: return -0.11001890897750854;
  t242_n98: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t242_n106;
  t242_n99: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t242_n101;
  t242_n100: return -0.016758233308792114;
  t242_n101: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t242_n105;
  t242_n102: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t242_n104;
  t242_n103: return 0.39730966091156006;
  t242_n104: return 0.11711296439170837;
  t242_n105: return 0.1177123561501503;
  t242_n106: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t242_n112;
  t242_n107: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t242_n111;
  t242_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t242_n110;
  t242_n109: return 0.10546103119850159;
  t242_n110: return 0.09514773637056351;
  t242_n111: return -0.2045021504163742;
  t242_n112: if (E.getNumReferences() >= 3269328896 /*111.0*/) goto t242_n114;
  t242_n113: return -0.07458905130624771;
  t242_n114: return 0.11988051980733871;
  t242_n115: return 0.1319401115179062;
  t242_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t242_n118;
  t242_n117: return -0.027810320258140564;
  t242_n118: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t242_n120;
  t242_n119: return -0.10649131238460541;
  t242_n120: if (E.getNumReferences() >= 3273850880 /*163.0*/) goto t242_n124;
  t242_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t242_n123;
  t242_n122: return -0.10755404829978943;
  t242_n123: return 0.10549180954694748;
  t242_n124: if (E.getNumReferences() >= 3287580672 /*489.0*/) goto t242_n128;
  t242_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t242_n127;
  t242_n126: return -0.047495026141405106;
  t242_n127: return 0.22140797972679138;
  t242_n128: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t242_n132;
  t242_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t242_n131;
  t242_n130: return 0.11127340793609619;
  t242_n131: return 0.09917575120925903;
  t242_n132: return 0.05608639866113663;
  t242_n133: if (E.getNumReferences() >= 3318054912 /*6320.0*/) goto t242_n135;
  t242_n134: return 0.007940681651234627;
  t242_n135: if (E.getNumReferences() >= 3319092224 /*6826.5*/) goto t242_n137;
  t242_n136: return 0.1779320389032364;
  t242_n137: return 0.04571641981601715;
  t242_n138: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t242_n158;
  t242_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t242_n151;
  t242_n140: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t242_n142;
  t242_n141: return 0.005732151214033365;
  t242_n142: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t242_n150;
  t242_n143: if (E.getNumReferences() >= 3264020480 /*70.5*/) goto t242_n149;
  t242_n144: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t242_n146;
  t242_n145: return -0.10489640384912491;
  t242_n146: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t242_n148;
  t242_n147: return 0.11532219499349594;
  t242_n148: return -0.07451590150594711;
  t242_n149: return 0.11027500033378601;
  t242_n150: return 0.02755456231534481;
  t242_n151: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t242_n153;
  t242_n152: return -0.19179879128932953;
  t242_n153: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t242_n155;
  t242_n154: return 0.10716381669044495;
  t242_n155: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t242_n157;
  t242_n156: return 0.05614479258656502;
  t242_n157: return 0.10998804867267609;
  t242_n158: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t242_n162;
  t242_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t242_n161;
  t242_n160: return 0.01232842542231083;
  t242_n161: return 0.12131825089454651;
  t242_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t242_n170;
  t242_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t242_n165;
  t242_n164: return -0.03403427451848984;
  t242_n165: if (E.getNumReferences() >= 3290537984 /*646.5*/) goto t242_n169;
  t242_n166: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t242_n168;
  t242_n167: return 0.019937114790081978;
  t242_n168: return 0.12404908984899521;
  t242_n169: return -0.11405602842569351;
  t242_n170: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t242_n174;
  t242_n171: if (E.getNumReferences() >= 3276570624 /*204.5*/) goto t242_n173;
  t242_n172: return 0.10040375590324402;
  t242_n173: return 0.05527634546160698;
  t242_n174: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t242_n176;
  t242_n175: return 0.12809059023857117;
  t242_n176: return -0.3986850678920746;
  t242_n177: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t242_n179;
  t242_n178: return -0.004274423699826002;
  t242_n179: return 0.007294195704162121;
  t242_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t242_n184;
  t242_n181: if (E.getNumReferences() >= 3319477248 /*7014.5*/) goto t242_n183;
  t242_n182: return -0.03101371042430401;
  t242_n183: return 0.03001571260392666;
  t242_n184: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t242_n186;
  t242_n185: return 0.021812953054904938;
  t242_n186: if (E.getNumReferences() >= 3290316800 /*633.0*/) goto t242_n230;
  t242_n187: if (E.getNumReferences() >= 3289153536 /*562.0*/) goto t242_n213;
  t242_n188: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t242_n206;
  t242_n189: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t242_n205;
  t242_n190: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t242_n198;
  t242_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t242_n193;
  t242_n192: return 0.09175601601600647;
  t242_n193: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t242_n195;
  t242_n194: return -0.26476964354515076;
  t242_n195: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t242_n197;
  t242_n196: return 0.1748036891222;
  t242_n197: return 0.024145212024450302;
  t242_n198: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t242_n200;
  t242_n199: return -0.13450616598129272;
  t242_n200: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t242_n204;
  t242_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t242_n203;
  t242_n202: return -0.11206885427236557;
  t242_n203: return 0.14191827178001404;
  t242_n204: return -0.11878100782632828;
  t242_n205: return -0.03853902220726013;
  t242_n206: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t242_n210;
  t242_n207: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t242_n209;
  t242_n208: return 0.030464615672826767;
  t242_n209: return 0.0439116433262825;
  t242_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t242_n212;
  t242_n211: return -0.3010175824165344;
  t242_n212: return 0.08832195401191711;
  t242_n213: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t242_n225;
  t242_n214: if (E.getNumReferences() >= 3289210880 /*565.5*/) goto t242_n216;
  t242_n215: return 0.12431932985782623;
  t242_n216: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t242_n218;
  t242_n217: return -0.02070598304271698;
  t242_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t242_n220;
  t242_n219: return 0.0933123230934143;
  t242_n220: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t242_n224;
  t242_n221: if (E.getNumReferences() >= 3289735168 /*597.5*/) goto t242_n223;
  t242_n222: return 0.06162954866886139;
  t242_n223: return 0.11079247295856476;
  t242_n224: return -0.0075329928658902645;
  t242_n225: if (E.getNumReferences() >= 3289374720 /*575.5*/) goto t242_n227;
  t242_n226: return 0.14513441920280457;
  t242_n227: if (E.getFilterLength() >= 3247177728 /*17.5*/) goto t242_n229;
  t242_n228: return 0.1002577468752861;
  t242_n229: return 0.10810086876153946;
  t242_n230: if (E.getNumReferences() >= 3308015616 /*2757.0*/) goto t242_n232;
  t242_n231: return -0.020037777721881866;
  t242_n232: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t242_n250;
  t242_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t242_n235;
  t242_n234: return 0.00937426183372736;
  t242_n235: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t242_n249;
  t242_n236: if (E.getNumReferences() >= 3318737920 /*6653.5*/) goto t242_n244;
  t242_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t242_n243;
  t242_n238: if (E.getNumReferences() >= 3310948352 /*3473.0*/) goto t242_n240;
  t242_n239: return 0.11846938729286194;
  t242_n240: if (E.getNumReferences() >= 3315686400 /*5163.5*/) goto t242_n242;
  t242_n241: return -0.015767790377140045;
  t242_n242: return 0.08829144388437271;
  t242_n243: return -0.04678162932395935;
  t242_n244: if (E.getNumReferences() >= 3319330816 /*6943.0*/) goto t242_n246;
  t242_n245: return 0.12276113033294678;
  t242_n246: if (E.getNumReferences() >= 3346507648 /*63399.5*/) goto t242_n248;
  t242_n247: return 0.08637462556362152;
  t242_n248: return -0.36267808079719543;
  t242_n249: return 0.045882321894168854;
  t242_n250: if (E.getNumReferences() >= 3308521472 /*2880.5*/) goto t242_n254;
  t242_n251: if (E.getNumReferences() >= 3308406784 /*2852.5*/) goto t242_n253;
  t242_n252: return 0.02250438556075096;
  t242_n253: return 0.13372932374477386;
  t242_n254: return 0.009136805310845375;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree243(const Example& E) {
  t243_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t243_n114;
  t243_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t243_n3;
  t243_n2: return -0.014291533268988132;
  t243_n3: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t243_n5;
  t243_n4: return -0.0005509261391125619;
  t243_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t243_n23;
  t243_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t243_n20;
  t243_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n17;
  t243_n8: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t243_n12;
  t243_n9: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t243_n11;
  t243_n10: return -0.10391980409622192;
  t243_n11: return 1.1342415809631348;
  t243_n12: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t243_n14;
  t243_n13: return 0.13612185418605804;
  t243_n14: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t243_n16;
  t243_n15: return 0.10808280855417252;
  t243_n16: return 0.05430961027741432;
  t243_n17: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t243_n19;
  t243_n18: return 0.12031567841768265;
  t243_n19: return -0.3301578760147095;
  t243_n20: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t243_n22;
  t243_n21: return 0.02162541076540947;
  t243_n22: return 0.009455448016524315;
  t243_n23: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t243_n111;
  t243_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n26;
  t243_n25: return -0.0033411122858524323;
  t243_n26: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t243_n28;
  t243_n27: return 0.014438895508646965;
  t243_n28: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t243_n56;
  t243_n29: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t243_n43;
  t243_n30: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t243_n42;
  t243_n31: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t243_n33;
  t243_n32: return -0.19664739072322845;
  t243_n33: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n41;
  t243_n34: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n36;
  t243_n35: return 0.055700648576021194;
  t243_n36: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t243_n40;
  t243_n37: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t243_n39;
  t243_n38: return -0.12449770420789719;
  t243_n39: return 0.09992267191410065;
  t243_n40: return 0.05022849515080452;
  t243_n41: return 0.05698341131210327;
  t243_n42: return -0.013981223106384277;
  t243_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n55;
  t243_n44: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t243_n48;
  t243_n45: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t243_n47;
  t243_n46: return 0.027302047237753868;
  t243_n47: return 0.10574794560670853;
  t243_n48: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t243_n54;
  t243_n49: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t243_n51;
  t243_n50: return 0.032823849469423294;
  t243_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t243_n53;
  t243_n52: return 0.1069963127374649;
  t243_n53: return -0.1182061955332756;
  t243_n54: return -0.007231312338262796;
  t243_n55: return 0.0027437659446150064;
  t243_n56: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t243_n86;
  t243_n57: if (E.getNumReferences() >= 3317581824 /*6089.0*/) goto t243_n79;
  t243_n58: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t243_n78;
  t243_n59: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t243_n65;
  t243_n60: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t243_n62;
  t243_n61: return 0.05645768716931343;
  t243_n62: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n64;
  t243_n63: return 0.11663532257080078;
  t243_n64: return -0.10207562893629074;
  t243_n65: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t243_n67;
  t243_n66: return 0.12864680588245392;
  t243_n67: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t243_n71;
  t243_n68: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t243_n70;
  t243_n69: return 0.07577745616436005;
  t243_n70: return 0.11221788078546524;
  t243_n71: if (E.getNumReferences() >= 3272540160 /*143.0*/) goto t243_n77;
  t243_n72: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t243_n74;
  t243_n73: return -0.1103539988398552;
  t243_n74: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t243_n76;
  t243_n75: return -0.10405811667442322;
  t243_n76: return 0.1430792212486267;
  t243_n77: return 0.10389986634254456;
  t243_n78: return 0.009411065839231014;
  t243_n79: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t243_n85;
  t243_n80: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t243_n82;
  t243_n81: return 0.15151536464691162;
  t243_n82: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t243_n84;
  t243_n83: return -0.10495420545339584;
  t243_n84: return 0.10743152350187302;
  t243_n85: return 0.052397504448890686;
  t243_n86: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t243_n100;
  t243_n87: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t243_n89;
  t243_n88: return -0.04555375128984451;
  t243_n89: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t243_n93;
  t243_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t243_n92;
  t243_n91: return -0.2144087851047516;
  t243_n92: return 0.15991081297397614;
  t243_n93: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t243_n95;
  t243_n94: return -0.13069681823253632;
  t243_n95: if (E.getNumReferences() >= 3262906368 /*63.0*/) goto t243_n99;
  t243_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t243_n98;
  t243_n97: return 0.09650484472513199;
  t243_n98: return 0.07841862738132477;
  t243_n99: return 0.04504390060901642;
  t243_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n102;
  t243_n101: return -0.3108496367931366;
  t243_n102: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t243_n104;
  t243_n103: return -0.4520431160926819;
  t243_n104: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t243_n106;
  t243_n105: return -0.1284266859292984;
  t243_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n108;
  t243_n107: return 0.0640367865562439;
  t243_n108: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t243_n110;
  t243_n109: return -0.13704781234264374;
  t243_n110: return 0.1044459268450737;
  t243_n111: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t243_n113;
  t243_n112: return -0.030986500903964043;
  t243_n113: return 0.06695182621479034;
  t243_n114: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t243_n252;
  t243_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t243_n245;
  t243_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t243_n166;
  t243_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t243_n163;
  t243_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t243_n120;
  t243_n119: return 0.0017976780654862523;
  t243_n120: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t243_n162;
  t243_n121: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t243_n157;
  t243_n122: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t243_n134;
  t243_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n133;
  t243_n124: if (E.getNumReferences() >= 3324926976 /*11159.0*/) goto t243_n126;
  t243_n125: return -0.005709650926291943;
  t243_n126: if (E.getNumReferences() >= 3326202880 /*12405.0*/) goto t243_n132;
  t243_n127: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t243_n131;
  t243_n128: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t243_n130;
  t243_n129: return 0.1055377870798111;
  t243_n130: return 0.10520443320274353;
  t243_n131: return 0.0993914008140564;
  t243_n132: return 0.016647033393383026;
  t243_n133: return 0.017875803634524345;
  t243_n134: if (E.getNumReferences() >= 3308414976 /*2854.5*/) goto t243_n146;
  t243_n135: if (E.getNumReferences() >= 3295502336 /*949.5*/) goto t243_n145;
  t243_n136: if (E.getNumReferences() >= 3281895424 /*315.5*/) goto t243_n142;
  t243_n137: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t243_n141;
  t243_n138: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t243_n140;
  t243_n139: return 0.0033077914267778397;
  t243_n140: return -0.04108559712767601;
  t243_n141: return 0.0161689855158329;
  t243_n142: if (E.getNumReferences() >= 3282157568 /*323.5*/) goto t243_n144;
  t243_n143: return 0.11308705061674118;
  t243_n144: return 0.023911116644740105;
  t243_n145: return -0.12551161646842957;
  t243_n146: if (E.getNumReferences() >= 3310059520 /*3256.0*/) goto t243_n154;
  t243_n147: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t243_n149;
  t243_n148: return 0.11764741688966751;
  t243_n149: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t243_n151;
  t243_n150: return 0.009585648775100708;
  t243_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t243_n153;
  t243_n152: return 0.31590190529823303;
  t243_n153: return 0.3004128336906433;
  t243_n154: if (E.getFileProximityDistance() >= 3238002688 /*8.0*/) goto t243_n156;
  t243_n155: return 0.11037294566631317;
  t243_n156: return 0.00491925235837698;
  t243_n157: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n161;
  t243_n158: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t243_n160;
  t243_n159: return 0.05798967555165291;
  t243_n160: return -0.06327749788761139;
  t243_n161: return -0.029953544959425926;
  t243_n162: return -0.026990626007318497;
  t243_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t243_n165;
  t243_n164: return -0.038948219269514084;
  t243_n165: return -0.02800331450998783;
  t243_n166: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t243_n176;
  t243_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t243_n169;
  t243_n168: return -0.0016750250943005085;
  t243_n169: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t243_n171;
  t243_n170: return 0.0004362122272141278;
  t243_n171: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t243_n173;
  t243_n172: return 0.019873708486557007;
  t243_n173: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t243_n175;
  t243_n174: return 0.08645296096801758;
  t243_n175: return 0.0368146151304245;
  t243_n176: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t243_n182;
  t243_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n179;
  t243_n178: return 0.03553200885653496;
  t243_n179: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t243_n181;
  t243_n180: return 0.037773314863443375;
  t243_n181: return 0.0513138473033905;
  t243_n182: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t243_n224;
  t243_n183: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t243_n185;
  t243_n184: return 0.023729586973786354;
  t243_n185: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t243_n193;
  t243_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n192;
  t243_n187: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t243_n189;
  t243_n188: return -0.17837275564670563;
  t243_n189: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t243_n191;
  t243_n190: return 0.10443465411663055;
  t243_n191: return 0.0916736051440239;
  t243_n192: return -0.011968466453254223;
  t243_n193: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n215;
  t243_n194: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t243_n214;
  t243_n195: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t243_n197;
  t243_n196: return 0.027018923312425613;
  t243_n197: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t243_n205;
  t243_n198: if (E.getNumReferences() >= 3344088704 /*53950.5*/) goto t243_n200;
  t243_n199: return 0.11912516504526138;
  t243_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n204;
  t243_n201: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t243_n203;
  t243_n202: return -0.11253441870212555;
  t243_n203: return 0.12185664474964142;
  t243_n204: return -0.5120013356208801;
  t243_n205: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t243_n209;
  t243_n206: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t243_n208;
  t243_n207: return 0.11825064569711685;
  t243_n208: return 0.06693071126937866;
  t243_n209: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n211;
  t243_n210: return 0.041056420654058456;
  t243_n211: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t243_n213;
  t243_n212: return 0.1300847828388214;
  t243_n213: return 0.10001510381698608;
  t243_n214: return -0.008232975378632545;
  t243_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n223;
  t243_n216: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t243_n222;
  t243_n217: if (E.getNumReferences() >= 3333923840 /*23506.0*/) goto t243_n221;
  t243_n218: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t243_n220;
  t243_n219: return -0.13309794664382935;
  t243_n220: return 0.11051501333713531;
  t243_n221: return 0.02886749804019928;
  t243_n222: return 0.10195942223072052;
  t243_n223: return 0.05794066563248634;
  t243_n224: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t243_n236;
  t243_n225: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n227;
  t243_n226: return 0.06696901470422745;
  t243_n227: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t243_n229;
  t243_n228: return 0.054118331521749496;
  t243_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t243_n233;
  t243_n230: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t243_n232;
  t243_n231: return -0.2066965401172638;
  t243_n232: return 0.12663054466247559;
  t243_n233: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t243_n235;
  t243_n234: return 0.28745418787002563;
  t243_n235: return 0.05778895318508148;
  t243_n236: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t243_n238;
  t243_n237: return -0.035839006304740906;
  t243_n238: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t243_n242;
  t243_n239: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t243_n241;
  t243_n240: return 0.07311569899320602;
  t243_n241: return 0.03474023565649986;
  t243_n242: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t243_n244;
  t243_n243: return 0.1476123034954071;
  t243_n244: return 0.10874636471271515;
  t243_n245: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t243_n251;
  t243_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t243_n248;
  t243_n247: return -0.013290917500853539;
  t243_n248: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t243_n250;
  t243_n249: return -0.10172094404697418;
  t243_n250: return 0.063081756234169;
  t243_n251: return 0.009790889918804169;
  t243_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t243_n254;
  t243_n253: return -0.1103893518447876;
  t243_n254: return -0.0005365421529859304;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree244(const Example& E) {
  t244_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t244_n70;
  t244_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t244_n3;
  t244_n2: return 0.0003301998949609697;
  t244_n3: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t244_n67;
  t244_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t244_n50;
  t244_n5: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t244_n39;
  t244_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t244_n8;
  t244_n7: return -0.03369836136698723;
  t244_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t244_n20;
  t244_n9: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n11;
  t244_n10: return -2.4025357561185956e-05;
  t244_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n19;
  t244_n12: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t244_n14;
  t244_n13: return 0.14650844037532806;
  t244_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n16;
  t244_n15: return 0.11384714394807816;
  t244_n16: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t244_n18;
  t244_n17: return -0.06431182473897934;
  t244_n18: return 0.10649868100881577;
  t244_n19: return 0.02011309564113617;
  t244_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n32;
  t244_n21: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t244_n29;
  t244_n22: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t244_n28;
  t244_n23: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t244_n27;
  t244_n24: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n26;
  t244_n25: return 0.02368502877652645;
  t244_n26: return 0.10225816071033478;
  t244_n27: return 1.0298571586608887;
  t244_n28: return -0.3979690372943878;
  t244_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n31;
  t244_n30: return 0.4781031608581543;
  t244_n31: return 0.14136268198490143;
  t244_n32: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t244_n34;
  t244_n33: return -0.03818484768271446;
  t244_n34: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t244_n38;
  t244_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t244_n37;
  t244_n36: return -0.17682458460330963;
  t244_n37: return 0.11422798782587051;
  t244_n38: return 0.07595492154359818;
  t244_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n41;
  t244_n40: return -0.12090957909822464;
  t244_n41: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n43;
  t244_n42: return 0.08227939158678055;
  t244_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t244_n49;
  t244_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n48;
  t244_n45: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t244_n47;
  t244_n46: return 0.15647192299365997;
  t244_n47: return 0.2740269601345062;
  t244_n48: return 0.0814194455742836;
  t244_n49: return 0.0946827232837677;
  t244_n50: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t244_n66;
  t244_n51: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t244_n53;
  t244_n52: return 0.0007919298950582743;
  t244_n53: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n55;
  t244_n54: return 0.015351654030382633;
  t244_n55: if (E.getNumReferences() >= 3282616320 /*337.5*/) goto t244_n61;
  t244_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t244_n60;
  t244_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t244_n59;
  t244_n58: return -0.0800805315375328;
  t244_n59: return 0.019320553168654442;
  t244_n60: return -0.07072221487760544;
  t244_n61: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n63;
  t244_n62: return -0.3905004858970642;
  t244_n63: if (E.getNumReferences() >= 3283795968 /*373.5*/) goto t244_n65;
  t244_n64: return 0.1155547946691513;
  t244_n65: return 0.04623846709728241;
  t244_n66: return 0.018320254981517792;
  t244_n67: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t244_n69;
  t244_n68: return 0.007123477756977081;
  t244_n69: return -0.052703842520713806;
  t244_n70: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t244_n148;
  t244_n71: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t244_n113;
  t244_n72: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n80;
  t244_n73: if (E.getNumReferences() >= 3309346816 /*3082.0*/) goto t244_n75;
  t244_n74: return -0.01450700405985117;
  t244_n75: if (E.getNumReferences() >= 3309430784 /*3102.5*/) goto t244_n79;
  t244_n76: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n78;
  t244_n77: return 0.1951405256986618;
  t244_n78: return 0.1437387615442276;
  t244_n79: return 0.006733370013535023;
  t244_n80: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t244_n100;
  t244_n81: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n91;
  t244_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n84;
  t244_n83: return -0.06972792744636536;
  t244_n84: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t244_n90;
  t244_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t244_n87;
  t244_n86: return 0.00023431057343259454;
  t244_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t244_n89;
  t244_n88: return 0.06310588121414185;
  t244_n89: return 0.10379229485988617;
  t244_n90: return -0.13570536673069;
  t244_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t244_n93;
  t244_n92: return 0.012195263989269733;
  t244_n93: if (E.getNumReferences() >= 3288375296 /*514.5*/) goto t244_n97;
  t244_n94: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t244_n96;
  t244_n95: return -0.3951488733291626;
  t244_n96: return 0.10901526361703873;
  t244_n97: if (E.getNumReferences() >= 3297292288 /*1093.5*/) goto t244_n99;
  t244_n98: return 0.031208543106913567;
  t244_n99: return 0.13518132269382477;
  t244_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t244_n104;
  t244_n101: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t244_n103;
  t244_n102: return 0.015342269092798233;
  t244_n103: return -0.15972721576690674;
  t244_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t244_n110;
  t244_n105: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t244_n107;
  t244_n106: return -0.2941517233848572;
  t244_n107: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n109;
  t244_n108: return 0.03311007842421532;
  t244_n109: return 0.07948721200227737;
  t244_n110: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t244_n112;
  t244_n111: return 0.0961519181728363;
  t244_n112: return 0.04664061218500137;
  t244_n113: if (E.getNumReferences() >= 3297431552 /*1110.5*/) goto t244_n147;
  t244_n114: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t244_n116;
  t244_n115: return -0.18999233841896057;
  t244_n116: if (E.getNumReferences() >= 3297239040 /*1087.0*/) goto t244_n146;
  t244_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n139;
  t244_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n124;
  t244_n119: if (E.getNumReferences() >= 3294199808 /*870.0*/) goto t244_n121;
  t244_n120: return -0.1356641799211502;
  t244_n121: if (E.getNumReferences() >= 3295920128 /*975.0*/) goto t244_n123;
  t244_n122: return 0.5645748972892761;
  t244_n123: return -0.12123937904834747;
  t244_n124: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t244_n134;
  t244_n125: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t244_n127;
  t244_n126: return -0.09795570373535156;
  t244_n127: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t244_n129;
  t244_n128: return 0.10829298198223114;
  t244_n129: if (E.getNumReferences() >= 3285762048 /*433.5*/) goto t244_n131;
  t244_n130: return 0.1174982339143753;
  t244_n131: if (E.getNumReferences() >= 3286564864 /*458.0*/) goto t244_n133;
  t244_n132: return -0.1671314537525177;
  t244_n133: return 0.10250408947467804;
  t244_n134: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n136;
  t244_n135: return -0.13077226281166077;
  t244_n136: if (E.getNumReferences() >= 3293782016 /*844.5*/) goto t244_n138;
  t244_n137: return 0.06490969657897949;
  t244_n138: return 0.1291416883468628;
  t244_n139: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t244_n143;
  t244_n140: if (E.getNumReferences() >= 3285794816 /*434.5*/) goto t244_n142;
  t244_n141: return 0.104634590446949;
  t244_n142: return -0.09637051075696945;
  t244_n143: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t244_n145;
  t244_n144: return 0.1065298393368721;
  t244_n145: return 0.06299653649330139;
  t244_n146: return 0.11427310109138489;
  t244_n147: return -0.03182745352387428;
  t244_n148: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t244_n254;
  t244_n149: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t244_n239;
  t244_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t244_n212;
  t244_n151: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n211;
  t244_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t244_n154;
  t244_n153: return 0.03331127017736435;
  t244_n154: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t244_n156;
  t244_n155: return -0.17457027733325958;
  t244_n156: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t244_n178;
  t244_n157: if (E.getNumReferences() >= 3293093888 /*802.5*/) goto t244_n175;
  t244_n158: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t244_n170;
  t244_n159: if (E.getNumReferences() >= 3289579520 /*588.0*/) goto t244_n169;
  t244_n160: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t244_n164;
  t244_n161: if (E.getNumReferences() >= 3289546752 /*586.0*/) goto t244_n163;
  t244_n162: return -0.12147478759288788;
  t244_n163: return 0.1419927328824997;
  t244_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t244_n168;
  t244_n165: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t244_n167;
  t244_n166: return 0.1344689130783081;
  t244_n167: return -0.702090859413147;
  t244_n168: return 0.228294238448143;
  t244_n169: return -0.022097334265708923;
  t244_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t244_n172;
  t244_n171: return -0.019196704030036926;
  t244_n172: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t244_n174;
  t244_n173: return 0.11944755166769028;
  t244_n174: return 0.05109637230634689;
  t244_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n177;
  t244_n176: return 0.12241429090499878;
  t244_n177: return -0.33031633496284485;
  t244_n178: if (E.getNumReferences() >= 3300868096 /*1530.0*/) goto t244_n180;
  t244_n179: return -0.10437213629484177;
  t244_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t244_n192;
  t244_n181: if (E.getNumReferences() >= 3300925440 /*1537.0*/) goto t244_n183;
  t244_n182: return 0.12238885462284088;
  t244_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t244_n185;
  t244_n184: return -0.04028942063450813;
  t244_n185: if (E.getNumReferences() >= 3318054912 /*6320.0*/) goto t244_n187;
  t244_n186: return 0.11140915006399155;
  t244_n187: if (E.getNumReferences() >= 3319748608 /*7147.0*/) goto t244_n189;
  t244_n188: return 0.20038889348506927;
  t244_n189: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t244_n191;
  t244_n190: return 0.10976547747850418;
  t244_n191: return -0.5514982342720032;
  t244_n192: if (E.getNumReferences() >= 3307524096 /*2637.0*/) goto t244_n202;
  t244_n193: if (E.getNumReferences() >= 3302617088 /*1743.5*/) goto t244_n195;
  t244_n194: return -0.02188606560230255;
  t244_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t244_n201;
  t244_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t244_n200;
  t244_n197: if (E.getNumReferences() >= 3305805824 /*2217.5*/) goto t244_n199;
  t244_n198: return -0.2382974773645401;
  t244_n199: return 0.10288917273283005;
  t244_n200: return 0.13783864676952362;
  t244_n201: return 0.0891818106174469;
  t244_n202: if (E.getNumReferences() >= 3324208128 /*10457.0*/) goto t244_n204;
  t244_n203: return -0.0547371469438076;
  t244_n204: if (E.getNumReferences() >= 3335664640 /*26906.0*/) goto t244_n210;
  t244_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t244_n207;
  t244_n206: return 0.07053167372941971;
  t244_n207: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t244_n209;
  t244_n208: return 0.0990854948759079;
  t244_n209: return 0.12583529949188232;
  t244_n210: return 0.016131166368722916;
  t244_n211: return -0.05708512291312218;
  t244_n212: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t244_n224;
  t244_n213: if (E.getNumReferences() >= 3289677824 /*594.0*/) goto t244_n223;
  t244_n214: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t244_n222;
  t244_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t244_n217;
  t244_n216: return -0.23175247013568878;
  t244_n217: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n221;
  t244_n218: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t244_n220;
  t244_n219: return 0.10314856469631195;
  t244_n220: return 0.06443853676319122;
  t244_n221: return -0.12297823280096054;
  t244_n222: return 0.1117144376039505;
  t244_n223: return 0.11669021844863892;
  t244_n224: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t244_n232;
  t244_n225: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n227;
  t244_n226: return -0.3987245261669159;
  t244_n227: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t244_n231;
  t244_n228: if (E.getNumReferences() >= 3323833856 /*10091.5*/) goto t244_n230;
  t244_n229: return 0.10726531594991684;
  t244_n230: return -0.16552285850048065;
  t244_n231: return -0.004747792612761259;
  t244_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t244_n234;
  t244_n233: return 0.017330963164567947;
  t244_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t244_n236;
  t244_n235: return 0.11179793626070023;
  t244_n236: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t244_n238;
  t244_n237: return -0.23300890624523163;
  t244_n238: return 0.11388379335403442;
  t244_n239: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t244_n243;
  t244_n240: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t244_n242;
  t244_n241: return -0.5118319392204285;
  t244_n242: return 0.09417217969894409;
  t244_n243: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t244_n245;
  t244_n244: return -0.022110674530267715;
  t244_n245: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t244_n253;
  t244_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t244_n248;
  t244_n247: return 0.043006181716918945;
  t244_n248: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t244_n250;
  t244_n249: return -0.003245291067287326;
  t244_n250: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t244_n252;
  t244_n251: return 0.11472619324922562;
  t244_n252: return -0.12033799290657043;
  t244_n253: return 0.10840333998203278;
  t244_n254: return 0.0003836951800622046;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree245(const Example& E) {
  t245_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t245_n124;
  t245_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t245_n3;
  t245_n2: return -0.00011064585123676807;
  t245_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t245_n47;
  t245_n4: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t245_n46;
  t245_n5: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t245_n21;
  t245_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t245_n10;
  t245_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t245_n9;
  t245_n8: return -0.11244378238916397;
  t245_n9: return 0.048492755740880966;
  t245_n10: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t245_n20;
  t245_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n15;
  t245_n12: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t245_n14;
  t245_n13: return 0.12855151295661926;
  t245_n14: return 0.10310903936624527;
  t245_n15: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n17;
  t245_n16: return 0.003911765292286873;
  t245_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n19;
  t245_n18: return -0.01695842295885086;
  t245_n19: return 0.13589034974575043;
  t245_n20: return -0.015047436580061913;
  t245_n21: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t245_n23;
  t245_n22: return -0.020676765590906143;
  t245_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol))) goto t245_n25;
  t245_n24: return -0.004557366482913494;
  t245_n25: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t245_n45;
  t245_n26: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t245_n28;
  t245_n27: return -0.14976535737514496;
  t245_n28: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n44;
  t245_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n37;
  t245_n30: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t245_n34;
  t245_n31: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t245_n33;
  t245_n32: return 0.0617416612803936;
  t245_n33: return -0.12019100785255432;
  t245_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t245_n36;
  t245_n35: return 0.03576066344976425;
  t245_n36: return 0.08868538588285446;
  t245_n37: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t245_n39;
  t245_n38: return 0.11449883878231049;
  t245_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n43;
  t245_n40: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t245_n42;
  t245_n41: return 0.027373045682907104;
  t245_n42: return 0.0982280895113945;
  t245_n43: return -0.4453681707382202;
  t245_n44: return 0.0156412273645401;
  t245_n45: return -0.4615057110786438;
  t245_n46: return -0.015643637627363205;
  t245_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t245_n57;
  t245_n48: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t245_n56;
  t245_n49: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t245_n51;
  t245_n50: return -0.013596965000033379;
  t245_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t245_n55;
  t245_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n54;
  t245_n53: return -0.06614430993795395;
  t245_n54: return 0.00830259919166565;
  t245_n55: return 0.019345181062817574;
  t245_n56: return 0.002447353210300207;
  t245_n57: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t245_n123;
  t245_n58: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t245_n122;
  t245_n59: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t245_n85;
  t245_n60: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t245_n64;
  t245_n61: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n63;
  t245_n62: return -0.03188754990696907;
  t245_n63: return 0.016677651554346085;
  t245_n64: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t245_n74;
  t245_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t245_n67;
  t245_n66: return 0.024278447031974792;
  t245_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n73;
  t245_n68: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n72;
  t245_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n71;
  t245_n70: return 0.05284853279590607;
  t245_n71: return 0.07039400190114975;
  t245_n72: return 0.0561978705227375;
  t245_n73: return -0.015889327973127365;
  t245_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t245_n76;
  t245_n75: return -0.06134013831615448;
  t245_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n78;
  t245_n77: return 0.05738753825426102;
  t245_n78: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t245_n84;
  t245_n79: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n81;
  t245_n80: return 0.08201143890619278;
  t245_n81: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n83;
  t245_n82: return -0.04640079289674759;
  t245_n83: return 0.12280134111642838;
  t245_n84: return 0.016654403880238533;
  t245_n85: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t245_n119;
  t245_n86: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t245_n118;
  t245_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t245_n101;
  t245_n88: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n90;
  t245_n89: return 0.05913282558321953;
  t245_n90: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n92;
  t245_n91: return 0.12262842059135437;
  t245_n92: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t245_n94;
  t245_n93: return 0.02766485884785652;
  t245_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n100;
  t245_n95: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t245_n99;
  t245_n96: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t245_n98;
  t245_n97: return 0.14077168703079224;
  t245_n98: return 0.04460734501481056;
  t245_n99: return 0.10030096769332886;
  t245_n100: return 0.0745137631893158;
  t245_n101: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t245_n117;
  t245_n102: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t245_n112;
  t245_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t245_n111;
  t245_n104: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t245_n110;
  t245_n105: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t245_n109;
  t245_n106: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n108;
  t245_n107: return -0.14958761632442474;
  t245_n108: return 0.27534809708595276;
  t245_n109: return 0.16077187657356262;
  t245_n110: return 0.06670229882001877;
  t245_n111: return 0.010340163484215736;
  t245_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t245_n114;
  t245_n113: return 0.12400427460670471;
  t245_n114: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t245_n116;
  t245_n115: return -0.027259277179837227;
  t245_n116: return 0.11707102507352829;
  t245_n117: return 0.03778110817074776;
  t245_n118: return 0.1108861118555069;
  t245_n119: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t245_n121;
  t245_n120: return -0.005056349094957113;
  t245_n121: return 0.12463697791099548;
  t245_n122: return -0.007567864377051592;
  t245_n123: return 6.791210034862161e-05;
  t245_n124: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t245_n126;
  t245_n125: return -0.013692625798285007;
  t245_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t245_n128;
  t245_n127: return -0.03606732189655304;
  t245_n128: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t245_n246;
  t245_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t245_n135;
  t245_n130: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t245_n132;
  t245_n131: return 0.02681570313870907;
  t245_n132: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t245_n134;
  t245_n133: return -0.10911396890878677;
  t245_n134: return 0.09149918705224991;
  t245_n135: if (E.getSymbolScopeDistance() >= 3240099840 /*10.0*/) goto t245_n227;
  t245_n136: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t245_n146;
  t245_n137: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n139;
  t245_n138: return 0.06242399662733078;
  t245_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t245_n143;
  t245_n140: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t245_n142;
  t245_n141: return 0.32932448387145996;
  t245_n142: return -0.05837811902165413;
  t245_n143: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n145;
  t245_n144: return 0.08548314869403839;
  t245_n145: return 0.02536473609507084;
  t245_n146: if (E.getNumReferences() >= 3316817920 /*5716.0*/) goto t245_n214;
  t245_n147: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t245_n213;
  t245_n148: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t245_n202;
  t245_n149: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t245_n195;
  t245_n150: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n156;
  t245_n151: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t245_n153;
  t245_n152: return -0.05886473506689072;
  t245_n153: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t245_n155;
  t245_n154: return 0.12765702605247498;
  t245_n155: return 0.0;
  t245_n156: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t245_n170;
  t245_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n159;
  t245_n158: return -0.12612244486808777;
  t245_n159: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t245_n169;
  t245_n160: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n162;
  t245_n161: return 0.05903898552060127;
  t245_n162: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t245_n164;
  t245_n163: return 0.09855317324399948;
  t245_n164: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t245_n168;
  t245_n165: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t245_n167;
  t245_n166: return 0.1043551117181778;
  t245_n167: return -0.11030663549900055;
  t245_n168: return -0.01942594163119793;
  t245_n169: return -0.24372056126594543;
  t245_n170: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t245_n174;
  t245_n171: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t245_n173;
  t245_n172: return 0.12733310461044312;
  t245_n173: return 0.013837252743542194;
  t245_n174: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t245_n194;
  t245_n175: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t245_n187;
  t245_n176: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t245_n186;
  t245_n177: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t245_n179;
  t245_n178: return 0.015183751471340656;
  t245_n179: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n185;
  t245_n180: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t245_n182;
  t245_n181: return 0.11817993968725204;
  t245_n182: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t245_n184;
  t245_n183: return -0.18427947163581848;
  t245_n184: return 0.1066359207034111;
  t245_n185: return -0.0013510639546439052;
  t245_n186: return -0.13613788783550262;
  t245_n187: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t245_n193;
  t245_n188: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n190;
  t245_n189: return -0.13498610258102417;
  t245_n190: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t245_n192;
  t245_n191: return -0.12893474102020264;
  t245_n192: return 0.13863377273082733;
  t245_n193: return 0.010986575856804848;
  t245_n194: return -0.15748481452465057;
  t245_n195: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t245_n197;
  t245_n196: return 0.11138173937797546;
  t245_n197: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t245_n199;
  t245_n198: return -0.10193940252065659;
  t245_n199: if (E.getNumReferences() >= 3246391296 /*16.0*/) goto t245_n201;
  t245_n200: return 0.03370087966322899;
  t245_n201: return 0.1146424412727356;
  t245_n202: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t245_n212;
  t245_n203: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t245_n211;
  t245_n204: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t245_n206;
  t245_n205: return 0.11946383118629456;
  t245_n206: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t245_n208;
  t245_n207: return -0.2384461760520935;
  t245_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n210;
  t245_n209: return 0.04969491437077522;
  t245_n210: return 0.1076115220785141;
  t245_n211: return 0.10597473382949829;
  t245_n212: return 0.06463758647441864;
  t245_n213: return -0.038876697421073914;
  t245_n214: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t245_n218;
  t245_n215: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t245_n217;
  t245_n216: return 0.12789955735206604;
  t245_n217: return -0.13243982195854187;
  t245_n218: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t245_n226;
  t245_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n221;
  t245_n220: return -0.27306121587753296;
  t245_n221: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t245_n225;
  t245_n222: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t245_n224;
  t245_n223: return 0.06734191626310349;
  t245_n224: return 0.096831314265728;
  t245_n225: return -0.1760173738002777;
  t245_n226: return -0.23426438868045807;
  t245_n227: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t245_n245;
  t245_n228: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t245_n236;
  t245_n229: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t245_n235;
  t245_n230: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t245_n232;
  t245_n231: return 0.06680751591920853;
  t245_n232: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t245_n234;
  t245_n233: return 0.10936983674764633;
  t245_n234: return -0.12920063734054565;
  t245_n235: return -0.04631899669766426;
  t245_n236: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t245_n242;
  t245_n237: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t245_n241;
  t245_n238: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t245_n240;
  t245_n239: return 0.03550605848431587;
  t245_n240: return 0.1073891818523407;
  t245_n241: return -0.04423518106341362;
  t245_n242: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t245_n244;
  t245_n243: return 0.10235729813575745;
  t245_n244: return 0.036874424666166306;
  t245_n245: return -0.047470226883888245;
  t245_n246: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t245_n248;
  t245_n247: return -0.01837390661239624;
  t245_n248: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t245_n254;
  t245_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t245_n253;
  t245_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t245_n252;
  t245_n251: return 0.07408559322357178;
  t245_n252: return 0.09646401554346085;
  t245_n253: return 0.013086427934467793;
  t245_n254: return -0.011453060433268547;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree246(const Example& E) {
  t246_n0: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t246_n2;
  t246_n1: return -0.0004465508973225951;
  t246_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t246_n66;
  t246_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n5;
  t246_n4: return -0.008066766895353794;
  t246_n5: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t246_n37;
  t246_n6: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t246_n18;
  t246_n7: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n15;
  t246_n8: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t246_n10;
  t246_n9: return -0.05204572156071663;
  t246_n10: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t246_n14;
  t246_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t246_n13;
  t246_n12: return 0.14251406490802765;
  t246_n13: return 0.040339939296245575;
  t246_n14: return -0.14480525255203247;
  t246_n15: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t246_n17;
  t246_n16: return 0.03605418652296066;
  t246_n17: return 0.10688542574644089;
  t246_n18: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t246_n30;
  t246_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n21;
  t246_n20: return 0.015971366316080093;
  t246_n21: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t246_n25;
  t246_n22: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t246_n24;
  t246_n23: return -0.23622941970825195;
  t246_n24: return -0.019489280879497528;
  t246_n25: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t246_n27;
  t246_n26: return -0.2515958547592163;
  t246_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t246_n29;
  t246_n28: return 0.06981664896011353;
  t246_n29: return -0.036479149013757706;
  t246_n30: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t246_n36;
  t246_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t246_n35;
  t246_n32: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n34;
  t246_n33: return -0.1387564241886139;
  t246_n34: return 0.12085825949907303;
  t246_n35: return 0.11777298897504807;
  t246_n36: return 0.02865126170217991;
  t246_n37: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t246_n53;
  t246_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t246_n40;
  t246_n39: return 0.00996603537350893;
  t246_n40: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t246_n50;
  t246_n41: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t246_n47;
  t246_n42: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t246_n44;
  t246_n43: return 0.010495811700820923;
  t246_n44: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t246_n46;
  t246_n45: return 0.11746040731668472;
  t246_n46: return 0.10433806478977203;
  t246_n47: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t246_n49;
  t246_n48: return 0.0015538682928308845;
  t246_n49: return 0.09974376857280731;
  t246_n50: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t246_n52;
  t246_n51: return -0.1600237637758255;
  t246_n52: return 0.12696658074855804;
  t246_n53: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t246_n55;
  t246_n54: return 0.01625117100775242;
  t246_n55: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t246_n59;
  t246_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t246_n58;
  t246_n57: return -0.16918134689331055;
  t246_n58: return 0.29658615589141846;
  t246_n59: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t246_n61;
  t246_n60: return 0.12887123227119446;
  t246_n61: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t246_n63;
  t246_n62: return -0.14676369726657867;
  t246_n63: if (E.getNumReferences() >= 3269984256 /*116.0*/) goto t246_n65;
  t246_n64: return -0.10090669989585876;
  t246_n65: return 0.1272565722465515;
  t246_n66: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t246_n144;
  t246_n67: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t246_n143;
  t246_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t246_n70;
  t246_n69: return -0.012492350302636623;
  t246_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t246_n72;
  t246_n71: return 0.01272678654640913;
  t246_n72: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t246_n128;
  t246_n73: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t246_n75;
  t246_n74: return 0.06317462772130966;
  t246_n75: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t246_n85;
  t246_n76: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t246_n82;
  t246_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n81;
  t246_n78: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n80;
  t246_n79: return 0.2481272965669632;
  t246_n80: return -0.22455818951129913;
  t246_n81: return 0.12596268951892853;
  t246_n82: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n84;
  t246_n83: return 0.11641713976860046;
  t246_n84: return -0.21080364286899567;
  t246_n85: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t246_n111;
  t246_n86: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t246_n96;
  t246_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n89;
  t246_n88: return -0.16009162366390228;
  t246_n89: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t246_n93;
  t246_n90: if (E.getFilterLength() >= 3231711232 /*5.0*/) goto t246_n92;
  t246_n91: return 0.0004573935584630817;
  t246_n92: return 0.10693460702896118;
  t246_n93: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t246_n95;
  t246_n94: return 0.09488510340452194;
  t246_n95: return -0.017856618389487267;
  t246_n96: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t246_n106;
  t246_n97: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t246_n105;
  t246_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t246_n104;
  t246_n99: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t246_n103;
  t246_n100: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t246_n102;
  t246_n101: return 0.10046664625406265;
  t246_n102: return 0.11194213479757309;
  t246_n103: return -0.11454617977142334;
  t246_n104: return -0.2762186527252197;
  t246_n105: return 0.09336404502391815;
  t246_n106: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t246_n108;
  t246_n107: return 0.028553999960422516;
  t246_n108: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n110;
  t246_n109: return -0.11005621403455734;
  t246_n110: return 0.1294529289007187;
  t246_n111: if (E.getNumReferences() >= 3287613440 /*490.0*/) goto t246_n121;
  t246_n112: if (E.getNumReferences() >= 3283894272 /*376.5*/) goto t246_n120;
  t246_n113: if (E.getNumReferences() >= 3282173952 /*324.0*/) goto t246_n119;
  t246_n114: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t246_n116;
  t246_n115: return -0.2604905962944031;
  t246_n116: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t246_n118;
  t246_n117: return 0.006930687464773655;
  t246_n118: return 0.08506131917238235;
  t246_n119: return 0.20152117311954498;
  t246_n120: return -0.35566169023513794;
  t246_n121: if (E.getNumReferences() >= 3291611136 /*712.0*/) goto t246_n127;
  t246_n122: if (E.getNumReferences() >= 3289251840 /*568.0*/) goto t246_n124;
  t246_n123: return 0.11731062084436417;
  t246_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t246_n126;
  t246_n125: return 0.11286357790231705;
  t246_n126: return 0.07403941452503204;
  t246_n127: return 0.053109437227249146;
  t246_n128: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t246_n130;
  t246_n129: return 0.016908859834074974;
  t246_n130: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t246_n132;
  t246_n131: return 0.045999910682439804;
  t246_n132: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t246_n134;
  t246_n133: return 0.11871279031038284;
  t246_n134: if (E.getNumReferences() >= 3297976320 /*1177.0*/) goto t246_n142;
  t246_n135: if (E.getNumReferences() >= 3289726976 /*597.0*/) goto t246_n137;
  t246_n136: return 0.03261341154575348;
  t246_n137: if (E.getNumReferences() >= 3291373568 /*697.5*/) goto t246_n139;
  t246_n138: return 0.11903676390647888;
  t246_n139: if (E.getNumReferences() >= 3295526912 /*951.0*/) goto t246_n141;
  t246_n140: return -0.00552723603323102;
  t246_n141: return 0.10908009111881256;
  t246_n142: return -0.09605124592781067;
  t246_n143: return -0.0017297338927164674;
  t246_n144: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t246_n242;
  t246_n145: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t246_n167;
  t246_n146: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t246_n166;
  t246_n147: if (E.getNumReferences() >= 3309545472 /*3130.5*/) goto t246_n155;
  t246_n148: if (E.getNumReferences() >= 3297005568 /*1058.5*/) goto t246_n152;
  t246_n149: if (E.getNumReferences() >= 3296845824 /*1039.0*/) goto t246_n151;
  t246_n150: return 0.01069692987948656;
  t246_n151: return 0.0911901667714119;
  t246_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t246_n154;
  t246_n153: return -0.4045717120170593;
  t246_n154: return -0.06564751267433167;
  t246_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t246_n159;
  t246_n156: if (E.getNumReferences() >= 3310942208 /*3471.5*/) goto t246_n158;
  t246_n157: return 0.11679867655038834;
  t246_n158: return -0.025370851159095764;
  t246_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t246_n161;
  t246_n160: return 0.0624435618519783;
  t246_n161: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t246_n163;
  t246_n162: return 0.04414663091301918;
  t246_n163: if (E.getNumReferences() >= 3322114560 /*8412.5*/) goto t246_n165;
  t246_n164: return 0.12106025218963623;
  t246_n165: return 0.07838878035545349;
  t246_n166: return 0.08252237737178802;
  t246_n167: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t246_n175;
  t246_n168: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t246_n174;
  t246_n169: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t246_n173;
  t246_n170: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t246_n172;
  t246_n171: return -0.5362826585769653;
  t246_n172: return 0.10890201479196548;
  t246_n173: return 0.1135982945561409;
  t246_n174: return 0.028552405536174774;
  t246_n175: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t246_n241;
  t246_n176: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t246_n194;
  t246_n177: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t246_n193;
  t246_n178: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t246_n180;
  t246_n179: return 0.056995611637830734;
  t246_n180: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t246_n186;
  t246_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t246_n185;
  t246_n182: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n184;
  t246_n183: return -0.21747741103172302;
  t246_n184: return 0.13196638226509094;
  t246_n185: return 0.14966756105422974;
  t246_n186: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t246_n192;
  t246_n187: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t246_n189;
  t246_n188: return 0.0035970599856227636;
  t246_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t246_n191;
  t246_n190: return 0.3091754913330078;
  t246_n191: return 0.12165240198373795;
  t246_n192: return 0.0394890122115612;
  t246_n193: return -0.05750241130590439;
  t246_n194: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t246_n210;
  t246_n195: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n205;
  t246_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t246_n198;
  t246_n197: return 0.018125204369425774;
  t246_n198: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t246_n200;
  t246_n199: return -0.31130215525627136;
  t246_n200: if (E.getNumReferences() >= 3270311936 /*118.5*/) goto t246_n202;
  t246_n201: return 0.707193911075592;
  t246_n202: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t246_n204;
  t246_n203: return 0.12555478513240814;
  t246_n204: return 0.11869364231824875;
  t246_n205: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t246_n207;
  t246_n206: return 0.12312506139278412;
  t246_n207: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t246_n209;
  t246_n208: return 0.14390763640403748;
  t246_n209: return -0.10195852071046829;
  t246_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t246_n234;
  t246_n211: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t246_n223;
  t246_n212: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t246_n214;
  t246_n213: return 0.013306334614753723;
  t246_n214: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t246_n222;
  t246_n215: if (E.getNumReferences() >= 3271983104 /*134.5*/) goto t246_n217;
  t246_n216: return 0.08224139362573624;
  t246_n217: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t246_n219;
  t246_n218: return 0.1346428543329239;
  t246_n219: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t246_n221;
  t246_n220: return 0.08571060001850128;
  t246_n221: return 0.13696153461933136;
  t246_n222: return -0.11705050617456436;
  t246_n223: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t246_n225;
  t246_n224: return -0.13125525414943695;
  t246_n225: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n233;
  t246_n226: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t246_n228;
  t246_n227: return -0.170371875166893;
  t246_n228: if (E.getNumReferences() >= 3274473472 /*172.5*/) goto t246_n230;
  t246_n229: return 0.10978538542985916;
  t246_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t246_n232;
  t246_n231: return -0.11924835294485092;
  t246_n232: return 0.11922727525234222;
  t246_n233: return 0.11523757129907608;
  t246_n234: if (E.getNumReferences() >= 3271360512 /*126.5*/) goto t246_n236;
  t246_n235: return 0.12412884831428528;
  t246_n236: if (E.getNumReferences() >= 3274145792 /*167.5*/) goto t246_n238;
  t246_n237: return -0.15443235635757446;
  t246_n238: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t246_n240;
  t246_n239: return 0.1173776164650917;
  t246_n240: return -0.10095905512571335;
  t246_n241: return 0.01581299491226673;
  t246_n242: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t246_n246;
  t246_n243: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t246_n245;
  t246_n244: return 0.1563107669353485;
  t246_n245: return 0.14308494329452515;
  t246_n246: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t246_n254;
  t246_n247: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t246_n253;
  t246_n248: if (E.getNumReferences() >= 3288834048 /*542.5*/) goto t246_n250;
  t246_n249: return 0.06411966681480408;
  t246_n250: if (E.getNumReferences() >= 3305973760 /*2258.5*/) goto t246_n252;
  t246_n251: return 0.13725678622722626;
  t246_n252: return 0.11433613300323486;
  t246_n253: return 0.04107775539159775;
  t246_n254: return 0.03766551613807678;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree247(const Example& E) {
  t247_n0: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t247_n2;
  t247_n1: return -0.0004609566240105778;
  t247_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t247_n98;
  t247_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t247_n37;
  t247_n4: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t247_n26;
  t247_n5: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t247_n7;
  t247_n6: return -0.15038278698921204;
  t247_n7: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t247_n15;
  t247_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t247_n12;
  t247_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t247_n11;
  t247_n10: return -0.11093934625387192;
  t247_n11: return 3.441368818283081;
  t247_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n14;
  t247_n13: return 0.1367291808128357;
  t247_n14: return 0.0905541181564331;
  t247_n15: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t247_n25;
  t247_n16: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t247_n24;
  t247_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t247_n19;
  t247_n18: return -0.10433045774698257;
  t247_n19: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t247_n23;
  t247_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n22;
  t247_n21: return 0.11377981305122375;
  t247_n22: return 0.37750130891799927;
  t247_n23: return -0.1782436966896057;
  t247_n24: return -0.11134780198335648;
  t247_n25: return 0.03559546172618866;
  t247_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n28;
  t247_n27: return 0.0029522664844989777;
  t247_n28: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t247_n30;
  t247_n29: return 0.01322633121162653;
  t247_n30: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t247_n32;
  t247_n31: return 0.023565970361232758;
  t247_n32: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t247_n34;
  t247_n33: return -0.15580004453659058;
  t247_n34: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t247_n36;
  t247_n35: return 0.1228584498167038;
  t247_n36: return -0.07213427126407623;
  t247_n37: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t247_n59;
  t247_n38: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t247_n56;
  t247_n39: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t247_n55;
  t247_n40: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t247_n44;
  t247_n41: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t247_n43;
  t247_n42: return -0.009904944337904453;
  t247_n43: return -0.08967658132314682;
  t247_n44: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t247_n48;
  t247_n45: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t247_n47;
  t247_n46: return 0.1181681677699089;
  t247_n47: return -0.11322139203548431;
  t247_n48: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t247_n54;
  t247_n49: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t247_n51;
  t247_n50: return 0.0770980641245842;
  t247_n51: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t247_n53;
  t247_n52: return 0.11538846790790558;
  t247_n53: return 0.17653606832027435;
  t247_n54: return 0.01520959660410881;
  t247_n55: return 0.09722674638032913;
  t247_n56: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t247_n58;
  t247_n57: return -0.0007148918230086565;
  t247_n58: return 0.12232260406017303;
  t247_n59: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t247_n61;
  t247_n60: return 0.09932247549295425;
  t247_n61: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t247_n73;
  t247_n62: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t247_n72;
  t247_n63: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t247_n65;
  t247_n64: return -0.14770936965942383;
  t247_n65: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t247_n71;
  t247_n66: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t247_n70;
  t247_n67: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t247_n69;
  t247_n68: return 0.06460385769605637;
  t247_n69: return 0.10712061822414398;
  t247_n70: return -0.05419374629855156;
  t247_n71: return -0.12757202982902527;
  t247_n72: return 0.12052737921476364;
  t247_n73: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t247_n89;
  t247_n74: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t247_n88;
  t247_n75: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t247_n77;
  t247_n76: return -0.17626217007637024;
  t247_n77: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t247_n81;
  t247_n78: if (E.getNumReferences() >= 3271491584 /*127.5*/) goto t247_n80;
  t247_n79: return 0.10152760148048401;
  t247_n80: return 0.067746601998806;
  t247_n81: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n83;
  t247_n82: return -0.3741404712200165;
  t247_n83: if (E.getNumReferences() >= 3269525504 /*112.5*/) goto t247_n85;
  t247_n84: return 0.10185196995735168;
  t247_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t247_n87;
  t247_n86: return -0.13613857328891754;
  t247_n87: return 0.0918041467666626;
  t247_n88: return 0.10419107228517532;
  t247_n89: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n91;
  t247_n90: return -0.48479169607162476;
  t247_n91: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t247_n97;
  t247_n92: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t247_n96;
  t247_n93: if (E.getNumReferences() >= 3302748160 /*1759.5*/) goto t247_n95;
  t247_n94: return -0.1335850954055786;
  t247_n95: return 0.05130413919687271;
  t247_n96: return 0.08725130558013916;
  t247_n97: return 0.09142334759235382;
  t247_n98: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t247_n150;
  t247_n99: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t247_n149;
  t247_n100: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t247_n102;
  t247_n101: return -0.010308351367712021;
  t247_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t247_n104;
  t247_n103: return 0.01211882010102272;
  t247_n104: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t247_n118;
  t247_n105: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t247_n115;
  t247_n106: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t247_n110;
  t247_n107: if (E.getNumReferences() >= 3262513152 /*61.5*/) goto t247_n109;
  t247_n108: return -0.22430811822414398;
  t247_n109: return 0.6005985140800476;
  t247_n110: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t247_n114;
  t247_n111: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t247_n113;
  t247_n112: return 0.11243436485528946;
  t247_n113: return 0.10920856893062592;
  t247_n114: return -0.21060575544834137;
  t247_n115: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t247_n117;
  t247_n116: return 0.050915613770484924;
  t247_n117: return 0.05779392272233963;
  t247_n118: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t247_n136;
  t247_n119: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t247_n121;
  t247_n120: return 0.010216918773949146;
  t247_n121: if (E.getNumReferences() >= 3275718656 /*191.5*/) goto t247_n131;
  t247_n122: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t247_n124;
  t247_n123: return 0.11036495864391327;
  t247_n124: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t247_n126;
  t247_n125: return -0.1178482174873352;
  t247_n126: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t247_n128;
  t247_n127: return -0.34679633378982544;
  t247_n128: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t247_n130;
  t247_n129: return 0.1107289046049118;
  t247_n130: return 0.06664256006479263;
  t247_n131: if (E.getNumReferences() >= 3281141760 /*292.5*/) goto t247_n135;
  t247_n132: if (E.getNumReferences() >= 3279060992 /*242.5*/) goto t247_n134;
  t247_n133: return 0.08123182505369186;
  t247_n134: return 0.11026246845722198;
  t247_n135: return 0.0644403025507927;
  t247_n136: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t247_n138;
  t247_n137: return 0.047310974448919296;
  t247_n138: if (E.getNumReferences() >= 3275685888 /*191.0*/) goto t247_n140;
  t247_n139: return 0.1166267991065979;
  t247_n140: if (E.getNumReferences() >= 3297976320 /*1177.0*/) goto t247_n148;
  t247_n141: if (E.getNumReferences() >= 3289726976 /*597.0*/) goto t247_n143;
  t247_n142: return 0.024798251688480377;
  t247_n143: if (E.getNumReferences() >= 3291373568 /*697.5*/) goto t247_n145;
  t247_n144: return 0.11764465272426605;
  t247_n145: if (E.getNumReferences() >= 3295526912 /*951.0*/) goto t247_n147;
  t247_n146: return 0.0002911796036642045;
  t247_n147: return 0.1069846823811531;
  t247_n148: return -0.09827876836061478;
  t247_n149: return -0.002628651913255453;
  t247_n150: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t247_n166;
  t247_n151: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t247_n165;
  t247_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t247_n164;
  t247_n153: if (E.getNumReferences() >= 3298926592 /*1293.0*/) goto t247_n155;
  t247_n154: return -0.04816006124019623;
  t247_n155: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t247_n157;
  t247_n156: return -0.3169704079627991;
  t247_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t247_n161;
  t247_n158: if (E.getNumReferences() >= 3337794560 /*31066.0*/) goto t247_n160;
  t247_n159: return -0.022041447460651398;
  t247_n160: return 0.0876360684633255;
  t247_n161: if (E.getNumReferences() >= 3342787456 /*48867.5*/) goto t247_n163;
  t247_n162: return 0.07767263799905777;
  t247_n163: return -0.3461264371871948;
  t247_n164: return 0.0019008297240361571;
  t247_n165: return 0.037872765213251114;
  t247_n166: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t247_n184;
  t247_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t247_n173;
  t247_n168: if (E.getNumReferences() >= 3300868096 /*1530.0*/) goto t247_n170;
  t247_n169: return 0.044736798852682114;
  t247_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t247_n172;
  t247_n171: return -0.21598611772060394;
  t247_n172: return 0.10512536019086838;
  t247_n173: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t247_n179;
  t247_n174: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t247_n176;
  t247_n175: return 0.1878661811351776;
  t247_n176: if (E.getNumReferences() >= 3281158144 /*293.0*/) goto t247_n178;
  t247_n177: return 0.5371376872062683;
  t247_n178: return 0.21412897109985352;
  t247_n179: if (E.getNumReferences() >= 3267428352 /*96.5*/) goto t247_n183;
  t247_n180: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t247_n182;
  t247_n181: return -0.007351303473114967;
  t247_n182: return 0.15461081266403198;
  t247_n183: return -0.23413294553756714;
  t247_n184: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t247_n238;
  t247_n185: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t247_n187;
  t247_n186: return 0.02185611054301262;
  t247_n187: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t247_n189;
  t247_n188: return 0.03892988711595535;
  t247_n189: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t247_n205;
  t247_n190: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t247_n198;
  t247_n191: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t247_n193;
  t247_n192: return 0.23350228369235992;
  t247_n193: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t247_n197;
  t247_n194: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t247_n196;
  t247_n195: return -0.10123856365680695;
  t247_n196: return 0.12117144465446472;
  t247_n197: return -0.10568578541278839;
  t247_n198: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t247_n204;
  t247_n199: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t247_n201;
  t247_n200: return 0.12349008023738861;
  t247_n201: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t247_n203;
  t247_n202: return -0.42468228936195374;
  t247_n203: return 0.14545755088329315;
  t247_n204: return -0.10158908367156982;
  t247_n205: if (E.getNumReferences() >= 3297632256 /*1135.0*/) goto t247_n237;
  t247_n206: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t247_n232;
  t247_n207: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t247_n209;
  t247_n208: return -0.029878851026296616;
  t247_n209: if (E.getNumReferences() >= 3274211328 /*168.5*/) goto t247_n215;
  t247_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t247_n212;
  t247_n211: return 0.026383737102150917;
  t247_n212: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t247_n214;
  t247_n213: return 0.1353038102388382;
  t247_n214: return -0.4144216477870941;
  t247_n215: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t247_n219;
  t247_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t247_n218;
  t247_n217: return -0.20567713677883148;
  t247_n218: return 0.06286017596721649;
  t247_n219: if (E.getNumReferences() >= 3277881344 /*224.5*/) goto t247_n223;
  t247_n220: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t247_n222;
  t247_n221: return 0.1963246762752533;
  t247_n222: return -0.14612703025341034;
  t247_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t247_n225;
  t247_n224: return -0.027875253930687904;
  t247_n225: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t247_n227;
  t247_n226: return 0.0680643692612648;
  t247_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t247_n229;
  t247_n228: return 0.11035647988319397;
  t247_n229: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t247_n231;
  t247_n230: return -0.21622978150844574;
  t247_n231: return 0.11673146486282349;
  t247_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t247_n234;
  t247_n233: return 0.06988973915576935;
  t247_n234: if (E.getNumReferences() >= 3297320960 /*1097.0*/) goto t247_n236;
  t247_n235: return 0.10213583707809448;
  t247_n236: return 0.07873786240816116;
  t247_n237: return 0.010942350141704082;
  t247_n238: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t247_n242;
  t247_n239: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t247_n241;
  t247_n240: return -0.10754184424877167;
  t247_n241: return 0.13758045434951782;
  t247_n242: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t247_n254;
  t247_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t247_n249;
  t247_n244: if (E.getNumReferences() >= 3276931072 /*210.0*/) goto t247_n246;
  t247_n245: return 0.045704953372478485;
  t247_n246: if (E.getNumReferences() >= 3312265216 /*3794.5*/) goto t247_n248;
  t247_n247: return 0.13741560280323029;
  t247_n248: return 0.10013829916715622;
  t247_n249: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t247_n251;
  t247_n250: return -0.004155643284320831;
  t247_n251: if (E.getNumReferences() >= 3319443456 /*6998.0*/) goto t247_n253;
  t247_n252: return 0.1283552050590515;
  t247_n253: return 0.10008159279823303;
  t247_n254: return 0.033932726830244064;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree248(const Example& E) {
  t248_n0: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t248_n46;
  t248_n1: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t248_n3;
  t248_n2: return 0.00028378781280480325;
  t248_n3: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t248_n5;
  t248_n4: return 0.054060399532318115;
  t248_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t248_n33;
  t248_n6: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t248_n8;
  t248_n7: return -0.04262249916791916;
  t248_n8: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t248_n10;
  t248_n9: return -0.00434889318421483;
  t248_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t248_n12;
  t248_n11: return -0.08432484418153763;
  t248_n12: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t248_n14;
  t248_n13: return 0.013616068288683891;
  t248_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t248_n16;
  t248_n15: return 0.02619304321706295;
  t248_n16: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t248_n30;
  t248_n17: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t248_n23;
  t248_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t248_n20;
  t248_n19: return 0.05943945050239563;
  t248_n20: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t248_n22;
  t248_n21: return 0.07361358404159546;
  t248_n22: return 0.11165367811918259;
  t248_n23: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t248_n29;
  t248_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t248_n26;
  t248_n25: return 0.11517544090747833;
  t248_n26: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t248_n28;
  t248_n27: return 0.04870970547199249;
  t248_n28: return 0.10800261050462723;
  t248_n29: return 0.08101015537977219;
  t248_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t248_n32;
  t248_n31: return -0.08325032144784927;
  t248_n32: return 0.055076032876968384;
  t248_n33: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t248_n35;
  t248_n34: return -0.006534134037792683;
  t248_n35: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t248_n45;
  t248_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t248_n38;
  t248_n37: return -0.006276382133364677;
  t248_n38: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t248_n42;
  t248_n39: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t248_n41;
  t248_n40: return 0.0479336716234684;
  t248_n41: return 0.025845885276794434;
  t248_n42: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t248_n44;
  t248_n43: return 0.10386934131383896;
  t248_n44: return -0.10852383822202682;
  t248_n45: return 0.004281277302652597;
  t248_n46: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t248_n174;
  t248_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t248_n115;
  t248_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t248_n50;
  t248_n49: return -0.007796413265168667;
  t248_n50: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t248_n60;
  t248_n51: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t248_n57;
  t248_n52: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t248_n54;
  t248_n53: return -0.06140444427728653;
  t248_n54: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t248_n56;
  t248_n55: return 0.13220445811748505;
  t248_n56: return 0.08961557596921921;
  t248_n57: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t248_n59;
  t248_n58: return 0.11443748325109482;
  t248_n59: return 0.04047856107354164;
  t248_n60: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t248_n114;
  t248_n61: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t248_n67;
  t248_n62: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t248_n66;
  t248_n63: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n65;
  t248_n64: return -0.02035646326839924;
  t248_n65: return -0.12201190739870071;
  t248_n66: return 0.10724468529224396;
  t248_n67: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t248_n83;
  t248_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t248_n82;
  t248_n69: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t248_n71;
  t248_n70: return 0.05513269081711769;
  t248_n71: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t248_n73;
  t248_n72: return 0.02795621007680893;
  t248_n73: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t248_n75;
  t248_n74: return 0.15579061210155487;
  t248_n75: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t248_n81;
  t248_n76: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t248_n80;
  t248_n77: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t248_n79;
  t248_n78: return 0.06324159353971481;
  t248_n79: return 0.14505338668823242;
  t248_n80: return 0.11350532621145248;
  t248_n81: return -0.13122405111789703;
  t248_n82: return -0.14229799807071686;
  t248_n83: if (E.getNumReferences() >= 3277357056 /*216.5*/) goto t248_n91;
  t248_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t248_n86;
  t248_n85: return -0.030358172953128815;
  t248_n86: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t248_n88;
  t248_n87: return -0.2383558601140976;
  t248_n88: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t248_n90;
  t248_n89: return 0.11874144524335861;
  t248_n90: return -0.5024594664573669;
  t248_n91: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t248_n93;
  t248_n92: return 0.15596972405910492;
  t248_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n103;
  t248_n94: if (E.getNumReferences() >= 3280125952 /*261.5*/) goto t248_n98;
  t248_n95: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t248_n97;
  t248_n96: return -0.1569981724023819;
  t248_n97: return -1.1538379192352295;
  t248_n98: if (E.getNumReferences() >= 3282059264 /*320.5*/) goto t248_n102;
  t248_n99: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t248_n101;
  t248_n100: return 0.048440080136060715;
  t248_n101: return 0.10957712680101395;
  t248_n102: return 0.01202539261430502;
  t248_n103: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t248_n109;
  t248_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t248_n108;
  t248_n105: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t248_n107;
  t248_n106: return 0.09878747165203094;
  t248_n107: return -0.07063421607017517;
  t248_n108: return 0.13059887290000916;
  t248_n109: if (E.getNumReferences() >= 3292479488 /*765.0*/) goto t248_n111;
  t248_n110: return -0.011642949655652046;
  t248_n111: if (E.getNumReferences() >= 3293904896 /*852.0*/) goto t248_n113;
  t248_n112: return 0.1133296936750412;
  t248_n113: return 0.034514378756284714;
  t248_n114: return 0.00998024269938469;
  t248_n115: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t248_n147;
  t248_n116: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t248_n144;
  t248_n117: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t248_n143;
  t248_n118: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t248_n128;
  t248_n119: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t248_n121;
  t248_n120: return -0.007879109121859074;
  t248_n121: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t248_n125;
  t248_n122: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t248_n124;
  t248_n123: return -0.5268344283103943;
  t248_n124: return 0.07684344798326492;
  t248_n125: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t248_n127;
  t248_n126: return -0.1810995638370514;
  t248_n127: return -0.017461102455854416;
  t248_n128: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t248_n132;
  t248_n129: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t248_n131;
  t248_n130: return 0.11468289792537689;
  t248_n131: return -0.11171689629554749;
  t248_n132: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t248_n140;
  t248_n133: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t248_n137;
  t248_n134: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n136;
  t248_n135: return 0.11161162704229355;
  t248_n136: return -0.12253851443529129;
  t248_n137: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t248_n139;
  t248_n138: return 0.1133110299706459;
  t248_n139: return 0.13864420354366302;
  t248_n140: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t248_n142;
  t248_n141: return -0.27450332045555115;
  t248_n142: return 0.01629233919084072;
  t248_n143: return 0.09570896625518799;
  t248_n144: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t248_n146;
  t248_n145: return 0.004782871343195438;
  t248_n146: return 0.1190045177936554;
  t248_n147: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t248_n149;
  t248_n148: return 0.09761980921030045;
  t248_n149: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t248_n161;
  t248_n150: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t248_n160;
  t248_n151: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t248_n159;
  t248_n152: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t248_n156;
  t248_n153: if (E.getNumReferences() >= 3263627264 /*67.5*/) goto t248_n155;
  t248_n154: return -0.06977588683366776;
  t248_n155: return 0.09690948575735092;
  t248_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t248_n158;
  t248_n157: return 0.10499965399503708;
  t248_n158: return -0.2963074743747711;
  t248_n159: return -0.11926085501909256;
  t248_n160: return 0.11818575114011765;
  t248_n161: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t248_n169;
  t248_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n168;
  t248_n163: if (E.getNumReferences() >= 3274178560 /*168.0*/) goto t248_n167;
  t248_n164: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t248_n166;
  t248_n165: return -0.5130957365036011;
  t248_n166: return 0.10672619938850403;
  t248_n167: return -0.1830594539642334;
  t248_n168: return 0.016623420640826225;
  t248_n169: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t248_n173;
  t248_n170: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t248_n172;
  t248_n171: return 0.0032357126474380493;
  t248_n172: return 0.10215093195438385;
  t248_n173: return -0.0720766931772232;
  t248_n174: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t248_n176;
  t248_n175: return -0.0014719549799337983;
  t248_n176: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t248_n180;
  t248_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t248_n179;
  t248_n178: return -0.004403667990118265;
  t248_n179: return 0.0369252935051918;
  t248_n180: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t248_n198;
  t248_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t248_n195;
  t248_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t248_n184;
  t248_n183: return 0.04565691575407982;
  t248_n184: if (E.getNumReferences() >= 3282747392 /*341.5*/) goto t248_n194;
  t248_n185: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t248_n193;
  t248_n186: if (E.getNumReferences() >= 3267035136 /*93.5*/) goto t248_n192;
  t248_n187: if (E.getNumReferences() >= 3264479232 /*74.0*/) goto t248_n191;
  t248_n188: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t248_n190;
  t248_n189: return 0.11094583570957184;
  t248_n190: return -0.12242031842470169;
  t248_n191: return -0.24618719518184662;
  t248_n192: return 1.208583116531372;
  t248_n193: return -0.23771978914737701;
  t248_n194: return 0.12654827535152435;
  t248_n195: if (E.getNumReferences() >= 3277717504 /*222.0*/) goto t248_n197;
  t248_n196: return -0.11950838565826416;
  t248_n197: return 0.1298237144947052;
  t248_n198: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t248_n238;
  t248_n199: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t248_n201;
  t248_n200: return 0.020631996914744377;
  t248_n201: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t248_n203;
  t248_n202: return 0.03412002697587013;
  t248_n203: if (E.getNumReferences() >= 3270574080 /*120.5*/) goto t248_n219;
  t248_n204: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t248_n212;
  t248_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t248_n207;
  t248_n206: return 0.1967143714427948;
  t248_n207: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t248_n211;
  t248_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t248_n210;
  t248_n209: return -0.10104213654994965;
  t248_n210: return 0.1187824085354805;
  t248_n211: return -0.10472463071346283;
  t248_n212: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t248_n218;
  t248_n213: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t248_n215;
  t248_n214: return 0.12134534120559692;
  t248_n215: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t248_n217;
  t248_n216: return -0.167813241481781;
  t248_n217: return 0.13830088078975677;
  t248_n218: return -0.10138536989688873;
  t248_n219: if (E.getNumReferences() >= 3297632256 /*1135.0*/) goto t248_n237;
  t248_n220: if (E.getNumReferences() >= 3297136640 /*1074.5*/) goto t248_n232;
  t248_n221: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t248_n223;
  t248_n222: return -0.023598812520503998;
  t248_n223: if (E.getNumReferences() >= 3274211328 /*168.5*/) goto t248_n229;
  t248_n224: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t248_n226;
  t248_n225: return 0.025360114872455597;
  t248_n226: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t248_n228;
  t248_n227: return 0.13167110085487366;
  t248_n228: return -0.4161844551563263;
  t248_n229: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t248_n231;
  t248_n230: return 0.017794622108340263;
  t248_n231: return 0.06894981116056442;
  t248_n232: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t248_n234;
  t248_n233: return 0.06387826800346375;
  t248_n234: if (E.getNumReferences() >= 3297320960 /*1097.0*/) goto t248_n236;
  t248_n235: return 0.10156987607479095;
  t248_n236: return 0.0756220668554306;
  t248_n237: return 0.012185901403427124;
  t248_n238: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t248_n242;
  t248_n239: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t248_n241;
  t248_n240: return -0.10658188909292221;
  t248_n241: return 0.13343310356140137;
  t248_n242: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t248_n254;
  t248_n243: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t248_n249;
  t248_n244: if (E.getNumReferences() >= 3276931072 /*210.0*/) goto t248_n246;
  t248_n245: return 0.05263087898492813;
  t248_n246: if (E.getNumReferences() >= 3312265216 /*3794.5*/) goto t248_n248;
  t248_n247: return 0.13323643803596497;
  t248_n248: return 0.10012524574995041;
  t248_n249: if (E.getNumReferences() >= 3308357632 /*2840.5*/) goto t248_n251;
  t248_n250: return 0.0002132891968358308;
  t248_n251: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t248_n253;
  t248_n252: return 0.12346275895833969;
  t248_n253: return 0.1000736728310585;
  t248_n254: return 0.03304452449083328;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree249(const Example& E) {
  t249_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t249_n2;
  t249_n1: return -0.0004340603481978178;
  t249_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t249_n152;
  t249_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t249_n81;
  t249_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n52;
  t249_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t249_n51;
  t249_n6: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t249_n48;
  t249_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t249_n19;
  t249_n8: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t249_n14;
  t249_n9: if (E.getNumReferences() >= 3339097344 /*34453.0*/) goto t249_n11;
  t249_n10: return -0.03941169008612633;
  t249_n11: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t249_n13;
  t249_n12: return -0.00042429837048985064;
  t249_n13: return 0.07015544921159744;
  t249_n14: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t249_n16;
  t249_n15: return -0.0848596841096878;
  t249_n16: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t249_n18;
  t249_n17: return 0.02129465714097023;
  t249_n18: return -0.17895781993865967;
  t249_n19: if (E.getNumReferences() >= 3276734464 /*207.0*/) goto t249_n23;
  t249_n20: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t249_n22;
  t249_n21: return 0.09655549377202988;
  t249_n22: return -0.2230987250804901;
  t249_n23: if (E.getNumReferences() >= 3332163840 /*20068.5*/) goto t249_n47;
  t249_n24: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t249_n32;
  t249_n25: if (E.getNumReferences() >= 3288186880 /*507.5*/) goto t249_n31;
  t249_n26: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t249_n28;
  t249_n27: return -0.021965408697724342;
  t249_n28: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t249_n30;
  t249_n29: return 0.10697142779827118;
  t249_n30: return 0.06377384066581726;
  t249_n31: return -0.06914026290178299;
  t249_n32: if (E.getNumReferences() >= 3310237696 /*3299.5*/) goto t249_n44;
  t249_n33: if (E.getNumReferences() >= 3305103360 /*2047.0*/) goto t249_n43;
  t249_n34: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t249_n42;
  t249_n35: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t249_n37;
  t249_n36: return -0.10804560035467148;
  t249_n37: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t249_n41;
  t249_n38: if (E.getNumReferences() >= 3292536832 /*768.5*/) goto t249_n40;
  t249_n39: return 0.11825267970561981;
  t249_n40: return 0.07404395192861557;
  t249_n41: return -0.07205043733119965;
  t249_n42: return -0.10423438251018524;
  t249_n43: return 0.11338012665510178;
  t249_n44: if (E.getNumReferences() >= 3323808256 /*10066.5*/) goto t249_n46;
  t249_n45: return -0.14235398173332214;
  t249_n46: return 0.09201763570308685;
  t249_n47: return -0.03674141690135002;
  t249_n48: if (E.getNumReferences() >= 3275325440 /*185.5*/) goto t249_n50;
  t249_n49: return 0.14616413414478302;
  t249_n50: return -0.21344327926635742;
  t249_n51: return 0.005379298701882362;
  t249_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t249_n54;
  t249_n53: return -0.05957377701997757;
  t249_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t249_n58;
  t249_n55: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t249_n57;
  t249_n56: return 0.013686046004295349;
  t249_n57: return -0.12645716965198517;
  t249_n58: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t249_n76;
  t249_n59: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t249_n61;
  t249_n60: return -0.0354217104613781;
  t249_n61: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t249_n75;
  t249_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t249_n74;
  t249_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t249_n65;
  t249_n64: return -0.10068606585264206;
  t249_n65: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t249_n73;
  t249_n66: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t249_n68;
  t249_n67: return -0.17536714673042297;
  t249_n68: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t249_n70;
  t249_n69: return -0.07487877458333969;
  t249_n70: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n72;
  t249_n71: return 0.08025030046701431;
  t249_n72: return 0.12416517734527588;
  t249_n73: return 0.09945792704820633;
  t249_n74: return 0.09726159274578094;
  t249_n75: return 0.026334967464208603;
  t249_n76: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t249_n78;
  t249_n77: return -0.1508762389421463;
  t249_n78: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t249_n80;
  t249_n79: return 0.11894161999225616;
  t249_n80: return -0.0686635673046112;
  t249_n81: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t249_n107;
  t249_n82: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t249_n104;
  t249_n83: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t249_n103;
  t249_n84: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t249_n86;
  t249_n85: return -0.02530755288898945;
  t249_n86: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t249_n90;
  t249_n87: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t249_n89;
  t249_n88: return 0.11324197798967361;
  t249_n89: return -0.11037623882293701;
  t249_n90: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t249_n102;
  t249_n91: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t249_n99;
  t249_n92: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n98;
  t249_n93: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t249_n95;
  t249_n94: return 0.11970030516386032;
  t249_n95: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t249_n97;
  t249_n96: return -0.19290970265865326;
  t249_n97: return 0.4340083599090576;
  t249_n98: return 0.047671087086200714;
  t249_n99: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n101;
  t249_n100: return 0.11289473623037338;
  t249_n101: return 0.055243875831365585;
  t249_n102: return 0.013449737802147865;
  t249_n103: return 0.09658174961805344;
  t249_n104: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t249_n106;
  t249_n105: return -0.017799725756049156;
  t249_n106: return 0.11446329206228256;
  t249_n107: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t249_n131;
  t249_n108: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t249_n130;
  t249_n109: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n115;
  t249_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n112;
  t249_n111: return -0.33344215154647827;
  t249_n112: if (E.getNumReferences() >= 3259367424 /*49.5*/) goto t249_n114;
  t249_n113: return 0.09873690456151962;
  t249_n114: return 0.027316788211464882;
  t249_n115: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t249_n121;
  t249_n116: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t249_n120;
  t249_n117: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t249_n119;
  t249_n118: return 0.10313525795936584;
  t249_n119: return 0.10309214144945145;
  t249_n120: return 0.05303477123379707;
  t249_n121: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t249_n123;
  t249_n122: return -0.08279391378164291;
  t249_n123: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t249_n129;
  t249_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n126;
  t249_n125: return 0.0977054238319397;
  t249_n126: if (E.getNumReferences() >= 3260809216 /*55.0*/) goto t249_n128;
  t249_n127: return 0.11796632409095764;
  t249_n128: return -0.24189887940883636;
  t249_n129: return -0.09027464687824249;
  t249_n130: return 0.11593613773584366;
  t249_n131: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n139;
  t249_n132: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n138;
  t249_n133: if (E.getNumReferences() >= 3274178560 /*168.0*/) goto t249_n137;
  t249_n134: if (E.getNumReferences() >= 3269001216 /*108.5*/) goto t249_n136;
  t249_n135: return -0.3297380805015564;
  t249_n136: return 0.10548937320709229;
  t249_n137: return -0.197080597281456;
  t249_n138: return 0.013692863285541534;
  t249_n139: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t249_n151;
  t249_n140: if (E.getNumReferences() >= 3274047488 /*166.0*/) goto t249_n150;
  t249_n141: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n143;
  t249_n142: return -0.20664642751216888;
  t249_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t249_n145;
  t249_n144: return 0.0881505012512207;
  t249_n145: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t249_n147;
  t249_n146: return -0.04863353073596954;
  t249_n147: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t249_n149;
  t249_n148: return 0.014896823093295097;
  t249_n149: return 0.10662771761417389;
  t249_n150: return 0.09233442693948746;
  t249_n151: return -0.06067914515733719;
  t249_n152: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t249_n230;
  t249_n153: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t249_n165;
  t249_n154: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t249_n156;
  t249_n155: return -0.02660883590579033;
  t249_n156: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t249_n164;
  t249_n157: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t249_n159;
  t249_n158: return -0.019650384783744812;
  t249_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t249_n161;
  t249_n160: return 0.017170196399092674;
  t249_n161: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t249_n163;
  t249_n162: return 0.05839894339442253;
  t249_n163: return 0.042001690715551376;
  t249_n164: return 0.005162880290299654;
  t249_n165: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t249_n167;
  t249_n166: return -0.030798083171248436;
  t249_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t249_n207;
  t249_n168: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t249_n170;
  t249_n169: return -0.003200497245416045;
  t249_n170: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t249_n204;
  t249_n171: if (E.getNumReferences() >= 3285516288 /*426.0*/) goto t249_n173;
  t249_n172: return -0.011549372225999832;
  t249_n173: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t249_n183;
  t249_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n176;
  t249_n175: return 0.06000044569373131;
  t249_n176: if (E.getNumReferences() >= 3326347776 /*12546.5*/) goto t249_n180;
  t249_n177: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t249_n179;
  t249_n178: return 0.12102532386779785;
  t249_n179: return -0.1152951791882515;
  t249_n180: if (E.getNumReferences() >= 3333374720 /*22433.5*/) goto t249_n182;
  t249_n181: return 0.2770821750164032;
  t249_n182: return -0.03952778875827789;
  t249_n183: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t249_n185;
  t249_n184: return 0.07281368225812912;
  t249_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t249_n203;
  t249_n186: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t249_n202;
  t249_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t249_n201;
  t249_n188: if (E.getNumReferences() >= 3290619904 /*651.5*/) goto t249_n190;
  t249_n189: return -0.10410080850124359;
  t249_n190: if (E.getNumReferences() >= 3291021312 /*676.0*/) goto t249_n192;
  t249_n191: return 0.1268501877784729;
  t249_n192: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t249_n198;
  t249_n193: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t249_n197;
  t249_n194: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t249_n196;
  t249_n195: return 0.11632902175188065;
  t249_n196: return 0.08968929201364517;
  t249_n197: return -0.14158201217651367;
  t249_n198: if (E.getNumReferences() >= 3308046336 /*2764.5*/) goto t249_n200;
  t249_n199: return 0.10979311913251877;
  t249_n200: return 0.07061515003442764;
  t249_n201: return -0.012832462787628174;
  t249_n202: return -0.12554067373275757;
  t249_n203: return 0.04063865914940834;
  t249_n204: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t249_n206;
  t249_n205: return -0.09424977004528046;
  t249_n206: return 0.1283944845199585;
  t249_n207: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t249_n211;
  t249_n208: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t249_n210;
  t249_n209: return -0.11822741478681564;
  t249_n210: return 0.12772338092327118;
  t249_n211: if (E.getNumReferences() >= 3325630464 /*11846.0*/) goto t249_n213;
  t249_n212: return 0.013928079977631569;
  t249_n213: if (E.getNumReferences() >= 3350198912 /*90101.0*/) goto t249_n229;
  t249_n214: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t249_n222;
  t249_n215: if (E.getNumReferences() >= 3348327104 /*75477.5*/) goto t249_n217;
  t249_n216: return 0.034325748682022095;
  t249_n217: if (E.getNumReferences() >= 3348491712 /*76763.5*/) goto t249_n221;
  t249_n218: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t249_n220;
  t249_n219: return 0.05646951124072075;
  t249_n220: return 0.004860611632466316;
  t249_n221: return 0.039683613926172256;
  t249_n222: if (E.getNumReferences() >= 3333936384 /*23530.5*/) goto t249_n224;
  t249_n223: return 0.0467170886695385;
  t249_n224: if (E.getNumReferences() >= 3335077120 /*25758.5*/) goto t249_n226;
  t249_n225: return 0.11048052459955215;
  t249_n226: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t249_n228;
  t249_n227: return -0.17512422800064087;
  t249_n228: return 0.12345641106367111;
  t249_n229: return -0.009149143472313881;
  t249_n230: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t249_n242;
  t249_n231: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t249_n241;
  t249_n232: if (E.getNumReferences() >= 3301228544 /*1574.0*/) goto t249_n234;
  t249_n233: return -0.050683654844760895;
  t249_n234: if (E.getNumReferences() >= 3301416960 /*1597.0*/) goto t249_n236;
  t249_n235: return 0.09780242294073105;
  t249_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t249_n238;
  t249_n237: return 0.009001832455396652;
  t249_n238: if (E.getNumReferences() >= 3304833024 /*2014.0*/) goto t249_n240;
  t249_n239: return 0.10708367824554443;
  t249_n240: return 0.04509671404957771;
  t249_n241: return 0.022580942139029503;
  t249_n242: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t249_n244;
  t249_n243: return 0.03302409127354622;
  t249_n244: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t249_n254;
  t249_n245: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t249_n249;
  t249_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t249_n248;
  t249_n247: return -0.08674107491970062;
  t249_n248: return 0.13062773644924164;
  t249_n249: if (E.getNumReferences() >= 3288948736 /*549.5*/) goto t249_n251;
  t249_n250: return 0.05711936950683594;
  t249_n251: if (E.getNumReferences() >= 3291684864 /*716.5*/) goto t249_n253;
  t249_n252: return 0.12734901905059814;
  t249_n253: return 0.017207736149430275;
  t249_n254: return 0.03847238048911095;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree250(const Example& E) {
  t250_n0: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t250_n86;
  t250_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t250_n5;
  t250_n2: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t250_n4;
  t250_n3: return -0.07573062181472778;
  t250_n4: return -0.007578597869724035;
  t250_n5: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t250_n7;
  t250_n6: return -0.00047731728409416974;
  t250_n7: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t250_n9;
  t250_n8: return 0.02088080905377865;
  t250_n9: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t250_n15;
  t250_n10: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t250_n14;
  t250_n11: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t250_n13;
  t250_n12: return 0.03127611428499222;
  t250_n13: return 0.12149722874164581;
  t250_n14: return 0.01016273908317089;
  t250_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t250_n83;
  t250_n16: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n18;
  t250_n17: return -0.0234710443764925;
  t250_n18: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t250_n64;
  t250_n19: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t250_n57;
  t250_n20: if (E.getNumReferences() >= 3259498496 /*50.0*/) goto t250_n56;
  t250_n21: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t250_n51;
  t250_n22: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t250_n44;
  t250_n23: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t250_n43;
  t250_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n28;
  t250_n25: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t250_n27;
  t250_n26: return 0.027858823537826538;
  t250_n27: return 0.09296302497386932;
  t250_n28: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t250_n42;
  t250_n29: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t250_n41;
  t250_n30: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t250_n32;
  t250_n31: return 0.043143436312675476;
  t250_n32: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t250_n38;
  t250_n33: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t250_n37;
  t250_n34: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t250_n36;
  t250_n35: return -0.12939660251140594;
  t250_n36: return 0.08814314752817154;
  t250_n37: return 0.07477985322475433;
  t250_n38: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t250_n40;
  t250_n39: return -0.38603541254997253;
  t250_n40: return 0.06655760109424591;
  t250_n41: return 0.015633031725883484;
  t250_n42: return 0.019044112414121628;
  t250_n43: return 0.020483991131186485;
  t250_n44: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t250_n46;
  t250_n45: return 0.1289733350276947;
  t250_n46: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t250_n48;
  t250_n47: return -0.10180874913930893;
  t250_n48: if (E.getNumReferences() >= 3246391296 /*16.0*/) goto t250_n50;
  t250_n49: return 0.03407949581742287;
  t250_n50: return 0.11056777089834213;
  t250_n51: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t250_n55;
  t250_n52: if (E.getNumReferences() >= 3256090624 /*37.0*/) goto t250_n54;
  t250_n53: return 0.12991102039813995;
  t250_n54: return 0.08924510329961777;
  t250_n55: return 0.012420160695910454;
  t250_n56: return 0.10276858508586884;
  t250_n57: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t250_n63;
  t250_n58: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t250_n60;
  t250_n59: return 0.14148454368114471;
  t250_n60: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t250_n62;
  t250_n61: return 0.10179043561220169;
  t250_n62: return -0.12127161026000977;
  t250_n63: return 0.011214923113584518;
  t250_n64: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t250_n82;
  t250_n65: if (E.getNumReferences() >= 3267624960 /*98.0*/) goto t250_n73;
  t250_n66: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t250_n72;
  t250_n67: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t250_n69;
  t250_n68: return 0.08040080964565277;
  t250_n69: if (E.getNumReferences() >= 3245342720 /*15.0*/) goto t250_n71;
  t250_n70: return 0.10967136919498444;
  t250_n71: return -0.12931013107299805;
  t250_n72: return -0.053608719259500504;
  t250_n73: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t250_n79;
  t250_n74: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t250_n78;
  t250_n75: if (E.getNumReferences() >= 3274670080 /*175.5*/) goto t250_n77;
  t250_n76: return 0.032194048166275024;
  t250_n77: return 0.10593065619468689;
  t250_n78: return -0.04560554772615433;
  t250_n79: if (E.getNumReferences() >= 3272835072 /*147.5*/) goto t250_n81;
  t250_n80: return 0.10083342343568802;
  t250_n81: return 0.04121845215559006;
  t250_n82: return -0.037802428007125854;
  t250_n83: if (E.getNumReferences() >= 3342541568 /*47907.0*/) goto t250_n85;
  t250_n84: return -0.02233300171792507;
  t250_n85: return 0.059258364140987396;
  t250_n86: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t250_n254;
  t250_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Type))) goto t250_n249;
  t250_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t250_n134;
  t250_n89: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t250_n131;
  t250_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t250_n100;
  t250_n91: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t250_n93;
  t250_n92: return 0.0011782569345086813;
  t250_n93: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t250_n99;
  t250_n94: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n96;
  t250_n95: return 0.08326181769371033;
  t250_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t250_n98;
  t250_n97: return 0.1351311355829239;
  t250_n98: return 0.15589416027069092;
  t250_n99: return -0.023495834320783615;
  t250_n100: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t250_n128;
  t250_n101: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t250_n123;
  t250_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n108;
  t250_n103: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t250_n105;
  t250_n104: return -0.023973682895302773;
  t250_n105: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t250_n107;
  t250_n106: return -0.04260933771729469;
  t250_n107: return 0.013481304049491882;
  t250_n108: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t250_n110;
  t250_n109: return 0.017130127176642418;
  t250_n110: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t250_n118;
  t250_n111: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t250_n115;
  t250_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n114;
  t250_n113: return -0.03404458984732628;
  t250_n114: return 0.03392718359827995;
  t250_n115: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t250_n117;
  t250_n116: return -0.03456352651119232;
  t250_n117: return -0.005347564350813627;
  t250_n118: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t250_n120;
  t250_n119: return 0.04838518425822258;
  t250_n120: if (E.getNumReferences() >= 3256352768 /*38.0*/) goto t250_n122;
  t250_n121: return -0.15651898086071014;
  t250_n122: return 0.023331401869654655;
  t250_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n127;
  t250_n124: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n126;
  t250_n125: return 0.05275541543960571;
  t250_n126: return -0.054345861077308655;
  t250_n127: return -0.020629795268177986;
  t250_n128: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n130;
  t250_n129: return -0.02754412591457367;
  t250_n130: return -0.34511348605155945;
  t250_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t250_n133;
  t250_n132: return -0.03466760739684105;
  t250_n133: return -0.0258746650069952;
  t250_n134: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t250_n162;
  t250_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t250_n139;
  t250_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n138;
  t250_n137: return 0.002392733469605446;
  t250_n138: return -0.007376069203019142;
  t250_n139: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n141;
  t250_n140: return 0.000376583804609254;
  t250_n141: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n151;
  t250_n142: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t250_n146;
  t250_n143: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t250_n145;
  t250_n144: return 0.022719500586390495;
  t250_n145: return -0.0278455913066864;
  t250_n146: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t250_n150;
  t250_n147: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t250_n149;
  t250_n148: return 0.06878212839365005;
  t250_n149: return 0.11805698275566101;
  t250_n150: return 0.03371823951601982;
  t250_n151: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t250_n159;
  t250_n152: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t250_n158;
  t250_n153: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t250_n157;
  t250_n154: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n156;
  t250_n155: return 0.11517172306776047;
  t250_n156: return -0.14779546856880188;
  t250_n157: return 0.016522318124771118;
  t250_n158: return -0.0018795536598190665;
  t250_n159: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t250_n161;
  t250_n160: return 0.10000487416982651;
  t250_n161: return 0.07862933725118637;
  t250_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t250_n172;
  t250_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n169;
  t250_n164: if (E.getNumReferences() >= 3342343040 /*47131.5*/) goto t250_n166;
  t250_n165: return 0.03164372220635414;
  t250_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n168;
  t250_n167: return 0.04520007222890854;
  t250_n168: return 0.04320826008915901;
  t250_n169: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t250_n171;
  t250_n170: return 0.03632902726531029;
  t250_n171: return 0.047829363495111465;
  t250_n172: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t250_n228;
  t250_n173: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t250_n189;
  t250_n174: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t250_n176;
  t250_n175: return -0.038455042988061905;
  t250_n176: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t250_n178;
  t250_n177: return 0.042074453085660934;
  t250_n178: if (E.getNumReferences() >= 3320975360 /*7746.0*/) goto t250_n186;
  t250_n179: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t250_n185;
  t250_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t250_n182;
  t250_n181: return 0.008281557820737362;
  t250_n182: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t250_n184;
  t250_n183: return 0.0422414094209671;
  t250_n184: return 0.10449296236038208;
  t250_n185: return -0.0007647154270671308;
  t250_n186: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t250_n188;
  t250_n187: return 0.13325664401054382;
  t250_n188: return -0.2344980686903;
  t250_n189: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t250_n197;
  t250_n190: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n196;
  t250_n191: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t250_n193;
  t250_n192: return -0.16391782462596893;
  t250_n193: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t250_n195;
  t250_n194: return 0.10247654467821121;
  t250_n195: return 0.08784588426351547;
  t250_n196: return 0.0030287466943264008;
  t250_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n219;
  t250_n198: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t250_n218;
  t250_n199: if (E.getNumReferences() >= 3343172480 /*50371.5*/) goto t250_n201;
  t250_n200: return 0.02444671094417572;
  t250_n201: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t250_n209;
  t250_n202: if (E.getNumReferences() >= 3344088704 /*53950.5*/) goto t250_n204;
  t250_n203: return 0.11743149906396866;
  t250_n204: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t250_n208;
  t250_n205: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t250_n207;
  t250_n206: return -0.013116692192852497;
  t250_n207: return 0.11731349676847458;
  t250_n208: return -0.7964848875999451;
  t250_n209: if (E.getNumReferences() >= 3343967744 /*53478.0*/) goto t250_n213;
  t250_n210: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t250_n212;
  t250_n211: return 0.11553163081407547;
  t250_n212: return 0.05040830373764038;
  t250_n213: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t250_n215;
  t250_n214: return 0.03549725562334061;
  t250_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t250_n217;
  t250_n216: return 0.12421101331710815;
  t250_n217: return 0.10001281648874283;
  t250_n218: return -0.005799827631562948;
  t250_n219: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n227;
  t250_n220: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t250_n226;
  t250_n221: if (E.getNumReferences() >= 3333923840 /*23506.0*/) goto t250_n225;
  t250_n222: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t250_n224;
  t250_n223: return -0.12803493440151215;
  t250_n224: return 0.10749463737010956;
  t250_n225: return 0.022213829681277275;
  t250_n226: return 0.09946668148040771;
  t250_n227: return 0.05516577512025833;
  t250_n228: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t250_n240;
  t250_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n231;
  t250_n230: return 0.06881152838468552;
  t250_n231: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t250_n233;
  t250_n232: return 0.05202244594693184;
  t250_n233: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t250_n237;
  t250_n234: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t250_n236;
  t250_n235: return -0.15090809762477875;
  t250_n236: return 0.12948325276374817;
  t250_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t250_n239;
  t250_n238: return 0.24948589503765106;
  t250_n239: return 0.05299833044409752;
  t250_n240: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t250_n248;
  t250_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t250_n243;
  t250_n242: return -0.039742350578308105;
  t250_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t250_n245;
  t250_n244: return 0.12656207382678986;
  t250_n245: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t250_n247;
  t250_n246: return 0.2047608345746994;
  t250_n247: return 0.09131361544132233;
  t250_n248: return 0.030073465779423714;
  t250_n249: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t250_n251;
  t250_n250: return -0.11600925028324127;
  t250_n251: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t250_n253;
  t250_n252: return 0.009670496918261051;
  t250_n253: return -0.006590001285076141;
  t250_n254: return -0.002280907006934285;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree251(const Example& E) {
  t251_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t251_n254;
  t251_n1: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t251_n253;
  t251_n2: if (E.getNumReferences() >= 3294683136 /*899.5*/) goto t251_n248;
  t251_n3: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t251_n217;
  t251_n4: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t251_n174;
  t251_n5: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t251_n55;
  t251_n6: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n8;
  t251_n7: return 0.0008460190729238093;
  t251_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t251_n54;
  t251_n9: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t251_n19;
  t251_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t251_n12;
  t251_n11: return -0.058537062257528305;
  t251_n12: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n14;
  t251_n13: return -0.046792056411504745;
  t251_n14: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t251_n16;
  t251_n15: return -0.03894174471497536;
  t251_n16: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t251_n18;
  t251_n17: return 0.1292792111635208;
  t251_n18: return 0.0413772389292717;
  t251_n19: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t251_n21;
  t251_n20: return -0.03426407277584076;
  t251_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t251_n23;
  t251_n22: return 0.008590622805058956;
  t251_n23: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t251_n53;
  t251_n24: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t251_n42;
  t251_n25: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t251_n41;
  t251_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n28;
  t251_n27: return -0.29045411944389343;
  t251_n28: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t251_n38;
  t251_n29: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n31;
  t251_n30: return 0.05312122032046318;
  t251_n31: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n33;
  t251_n32: return 0.09124018996953964;
  t251_n33: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t251_n37;
  t251_n34: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n36;
  t251_n35: return 0.14626410603523254;
  t251_n36: return 0.09473678469657898;
  t251_n37: return 0.12394542992115021;
  t251_n38: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t251_n40;
  t251_n39: return 0.015380339697003365;
  t251_n40: return 0.104399673640728;
  t251_n41: return 0.08841776847839355;
  t251_n42: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t251_n52;
  t251_n43: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n45;
  t251_n44: return -0.13926951587200165;
  t251_n45: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t251_n51;
  t251_n46: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t251_n50;
  t251_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t251_n49;
  t251_n48: return 0.05659663677215576;
  t251_n49: return 0.07671685516834259;
  t251_n50: return 0.10782863944768906;
  t251_n51: return -0.030997369438409805;
  t251_n52: return -0.1777627021074295;
  t251_n53: return -0.06182757392525673;
  t251_n54: return 0.023305682465434074;
  t251_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t251_n131;
  t251_n56: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t251_n66;
  t251_n57: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n63;
  t251_n58: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t251_n60;
  t251_n59: return -0.028497369959950447;
  t251_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t251_n62;
  t251_n61: return 0.0886923149228096;
  t251_n62: return 0.10490810871124268;
  t251_n63: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n65;
  t251_n64: return -0.664527177810669;
  t251_n65: return -0.006351650692522526;
  t251_n66: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t251_n130;
  t251_n67: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t251_n75;
  t251_n68: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n72;
  t251_n69: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t251_n71;
  t251_n70: return -0.022141749039292336;
  t251_n71: return -0.13330256938934326;
  t251_n72: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t251_n74;
  t251_n73: return 0.023765916004776955;
  t251_n74: return -0.0052779195830225945;
  t251_n75: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t251_n123;
  t251_n76: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t251_n122;
  t251_n77: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t251_n79;
  t251_n78: return 0.023402228951454163;
  t251_n79: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n93;
  t251_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n82;
  t251_n81: return -0.06381210684776306;
  t251_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n84;
  t251_n83: return -0.05588669702410698;
  t251_n84: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t251_n86;
  t251_n85: return 0.02125735767185688;
  t251_n86: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n92;
  t251_n87: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t251_n91;
  t251_n88: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t251_n90;
  t251_n89: return 0.118331179022789;
  t251_n90: return -0.030166111886501312;
  t251_n91: return -0.16322004795074463;
  t251_n92: return 0.36540260910987854;
  t251_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t251_n95;
  t251_n94: return 0.08047620207071304;
  t251_n95: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t251_n119;
  t251_n96: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n98;
  t251_n97: return -0.061719827353954315;
  t251_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n108;
  t251_n99: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t251_n103;
  t251_n100: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t251_n102;
  t251_n101: return -0.1286735087633133;
  t251_n102: return 0.23879677057266235;
  t251_n103: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t251_n107;
  t251_n104: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t251_n106;
  t251_n105: return 0.14156855642795563;
  t251_n106: return 0.12586282193660736;
  t251_n107: return 0.043722521513700485;
  t251_n108: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n114;
  t251_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t251_n113;
  t251_n110: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t251_n112;
  t251_n111: return -0.15810100734233856;
  t251_n112: return 0.11763371527194977;
  t251_n113: return 0.09545930474996567;
  t251_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel))) goto t251_n116;
  t251_n115: return 0.09294086694717407;
  t251_n116: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t251_n118;
  t251_n117: return 0.12283080816268921;
  t251_n118: return 0.12704052031040192;
  t251_n119: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n121;
  t251_n120: return 0.13113564252853394;
  t251_n121: return 0.16428446769714355;
  t251_n122: return -0.04689015448093414;
  t251_n123: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n129;
  t251_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t251_n126;
  t251_n125: return -0.11600060015916824;
  t251_n126: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t251_n128;
  t251_n127: return 0.19707907736301422;
  t251_n128: return 0.2890290319919586;
  t251_n129: return -0.866955578327179;
  t251_n130: return 0.4444006085395813;
  t251_n131: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t251_n161;
  t251_n132: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t251_n160;
  t251_n133: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t251_n159;
  t251_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t251_n136;
  t251_n135: return -0.03964156284928322;
  t251_n136: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n144;
  t251_n137: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t251_n143;
  t251_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n142;
  t251_n139: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t251_n141;
  t251_n140: return 0.10279899090528488;
  t251_n141: return -1.1287521123886108;
  t251_n142: return -0.07556550204753876;
  t251_n143: return -0.0385507196187973;
  t251_n144: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t251_n154;
  t251_n145: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n151;
  t251_n146: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n150;
  t251_n147: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t251_n149;
  t251_n148: return -0.12610097229480743;
  t251_n149: return 0.10165658593177795;
  t251_n150: return 0.14470604062080383;
  t251_n151: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n153;
  t251_n152: return 0.12639838457107544;
  t251_n153: return -0.1162201538681984;
  t251_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n156;
  t251_n155: return -0.15668006241321564;
  t251_n156: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t251_n158;
  t251_n157: return -0.101308174431324;
  t251_n158: return 0.14163044095039368;
  t251_n159: return -0.020135659724473953;
  t251_n160: return -0.021555837243795395;
  t251_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t251_n173;
  t251_n162: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t251_n172;
  t251_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t251_n165;
  t251_n164: return 0.03466653451323509;
  t251_n165: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t251_n167;
  t251_n166: return 0.09830939769744873;
  t251_n167: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n171;
  t251_n168: if (E.getNumReferences() >= 3235905536 /*7.0*/) goto t251_n170;
  t251_n169: return 0.049078360199928284;
  t251_n170: return 0.1087256520986557;
  t251_n171: return -0.10037816315889359;
  t251_n172: return -0.10514752566814423;
  t251_n173: return 0.09890104830265045;
  t251_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t251_n176;
  t251_n175: return -0.1136365607380867;
  t251_n176: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t251_n216;
  t251_n177: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t251_n215;
  t251_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t251_n180;
  t251_n179: return 0.047249291092157364;
  t251_n180: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t251_n188;
  t251_n181: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t251_n183;
  t251_n182: return 0.024623528122901917;
  t251_n183: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t251_n185;
  t251_n184: return 0.0014247403014451265;
  t251_n185: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t251_n187;
  t251_n186: return 0.10564199090003967;
  t251_n187: return -0.045549433678388596;
  t251_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t251_n190;
  t251_n189: return 0.023787586018443108;
  t251_n190: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t251_n194;
  t251_n191: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t251_n193;
  t251_n192: return -0.02786530740559101;
  t251_n193: return 0.15959013998508453;
  t251_n194: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t251_n202;
  t251_n195: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t251_n197;
  t251_n196: return 0.090665303170681;
  t251_n197: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t251_n201;
  t251_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n200;
  t251_n199: return 0.12297441065311432;
  t251_n200: return 0.05045964941382408;
  t251_n201: return 0.10715647786855698;
  t251_n202: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t251_n214;
  t251_n203: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t251_n213;
  t251_n204: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t251_n210;
  t251_n205: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t251_n207;
  t251_n206: return 0.06850829720497131;
  t251_n207: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t251_n209;
  t251_n208: return 0.11116161942481995;
  t251_n209: return 0.11666788905858994;
  t251_n210: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t251_n212;
  t251_n211: return 0.12468157708644867;
  t251_n212: return -0.09014154225587845;
  t251_n213: return -0.3826810121536255;
  t251_n214: return -0.028742263093590736;
  t251_n215: return -0.0035868166014552116;
  t251_n216: return 0.0067685442045331;
  t251_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol))) goto t251_n219;
  t251_n218: return 0.009406433440744877;
  t251_n219: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t251_n243;
  t251_n220: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t251_n224;
  t251_n221: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t251_n223;
  t251_n222: return -0.12459689378738403;
  t251_n223: return 0.03602784126996994;
  t251_n224: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t251_n236;
  t251_n225: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n227;
  t251_n226: return -0.06676075607538223;
  t251_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t251_n235;
  t251_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t251_n230;
  t251_n229: return -0.9702273011207581;
  t251_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n234;
  t251_n231: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n233;
  t251_n232: return 0.1281798779964447;
  t251_n233: return 0.1204414889216423;
  t251_n234: return -0.10590244829654694;
  t251_n235: return 0.12429303675889969;
  t251_n236: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t251_n238;
  t251_n237: return -0.025740966200828552;
  t251_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n240;
  t251_n239: return 0.05019634589552879;
  t251_n240: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n242;
  t251_n241: return -0.18996018171310425;
  t251_n242: return 0.11993817985057831;
  t251_n243: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t251_n247;
  t251_n244: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t251_n246;
  t251_n245: return 0.03862281143665314;
  t251_n246: return -0.028713682666420937;
  t251_n247: return -5.621318268822506e-05;
  t251_n248: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t251_n250;
  t251_n249: return -0.17434997856616974;
  t251_n250: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t251_n252;
  t251_n251: return -1.1187759637832642;
  t251_n252: return 0.09991370886564255;
  t251_n253: return -0.022754816338419914;
  t251_n254: return -0.0005396142369136214;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree252(const Example& E) {
  t252_n0: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t252_n206;
  t252_n1: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t252_n115;
  t252_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n4;
  t252_n3: return -0.0020793613512068987;
  t252_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n66;
  t252_n5: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t252_n13;
  t252_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n8;
  t252_n7: return -0.007689312566071749;
  t252_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Namespace))) goto t252_n10;
  t252_n9: return -0.028877463191747665;
  t252_n10: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t252_n12;
  t252_n11: return -0.09502160549163818;
  t252_n12: return 0.04206758365035057;
  t252_n13: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t252_n57;
  t252_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n30;
  t252_n15: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n27;
  t252_n16: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t252_n26;
  t252_n17: if (E.getNumReferences() >= 3252944896 /*28.5*/) goto t252_n23;
  t252_n18: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n20;
  t252_n19: return -0.009944042190909386;
  t252_n20: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t252_n22;
  t252_n21: return 0.13750946521759033;
  t252_n22: return 0.03890620917081833;
  t252_n23: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t252_n25;
  t252_n24: return 0.1106770858168602;
  t252_n25: return -0.004074375610798597;
  t252_n26: return -0.030939044430851936;
  t252_n27: if (E.getNumReferences() >= 3355694624 /*135000.5*/) goto t252_n29;
  t252_n28: return 0.006649407558143139;
  t252_n29: return -0.08667148649692535;
  t252_n30: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t252_n32;
  t252_n31: return 0.015317412093281746;
  t252_n32: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t252_n38;
  t252_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n37;
  t252_n34: if (E.getFileProximityDistance() >= 3251634176 /*26.0*/) goto t252_n36;
  t252_n35: return -0.007866493426263332;
  t252_n36: return 0.09093550592660904;
  t252_n37: return 0.01284045446664095;
  t252_n38: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t252_n56;
  t252_n39: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n41;
  t252_n40: return 0.10535865277051926;
  t252_n41: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t252_n53;
  t252_n42: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t252_n52;
  t252_n43: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t252_n51;
  t252_n44: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t252_n46;
  t252_n45: return 0.11742610484361649;
  t252_n46: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t252_n48;
  t252_n47: return -0.1144365444779396;
  t252_n48: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t252_n50;
  t252_n49: return 0.12139711529016495;
  t252_n50: return 0.022228216752409935;
  t252_n51: return -0.047988250851631165;
  t252_n52: return -0.06512752920389175;
  t252_n53: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t252_n55;
  t252_n54: return -0.007541762199252844;
  t252_n55: return 0.1141665130853653;
  t252_n56: return 0.013401973061263561;
  t252_n57: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t252_n59;
  t252_n58: return 0.018367625772953033;
  t252_n59: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t252_n65;
  t252_n60: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t252_n62;
  t252_n61: return -0.05045308172702789;
  t252_n62: if (E.getNumReferences() >= 3369849520 /*450197.5*/) goto t252_n64;
  t252_n63: return 0.09349492937326431;
  t252_n64: return 0.0406775139272213;
  t252_n65: return 0.015857592225074768;
  t252_n66: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t252_n114;
  t252_n67: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n97;
  t252_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n94;
  t252_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t252_n91;
  t252_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t252_n88;
  t252_n71: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t252_n77;
  t252_n72: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t252_n74;
  t252_n73: return -0.016590436920523643;
  t252_n74: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n76;
  t252_n75: return -0.13403891026973724;
  t252_n76: return -0.057892560958862305;
  t252_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t252_n79;
  t252_n78: return -0.32224786281585693;
  t252_n79: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t252_n85;
  t252_n80: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t252_n82;
  t252_n81: return 0.04054633155465126;
  t252_n82: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t252_n84;
  t252_n83: return 0.1010517030954361;
  t252_n84: return 0.04866061359643936;
  t252_n85: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t252_n87;
  t252_n86: return 0.08670175075531006;
  t252_n87: return -0.03791720047593117;
  t252_n88: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t252_n90;
  t252_n89: return -0.04514126107096672;
  t252_n90: return -0.019096767529845238;
  t252_n91: if (E.getSymbolScopeDistance() >= 3238002688 /*8.0*/) goto t252_n93;
  t252_n92: return 0.004176125396043062;
  t252_n93: return 0.08902600407600403;
  t252_n94: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n96;
  t252_n95: return 0.035690128803253174;
  t252_n96: return -0.0002662641345523298;
  t252_n97: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t252_n99;
  t252_n98: return -0.13693705201148987;
  t252_n99: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t252_n113;
  t252_n100: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t252_n102;
  t252_n101: return -0.032500479370355606;
  t252_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n104;
  t252_n103: return -0.011921325698494911;
  t252_n104: if (E.getNumReferences() >= 3313405952 /*4073.0*/) goto t252_n112;
  t252_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n109;
  t252_n106: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t252_n108;
  t252_n107: return 0.027379313483834267;
  t252_n108: return 0.11452055722475052;
  t252_n109: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t252_n111;
  t252_n110: return 0.11580731719732285;
  t252_n111: return 0.10050761699676514;
  t252_n112: return -0.020809466019272804;
  t252_n113: return 0.10220186412334442;
  t252_n114: return 0.004363608546555042;
  t252_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t252_n167;
  t252_n116: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n144;
  t252_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n123;
  t252_n118: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t252_n120;
  t252_n119: return 0.007012073416262865;
  t252_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t252_n122;
  t252_n121: return 0.020526858046650887;
  t252_n122: return 0.03712324798107147;
  t252_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n125;
  t252_n124: return -0.0033736161421984434;
  t252_n125: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t252_n141;
  t252_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n128;
  t252_n127: return -0.132486030459404;
  t252_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n132;
  t252_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess))) goto t252_n131;
  t252_n130: return 0.014797191135585308;
  t252_n131: return 0.07122936844825745;
  t252_n132: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t252_n134;
  t252_n133: return 0.16767112910747528;
  t252_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t252_n136;
  t252_n135: return 0.012193274684250355;
  t252_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t252_n140;
  t252_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n139;
  t252_n138: return -0.074927918612957;
  t252_n139: return 0.11047631502151489;
  t252_n140: return 0.021662145853042603;
  t252_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t252_n143;
  t252_n142: return -0.0015212384751066566;
  t252_n143: return 0.008665969595313072;
  t252_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n150;
  t252_n145: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n147;
  t252_n146: return -0.03919480741024017;
  t252_n147: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t252_n149;
  t252_n148: return -0.0326240248978138;
  t252_n149: return -0.01839413121342659;
  t252_n150: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t252_n152;
  t252_n151: return -0.00823840219527483;
  t252_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n154;
  t252_n153: return -0.10285238176584244;
  t252_n154: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t252_n156;
  t252_n155: return -0.023180076852440834;
  t252_n156: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n160;
  t252_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n159;
  t252_n158: return 0.05000671371817589;
  t252_n159: return -0.005953923333436251;
  t252_n160: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n162;
  t252_n161: return -0.004941958002746105;
  t252_n162: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t252_n164;
  t252_n163: return -0.018215050920844078;
  t252_n164: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t252_n166;
  t252_n165: return 0.04457826539874077;
  t252_n166: return 0.002713683992624283;
  t252_n167: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n173;
  t252_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t252_n170;
  t252_n169: return 0.0012707317946478724;
  t252_n170: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n172;
  t252_n171: return 0.09007865935564041;
  t252_n172: return -0.01300374697893858;
  t252_n173: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t252_n199;
  t252_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t252_n194;
  t252_n175: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t252_n183;
  t252_n176: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t252_n178;
  t252_n177: return 0.024470604956150055;
  t252_n178: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t252_n180;
  t252_n179: return -0.06578332930803299;
  t252_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t252_n182;
  t252_n181: return 0.008668291382491589;
  t252_n182: return 0.11700703948736191;
  t252_n183: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t252_n193;
  t252_n184: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t252_n188;
  t252_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n187;
  t252_n186: return 0.08081656694412231;
  t252_n187: return 0.0034589567221701145;
  t252_n188: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n192;
  t252_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n191;
  t252_n190: return 0.08990965038537979;
  t252_n191: return 0.0903884544968605;
  t252_n192: return -0.01636631414294243;
  t252_n193: return 0.026460453867912292;
  t252_n194: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n198;
  t252_n195: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t252_n197;
  t252_n196: return 0.027539875358343124;
  t252_n197: return 0.10113009065389633;
  t252_n198: return 0.06012967973947525;
  t252_n199: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n205;
  t252_n200: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n204;
  t252_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t252_n203;
  t252_n202: return 0.18870697915554047;
  t252_n203: return 0.11856451630592346;
  t252_n204: return 0.17707036435604095;
  t252_n205: return -0.2312706708908081;
  t252_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t252_n248;
  t252_n207: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t252_n219;
  t252_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t252_n218;
  t252_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n211;
  t252_n210: return -0.08450503647327423;
  t252_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n217;
  t252_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n216;
  t252_n213: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t252_n215;
  t252_n214: return -0.26664984226226807;
  t252_n215: return -0.05236033350229263;
  t252_n216: return -0.1101333349943161;
  t252_n217: return -0.06813525408506393;
  t252_n218: return -0.051707543432712555;
  t252_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t252_n221;
  t252_n220: return -0.021928058937191963;
  t252_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n245;
  t252_n222: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t252_n224;
  t252_n223: return -0.00569854024797678;
  t252_n224: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t252_n236;
  t252_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t252_n231;
  t252_n226: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t252_n230;
  t252_n227: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n229;
  t252_n228: return 0.027001507580280304;
  t252_n229: return -0.012197542935609818;
  t252_n230: return 0.07042620331048965;
  t252_n231: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n235;
  t252_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t252_n234;
  t252_n233: return 0.008464718237519264;
  t252_n234: return 0.09354447573423386;
  t252_n235: return 0.05475258454680443;
  t252_n236: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n238;
  t252_n237: return 0.002088500652462244;
  t252_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t252_n242;
  t252_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t252_n241;
  t252_n240: return -0.13714982569217682;
  t252_n241: return 0.034774258732795715;
  t252_n242: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t252_n244;
  t252_n243: return -0.1078651025891304;
  t252_n244: return 0.06119586154818535;
  t252_n245: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t252_n247;
  t252_n246: return 0.01678338088095188;
  t252_n247: return 0.023935288190841675;
  t252_n248: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t252_n252;
  t252_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t252_n251;
  t252_n250: return -0.10700736194849014;
  t252_n251: return 0.061761416494846344;
  t252_n252: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t252_n254;
  t252_n253: return 0.09740471839904785;
  t252_n254: return 0.048605289310216904;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree253(const Example& E) {
  t253_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t253_n246;
  t253_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t253_n3;
  t253_n2: return -0.00022941002680454403;
  t253_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t253_n67;
  t253_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t253_n26;
  t253_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t253_n17;
  t253_n6: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t253_n10;
  t253_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t253_n9;
  t253_n8: return -0.0345194935798645;
  t253_n9: return 0.06490453332662582;
  t253_n10: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t253_n12;
  t253_n11: return -0.5144620537757874;
  t253_n12: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t253_n16;
  t253_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t253_n15;
  t253_n14: return 0.021105028688907623;
  t253_n15: return 0.09700210392475128;
  t253_n16: return -0.003434708109125495;
  t253_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n21;
  t253_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n20;
  t253_n19: return -0.6474971771240234;
  t253_n20: return 0.03680209815502167;
  t253_n21: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t253_n25;
  t253_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n24;
  t253_n23: return 0.10127002000808716;
  t253_n24: return 0.05029893293976784;
  t253_n25: return -0.3924272358417511;
  t253_n26: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t253_n66;
  t253_n27: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t253_n47;
  t253_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t253_n36;
  t253_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t253_n33;
  t253_n30: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t253_n32;
  t253_n31: return -0.026652932167053223;
  t253_n32: return -1.0805878639221191;
  t253_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n35;
  t253_n34: return 0.053597111254930496;
  t253_n35: return 0.04461684450507164;
  t253_n36: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t253_n46;
  t253_n37: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n41;
  t253_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t253_n40;
  t253_n39: return 0.1275259256362915;
  t253_n40: return 0.10083575546741486;
  t253_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n43;
  t253_n42: return 0.0005967382458038628;
  t253_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n45;
  t253_n44: return -0.04606667906045914;
  t253_n45: return 0.1340135782957077;
  t253_n46: return 0.02141869254410267;
  t253_n47: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t253_n49;
  t253_n48: return -0.006146968342363834;
  t253_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t253_n51;
  t253_n50: return -0.015014315024018288;
  t253_n51: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t253_n63;
  t253_n52: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n54;
  t253_n53: return -0.0011864195112138987;
  t253_n54: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t253_n60;
  t253_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n57;
  t253_n56: return -0.19390304386615753;
  t253_n57: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t253_n59;
  t253_n58: return 0.10781136155128479;
  t253_n59: return -0.007131829857826233;
  t253_n60: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n62;
  t253_n61: return 0.09316180646419525;
  t253_n62: return 0.08056730031967163;
  t253_n63: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n65;
  t253_n64: return -0.11734914034605026;
  t253_n65: return 0.031635582447052;
  t253_n66: return -0.009361336007714272;
  t253_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t253_n127;
  t253_n68: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t253_n100;
  t253_n69: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t253_n93;
  t253_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n78;
  t253_n71: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n75;
  t253_n72: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t253_n74;
  t253_n73: return -0.04177619144320488;
  t253_n74: return -0.036185938864946365;
  t253_n75: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t253_n77;
  t253_n76: return -0.031762801110744476;
  t253_n77: return -0.014706515707075596;
  t253_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t253_n80;
  t253_n79: return -0.006524031516164541;
  t253_n80: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n82;
  t253_n81: return -0.10508742928504944;
  t253_n82: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t253_n84;
  t253_n83: return -0.019789207726716995;
  t253_n84: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n86;
  t253_n85: return 0.027388274669647217;
  t253_n86: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n88;
  t253_n87: return -0.015231345780193806;
  t253_n88: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n92;
  t253_n89: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n91;
  t253_n90: return 0.01575714536011219;
  t253_n91: return -0.03472084552049637;
  t253_n92: return 0.029941817745566368;
  t253_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t253_n95;
  t253_n94: return -0.018803734332323074;
  t253_n95: if (E.getNumReferences() >= 3361088608 /*219281.5*/) goto t253_n97;
  t253_n96: return 0.0028699992690235376;
  t253_n97: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t253_n99;
  t253_n98: return 0.006888491101562977;
  t253_n99: return 0.10821014642715454;
  t253_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n114;
  t253_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n107;
  t253_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t253_n106;
  t253_n103: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n105;
  t253_n104: return -0.03964724764227867;
  t253_n105: return -0.06176937744021416;
  t253_n106: return -0.1012917011976242;
  t253_n107: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n111;
  t253_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t253_n110;
  t253_n109: return 0.01697051152586937;
  t253_n110: return 0.06298814713954926;
  t253_n111: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t253_n113;
  t253_n112: return 0.0596969798207283;
  t253_n113: return -0.031014055013656616;
  t253_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t253_n116;
  t253_n115: return 0.0002526360040064901;
  t253_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n126;
  t253_n117: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t253_n119;
  t253_n118: return -0.1547868847846985;
  t253_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n121;
  t253_n120: return 0.07519499957561493;
  t253_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n123;
  t253_n122: return -0.18745195865631104;
  t253_n123: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n125;
  t253_n124: return 0.035286154597997665;
  t253_n125: return 0.010588880628347397;
  t253_n126: return 0.0030008077155798674;
  t253_n127: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t253_n245;
  t253_n128: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t253_n182;
  t253_n129: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t253_n137;
  t253_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n132;
  t253_n131: return -0.030145123600959778;
  t253_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n134;
  t253_n133: return 0.01584797538816929;
  t253_n134: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t253_n136;
  t253_n135: return -0.21088498830795288;
  t253_n136: return -0.04823673143982887;
  t253_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t253_n169;
  t253_n138: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n142;
  t253_n139: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t253_n141;
  t253_n140: return 0.019953157752752304;
  t253_n141: return 0.10585463792085648;
  t253_n142: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t253_n158;
  t253_n143: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n155;
  t253_n144: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n146;
  t253_n145: return 0.02248941920697689;
  t253_n146: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t253_n152;
  t253_n147: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n149;
  t253_n148: return 0.025972405448555946;
  t253_n149: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t253_n151;
  t253_n150: return 0.2083941400051117;
  t253_n151: return -0.11550460755825043;
  t253_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n154;
  t253_n153: return -0.24293704330921173;
  t253_n154: return 0.04245605692267418;
  t253_n155: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n157;
  t253_n156: return -0.132082000374794;
  t253_n157: return 0.018476072698831558;
  t253_n158: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n168;
  t253_n159: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t253_n167;
  t253_n160: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n164;
  t253_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n163;
  t253_n162: return -0.10490292310714722;
  t253_n163: return 0.07602562755346298;
  t253_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n166;
  t253_n165: return -0.015774767845869064;
  t253_n166: return 0.11112193763256073;
  t253_n167: return -0.0015620560152456164;
  t253_n168: return 0.06109952926635742;
  t253_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n179;
  t253_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n172;
  t253_n171: return 0.04266345873475075;
  t253_n172: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n174;
  t253_n173: return 0.06105751916766167;
  t253_n174: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t253_n176;
  t253_n175: return -0.0004760785959661007;
  t253_n176: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n178;
  t253_n177: return 0.09395778179168701;
  t253_n178: return -0.13091479241847992;
  t253_n179: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n181;
  t253_n180: return 0.06179629638791084;
  t253_n181: return -0.008888883516192436;
  t253_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t253_n216;
  t253_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t253_n185;
  t253_n184: return 0.017468545585870743;
  t253_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t253_n209;
  t253_n186: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n202;
  t253_n187: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t253_n201;
  t253_n188: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t253_n198;
  t253_n189: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t253_n193;
  t253_n190: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t253_n192;
  t253_n191: return 0.09522270411252975;
  t253_n192: return -0.005489036440849304;
  t253_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n195;
  t253_n194: return 0.08144323527812958;
  t253_n195: if (E.getNumReferences() >= 3261333504 /*57.0*/) goto t253_n197;
  t253_n196: return 0.1181570291519165;
  t253_n197: return 0.061721328645944595;
  t253_n198: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t253_n200;
  t253_n199: return 0.11962874233722687;
  t253_n200: return 0.09808763116598129;
  t253_n201: return -0.21556618809700012;
  t253_n202: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t253_n208;
  t253_n203: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t253_n207;
  t253_n204: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t253_n206;
  t253_n205: return 0.12123316526412964;
  t253_n206: return 0.17153333127498627;
  t253_n207: return -0.24991680681705475;
  t253_n208: return 0.054148733615875244;
  t253_n209: if (E.getFilterLength() >= 3240624128 /*10.5*/) goto t253_n215;
  t253_n210: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t253_n212;
  t253_n211: return 0.03952523693442345;
  t253_n212: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n214;
  t253_n213: return -0.10977281630039215;
  t253_n214: return 0.12232045829296112;
  t253_n215: return 0.08110447973012924;
  t253_n216: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t253_n242;
  t253_n217: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t253_n241;
  t253_n218: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t253_n232;
  t253_n219: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n221;
  t253_n220: return 0.02167471870779991;
  t253_n221: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t253_n225;
  t253_n222: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n224;
  t253_n223: return 0.11773620545864105;
  t253_n224: return 0.10617902129888535;
  t253_n225: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t253_n231;
  t253_n226: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t253_n230;
  t253_n227: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n229;
  t253_n228: return 0.052987802773714066;
  t253_n229: return 0.13507574796676636;
  t253_n230: return 0.010002391412854195;
  t253_n231: return -0.1964438557624817;
  t253_n232: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t253_n238;
  t253_n233: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t253_n235;
  t253_n234: return 0.11810562759637833;
  t253_n235: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t253_n237;
  t253_n236: return 0.02854950726032257;
  t253_n237: return 0.09650301933288574;
  t253_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t253_n240;
  t253_n239: return -0.21239346265792847;
  t253_n240: return 0.0820024237036705;
  t253_n241: return 0.01731724664568901;
  t253_n242: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t253_n244;
  t253_n243: return 0.11725085228681564;
  t253_n244: return -0.11187401413917542;
  t253_n245: return -0.01225768867880106;
  t253_n246: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t253_n248;
  t253_n247: return -0.012028241530060768;
  t253_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t253_n250;
  t253_n249: return -0.030720701441168785;
  t253_n250: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t253_n252;
  t253_n251: return 0.0378655344247818;
  t253_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t253_n254;
  t253_n253: return -0.035682130604982376;
  t253_n254: return 0.13695786893367767;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree254(const Example& E) {
  t254_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t254_n234;
  t254_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t254_n3;
  t254_n2: return -0.06330560892820358;
  t254_n3: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t254_n5;
  t254_n4: return -0.0005404078401625156;
  t254_n5: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t254_n43;
  t254_n6: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n22;
  t254_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t254_n9;
  t254_n8: return -0.0185096375644207;
  t254_n9: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t254_n17;
  t254_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t254_n16;
  t254_n11: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n13;
  t254_n12: return 0.04795445129275322;
  t254_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t254_n15;
  t254_n14: return -0.14756964147090912;
  t254_n15: return 0.040828753262758255;
  t254_n16: return -0.006196929607540369;
  t254_n17: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t254_n21;
  t254_n18: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n20;
  t254_n19: return 0.06262266635894775;
  t254_n20: return 0.12123763561248779;
  t254_n21: return -0.06623344123363495;
  t254_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t254_n24;
  t254_n23: return 0.000816730665974319;
  t254_n24: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t254_n26;
  t254_n25: return 0.0014817174524068832;
  t254_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n38;
  t254_n27: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n29;
  t254_n28: return 0.03513381630182266;
  t254_n29: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t254_n35;
  t254_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t254_n34;
  t254_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t254_n33;
  t254_n32: return -0.0011900727404281497;
  t254_n33: return 0.07451562583446503;
  t254_n34: return 0.06724726408720016;
  t254_n35: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t254_n37;
  t254_n36: return 0.10466492176055908;
  t254_n37: return -0.03547479584813118;
  t254_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t254_n40;
  t254_n39: return 0.010542323812842369;
  t254_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n42;
  t254_n41: return 0.008978168480098248;
  t254_n42: return -0.029770171269774437;
  t254_n43: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t254_n45;
  t254_n44: return 0.0037405905313789845;
  t254_n45: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t254_n145;
  t254_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n92;
  t254_n47: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n83;
  t254_n48: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t254_n54;
  t254_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t254_n53;
  t254_n50: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t254_n52;
  t254_n51: return 0.08932241052389145;
  t254_n52: return 0.08576695621013641;
  t254_n53: return 0.12128893285989761;
  t254_n54: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t254_n74;
  t254_n55: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t254_n69;
  t254_n56: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t254_n68;
  t254_n57: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t254_n65;
  t254_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n62;
  t254_n59: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n61;
  t254_n60: return -0.6827035546302795;
  t254_n61: return 0.09406092017889023;
  t254_n62: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t254_n64;
  t254_n63: return -0.013304569758474827;
  t254_n64: return 0.1053013950586319;
  t254_n65: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t254_n67;
  t254_n66: return 0.1003301590681076;
  t254_n67: return -0.31519246101379395;
  t254_n68: return 0.10060533136129379;
  t254_n69: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t254_n71;
  t254_n70: return -0.46977493166923523;
  t254_n71: if (E.getNumReferences() >= 3252420608 /*27.5*/) goto t254_n73;
  t254_n72: return 0.081718310713768;
  t254_n73: return -0.5302497148513794;
  t254_n74: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t254_n80;
  t254_n75: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n77;
  t254_n76: return -0.2751978933811188;
  t254_n77: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t254_n79;
  t254_n78: return 0.10728456825017929;
  t254_n79: return 0.10608716309070587;
  t254_n80: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t254_n82;
  t254_n81: return 0.09392169117927551;
  t254_n82: return -0.05897641181945801;
  t254_n83: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t254_n89;
  t254_n84: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t254_n88;
  t254_n85: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t254_n87;
  t254_n86: return -0.042023930698633194;
  t254_n87: return 0.05869950354099274;
  t254_n88: return -0.44802945852279663;
  t254_n89: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t254_n91;
  t254_n90: return 0.09119075536727905;
  t254_n91: return -2.864040834538173e-05;
  t254_n92: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t254_n132;
  t254_n93: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t254_n131;
  t254_n94: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t254_n130;
  t254_n95: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t254_n127;
  t254_n96: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t254_n102;
  t254_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n101;
  t254_n98: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t254_n100;
  t254_n99: return -0.04579384997487068;
  t254_n100: return -0.7947765588760376;
  t254_n101: return 0.0035281393211334944;
  t254_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n114;
  t254_n103: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t254_n109;
  t254_n104: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t254_n106;
  t254_n105: return 0.1104634553194046;
  t254_n106: if (E.getNumReferences() >= 3249799168 /*22.5*/) goto t254_n108;
  t254_n107: return -0.13418301939964294;
  t254_n108: return 0.0760679543018341;
  t254_n109: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t254_n111;
  t254_n110: return 0.058879364281892776;
  t254_n111: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t254_n113;
  t254_n112: return -0.1232684999704361;
  t254_n113: return 0.11072304099798203;
  t254_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n124;
  t254_n115: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t254_n119;
  t254_n116: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t254_n118;
  t254_n117: return 0.027520939707756042;
  t254_n118: return -0.3508301377296448;
  t254_n119: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t254_n121;
  t254_n120: return -0.06461624801158905;
  t254_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n123;
  t254_n122: return -0.032635465264320374;
  t254_n123: return 0.10073527693748474;
  t254_n124: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t254_n126;
  t254_n125: return 0.12117592245340347;
  t254_n126: return -0.8107118010520935;
  t254_n127: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t254_n129;
  t254_n128: return 0.1267196536064148;
  t254_n129: return -0.8808537721633911;
  t254_n130: return 0.1052454486489296;
  t254_n131: return -0.13202494382858276;
  t254_n132: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t254_n134;
  t254_n133: return 0.1094621866941452;
  t254_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t254_n136;
  t254_n135: return -0.0913144201040268;
  t254_n136: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t254_n144;
  t254_n137: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t254_n139;
  t254_n138: return 0.02584495209157467;
  t254_n139: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t254_n141;
  t254_n140: return -0.385940283536911;
  t254_n141: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t254_n143;
  t254_n142: return 0.11237253993749619;
  t254_n143: return 0.10760516673326492;
  t254_n144: return 0.009179751388728619;
  t254_n145: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t254_n151;
  t254_n146: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t254_n150;
  t254_n147: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n149;
  t254_n148: return 0.09640238434076309;
  t254_n149: return -0.08133924007415771;
  t254_n150: return 0.10711188614368439;
  t254_n151: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t254_n175;
  t254_n152: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n162;
  t254_n153: if (E.getNumReferences() >= 3301138432 /*1563.0*/) goto t254_n157;
  t254_n154: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t254_n156;
  t254_n155: return 0.0320681668817997;
  t254_n156: return -0.17654705047607422;
  t254_n157: if (E.getNumReferences() >= 3303743488 /*1881.0*/) goto t254_n159;
  t254_n158: return 0.10394328832626343;
  t254_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n161;
  t254_n160: return -0.19030368328094482;
  t254_n161: return 0.0852402076125145;
  t254_n162: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t254_n168;
  t254_n163: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t254_n165;
  t254_n164: return 0.08616834133863449;
  t254_n165: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t254_n167;
  t254_n166: return -0.6656498312950134;
  t254_n167: return 0.09660597890615463;
  t254_n168: if (E.getNumReferences() >= 3289096192 /*558.5*/) goto t254_n170;
  t254_n169: return -0.015178145840764046;
  t254_n170: if (E.getNumReferences() >= 3294158848 /*867.5*/) goto t254_n174;
  t254_n171: if (E.getNumReferences() >= 3292667904 /*776.5*/) goto t254_n173;
  t254_n172: return 0.028067993000149727;
  t254_n173: return 0.11478810757398605;
  t254_n174: return 0.008163847960531712;
  t254_n175: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t254_n197;
  t254_n176: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t254_n194;
  t254_n177: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t254_n189;
  t254_n178: if (E.getNumReferences() >= 3281272832 /*296.5*/) goto t254_n188;
  t254_n179: if (E.getNumReferences() >= 3276472320 /*203.0*/) goto t254_n187;
  t254_n180: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t254_n184;
  t254_n181: if (E.getNumReferences() >= 3269591040 /*113.0*/) goto t254_n183;
  t254_n182: return -0.030436426401138306;
  t254_n183: return -0.727903425693512;
  t254_n184: if (E.getNumReferences() >= 3274309632 /*170.0*/) goto t254_n186;
  t254_n185: return 0.12001729756593704;
  t254_n186: return -0.056537169963121414;
  t254_n187: return -0.6707778573036194;
  t254_n188: return 0.06187942251563072;
  t254_n189: if (E.getNumReferences() >= 3310616576 /*3392.0*/) goto t254_n193;
  t254_n190: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t254_n192;
  t254_n191: return 0.1001463532447815;
  t254_n192: return 0.06550636142492294;
  t254_n193: return 0.05463699996471405;
  t254_n194: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t254_n196;
  t254_n195: return -0.13108596205711365;
  t254_n196: return 0.08493878692388535;
  t254_n197: if (E.getNumReferences() >= 3260678144 /*54.5*/) goto t254_n211;
  t254_n198: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t254_n208;
  t254_n199: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t254_n201;
  t254_n200: return 0.021126385778188705;
  t254_n201: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t254_n203;
  t254_n202: return 0.11034499108791351;
  t254_n203: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t254_n207;
  t254_n204: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t254_n206;
  t254_n205: return 0.10415960103273392;
  t254_n206: return -0.006285248789936304;
  t254_n207: return 0.22015999257564545;
  t254_n208: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t254_n210;
  t254_n209: return -0.06988973915576935;
  t254_n210: return 0.08799639344215393;
  t254_n211: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t254_n213;
  t254_n212: return -0.026994751766324043;
  t254_n213: if (E.getNumReferences() >= 3332148992 /*20039.5*/) goto t254_n233;
  t254_n214: if (E.getNumReferences() >= 3321412608 /*7959.5*/) goto t254_n228;
  t254_n215: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t254_n217;
  t254_n216: return 0.04001140967011452;
  t254_n217: if (E.getNumReferences() >= 3307327488 /*2589.0*/) goto t254_n225;
  t254_n218: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t254_n220;
  t254_n219: return -0.25596871972084045;
  t254_n220: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n222;
  t254_n221: return 0.08262507617473602;
  t254_n222: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t254_n224;
  t254_n223: return -0.49374544620513916;
  t254_n224: return 0.01753547601401806;
  t254_n225: if (E.getNumReferences() >= 3310909440 /*3463.5*/) goto t254_n227;
  t254_n226: return 0.1035982146859169;
  t254_n227: return -0.0071105039678514;
  t254_n228: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t254_n232;
  t254_n229: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t254_n231;
  t254_n230: return 0.07340869307518005;
  t254_n231: return 0.10286301374435425;
  t254_n232: return 0.07503686845302582;
  t254_n233: return 0.0037375465035438538;
  t254_n234: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t254_n246;
  t254_n235: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n239;
  t254_n236: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t254_n238;
  t254_n237: return -0.09168242663145065;
  t254_n238: return 0.09224024415016174;
  t254_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t254_n245;
  t254_n240: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t254_n242;
  t254_n241: return -0.13441121578216553;
  t254_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t254_n244;
  t254_n243: return -0.2125571370124817;
  t254_n244: return -0.1339312642812729;
  t254_n245: return -0.07662549614906311;
  t254_n246: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t254_n252;
  t254_n247: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t254_n251;
  t254_n248: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t254_n250;
  t254_n249: return 0.002657294739037752;
  t254_n250: return 0.0652896910905838;
  t254_n251: return -0.17741985619068146;
  t254_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t254_n254;
  t254_n253: return 0.08548223972320557;
  t254_n254: return -0.06010254845023155;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree255(const Example& E) {
  t255_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t255_n26;
  t255_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n3;
  t255_n2: return -0.0018491409718990326;
  t255_n3: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t255_n5;
  t255_n4: return 0.003343840828165412;
  t255_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t255_n7;
  t255_n6: return 0.007678324356675148;
  t255_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t255_n9;
  t255_n8: return -0.0233792532235384;
  t255_n9: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t255_n23;
  t255_n10: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t255_n16;
  t255_n11: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t255_n13;
  t255_n12: return -0.059510041028261185;
  t255_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n15;
  t255_n14: return -0.12867006659507751;
  t255_n15: return 0.0657811239361763;
  t255_n16: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t255_n22;
  t255_n17: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t255_n21;
  t255_n18: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t255_n20;
  t255_n19: return -0.10610458999872208;
  t255_n20: return 0.0951056107878685;
  t255_n21: return -0.13303391635417938;
  t255_n22: return -0.005554351024329662;
  t255_n23: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t255_n25;
  t255_n24: return 0.0276038721203804;
  t255_n25: return -0.03279587998986244;
  t255_n26: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t255_n172;
  t255_n27: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t255_n155;
  t255_n28: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t255_n116;
  t255_n29: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t255_n77;
  t255_n30: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t255_n76;
  t255_n31: if (E.getNumReferences() >= 3263496192 /*66.5*/) goto t255_n69;
  t255_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t255_n36;
  t255_n33: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t255_n35;
  t255_n34: return -0.13090580701828003;
  t255_n35: return 0.021853163838386536;
  t255_n36: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t255_n68;
  t255_n37: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t255_n59;
  t255_n38: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t255_n58;
  t255_n39: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t255_n53;
  t255_n40: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t255_n52;
  t255_n41: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n51;
  t255_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t255_n48;
  t255_n43: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n47;
  t255_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t255_n46;
  t255_n45: return 0.055859945714473724;
  t255_n46: return 0.10922630876302719;
  t255_n47: return -0.09530458599328995;
  t255_n48: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t255_n50;
  t255_n49: return -0.0553278774023056;
  t255_n50: return 0.031484268605709076;
  t255_n51: return 0.10915285348892212;
  t255_n52: return -0.7335802912712097;
  t255_n53: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t255_n57;
  t255_n54: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t255_n56;
  t255_n55: return -0.01080633420497179;
  t255_n56: return 0.10913901031017303;
  t255_n57: return 0.02816588617861271;
  t255_n58: return -0.3982486128807068;
  t255_n59: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t255_n65;
  t255_n60: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t255_n62;
  t255_n61: return 0.12897127866744995;
  t255_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n64;
  t255_n63: return -0.06871877610683441;
  t255_n64: return 0.08213836699724197;
  t255_n65: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t255_n67;
  t255_n66: return -0.15905240178108215;
  t255_n67: return 0.10593260824680328;
  t255_n68: return -0.12274354696273804;
  t255_n69: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t255_n71;
  t255_n70: return 0.11468454450368881;
  t255_n71: if (E.getNumReferences() >= 3268280320 /*103.0*/) goto t255_n75;
  t255_n72: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t255_n74;
  t255_n73: return -0.056421633809804916;
  t255_n74: return 0.10110213607549667;
  t255_n75: return -0.21819841861724854;
  t255_n76: return 0.08891133219003677;
  t255_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n79;
  t255_n78: return -0.004468098282814026;
  t255_n79: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t255_n87;
  t255_n80: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t255_n86;
  t255_n81: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t255_n83;
  t255_n82: return -0.02310977689921856;
  t255_n83: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n85;
  t255_n84: return -0.17614521086215973;
  t255_n85: return -0.03665890172123909;
  t255_n86: return 0.09143585711717606;
  t255_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t255_n89;
  t255_n88: return -0.0025120878126472235;
  t255_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t255_n91;
  t255_n90: return -0.0004833569109905511;
  t255_n91: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t255_n115;
  t255_n92: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t255_n114;
  t255_n93: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t255_n103;
  t255_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t255_n96;
  t255_n95: return 0.0473414808511734;
  t255_n96: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n102;
  t255_n97: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n99;
  t255_n98: return 0.05302591994404793;
  t255_n99: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t255_n101;
  t255_n100: return 0.13500060141086578;
  t255_n101: return 0.06089634820818901;
  t255_n102: return -0.11379364132881165;
  t255_n103: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t255_n107;
  t255_n104: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t255_n106;
  t255_n105: return 0.019321003928780556;
  t255_n106: return -0.0846891850233078;
  t255_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t255_n113;
  t255_n108: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t255_n112;
  t255_n109: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n111;
  t255_n110: return 0.045501500368118286;
  t255_n111: return 0.019356975331902504;
  t255_n112: return -0.014749920926988125;
  t255_n113: return 0.07387275248765945;
  t255_n114: return -0.13316014409065247;
  t255_n115: return -0.09176503866910934;
  t255_n116: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n118;
  t255_n117: return -0.07729616016149521;
  t255_n118: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t255_n154;
  t255_n119: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n129;
  t255_n120: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t255_n128;
  t255_n121: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t255_n127;
  t255_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n126;
  t255_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n125;
  t255_n124: return -0.10860514640808105;
  t255_n125: return 0.12159336358308792;
  t255_n126: return -0.14240950345993042;
  t255_n127: return 0.029669957235455513;
  t255_n128: return -0.0969068855047226;
  t255_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t255_n131;
  t255_n130: return -0.13729070127010345;
  t255_n131: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t255_n147;
  t255_n132: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t255_n144;
  t255_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t255_n135;
  t255_n134: return -0.11269166320562363;
  t255_n135: if (E.getFileProximityDistance() >= 3240099840 /*10.0*/) goto t255_n143;
  t255_n136: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t255_n140;
  t255_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t255_n139;
  t255_n138: return 0.08462687581777573;
  t255_n139: return -0.4226550757884979;
  t255_n140: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n142;
  t255_n141: return 0.0;
  t255_n142: return 0.085477314889431;
  t255_n143: return -0.11699500679969788;
  t255_n144: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t255_n146;
  t255_n145: return 0.11213864386081696;
  t255_n146: return 0.10030461847782135;
  t255_n147: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t255_n149;
  t255_n148: return -0.07115644961595535;
  t255_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t255_n151;
  t255_n150: return -0.7843937277793884;
  t255_n151: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t255_n153;
  t255_n152: return 0.11670615524053574;
  t255_n153: return 0.09361445158720016;
  t255_n154: return -0.06041456758975983;
  t255_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t255_n165;
  t255_n156: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t255_n162;
  t255_n157: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t255_n161;
  t255_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t255_n160;
  t255_n159: return -0.010968637652695179;
  t255_n160: return 0.007505600806325674;
  t255_n161: return -0.0013412612024694681;
  t255_n162: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t255_n164;
  t255_n163: return 0.00572931906208396;
  t255_n164: return 0.014997153542935848;
  t255_n165: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t255_n171;
  t255_n166: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t255_n168;
  t255_n167: return 0.047753576189279556;
  t255_n168: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t255_n170;
  t255_n169: return 0.06684277951717377;
  t255_n170: return 0.12198799103498459;
  t255_n171: return 0.011835573241114616;
  t255_n172: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t255_n174;
  t255_n173: return 0.007871419191360474;
  t255_n174: if (E.getNumReferences() >= 3364818608 /*292981.5*/) goto t255_n234;
  t255_n175: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t255_n233;
  t255_n176: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t255_n210;
  t255_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n207;
  t255_n178: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t255_n192;
  t255_n179: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t255_n181;
  t255_n180: return -0.025769967585802078;
  t255_n181: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t255_n185;
  t255_n182: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n184;
  t255_n183: return 0.13628047704696655;
  t255_n184: return -0.04109989106655121;
  t255_n185: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t255_n187;
  t255_n186: return -0.026009034365415573;
  t255_n187: if (E.getNumReferences() >= 3275915264 /*194.5*/) goto t255_n191;
  t255_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t255_n190;
  t255_n189: return 0.070391446352005;
  t255_n190: return 0.10739361494779587;
  t255_n191: return 0.03232298791408539;
  t255_n192: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t255_n198;
  t255_n193: if (E.getNumReferences() >= 3287138304 /*475.5*/) goto t255_n197;
  t255_n194: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t255_n196;
  t255_n195: return 0.006414922885596752;
  t255_n196: return -0.07199607044458389;
  t255_n197: return 0.08161401003599167;
  t255_n198: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t255_n200;
  t255_n199: return -0.010600385256111622;
  t255_n200: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t255_n206;
  t255_n201: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n205;
  t255_n202: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t255_n204;
  t255_n203: return 0.07473945617675781;
  t255_n204: return 0.13975076377391815;
  t255_n205: return 0.048765674233436584;
  t255_n206: return 0.004976572003215551;
  t255_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor))) goto t255_n209;
  t255_n208: return -0.010709322057664394;
  t255_n209: return 0.012053263373672962;
  t255_n210: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t255_n212;
  t255_n211: return -2.6575333322398365e-05;
  t255_n212: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t255_n214;
  t255_n213: return -0.008302743546664715;
  t255_n214: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t255_n232;
  t255_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t255_n221;
  t255_n216: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n220;
  t255_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t255_n219;
  t255_n218: return 0.047695357352495193;
  t255_n219: return 0.09294446557760239;
  t255_n220: return 0.05698477104306221;
  t255_n221: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t255_n231;
  t255_n222: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t255_n224;
  t255_n223: return -0.02441822551190853;
  t255_n224: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n226;
  t255_n225: return 0.07923030108213425;
  t255_n226: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t255_n230;
  t255_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t255_n229;
  t255_n228: return -0.12645216286182404;
  t255_n229: return 0.12092971801757812;
  t255_n230: return 0.07245223969221115;
  t255_n231: return -0.09649620205163956;
  t255_n232: return 0.014157391153275967;
  t255_n233: return 0.0010279575362801552;
  t255_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t255_n236;
  t255_n235: return 0.01459662988781929;
  t255_n236: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t255_n246;
  t255_n237: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t255_n243;
  t255_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t255_n242;
  t255_n239: if (E.getNumReferences() >= 3365247648 /*306389.0*/) goto t255_n241;
  t255_n240: return 0.07803408801555634;
  t255_n241: return -0.20620740950107574;
  t255_n242: return 0.10499832779169083;
  t255_n243: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n245;
  t255_n244: return -0.01569921337068081;
  t255_n245: return 0.07732664793729782;
  t255_n246: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t255_n248;
  t255_n247: return -0.0056165531277656555;
  t255_n248: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t255_n254;
  t255_n249: if (E.getNumReferences() >= 3368194704 /*398484.5*/) goto t255_n251;
  t255_n250: return -0.031952500343322754;
  t255_n251: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t255_n253;
  t255_n252: return 0.0944083109498024;
  t255_n253: return 0.09153558313846588;
  t255_n254: return -0.055179279297590256;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree256(const Example& E) {
  t256_n0: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t256_n254;
  t256_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t256_n145;
  t256_n2: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t256_n72;
  t256_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t256_n71;
  t256_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t256_n28;
  t256_n5: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t256_n25;
  t256_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n8;
  t256_n7: return 0.004443442914634943;
  t256_n8: if (E.getNumReferences() >= 3277979648 /*226.0*/) goto t256_n12;
  t256_n9: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t256_n11;
  t256_n10: return -0.018310632556676865;
  t256_n11: return 0.011634891852736473;
  t256_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t256_n18;
  t256_n13: if (E.getNumReferences() >= 3278569472 /*235.0*/) goto t256_n15;
  t256_n14: return 0.09666075557470322;
  t256_n15: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n17;
  t256_n16: return -0.1747322976589203;
  t256_n17: return 0.06214071810245514;
  t256_n18: if (E.getNumReferences() >= 3280453632 /*271.5*/) goto t256_n20;
  t256_n19: return 0.12097789347171783;
  t256_n20: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t256_n22;
  t256_n21: return -0.22827713191509247;
  t256_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n24;
  t256_n23: return 0.12872864305973053;
  t256_n24: return 0.09805088490247726;
  t256_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t256_n27;
  t256_n26: return -0.02881845273077488;
  t256_n27: return -0.007622479926794767;
  t256_n28: if (E.getNumReferences() >= 3264610304 /*75.0*/) goto t256_n68;
  t256_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n31;
  t256_n30: return -0.042101044207811356;
  t256_n31: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n33;
  t256_n32: return 0.010361921973526478;
  t256_n33: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t256_n57;
  t256_n34: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t256_n46;
  t256_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t256_n39;
  t256_n36: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t256_n38;
  t256_n37: return 0.049389470368623734;
  t256_n38: return 0.0924396738409996;
  t256_n39: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t256_n43;
  t256_n40: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n42;
  t256_n41: return -0.48471927642822266;
  t256_n42: return 0.22349633276462555;
  t256_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n45;
  t256_n44: return 0.07312899082899094;
  t256_n45: return 0.11462800204753876;
  t256_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t256_n48;
  t256_n47: return -0.0888548493385315;
  t256_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n56;
  t256_n49: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t256_n55;
  t256_n50: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t256_n54;
  t256_n51: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n53;
  t256_n52: return 0.1357232928276062;
  t256_n53: return 0.097050242125988;
  t256_n54: return 0.030134523287415504;
  t256_n55: return 0.0654887929558754;
  t256_n56: return 0.046565573662519455;
  t256_n57: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n61;
  t256_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n60;
  t256_n59: return -1.4516109228134155;
  t256_n60: return -0.4057711362838745;
  t256_n61: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t256_n63;
  t256_n62: return -0.06579741835594177;
  t256_n63: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t256_n67;
  t256_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n66;
  t256_n65: return 0.11048150062561035;
  t256_n66: return 0.11095511168241501;
  t256_n67: return 0.020845472812652588;
  t256_n68: if (E.getNumReferences() >= 3265396736 /*81.0*/) goto t256_n70;
  t256_n69: return 0.11559563130140305;
  t256_n70: return -0.002653174102306366;
  t256_n71: return 0.00751916691660881;
  t256_n72: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t256_n122;
  t256_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t256_n75;
  t256_n74: return 0.007638154085725546;
  t256_n75: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n77;
  t256_n76: return 0.13674059510231018;
  t256_n77: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t256_n105;
  t256_n78: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n84;
  t256_n79: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t256_n83;
  t256_n80: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t256_n82;
  t256_n81: return -0.018903132528066635;
  t256_n82: return 0.0765618234872818;
  t256_n83: return 0.08092204481363297;
  t256_n84: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t256_n100;
  t256_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t256_n87;
  t256_n86: return 0.10371749848127365;
  t256_n87: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t256_n99;
  t256_n88: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t256_n94;
  t256_n89: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t256_n93;
  t256_n90: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n92;
  t256_n91: return 0.11975718289613724;
  t256_n92: return 0.13034173846244812;
  t256_n93: return -0.14466078579425812;
  t256_n94: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t256_n96;
  t256_n95: return -0.0006749294698238373;
  t256_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t256_n98;
  t256_n97: return -0.5009667873382568;
  t256_n98: return 0.11761674284934998;
  t256_n99: return 0.06134583428502083;
  t256_n100: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t256_n102;
  t256_n101: return -0.0037815000396221876;
  t256_n102: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t256_n104;
  t256_n103: return 0.06818380206823349;
  t256_n104: return 0.10655096173286438;
  t256_n105: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t256_n119;
  t256_n106: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t256_n118;
  t256_n107: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n115;
  t256_n108: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t256_n110;
  t256_n109: return 0.14291241765022278;
  t256_n110: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n112;
  t256_n111: return 0.12900736927986145;
  t256_n112: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n114;
  t256_n113: return 0.12175451219081879;
  t256_n114: return -0.10515440255403519;
  t256_n115: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n117;
  t256_n116: return 0.17687374353408813;
  t256_n117: return -0.29417234659194946;
  t256_n118: return -0.01425214298069477;
  t256_n119: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t256_n121;
  t256_n120: return 0.12656421959400177;
  t256_n121: return -0.3121412992477417;
  t256_n122: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n124;
  t256_n123: return 0.16214226186275482;
  t256_n124: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n126;
  t256_n125: return 0.10638118535280228;
  t256_n126: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t256_n128;
  t256_n127: return 0.031701020896434784;
  t256_n128: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n138;
  t256_n129: if (E.getNumReferences() >= 3284434944 /*393.0*/) goto t256_n137;
  t256_n130: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t256_n134;
  t256_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t256_n133;
  t256_n132: return -0.19380560517311096;
  t256_n133: return 0.07236587256193161;
  t256_n134: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t256_n136;
  t256_n135: return 0.11991619318723679;
  t256_n136: return 0.14446179568767548;
  t256_n137: return 0.10055378824472427;
  t256_n138: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n144;
  t256_n139: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n141;
  t256_n140: return 0.1905146837234497;
  t256_n141: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t256_n143;
  t256_n142: return 0.1327289640903473;
  t256_n143: return 0.24683961272239685;
  t256_n144: return 0.03056390769779682;
  t256_n145: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t256_n179;
  t256_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t256_n164;
  t256_n147: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n149;
  t256_n148: return 0.012416910380125046;
  t256_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t256_n151;
  t256_n150: return 0.006539677735418081;
  t256_n151: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n153;
  t256_n152: return -0.020294660702347755;
  t256_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t256_n159;
  t256_n154: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n158;
  t256_n155: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n157;
  t256_n156: return 0.10378621518611908;
  t256_n157: return -0.21414905786514282;
  t256_n158: return 0.019484711810946465;
  t256_n159: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t256_n161;
  t256_n160: return 0.00882426742464304;
  t256_n161: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t256_n163;
  t256_n162: return 0.10504695028066635;
  t256_n163: return 0.05091595649719238;
  t256_n164: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n178;
  t256_n165: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t256_n175;
  t256_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n168;
  t256_n167: return -0.21708887815475464;
  t256_n168: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n174;
  t256_n169: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n173;
  t256_n170: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n172;
  t256_n171: return 0.10762742161750793;
  t256_n172: return 0.14079706370830536;
  t256_n173: return 0.0033703241497278214;
  t256_n174: return -0.0033679683692753315;
  t256_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n177;
  t256_n176: return -0.13630296289920807;
  t256_n177: return 0.0703202411532402;
  t256_n178: return 0.016731664538383484;
  t256_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t256_n187;
  t256_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t256_n186;
  t256_n181: if (E.getNumReferences() >= 3262382080 /*61.0*/) goto t256_n185;
  t256_n182: if (E.getNumReferences() >= 3256614912 /*39.0*/) goto t256_n184;
  t256_n183: return -0.03834613040089607;
  t256_n184: return -0.8270891904830933;
  t256_n185: return 0.05079155042767525;
  t256_n186: return 0.044642046093940735;
  t256_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t256_n223;
  t256_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n208;
  t256_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t256_n199;
  t256_n190: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t256_n196;
  t256_n191: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n193;
  t256_n192: return -0.061083946377038956;
  t256_n193: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t256_n195;
  t256_n194: return 0.08812187612056732;
  t256_n195: return -0.03883935511112213;
  t256_n196: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n198;
  t256_n197: return 0.06644700467586517;
  t256_n198: return 0.04794720560312271;
  t256_n199: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n205;
  t256_n200: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t256_n202;
  t256_n201: return 0.050941433757543564;
  t256_n202: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t256_n204;
  t256_n203: return 0.10987933725118637;
  t256_n204: return 0.12384413927793503;
  t256_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t256_n207;
  t256_n206: return -0.2528441548347473;
  t256_n207: return 0.07852162420749664;
  t256_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n220;
  t256_n209: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n219;
  t256_n210: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t256_n218;
  t256_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n213;
  t256_n212: return -0.18447759747505188;
  t256_n213: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n217;
  t256_n214: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n216;
  t256_n215: return 0.028115270659327507;
  t256_n216: return 0.14342723786830902;
  t256_n217: return -0.037210822105407715;
  t256_n218: return 0.09298119693994522;
  t256_n219: return -0.39613139629364014;
  t256_n220: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t256_n222;
  t256_n221: return 0.05259379744529724;
  t256_n222: return 0.0847054049372673;
  t256_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t256_n233;
  t256_n224: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t256_n230;
  t256_n225: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t256_n229;
  t256_n226: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n228;
  t256_n227: return -0.13043390214443207;
  t256_n228: return 0.020395681262016296;
  t256_n229: return -0.5890836715698242;
  t256_n230: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t256_n232;
  t256_n231: return -0.23293966054916382;
  t256_n232: return 0.1115301176905632;
  t256_n233: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t256_n237;
  t256_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t256_n236;
  t256_n235: return 0.012410130351781845;
  t256_n236: return -0.4990866482257843;
  t256_n237: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t256_n251;
  t256_n238: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t256_n250;
  t256_n239: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t256_n249;
  t256_n240: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t256_n242;
  t256_n241: return -2.4860033988952637;
  t256_n242: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t256_n248;
  t256_n243: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t256_n247;
  t256_n244: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t256_n246;
  t256_n245: return 0.07271730154752731;
  t256_n246: return 0.12016892433166504;
  t256_n247: return -0.06396150588989258;
  t256_n248: return 0.04077741503715515;
  t256_n249: return 0.07140224426984787;
  t256_n250: return 0.09785646945238113;
  t256_n251: if (E.getNumReferences() >= 3280453632 /*271.5*/) goto t256_n253;
  t256_n252: return -0.5534387826919556;
  t256_n253: return 0.06296020746231079;
  t256_n254: return -0.0002683565835468471;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree257(const Example& E) {
  t257_n0: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t257_n2;
  t257_n1: return -0.0016287690959870815;
  t257_n2: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t257_n36;
  t257_n3: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n5;
  t257_n4: return -0.00044426051317714155;
  t257_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t257_n7;
  t257_n6: return 0.0025014053098857403;
  t257_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n35;
  t257_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n34;
  t257_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n33;
  t257_n10: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n14;
  t257_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t257_n13;
  t257_n12: return 0.08243444561958313;
  t257_n13: return 0.1171947717666626;
  t257_n14: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t257_n24;
  t257_n15: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t257_n23;
  t257_n16: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t257_n22;
  t257_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t257_n19;
  t257_n18: return 0.030933784320950508;
  t257_n19: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t257_n21;
  t257_n20: return -0.05372015759348869;
  t257_n21: return 0.09807556867599487;
  t257_n22: return 0.09738100320100784;
  t257_n23: return -0.0782788023352623;
  t257_n24: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t257_n30;
  t257_n25: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n27;
  t257_n26: return -0.19330443441867828;
  t257_n27: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t257_n29;
  t257_n28: return 0.1012674868106842;
  t257_n29: return 0.10258499532938004;
  t257_n30: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n32;
  t257_n31: return 0.09292490035295486;
  t257_n32: return -0.06065515801310539;
  t257_n33: return 0.0068273479118943214;
  t257_n34: return 0.009964913129806519;
  t257_n35: return 0.01089983806014061;
  t257_n36: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t257_n48;
  t257_n37: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t257_n39;
  t257_n38: return -0.0003577354073058814;
  t257_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t257_n41;
  t257_n40: return 0.006864032242447138;
  t257_n41: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t257_n47;
  t257_n42: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n46;
  t257_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n45;
  t257_n44: return 0.07275212556123734;
  t257_n45: return 0.07623990625143051;
  t257_n46: return 0.05819672718644142;
  t257_n47: return -0.02323675900697708;
  t257_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t257_n204;
  t257_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t257_n51;
  t257_n50: return -0.003734227502718568;
  t257_n51: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n65;
  t257_n52: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n54;
  t257_n53: return 0.09326878190040588;
  t257_n54: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t257_n62;
  t257_n55: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t257_n61;
  t257_n56: if (E.getNumReferences() >= 3245342720 /*15.0*/) goto t257_n58;
  t257_n57: return 0.128458172082901;
  t257_n58: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t257_n60;
  t257_n59: return 0.1014808714389801;
  t257_n60: return 0.1997881978750229;
  t257_n61: return -0.7573672533035278;
  t257_n62: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n64;
  t257_n63: return -0.045899346470832825;
  t257_n64: return 0.05153566971421242;
  t257_n65: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t257_n183;
  t257_n66: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t257_n182;
  t257_n67: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t257_n181;
  t257_n68: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n168;
  t257_n69: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n123;
  t257_n70: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n80;
  t257_n71: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t257_n79;
  t257_n72: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n74;
  t257_n73: return 0.01429225504398346;
  t257_n74: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n76;
  t257_n75: return 0.059700872749090195;
  t257_n76: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t257_n78;
  t257_n77: return 0.14542536437511444;
  t257_n78: return 0.10193628072738647;
  t257_n79: return -0.11618370562791824;
  t257_n80: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t257_n98;
  t257_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n89;
  t257_n82: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t257_n88;
  t257_n83: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n87;
  t257_n84: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n86;
  t257_n85: return -0.10968868434429169;
  t257_n86: return 0.099345363676548;
  t257_n87: return 0.10542808473110199;
  t257_n88: return 0.10396572947502136;
  t257_n89: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t257_n91;
  t257_n90: return 0.040482137352228165;
  t257_n91: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n95;
  t257_n92: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n94;
  t257_n93: return 0.11019545048475266;
  t257_n94: return -0.07934966683387756;
  t257_n95: if (E.getNumReferences() >= 3241148416 /*11.0*/) goto t257_n97;
  t257_n96: return 0.1194223091006279;
  t257_n97: return -1.7536739110946655;
  t257_n98: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t257_n106;
  t257_n99: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n101;
  t257_n100: return -0.11126550287008286;
  t257_n101: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t257_n105;
  t257_n102: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t257_n104;
  t257_n103: return 0.10134780406951904;
  t257_n104: return 0.10890646278858185;
  t257_n105: return -0.032007794827222824;
  t257_n106: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t257_n120;
  t257_n107: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n117;
  t257_n108: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t257_n114;
  t257_n109: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t257_n113;
  t257_n110: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n112;
  t257_n111: return 0.15357562899589539;
  t257_n112: return 0.07666414231061935;
  t257_n113: return -0.11589454114437103;
  t257_n114: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t257_n116;
  t257_n115: return 0.05350785702466965;
  t257_n116: return 0.13342362642288208;
  t257_n117: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t257_n119;
  t257_n118: return 0.009069526568055153;
  t257_n119: return 0.2061184048652649;
  t257_n120: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t257_n122;
  t257_n121: return 0.017671363428235054;
  t257_n122: return 0.12004760652780533;
  t257_n123: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t257_n165;
  t257_n124: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n126;
  t257_n125: return -0.007393680978566408;
  t257_n126: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t257_n128;
  t257_n127: return 0.014997257851064205;
  t257_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t257_n154;
  t257_n129: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t257_n145;
  t257_n130: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t257_n140;
  t257_n131: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n133;
  t257_n132: return 0.07390877604484558;
  t257_n133: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t257_n139;
  t257_n134: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t257_n136;
  t257_n135: return -0.3628704249858856;
  t257_n136: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t257_n138;
  t257_n137: return 0.10863613337278366;
  t257_n138: return -0.3150383532047272;
  t257_n139: return -0.9054198861122131;
  t257_n140: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t257_n144;
  t257_n141: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n143;
  t257_n142: return 0.09287860244512558;
  t257_n143: return 0.013147737830877304;
  t257_n144: return -0.5347589254379272;
  t257_n145: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t257_n149;
  t257_n146: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n148;
  t257_n147: return 0.11597798019647598;
  t257_n148: return 0.07218155264854431;
  t257_n149: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t257_n151;
  t257_n150: return -0.20014412701129913;
  t257_n151: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t257_n153;
  t257_n152: return 0.09967402368783951;
  t257_n153: return -0.19114470481872559;
  t257_n154: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t257_n158;
  t257_n155: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t257_n157;
  t257_n156: return -0.14198380708694458;
  t257_n157: return 0.047482941299676895;
  t257_n158: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t257_n164;
  t257_n159: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t257_n161;
  t257_n160: return 0.03644233196973801;
  t257_n161: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t257_n163;
  t257_n162: return 0.1186511442065239;
  t257_n163: return 0.11303875595331192;
  t257_n164: return -0.10059300065040588;
  t257_n165: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t257_n167;
  t257_n166: return 0.12025423347949982;
  t257_n167: return -0.11284638941287994;
  t257_n168: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n170;
  t257_n169: return -0.06631079316139221;
  t257_n170: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n172;
  t257_n171: return -0.023575056344270706;
  t257_n172: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t257_n176;
  t257_n173: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t257_n175;
  t257_n174: return 0.035705629736185074;
  t257_n175: return -0.2540794014930725;
  t257_n176: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t257_n178;
  t257_n177: return -0.02815195545554161;
  t257_n178: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t257_n180;
  t257_n179: return -0.2583119869232178;
  t257_n180: return 0.11069516837596893;
  t257_n181: return 0.013625369407236576;
  t257_n182: return -0.19932031631469727;
  t257_n183: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t257_n203;
  t257_n184: if (E.getNumReferences() >= 3267493888 /*97.0*/) goto t257_n202;
  t257_n185: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n189;
  t257_n186: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t257_n188;
  t257_n187: return -0.12037988007068634;
  t257_n188: return 0.11061451584100723;
  t257_n189: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t257_n191;
  t257_n190: return 0.10346711426973343;
  t257_n191: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t257_n199;
  t257_n192: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t257_n198;
  t257_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n195;
  t257_n194: return -0.13321299850940704;
  t257_n195: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t257_n197;
  t257_n196: return 0.0;
  t257_n197: return 0.09550625085830688;
  t257_n198: return -0.10796575993299484;
  t257_n199: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t257_n201;
  t257_n200: return 0.08870815485715866;
  t257_n201: return 0.12042589485645294;
  t257_n202: return 0.13892778754234314;
  t257_n203: return -0.011554007418453693;
  t257_n204: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t257_n206;
  t257_n205: return 0.04972703754901886;
  t257_n206: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t257_n226;
  t257_n207: if (E.getNumReferences() >= 3271950336 /*134.0*/) goto t257_n219;
  t257_n208: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t257_n210;
  t257_n209: return 0.012728845700621605;
  t257_n210: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n218;
  t257_n211: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t257_n213;
  t257_n212: return -0.26123517751693726;
  t257_n213: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t257_n215;
  t257_n214: return -0.05660562217235565;
  t257_n215: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t257_n217;
  t257_n216: return 0.13443930447101593;
  t257_n217: return 0.002671597758308053;
  t257_n218: return 0.029152989387512207;
  t257_n219: if (E.getNumReferences() >= 3272278016 /*139.0*/) goto t257_n221;
  t257_n220: return 0.11857405304908752;
  t257_n221: if (E.getNumReferences() >= 3276472320 /*203.0*/) goto t257_n225;
  t257_n222: if (E.getNumReferences() >= 3276013568 /*196.0*/) goto t257_n224;
  t257_n223: return 0.06402623653411865;
  t257_n224: return 0.15960821509361267;
  t257_n225: return 0.009088468737900257;
  t257_n226: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t257_n250;
  t257_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t257_n235;
  t257_n228: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t257_n230;
  t257_n229: return -0.15187227725982666;
  t257_n230: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t257_n232;
  t257_n231: return 0.11188036948442459;
  t257_n232: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t257_n234;
  t257_n233: return 0.08071994036436081;
  t257_n234: return -0.24283309280872345;
  t257_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t257_n243;
  t257_n236: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t257_n242;
  t257_n237: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t257_n239;
  t257_n238: return -0.02585117146372795;
  t257_n239: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t257_n241;
  t257_n240: return -0.5592742562294006;
  t257_n241: return -0.042681314051151276;
  t257_n242: return -0.08128079026937485;
  t257_n243: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t257_n247;
  t257_n244: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t257_n246;
  t257_n245: return -0.06239766255021095;
  t257_n246: return -0.2133937031030655;
  t257_n247: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t257_n249;
  t257_n248: return -0.04260475933551788;
  t257_n249: return 0.010566821321845055;
  t257_n250: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t257_n252;
  t257_n251: return -0.02841494418680668;
  t257_n252: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t257_n254;
  t257_n253: return 0.08804379403591156;
  t257_n254: return 0.02794104814529419;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree258(const Example& E) {
  t258_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t258_n2;
  t258_n1: return -0.0009104986675083637;
  t258_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t258_n182;
  t258_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t258_n103;
  t258_n4: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t258_n34;
  t258_n5: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t258_n7;
  t258_n6: return -0.00705066230148077;
  t258_n7: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t258_n23;
  t258_n8: if (E.getNumReferences() >= 3315371008 /*5009.5*/) goto t258_n22;
  t258_n9: if (E.getNumReferences() >= 3314935808 /*4797.0*/) goto t258_n11;
  t258_n10: return 0.004524436313658953;
  t258_n11: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t258_n17;
  t258_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n14;
  t258_n13: return -0.4609035551548004;
  t258_n14: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t258_n16;
  t258_n15: return 0.10512568801641464;
  t258_n16: return 0.06930702179670334;
  t258_n17: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n19;
  t258_n18: return 0.1124892607331276;
  t258_n19: if (E.getNumReferences() >= 3315329024 /*4989.0*/) goto t258_n21;
  t258_n20: return 0.029450321570038795;
  t258_n21: return 0.1082991436123848;
  t258_n22: return -0.011225493624806404;
  t258_n23: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t258_n29;
  t258_n24: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t258_n26;
  t258_n25: return 0.026878343895077705;
  t258_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n28;
  t258_n27: return 0.07801968604326248;
  t258_n28: return 0.048903003334999084;
  t258_n29: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n33;
  t258_n30: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t258_n32;
  t258_n31: return -0.43802717328071594;
  t258_n32: return 0.003569947788491845;
  t258_n33: return 0.038003213703632355;
  t258_n34: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t258_n58;
  t258_n35: if (E.getNumReferences() >= 3332258560 /*20253.5*/) goto t258_n37;
  t258_n36: return -0.014186330139636993;
  t258_n37: if (E.getNumReferences() >= 3332287488 /*20310.0*/) goto t258_n41;
  t258_n38: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t258_n40;
  t258_n39: return 0.09648146480321884;
  t258_n40: return 0.07469874620437622;
  t258_n41: if (E.getNumReferences() >= 3336505344 /*28548.0*/) goto t258_n53;
  t258_n42: if (E.getNumReferences() >= 3334726400 /*25073.5*/) goto t258_n44;
  t258_n43: return 0.01699345000088215;
  t258_n44: if (E.getNumReferences() >= 3334882048 /*25377.5*/) goto t258_n46;
  t258_n45: return 0.10363569110631943;
  t258_n46: if (E.getNumReferences() >= 3336322560 /*28191.0*/) goto t258_n52;
  t258_n47: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t258_n49;
  t258_n48: return -0.01871970109641552;
  t258_n49: if (E.getNumReferences() >= 3335284480 /*26163.5*/) goto t258_n51;
  t258_n50: return 0.015306600369513035;
  t258_n51: return 0.10862948000431061;
  t258_n52: return 0.11011920869350433;
  t258_n53: if (E.getNumReferences() >= 3337070336 /*29651.5*/) goto t258_n55;
  t258_n54: return -0.36921006441116333;
  t258_n55: if (E.getNumReferences() >= 3337668864 /*30820.5*/) goto t258_n57;
  t258_n56: return 0.08955628424882889;
  t258_n57: return -0.002799262525513768;
  t258_n58: if (E.getNumReferences() >= 3317607424 /*6101.5*/) goto t258_n92;
  t258_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t258_n61;
  t258_n60: return -0.05218547210097313;
  t258_n61: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n91;
  t258_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t258_n64;
  t258_n63: return -0.011230498552322388;
  t258_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t258_n74;
  t258_n65: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t258_n73;
  t258_n66: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n70;
  t258_n67: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t258_n69;
  t258_n68: return 0.12557923793792725;
  t258_n69: return -0.10757795721292496;
  t258_n70: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n72;
  t258_n71: return 0.12423530966043472;
  t258_n72: return 0.1578325480222702;
  t258_n73: return 0.022183259949088097;
  t258_n74: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n76;
  t258_n75: return -0.014683994464576244;
  t258_n76: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t258_n84;
  t258_n77: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t258_n79;
  t258_n78: return 0.006998992525041103;
  t258_n79: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t258_n83;
  t258_n80: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t258_n82;
  t258_n81: return 0.03847995027899742;
  t258_n82: return 0.10605543106794357;
  t258_n83: return 0.017759639769792557;
  t258_n84: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t258_n86;
  t258_n85: return 0.05390617623925209;
  t258_n86: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t258_n88;
  t258_n87: return 0.3725389540195465;
  t258_n88: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t258_n90;
  t258_n89: return 0.09160343557596207;
  t258_n90: return 0.08148679882287979;
  t258_n91: return 0.004619884770363569;
  t258_n92: if (E.getNumReferences() >= 3318311936 /*6445.5*/) goto t258_n94;
  t258_n93: return 0.11462986469268799;
  t258_n94: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t258_n96;
  t258_n95: return -0.02701181173324585;
  t258_n96: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n102;
  t258_n97: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n101;
  t258_n98: if (E.getNumReferences() >= 3332080128 /*19905.0*/) goto t258_n100;
  t258_n99: return 0.020172331482172012;
  t258_n100: return 0.09979776293039322;
  t258_n101: return 0.025011226534843445;
  t258_n102: return 0.01568802446126938;
  t258_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t258_n105;
  t258_n104: return -0.01658683829009533;
  t258_n105: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n123;
  t258_n106: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n122;
  t258_n107: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t258_n111;
  t258_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t258_n110;
  t258_n109: return 0.01664280891418457;
  t258_n110: return 0.029367132112383842;
  t258_n111: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t258_n117;
  t258_n112: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n114;
  t258_n113: return -0.10780029743909836;
  t258_n114: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n116;
  t258_n115: return 0.11326734721660614;
  t258_n116: return -0.06876543164253235;
  t258_n117: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t258_n121;
  t258_n118: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n120;
  t258_n119: return -0.10590440779924393;
  t258_n120: return 0.08378516137599945;
  t258_n121: return -0.13496273756027222;
  t258_n122: return 0.008697066456079483;
  t258_n123: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t258_n125;
  t258_n124: return -0.00011296905722701922;
  t258_n125: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t258_n181;
  t258_n126: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t258_n150;
  t258_n127: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t258_n139;
  t258_n128: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t258_n136;
  t258_n129: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t258_n133;
  t258_n130: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t258_n132;
  t258_n131: return 0.041292861104011536;
  t258_n132: return -0.0500897578895092;
  t258_n133: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t258_n135;
  t258_n134: return 0.11729192733764648;
  t258_n135: return 0.1010386198759079;
  t258_n136: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t258_n138;
  t258_n137: return 0.09161143004894257;
  t258_n138: return 0.05027703940868378;
  t258_n139: if (E.getNumReferences() >= 3292536832 /*768.5*/) goto t258_n149;
  t258_n140: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t258_n142;
  t258_n141: return 0.026092182844877243;
  t258_n142: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t258_n148;
  t258_n143: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t258_n147;
  t258_n144: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t258_n146;
  t258_n145: return -0.41823625564575195;
  t258_n146: return 0.10874812304973602;
  t258_n147: return 0.11600740253925323;
  t258_n148: return 0.010169805958867073;
  t258_n149: return -0.13512861728668213;
  t258_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n158;
  t258_n151: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t258_n157;
  t258_n152: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t258_n156;
  t258_n153: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t258_n155;
  t258_n154: return 0.17307740449905396;
  t258_n155: return -0.14843492209911346;
  t258_n156: return 0.09684508293867111;
  t258_n157: return 0.04122474044561386;
  t258_n158: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t258_n174;
  t258_n159: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t258_n171;
  t258_n160: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t258_n170;
  t258_n161: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t258_n163;
  t258_n162: return 0.06570427864789963;
  t258_n163: if (E.getFilterLength() >= 3225419776 /*3.0*/) goto t258_n165;
  t258_n164: return 0.12687897682189941;
  t258_n165: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t258_n169;
  t258_n166: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t258_n168;
  t258_n167: return -0.11345770210027695;
  t258_n168: return 0.11100168526172638;
  t258_n169: return -0.10201060771942139;
  t258_n170: return 0.0859074592590332;
  t258_n171: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t258_n173;
  t258_n172: return -0.10185927152633667;
  t258_n173: return 0.11453662067651749;
  t258_n174: if (E.getNumReferences() >= 3281879040 /*315.0*/) goto t258_n176;
  t258_n175: return 0.0006386296590790153;
  t258_n176: if (E.getNumReferences() >= 3285565440 /*427.5*/) goto t258_n180;
  t258_n177: if (E.getNumReferences() >= 3283468288 /*363.5*/) goto t258_n179;
  t258_n178: return 0.08298048377037048;
  t258_n179: return 0.12000449001789093;
  t258_n180: return -0.04036038741469383;
  t258_n181: return -0.0596906915307045;
  t258_n182: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t258_n206;
  t258_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t258_n195;
  t258_n184: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t258_n190;
  t258_n185: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n189;
  t258_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t258_n188;
  t258_n187: return -0.02279304340481758;
  t258_n188: return 0.04711790755391121;
  t258_n189: return -0.09789274632930756;
  t258_n190: if (E.getScope() & (BIT(Scope_type::FunctionScope))) goto t258_n192;
  t258_n191: return -0.023219455033540726;
  t258_n192: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t258_n194;
  t258_n193: return 0.0023725659120827913;
  t258_n194: return 0.09417658299207687;
  t258_n195: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t258_n205;
  t258_n196: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t258_n198;
  t258_n197: return -0.03432849794626236;
  t258_n198: if (E.getSymbolScopeDistance() >= 3246391296 /*16.0*/) goto t258_n204;
  t258_n199: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n201;
  t258_n200: return 0.02418237365782261;
  t258_n201: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t258_n203;
  t258_n202: return -0.003299869829788804;
  t258_n203: return 0.03458271920681;
  t258_n204: return -0.0331701934337616;
  t258_n205: return -0.00013975761248730123;
  t258_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t258_n236;
  t258_n207: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t258_n235;
  t258_n208: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t258_n214;
  t258_n209: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t258_n213;
  t258_n210: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t258_n212;
  t258_n211: return -0.007483676075935364;
  t258_n212: return -0.02392210252583027;
  t258_n213: return 0.03552043437957764;
  t258_n214: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t258_n230;
  t258_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t258_n217;
  t258_n216: return -0.026168236508965492;
  t258_n217: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t258_n219;
  t258_n218: return 0.0233133714646101;
  t258_n219: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t258_n223;
  t258_n220: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t258_n222;
  t258_n221: return -0.004624144174158573;
  t258_n222: return 0.10818703472614288;
  t258_n223: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t258_n229;
  t258_n224: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t258_n226;
  t258_n225: return 0.002361482009291649;
  t258_n226: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t258_n228;
  t258_n227: return 0.12014059722423553;
  t258_n228: return 0.065745510160923;
  t258_n229: return -0.14980584383010864;
  t258_n230: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t258_n232;
  t258_n231: return 0.10755881667137146;
  t258_n232: if (E.getNumReferences() >= 3294724096 /*902.0*/) goto t258_n234;
  t258_n233: return -0.0019662503618746996;
  t258_n234: return 0.08232202380895615;
  t258_n235: return 0.008556588552892208;
  t258_n236: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t258_n238;
  t258_n237: return 0.011426661163568497;
  t258_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t258_n248;
  t258_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t258_n247;
  t258_n240: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t258_n246;
  t258_n241: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t258_n245;
  t258_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t258_n244;
  t258_n243: return 0.02004663459956646;
  t258_n244: return 0.09857156127691269;
  t258_n245: return -0.13631998002529144;
  t258_n246: return 0.06285052746534348;
  t258_n247: return 0.0439436174929142;
  t258_n248: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t258_n250;
  t258_n249: return 0.003855382790789008;
  t258_n250: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t258_n252;
  t258_n251: return -0.025713136419653893;
  t258_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t258_n254;
  t258_n253: return 0.06845982372760773;
  t258_n254: return -0.07878891378641129;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree259(const Example& E) {
  t259_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t259_n236;
  t259_n1: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t259_n3;
  t259_n2: return -0.0013495102757588029;
  t259_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t259_n107;
  t259_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t259_n58;
  t259_n5: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t259_n13;
  t259_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t259_n10;
  t259_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n9;
  t259_n8: return -0.023197496309876442;
  t259_n9: return -0.01661246083676815;
  t259_n10: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t259_n12;
  t259_n11: return 0.023770833387970924;
  t259_n12: return 0.07112263888120651;
  t259_n13: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t259_n29;
  t259_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t259_n16;
  t259_n15: return -0.0071070315316319466;
  t259_n16: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n26;
  t259_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t259_n19;
  t259_n18: return 0.00041180316475220025;
  t259_n19: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t259_n23;
  t259_n20: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n22;
  t259_n21: return -0.3962693512439728;
  t259_n22: return 0.10617373883724213;
  t259_n23: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t259_n25;
  t259_n24: return 0.016110491007566452;
  t259_n25: return 0.08550921827554703;
  t259_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n28;
  t259_n27: return -0.030321968719363213;
  t259_n28: return 0.03155462071299553;
  t259_n29: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t259_n57;
  t259_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n42;
  t259_n31: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n35;
  t259_n32: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t259_n34;
  t259_n33: return -0.1257329285144806;
  t259_n34: return -0.016627566888928413;
  t259_n35: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t259_n41;
  t259_n36: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n38;
  t259_n37: return -0.0768725648522377;
  t259_n38: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t259_n40;
  t259_n39: return -0.0019382763421162963;
  t259_n40: return -0.07265356183052063;
  t259_n41: return 0.05605451762676239;
  t259_n42: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t259_n56;
  t259_n43: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n45;
  t259_n44: return -0.05659635365009308;
  t259_n45: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t259_n55;
  t259_n46: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t259_n48;
  t259_n47: return 0.04850909113883972;
  t259_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t259_n54;
  t259_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t259_n51;
  t259_n50: return 0.0347701720893383;
  t259_n51: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t259_n53;
  t259_n52: return 0.12732799351215363;
  t259_n53: return 0.11658623069524765;
  t259_n54: return 0.00016350123041775078;
  t259_n55: return -0.22706261277198792;
  t259_n56: return -0.004397178068757057;
  t259_n57: return 6.70454028295353e-05;
  t259_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag))) goto t259_n60;
  t259_n59: return 0.0022219480015337467;
  t259_n60: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t259_n100;
  t259_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n99;
  t259_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n90;
  t259_n63: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t259_n67;
  t259_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t259_n66;
  t259_n65: return 0.08436589688062668;
  t259_n66: return 0.1149919331073761;
  t259_n67: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t259_n81;
  t259_n68: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n80;
  t259_n69: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t259_n79;
  t259_n70: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t259_n78;
  t259_n71: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t259_n77;
  t259_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t259_n74;
  t259_n73: return 0.002064220141619444;
  t259_n74: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t259_n76;
  t259_n75: return -0.280791699886322;
  t259_n76: return 0.10882671922445297;
  t259_n77: return -0.3609050512313843;
  t259_n78: return 0.0955595150589943;
  t259_n79: return -0.05254359915852547;
  t259_n80: return 0.09808595478534698;
  t259_n81: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t259_n87;
  t259_n82: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t259_n84;
  t259_n83: return -0.18506252765655518;
  t259_n84: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t259_n86;
  t259_n85: return 0.09944383054971695;
  t259_n86: return 0.09806524962186813;
  t259_n87: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t259_n89;
  t259_n88: return 0.09211984276771545;
  t259_n89: return -0.06212412193417549;
  t259_n90: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t259_n96;
  t259_n91: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t259_n93;
  t259_n92: return -0.018345775082707405;
  t259_n93: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t259_n95;
  t259_n94: return 0.08790688961744308;
  t259_n95: return 0.014654295518994331;
  t259_n96: if (E.getNumReferences() >= 3254517760 /*31.5*/) goto t259_n98;
  t259_n97: return -0.6628628373146057;
  t259_n98: return -0.14770051836967468;
  t259_n99: return 0.009544874541461468;
  t259_n100: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t259_n106;
  t259_n101: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t259_n105;
  t259_n102: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n104;
  t259_n103: return 0.09389178454875946;
  t259_n104: return -0.07286907732486725;
  t259_n105: return 0.10561415553092957;
  t259_n106: return 0.0070419772528111935;
  t259_n107: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t259_n123;
  t259_n108: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t259_n114;
  t259_n109: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n113;
  t259_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t259_n112;
  t259_n111: return -0.10616511851549149;
  t259_n112: return 0.0019781175069510937;
  t259_n113: return -0.056155867874622345;
  t259_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t259_n116;
  t259_n115: return 0.006573302671313286;
  t259_n116: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t259_n122;
  t259_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n121;
  t259_n118: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n120;
  t259_n119: return 0.06883208453655243;
  t259_n120: return 0.07598504424095154;
  t259_n121: return 0.05139072239398956;
  t259_n122: return -0.024896366521716118;
  t259_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t259_n185;
  t259_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t259_n126;
  t259_n125: return -0.0010373103432357311;
  t259_n126: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n144;
  t259_n127: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n129;
  t259_n128: return 0.07980985939502716;
  t259_n129: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n137;
  t259_n130: if (E.getNumReferences() >= 3264348160 /*73.0*/) goto t259_n136;
  t259_n131: if (E.getNumReferences() >= 3245342720 /*15.0*/) goto t259_n133;
  t259_n132: return 0.12287650257349014;
  t259_n133: if (E.getNumReferences() >= 3253207040 /*29.0*/) goto t259_n135;
  t259_n134: return 0.10130491107702255;
  t259_n135: return 0.14952422678470612;
  t259_n136: return -0.44764867424964905;
  t259_n137: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n139;
  t259_n138: return -0.04323297366499901;
  t259_n139: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t259_n143;
  t259_n140: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t259_n142;
  t259_n141: return 0.05023467168211937;
  t259_n142: return -0.21412234008312225;
  t259_n143: return 0.1435607671737671;
  t259_n144: if (E.getNumReferences() >= 3262775296 /*62.5*/) goto t259_n146;
  t259_n145: return 0.015261368826031685;
  t259_n146: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t259_n168;
  t259_n147: if (E.getNumReferences() >= 3267493888 /*97.0*/) goto t259_n167;
  t259_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n152;
  t259_n149: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t259_n151;
  t259_n150: return -0.09903544187545776;
  t259_n151: return 0.10904479026794434;
  t259_n152: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t259_n154;
  t259_n153: return 0.10060470551252365;
  t259_n154: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t259_n164;
  t259_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t259_n163;
  t259_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n158;
  t259_n157: return -0.12531781196594238;
  t259_n158: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t259_n160;
  t259_n159: return 0.09227506071329117;
  t259_n160: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n162;
  t259_n161: return -0.2723976969718933;
  t259_n162: return 0.10764598101377487;
  t259_n163: return -0.30289411544799805;
  t259_n164: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t259_n166;
  t259_n165: return 0.0748811885714531;
  t259_n166: return 0.11876484006643295;
  t259_n167: return 0.13504458963871002;
  t259_n168: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n178;
  t259_n169: if (E.getNumReferences() >= 3314298880 /*4486.0*/) goto t259_n177;
  t259_n170: if (E.getNumReferences() >= 3304935424 /*2026.5*/) goto t259_n176;
  t259_n171: if (E.getNumReferences() >= 3286532096 /*457.0*/) goto t259_n173;
  t259_n172: return -0.19567078351974487;
  t259_n173: if (E.getNumReferences() >= 3288170496 /*507.0*/) goto t259_n175;
  t259_n174: return 0.11995924264192581;
  t259_n175: return 0.007836327888071537;
  t259_n176: return 0.11255156993865967;
  t259_n177: return -0.3885272741317749;
  t259_n178: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t259_n180;
  t259_n179: return -0.021064024418592453;
  t259_n180: if (E.getNumReferences() >= 3283124224 /*353.0*/) goto t259_n182;
  t259_n181: return -0.09104592353105545;
  t259_n182: if (E.getNumReferences() >= 3302817792 /*1768.0*/) goto t259_n184;
  t259_n183: return 0.10725328326225281;
  t259_n184: return 0.0675315260887146;
  t259_n185: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t259_n189;
  t259_n186: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n188;
  t259_n187: return 0.09091772884130478;
  t259_n188: return -0.016157058998942375;
  t259_n189: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t259_n235;
  t259_n190: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t259_n222;
  t259_n191: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t259_n205;
  t259_n192: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t259_n194;
  t259_n193: return 0.00010852632840396836;
  t259_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t259_n196;
  t259_n195: return 0.02900925651192665;
  t259_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t259_n204;
  t259_n197: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t259_n203;
  t259_n198: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t259_n200;
  t259_n199: return 0.056959107518196106;
  t259_n200: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t259_n202;
  t259_n201: return 0.09116728603839874;
  t259_n202: return 0.0689435601234436;
  t259_n203: return 0.05507558584213257;
  t259_n204: return 0.005595774855464697;
  t259_n205: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t259_n213;
  t259_n206: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n212;
  t259_n207: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t259_n211;
  t259_n208: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t259_n210;
  t259_n209: return -0.23708786070346832;
  t259_n210: return -0.6461445689201355;
  t259_n211: return -0.09098239243030548;
  t259_n212: return 0.017460709437727928;
  t259_n213: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t259_n217;
  t259_n214: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t259_n216;
  t259_n215: return 0.14215713739395142;
  t259_n216: return -0.002076047472655773;
  t259_n217: if (E.getNumReferences() >= 3281453056 /*302.0*/) goto t259_n221;
  t259_n218: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t259_n220;
  t259_n219: return -0.014970095828175545;
  t259_n220: return 0.10288294404745102;
  t259_n221: return -0.13385945558547974;
  t259_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n230;
  t259_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n225;
  t259_n224: return -0.2256964147090912;
  t259_n225: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t259_n229;
  t259_n226: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t259_n228;
  t259_n227: return -0.024365171790122986;
  t259_n228: return -0.1719551533460617;
  t259_n229: return -0.07360262423753738;
  t259_n230: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t259_n232;
  t259_n231: return -0.03725667670369148;
  t259_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t259_n234;
  t259_n233: return -0.021199239417910576;
  t259_n234: return 0.019323257729411125;
  t259_n235: return 0.014981926418840885;
  t259_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t259_n252;
  t259_n237: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t259_n251;
  t259_n238: if (E.getNumReferences() >= 3284877312 /*406.5*/) goto t259_n240;
  t259_n239: return -0.05201007425785065;
  t259_n240: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t259_n250;
  t259_n241: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t259_n249;
  t259_n242: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t259_n244;
  t259_n243: return -0.1241447851061821;
  t259_n244: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t259_n246;
  t259_n245: return 0.3729100823402405;
  t259_n246: if (E.getNumReferences() >= 3302293504 /*1704.0*/) goto t259_n248;
  t259_n247: return 0.08573751151561737;
  t259_n248: return 0.16097795963287354;
  t259_n249: return 0.27522552013397217;
  t259_n250: return -0.1016203761100769;
  t259_n251: return -0.08947356790304184;
  t259_n252: if (E.getNumReferences() >= 3294519296 /*889.5*/) goto t259_n254;
  t259_n253: return -0.013496224768459797;
  t259_n254: return 0.09609353542327881;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree260(const Example& E) {
  t260_n0: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t260_n254;
  t260_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Symbol))) goto t260_n111;
  t260_n2: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t260_n38;
  t260_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t260_n35;
  t260_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t260_n6;
  t260_n5: return -0.009155933745205402;
  t260_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n8;
  t260_n7: return -0.002265893155708909;
  t260_n8: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t260_n30;
  t260_n9: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t260_n11;
  t260_n10: return -0.012080885469913483;
  t260_n11: if (E.getNumReferences() >= 3253993472 /*30.5*/) goto t260_n29;
  t260_n12: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n16;
  t260_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t260_n15;
  t260_n14: return 0.013926873914897442;
  t260_n15: return 0.08810165524482727;
  t260_n16: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t260_n20;
  t260_n17: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t260_n19;
  t260_n18: return 0.0018232539296150208;
  t260_n19: return 0.107339046895504;
  t260_n20: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t260_n22;
  t260_n21: return -0.00868942029774189;
  t260_n22: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n24;
  t260_n23: return -0.031155047938227654;
  t260_n24: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t260_n26;
  t260_n25: return 0.1034289002418518;
  t260_n26: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n28;
  t260_n27: return 0.11486957967281342;
  t260_n28: return -0.20868636667728424;
  t260_n29: return -0.11726655811071396;
  t260_n30: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t260_n32;
  t260_n31: return 0.10459373146295547;
  t260_n32: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t260_n34;
  t260_n33: return 0.09623853117227554;
  t260_n34: return -0.009244185872375965;
  t260_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t260_n37;
  t260_n36: return -0.11759842187166214;
  t260_n37: return 0.009409592486917973;
  t260_n38: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t260_n90;
  t260_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t260_n41;
  t260_n40: return 0.00946089532226324;
  t260_n41: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n43;
  t260_n42: return 0.09609241038560867;
  t260_n43: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t260_n73;
  t260_n44: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t260_n50;
  t260_n45: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t260_n49;
  t260_n46: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n48;
  t260_n47: return -0.022746577858924866;
  t260_n48: return 0.07427014410495758;
  t260_n49: return 0.07595571875572205;
  t260_n50: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n62;
  t260_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t260_n53;
  t260_n52: return -0.12108895927667618;
  t260_n53: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n55;
  t260_n54: return 0.11023548990488052;
  t260_n55: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t260_n61;
  t260_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n58;
  t260_n57: return 0.11530744284391403;
  t260_n58: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n60;
  t260_n59: return -0.10186176002025604;
  t260_n60: return 0.1095009297132492;
  t260_n61: return 0.0512995570898056;
  t260_n62: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n64;
  t260_n63: return 0.0045605795457959175;
  t260_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t260_n70;
  t260_n65: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t260_n67;
  t260_n66: return 0.06177366524934769;
  t260_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t260_n69;
  t260_n68: return 0.06549949198961258;
  t260_n69: return 0.10673180222511292;
  t260_n70: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t260_n72;
  t260_n71: return 0.11431064456701279;
  t260_n72: return -0.10401105135679245;
  t260_n73: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t260_n87;
  t260_n74: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t260_n86;
  t260_n75: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t260_n85;
  t260_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n84;
  t260_n77: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n79;
  t260_n78: return 0.1479116678237915;
  t260_n79: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t260_n83;
  t260_n80: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t260_n82;
  t260_n81: return -0.10527046024799347;
  t260_n82: return 0.1034703478217125;
  t260_n83: return 0.11785993725061417;
  t260_n84: return 0.16108763217926025;
  t260_n85: return -0.39504843950271606;
  t260_n86: return -0.008443833328783512;
  t260_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n89;
  t260_n88: return 0.12305029481649399;
  t260_n89: return -0.23226803541183472;
  t260_n90: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n94;
  t260_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t260_n93;
  t260_n92: return 0.08384886384010315;
  t260_n93: return 0.5084651708602905;
  t260_n94: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n96;
  t260_n95: return 0.10043323785066605;
  t260_n96: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t260_n98;
  t260_n97: return 0.038028500974178314;
  t260_n98: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n104;
  t260_n99: if (E.getNumReferences() >= 3284434944 /*393.0*/) goto t260_n103;
  t260_n100: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n102;
  t260_n101: return -0.13871626555919647;
  t260_n102: return 0.11152050644159317;
  t260_n103: return 0.09879007190465927;
  t260_n104: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n110;
  t260_n105: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n107;
  t260_n106: return 0.19649945199489594;
  t260_n107: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n109;
  t260_n108: return 0.1291174739599228;
  t260_n109: return 0.24732717871665955;
  t260_n110: return 0.013858456164598465;
  t260_n111: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t260_n175;
  t260_n112: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t260_n154;
  t260_n113: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n131;
  t260_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n116;
  t260_n115: return 0.01649019867181778;
  t260_n116: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t260_n118;
  t260_n117: return 0.0129423001781106;
  t260_n118: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n120;
  t260_n119: return -0.025441855192184448;
  t260_n120: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t260_n126;
  t260_n121: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t260_n125;
  t260_n122: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n124;
  t260_n123: return 0.09992820024490356;
  t260_n124: return -0.1401832401752472;
  t260_n125: return 0.03603190556168556;
  t260_n126: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t260_n128;
  t260_n127: return 0.0100418571382761;
  t260_n128: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t260_n130;
  t260_n129: return 0.11537738144397736;
  t260_n130: return -0.38762691617012024;
  t260_n131: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n147;
  t260_n132: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n134;
  t260_n133: return -0.02630370669066906;
  t260_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t260_n136;
  t260_n135: return -0.07634644955396652;
  t260_n136: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t260_n140;
  t260_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n139;
  t260_n138: return 0.04676845669746399;
  t260_n139: return -0.05964115634560585;
  t260_n140: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n146;
  t260_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t260_n143;
  t260_n142: return 0.09236165136098862;
  t260_n143: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t260_n145;
  t260_n144: return 0.16264384984970093;
  t260_n145: return 0.10304409265518188;
  t260_n146: return 0.06834578514099121;
  t260_n147: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n149;
  t260_n148: return -0.10086800158023834;
  t260_n149: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t260_n151;
  t260_n150: return 0.016132406890392303;
  t260_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t260_n153;
  t260_n152: return -0.12353039532899857;
  t260_n153: return 0.0296370517462492;
  t260_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t260_n164;
  t260_n155: if (E.getNumReferences() >= 3242196992 /*12.0*/) goto t260_n163;
  t260_n156: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t260_n158;
  t260_n157: return -0.04491422325372696;
  t260_n158: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n162;
  t260_n159: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n161;
  t260_n160: return 0.09963290393352509;
  t260_n161: return 0.057429611682891846;
  t260_n162: return -0.12641610205173492;
  t260_n163: return 0.0508728101849556;
  t260_n164: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n174;
  t260_n165: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n173;
  t260_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n172;
  t260_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n171;
  t260_n168: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t260_n170;
  t260_n169: return 0.10752884298563004;
  t260_n170: return 0.1258438378572464;
  t260_n171: return 0.018242422491312027;
  t260_n172: return 0.0818495973944664;
  t260_n173: return 0.02291700430214405;
  t260_n174: return 0.01651429943740368;
  t260_n175: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t260_n179;
  t260_n176: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t260_n178;
  t260_n177: return -0.024942470714449883;
  t260_n178: return 0.04356852173805237;
  t260_n179: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t260_n247;
  t260_n180: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t260_n200;
  t260_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n197;
  t260_n182: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n194;
  t260_n183: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n191;
  t260_n184: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n186;
  t260_n185: return -0.10074158757925034;
  t260_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n190;
  t260_n187: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n189;
  t260_n188: return 0.021279674023389816;
  t260_n189: return -0.12594595551490784;
  t260_n190: return 0.02231616899371147;
  t260_n191: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n193;
  t260_n192: return 0.10371946543455124;
  t260_n193: return -0.11421779543161392;
  t260_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n196;
  t260_n195: return 0.10006225109100342;
  t260_n196: return -0.08317945897579193;
  t260_n197: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n199;
  t260_n198: return 0.08206052333116531;
  t260_n199: return 0.014657232910394669;
  t260_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t260_n232;
  t260_n201: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t260_n213;
  t260_n202: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t260_n210;
  t260_n203: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t260_n209;
  t260_n204: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t260_n208;
  t260_n205: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n207;
  t260_n206: return -0.1961740404367447;
  t260_n207: return 0.10549812018871307;
  t260_n208: return -0.04188656434416771;
  t260_n209: return 0.09591767936944962;
  t260_n210: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t260_n212;
  t260_n211: return 0.05288943648338318;
  t260_n212: return -0.3338080644607544;
  t260_n213: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t260_n227;
  t260_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n226;
  t260_n215: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n219;
  t260_n216: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n218;
  t260_n217: return 0.07328318059444427;
  t260_n218: return -0.7142096161842346;
  t260_n219: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t260_n223;
  t260_n220: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t260_n222;
  t260_n221: return 0.10392993688583374;
  t260_n222: return 0.02809332124888897;
  t260_n223: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t260_n225;
  t260_n224: return 0.04712136089801788;
  t260_n225: return 0.10448069125413895;
  t260_n226: return 0.018492601811885834;
  t260_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t260_n229;
  t260_n228: return -0.012396492063999176;
  t260_n229: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t260_n231;
  t260_n230: return 0.08879254758358002;
  t260_n231: return -0.029904775321483612;
  t260_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t260_n242;
  t260_n233: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t260_n237;
  t260_n234: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n236;
  t260_n235: return 0.11205079406499863;
  t260_n236: return -1.640018105506897;
  t260_n237: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t260_n241;
  t260_n238: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t260_n240;
  t260_n239: return -0.3688066303730011;
  t260_n240: return 0.0982869490981102;
  t260_n241: return -0.18600863218307495;
  t260_n242: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t260_n244;
  t260_n243: return -0.06938444823026657;
  t260_n244: if (E.getNumReferences() >= 3252682752 /*28.0*/) goto t260_n246;
  t260_n245: return 0.10887053608894348;
  t260_n246: return -0.2346607893705368;
  t260_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t260_n253;
  t260_n248: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t260_n252;
  t260_n249: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t260_n251;
  t260_n250: return -0.21467049419879913;
  t260_n251: return 0.10241910815238953;
  t260_n252: return -0.41272592544555664;
  t260_n253: return 0.11462979018688202;
  t260_n254: return -0.00025769066996872425;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree261(const Example& E) {
  t261_n0: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t261_n2;
  t261_n1: return 0.0024534454569220543;
  t261_n2: if (E.getNumReferences() >= 3297832960 /*1159.5*/) goto t261_n240;
  t261_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t261_n5;
  t261_n4: return -0.00015061514568515122;
  t261_n5: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t261_n157;
  t261_n6: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t261_n8;
  t261_n7: return -0.0046946513466537;
  t261_n8: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t261_n10;
  t261_n9: return 0.006105051841586828;
  t261_n10: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t261_n12;
  t261_n11: return -0.11832858622074127;
  t261_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t261_n14;
  t261_n13: return 0.019386881962418556;
  t261_n14: if (E.getNumReferences() >= 3297464320 /*1114.5*/) goto t261_n156;
  t261_n15: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n67;
  t261_n16: if (E.getNumReferences() >= 3273097216 /*151.5*/) goto t261_n58;
  t261_n17: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t261_n47;
  t261_n18: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t261_n20;
  t261_n19: return 0.032492898404598236;
  t261_n20: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t261_n24;
  t261_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n23;
  t261_n22: return 0.059991102665662766;
  t261_n23: return 0.11858442425727844;
  t261_n24: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t261_n26;
  t261_n25: return 0.00311466446146369;
  t261_n26: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t261_n42;
  t261_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t261_n33;
  t261_n28: if (E.getNumReferences() >= 3272638464 /*144.5*/) goto t261_n30;
  t261_n29: return -0.0061901044100522995;
  t261_n30: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n32;
  t261_n31: return 0.15590910613536835;
  t261_n32: return 0.11246275156736374;
  t261_n33: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t261_n41;
  t261_n34: if (E.getNumReferences() >= 3271294976 /*126.0*/) goto t261_n40;
  t261_n35: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t261_n37;
  t261_n36: return -0.11243713647127151;
  t261_n37: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n39;
  t261_n38: return 0.18153882026672363;
  t261_n39: return 0.14918984472751617;
  t261_n40: return 0.008277310989797115;
  t261_n41: return -0.12030947208404541;
  t261_n42: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t261_n46;
  t261_n43: if (E.getNumReferences() >= 3268870144 /*107.5*/) goto t261_n45;
  t261_n44: return 0.24956609308719635;
  t261_n45: return 0.10176955163478851;
  t261_n46: return -0.2537081241607666;
  t261_n47: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t261_n57;
  t261_n48: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t261_n52;
  t261_n49: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t261_n51;
  t261_n50: return -0.18512648344039917;
  t261_n51: return 0.12475273758172989;
  t261_n52: if (E.getNumReferences() >= 3255697408 /*35.5*/) goto t261_n56;
  t261_n53: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t261_n55;
  t261_n54: return 0.10719791799783707;
  t261_n55: return 0.1025756448507309;
  t261_n56: return -0.020898040384054184;
  t261_n57: return -0.0727899894118309;
  t261_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t261_n62;
  t261_n59: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t261_n61;
  t261_n60: return -0.02778657339513302;
  t261_n61: return -0.1154232919216156;
  t261_n62: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t261_n64;
  t261_n63: return -0.014425419270992279;
  t261_n64: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n66;
  t261_n65: return 0.12265966832637787;
  t261_n66: return 0.0710642859339714;
  t261_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t261_n149;
  t261_n68: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t261_n94;
  t261_n69: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t261_n89;
  t261_n70: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t261_n88;
  t261_n71: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t261_n73;
  t261_n72: return 0.04254743084311485;
  t261_n73: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t261_n87;
  t261_n74: if (E.getNumReferences() >= 3270180864 /*117.5*/) goto t261_n86;
  t261_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t261_n77;
  t261_n76: return -0.012106589041650295;
  t261_n77: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t261_n85;
  t261_n78: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n80;
  t261_n79: return 0.024951154366135597;
  t261_n80: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t261_n84;
  t261_n81: if (E.getNumReferences() >= 3266576384 /*90.0*/) goto t261_n83;
  t261_n82: return 0.10995656251907349;
  t261_n83: return 0.12788335978984833;
  t261_n84: return 0.8514944314956665;
  t261_n85: return 0.10541963577270508;
  t261_n86: return -0.0355105921626091;
  t261_n87: return -0.1419798880815506;
  t261_n88: return -0.006621848326176405;
  t261_n89: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t261_n91;
  t261_n90: return 0.009836188517510891;
  t261_n91: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t261_n93;
  t261_n92: return 0.13483816385269165;
  t261_n93: return -0.14183375239372253;
  t261_n94: if (E.getNumReferences() >= 3273621504 /*159.5*/) goto t261_n104;
  t261_n95: if (E.getNumReferences() >= 3273359360 /*155.5*/) goto t261_n103;
  t261_n96: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t261_n100;
  t261_n97: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t261_n99;
  t261_n98: return 0.1632845252752304;
  t261_n99: return 0.09469707310199738;
  t261_n100: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t261_n102;
  t261_n101: return -0.08782467246055603;
  t261_n102: return 0.08484413474798203;
  t261_n103: return 0.12989096343517303;
  t261_n104: if (E.getNumReferences() >= 3287318528 /*481.0*/) goto t261_n124;
  t261_n105: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t261_n111;
  t261_n106: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t261_n110;
  t261_n107: if (E.getNumReferences() >= 3274342400 /*170.5*/) goto t261_n109;
  t261_n108: return -0.0072292182594537735;
  t261_n109: return 0.10209226608276367;
  t261_n110: return -0.07748360931873322;
  t261_n111: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t261_n123;
  t261_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n120;
  t261_n113: if (E.getNumReferences() >= 3283386368 /*361.0*/) goto t261_n119;
  t261_n114: if (E.getNumReferences() >= 3281780736 /*312.0*/) goto t261_n118;
  t261_n115: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t261_n117;
  t261_n116: return 0.10555781424045563;
  t261_n117: return -0.10216421633958817;
  t261_n118: return 0.22189638018608093;
  t261_n119: return -0.15419267117977142;
  t261_n120: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t261_n122;
  t261_n121: return -0.11057237535715103;
  t261_n122: return 0.10950304567813873;
  t261_n123: return -0.03429615497589111;
  t261_n124: if (E.getNumReferences() >= 3287859200 /*497.5*/) goto t261_n126;
  t261_n125: return 0.11088074743747711;
  t261_n126: if (E.getNumReferences() >= 3295395840 /*943.0*/) goto t261_n146;
  t261_n127: if (E.getNumReferences() >= 3293257728 /*812.5*/) goto t261_n143;
  t261_n128: if (E.getNumReferences() >= 3290841088 /*665.0*/) goto t261_n142;
  t261_n129: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n137;
  t261_n130: if (E.getNumReferences() >= 3290292224 /*631.5*/) goto t261_n136;
  t261_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t261_n133;
  t261_n132: return -0.09172262251377106;
  t261_n133: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t261_n135;
  t261_n134: return 0.13357321918010712;
  t261_n135: return 0.03861953690648079;
  t261_n136: return -1.9739550352096558;
  t261_n137: if (E.getNumReferences() >= 3290144768 /*622.5*/) goto t261_n141;
  t261_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t261_n140;
  t261_n139: return 0.11566611379384995;
  t261_n140: return -0.008127523586153984;
  t261_n141: return 0.11869083344936371;
  t261_n142: return -0.1491771787405014;
  t261_n143: if (E.getNumReferences() >= 3293855744 /*849.0*/) goto t261_n145;
  t261_n144: return 0.11944328993558884;
  t261_n145: return 0.140952467918396;
  t261_n146: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t261_n148;
  t261_n147: return -0.6025333404541016;
  t261_n148: return 0.11833794414997101;
  t261_n149: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t261_n153;
  t261_n150: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t261_n152;
  t261_n151: return 0.12230399250984192;
  t261_n152: return -0.10698050260543823;
  t261_n153: if (E.getNumReferences() >= 3283681280 /*370.0*/) goto t261_n155;
  t261_n154: return 0.04814609885215759;
  t261_n155: return 0.15145422518253326;
  t261_n156: return 0.1091514378786087;
  t261_n157: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t261_n159;
  t261_n158: return -0.033069808036088943;
  t261_n159: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace))) goto t261_n229;
  t261_n160: if (E.getNumReferences() >= 3280797696 /*282.0*/) goto t261_n180;
  t261_n161: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t261_n163;
  t261_n162: return -0.0069010015577077866;
  t261_n163: if (E.getNumReferences() >= 3280224256 /*264.5*/) goto t261_n173;
  t261_n164: if (E.getNumReferences() >= 3279781888 /*253.5*/) goto t261_n172;
  t261_n165: if (E.getNumReferences() >= 3278929920 /*240.5*/) goto t261_n167;
  t261_n166: return 0.023632634431123734;
  t261_n167: if (E.getNumReferences() >= 3278995456 /*241.5*/) goto t261_n169;
  t261_n168: return 0.13613127171993256;
  t261_n169: if (E.getNumReferences() >= 3279618048 /*251.0*/) goto t261_n171;
  t261_n170: return 0.06613736599683762;
  t261_n171: return 0.141680046916008;
  t261_n172: return -0.2067154496908188;
  t261_n173: if (E.getNumReferences() >= 3280502784 /*273.0*/) goto t261_n179;
  t261_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n176;
  t261_n175: return 0.09916649013757706;
  t261_n176: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n178;
  t261_n177: return 0.15112599730491638;
  t261_n178: return 0.12060169130563736;
  t261_n179: return 0.011274680495262146;
  t261_n180: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t261_n182;
  t261_n181: return -0.12587764859199524;
  t261_n182: if (E.getNumReferences() >= 3286974464 /*470.5*/) goto t261_n184;
  t261_n183: return -0.0724993422627449;
  t261_n184: if (E.getNumReferences() >= 3287040000 /*472.5*/) goto t261_n188;
  t261_n185: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n187;
  t261_n186: return 0.10882899165153503;
  t261_n187: return -0.3903099000453949;
  t261_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t261_n212;
  t261_n189: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t261_n191;
  t261_n190: return -0.05770701542496681;
  t261_n191: if (E.getNumReferences() >= 3296731136 /*1025.0*/) goto t261_n205;
  t261_n192: if (E.getNumReferences() >= 3293413376 /*822.0*/) goto t261_n204;
  t261_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t261_n195;
  t261_n194: return -0.20186083018779755;
  t261_n195: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t261_n199;
  t261_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t261_n198;
  t261_n197: return 0.10083174705505371;
  t261_n198: return 0.032033395022153854;
  t261_n199: if (E.getNumReferences() >= 3290390528 /*637.5*/) goto t261_n201;
  t261_n200: return 0.008841014467179775;
  t261_n201: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t261_n203;
  t261_n202: return 0.15551824867725372;
  t261_n203: return 0.08168961107730865;
  t261_n204: return -0.3375546932220459;
  t261_n205: if (E.getNumReferences() >= 3297198080 /*1082.0*/) goto t261_n211;
  t261_n206: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t261_n208;
  t261_n207: return 0.11701745539903641;
  t261_n208: if (E.getNumReferences() >= 3296980992 /*1055.5*/) goto t261_n210;
  t261_n209: return 0.22787946462631226;
  t261_n210: return 0.12326952815055847;
  t261_n211: return -0.03834453597664833;
  t261_n212: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t261_n224;
  t261_n213: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t261_n215;
  t261_n214: return -0.044505055993795395;
  t261_n215: if (E.getNumReferences() >= 3289071616 /*557.0*/) goto t261_n219;
  t261_n216: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t261_n218;
  t261_n217: return -0.06125618889927864;
  t261_n218: return 0.1488644927740097;
  t261_n219: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t261_n223;
  t261_n220: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t261_n222;
  t261_n221: return 0.08970051258802414;
  t261_n222: return -0.013417400419712067;
  t261_n223: return -0.3869909942150116;
  t261_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t261_n228;
  t261_n225: if (E.getNumReferences() >= 3290988544 /*674.0*/) goto t261_n227;
  t261_n226: return 0.08278180658817291;
  t261_n227: return 0.10269227623939514;
  t261_n228: return 0.06456772983074188;
  t261_n229: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t261_n233;
  t261_n230: if (E.getNumReferences() >= 3276472320 /*203.0*/) goto t261_n232;
  t261_n231: return -0.1690768152475357;
  t261_n232: return 0.058852244168519974;
  t261_n233: if (E.getNumReferences() >= 3282370560 /*330.0*/) goto t261_n239;
  t261_n234: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t261_n238;
  t261_n235: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t261_n237;
  t261_n236: return 0.056551743298769;
  t261_n237: return 0.10424909740686417;
  t261_n238: return 0.05930929258465767;
  t261_n239: return -0.025294866412878036;
  t261_n240: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t261_n254;
  t261_n241: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t261_n247;
  t261_n242: if (E.getNumReferences() >= 3297878016 /*1165.0*/) goto t261_n246;
  t261_n243: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t261_n245;
  t261_n244: return -0.04907950386404991;
  t261_n245: return 0.5231308937072754;
  t261_n246: return 0.009046928025782108;
  t261_n247: if (E.getNumReferences() >= 3307966464 /*2745.0*/) goto t261_n253;
  t261_n248: if (E.getNumReferences() >= 3303108608 /*1803.5*/) goto t261_n252;
  t261_n249: if (E.getNumReferences() >= 3299176448 /*1323.5*/) goto t261_n251;
  t261_n250: return 0.10868077725172043;
  t261_n251: return -0.3056700825691223;
  t261_n252: return 0.09728150814771652;
  t261_n253: return 0.006666501984000206;
  t261_n254: return 0.0020920021925121546;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree262(const Example& E) {
  t262_n0: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t262_n108;
  t262_n1: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t262_n35;
  t262_n2: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n22;
  t262_n3: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n21;
  t262_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n6;
  t262_n5: return -0.008244043216109276;
  t262_n6: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n18;
  t262_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n15;
  t262_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n10;
  t262_n9: return -0.02149556577205658;
  t262_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t262_n14;
  t262_n11: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t262_n13;
  t262_n12: return -0.1600462794303894;
  t262_n13: return 0.0041241771541535854;
  t262_n14: return 0.04647732153534889;
  t262_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t262_n17;
  t262_n16: return -0.20638687908649445;
  t262_n17: return 0.09097184240818024;
  t262_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t262_n20;
  t262_n19: return -0.010074760764837265;
  t262_n20: return 0.03026833012700081;
  t262_n21: return -0.012935210950672626;
  t262_n22: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t262_n32;
  t262_n23: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n27;
  t262_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t262_n26;
  t262_n25: return -0.026317942887544632;
  t262_n26: return -0.00905661378055811;
  t262_n27: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n29;
  t262_n28: return -0.007073251996189356;
  t262_n29: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n31;
  t262_n30: return 0.013970187865197659;
  t262_n31: return -0.02045024186372757;
  t262_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t262_n34;
  t262_n33: return 0.0012968543451279402;
  t262_n34: return 0.061587631702423096;
  t262_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t262_n107;
  t262_n36: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n106;
  t262_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t262_n81;
  t262_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n44;
  t262_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n43;
  t262_n40: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n42;
  t262_n41: return 0.009859366342425346;
  t262_n42: return -0.04682939127087593;
  t262_n43: return -0.003101843409240246;
  t262_n44: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n64;
  t262_n45: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n63;
  t262_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n50;
  t262_n47: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t262_n49;
  t262_n48: return -0.037456195801496506;
  t262_n49: return 0.016073863953351974;
  t262_n50: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t262_n60;
  t262_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Namespace))) goto t262_n55;
  t262_n52: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n54;
  t262_n53: return -0.10780937969684601;
  t262_n54: return -0.0009442463051527739;
  t262_n55: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t262_n59;
  t262_n56: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t262_n58;
  t262_n57: return 0.004181920550763607;
  t262_n58: return 0.017900830134749413;
  t262_n59: return -0.013249770738184452;
  t262_n60: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n62;
  t262_n61: return -0.07156478613615036;
  t262_n62: return -0.4588032066822052;
  t262_n63: return -0.4149528443813324;
  t262_n64: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t262_n76;
  t262_n65: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t262_n73;
  t262_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n68;
  t262_n67: return 0.012518598698079586;
  t262_n68: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n70;
  t262_n69: return 0.003971195314079523;
  t262_n70: if (E.getFilterLength() >= 3239051264 /*9.0*/) goto t262_n72;
  t262_n71: return 0.09001348912715912;
  t262_n72: return 0.10780789703130722;
  t262_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n75;
  t262_n74: return 0.1001659408211708;
  t262_n75: return -0.007081310730427504;
  t262_n76: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n80;
  t262_n77: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t262_n79;
  t262_n78: return 0.0030867040622979403;
  t262_n79: return 0.13598109781742096;
  t262_n80: return 0.03604250028729439;
  t262_n81: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t262_n103;
  t262_n82: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n98;
  t262_n83: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t262_n95;
  t262_n84: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t262_n86;
  t262_n85: return -0.004191744141280651;
  t262_n86: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n90;
  t262_n87: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n89;
  t262_n88: return 0.019402794539928436;
  t262_n89: return 0.7818167805671692;
  t262_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t262_n92;
  t262_n91: return -0.010768801905214787;
  t262_n92: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t262_n94;
  t262_n93: return 0.026381682604551315;
  t262_n94: return -0.011222007684409618;
  t262_n95: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n97;
  t262_n96: return 0.10062766075134277;
  t262_n97: return -0.044089436531066895;
  t262_n98: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n100;
  t262_n99: return 0.01853042282164097;
  t262_n100: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t262_n102;
  t262_n101: return -0.006167309358716011;
  t262_n102: return 0.011526966467499733;
  t262_n103: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t262_n105;
  t262_n104: return 0.08259996026754379;
  t262_n105: return 0.006063962355256081;
  t262_n106: return 0.021013807505369186;
  t262_n107: return 0.06946537643671036;
  t262_n108: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t262_n110;
  t262_n109: return -0.0013524553505703807;
  t262_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t262_n112;
  t262_n111: return 0.00012157700257375836;
  t262_n112: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t262_n172;
  t262_n113: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t262_n115;
  t262_n114: return 0.0032739804591983557;
  t262_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n117;
  t262_n116: return -0.011486383154988289;
  t262_n117: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n119;
  t262_n118: return 0.06497560441493988;
  t262_n119: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n163;
  t262_n120: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t262_n158;
  t262_n121: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n149;
  t262_n122: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n142;
  t262_n123: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t262_n125;
  t262_n124: return 0.01418117806315422;
  t262_n125: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n141;
  t262_n126: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n130;
  t262_n127: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n129;
  t262_n128: return 0.11792461574077606;
  t262_n129: return -0.07444991171360016;
  t262_n130: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t262_n134;
  t262_n131: if (E.getSymbolScopeDistance() >= 3221225472 /*2.0*/) goto t262_n133;
  t262_n132: return 0.10827227681875229;
  t262_n133: return 0.07019975781440735;
  t262_n134: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t262_n140;
  t262_n135: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t262_n137;
  t262_n136: return -1.3608899116516113;
  t262_n137: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t262_n139;
  t262_n138: return 0.08352747559547424;
  t262_n139: return -0.4437861740589142;
  t262_n140: return 0.13337227702140808;
  t262_n141: return -0.04905097559094429;
  t262_n142: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n144;
  t262_n143: return 0.2948704659938812;
  t262_n144: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n146;
  t262_n145: return 0.06763731688261032;
  t262_n146: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t262_n148;
  t262_n147: return 0.143254816532135;
  t262_n148: return -0.10781954973936081;
  t262_n149: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t262_n153;
  t262_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t262_n152;
  t262_n151: return -0.0354510098695755;
  t262_n152: return 0.06758815795183182;
  t262_n153: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t262_n157;
  t262_n154: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t262_n156;
  t262_n155: return -0.03359582647681236;
  t262_n156: return 0.0997525230050087;
  t262_n157: return 0.10845855623483658;
  t262_n158: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t262_n160;
  t262_n159: return -0.08159051835536957;
  t262_n160: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t262_n162;
  t262_n161: return 0.0986877977848053;
  t262_n162: return 0.06630610674619675;
  t262_n163: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n171;
  t262_n164: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t262_n166;
  t262_n165: return 0.0516473725438118;
  t262_n166: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n170;
  t262_n167: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n169;
  t262_n168: return 0.1761477291584015;
  t262_n169: return -0.37156572937965393;
  t262_n170: return 0.049808863550424576;
  t262_n171: return -0.032898854464292526;
  t262_n172: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t262_n244;
  t262_n173: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t262_n211;
  t262_n174: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n176;
  t262_n175: return -0.0007557005155831575;
  t262_n176: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t262_n190;
  t262_n177: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n179;
  t262_n178: return -0.024989569559693336;
  t262_n179: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t262_n189;
  t262_n180: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n182;
  t262_n181: return -0.10352250188589096;
  t262_n182: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t262_n184;
  t262_n183: return -0.0650520920753479;
  t262_n184: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t262_n186;
  t262_n185: return -0.005746627692133188;
  t262_n186: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t262_n188;
  t262_n187: return 0.054718438535928726;
  t262_n188: return -0.003524956526234746;
  t262_n189: return 0.133326455950737;
  t262_n190: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t262_n196;
  t262_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n193;
  t262_n192: return -0.0631726086139679;
  t262_n193: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t262_n195;
  t262_n194: return 0.0031788838095963;
  t262_n195: return -0.03442783281207085;
  t262_n196: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t262_n198;
  t262_n197: return -0.04407269135117531;
  t262_n198: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n210;
  t262_n199: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n201;
  t262_n200: return 0.02272173762321472;
  t262_n201: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t262_n207;
  t262_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t262_n204;
  t262_n203: return -0.10382838547229767;
  t262_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t262_n206;
  t262_n205: return -0.13317474722862244;
  t262_n206: return 0.14660070836544037;
  t262_n207: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t262_n209;
  t262_n208: return -0.004277427680790424;
  t262_n209: return 0.08221179991960526;
  t262_n210: return 0.013942623510956764;
  t262_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t262_n213;
  t262_n212: return 0.004638136830180883;
  t262_n213: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t262_n243;
  t262_n214: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t262_n218;
  t262_n215: if (E.getNumReferences() >= 3270443008 /*119.5*/) goto t262_n217;
  t262_n216: return -0.011436648666858673;
  t262_n217: return 0.09871672093868256;
  t262_n218: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t262_n242;
  t262_n219: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t262_n241;
  t262_n220: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t262_n234;
  t262_n221: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t262_n225;
  t262_n222: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t262_n224;
  t262_n223: return 0.12032372504472733;
  t262_n224: return -0.12491938471794128;
  t262_n225: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t262_n229;
  t262_n226: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t262_n228;
  t262_n227: return 0.019345544278621674;
  t262_n228: return 0.1059982180595398;
  t262_n229: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t262_n233;
  t262_n230: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n232;
  t262_n231: return 0.10284197330474854;
  t262_n232: return -0.11303997039794922;
  t262_n233: return 0.07389620691537857;
  t262_n234: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t262_n236;
  t262_n235: return 0.1569535881280899;
  t262_n236: if (E.getNumReferences() >= 3299532800 /*1367.0*/) goto t262_n240;
  t262_n237: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t262_n239;
  t262_n238: return 0.14008520543575287;
  t262_n239: return 0.09713130444288254;
  t262_n240: return 0.11039789021015167;
  t262_n241: return 0.04188837856054306;
  t262_n242: return -0.0005387468263506889;
  t262_n243: return -0.0002354362659389153;
  t262_n244: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t262_n248;
  t262_n245: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t262_n247;
  t262_n246: return 0.005492060910910368;
  t262_n247: return 0.11397143453359604;
  t262_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t262_n254;
  t262_n249: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t262_n253;
  t262_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t262_n252;
  t262_n251: return 0.08401627838611603;
  t262_n252: return 0.04258376732468605;
  t262_n253: return 0.040218353271484375;
  t262_n254: return -0.040595464408397675;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree263(const Example& E) {
  t263_n0: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t263_n2;
  t263_n1: return 0.0023874929174780846;
  t263_n2: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t263_n44;
  t263_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t263_n7;
  t263_n4: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t263_n6;
  t263_n5: return -0.0006029728683643043;
  t263_n6: return 0.00908026471734047;
  t263_n7: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n9;
  t263_n8: return -0.020663456991314888;
  t263_n9: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t263_n25;
  t263_n10: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t263_n24;
  t263_n11: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n15;
  t263_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t263_n14;
  t263_n13: return -0.08763932436704636;
  t263_n14: return 0.019318927079439163;
  t263_n15: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t263_n23;
  t263_n16: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t263_n22;
  t263_n17: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n21;
  t263_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t263_n20;
  t263_n19: return -0.9319264888763428;
  t263_n20: return -0.44293856620788574;
  t263_n21: return -0.14834250509738922;
  t263_n22: return -0.02159433253109455;
  t263_n23: return -0.07170332968235016;
  t263_n24: return 0.037735603749752045;
  t263_n25: if (E.getNumReferences() >= 3368194704 /*398484.5*/) goto t263_n41;
  t263_n26: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t263_n28;
  t263_n27: return -0.059274982661008835;
  t263_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t263_n38;
  t263_n29: if (E.getNumReferences() >= 3247964160 /*19.0*/) goto t263_n33;
  t263_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t263_n32;
  t263_n31: return -0.42289865016937256;
  t263_n32: return -0.02180936373770237;
  t263_n33: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n37;
  t263_n34: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t263_n36;
  t263_n35: return 0.1185101717710495;
  t263_n36: return -0.0030759975779801607;
  t263_n37: return 0.11435981839895248;
  t263_n38: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n40;
  t263_n39: return 0.09520106762647629;
  t263_n40: return 0.08800731599330902;
  t263_n41: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n43;
  t263_n42: return 0.0101467315107584;
  t263_n43: return 0.07417891174554825;
  t263_n44: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t263_n254;
  t263_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t263_n47;
  t263_n46: return -0.003154890378937125;
  t263_n47: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t263_n55;
  t263_n48: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t263_n50;
  t263_n49: return 3.358894173288718e-05;
  t263_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t263_n52;
  t263_n51: return 0.007783149369060993;
  t263_n52: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t263_n54;
  t263_n53: return 0.025493767112493515;
  t263_n54: return -0.15646100044250488;
  t263_n55: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t263_n225;
  t263_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t263_n110;
  t263_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t263_n77;
  t263_n58: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t263_n68;
  t263_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n67;
  t263_n60: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t263_n66;
  t263_n61: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t263_n65;
  t263_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t263_n64;
  t263_n63: return 0.07139299809932709;
  t263_n64: return 0.0995524600148201;
  t263_n65: return 0.01742180809378624;
  t263_n66: return -0.052290625870227814;
  t263_n67: return -0.03632097318768501;
  t263_n68: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n72;
  t263_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n71;
  t263_n70: return 0.07969311624765396;
  t263_n71: return -1.3787411451339722;
  t263_n72: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t263_n74;
  t263_n73: return 0.12549297511577606;
  t263_n74: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t263_n76;
  t263_n75: return -0.04612200707197189;
  t263_n76: return 0.10691125690937042;
  t263_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t263_n99;
  t263_n78: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n80;
  t263_n79: return 0.02395429089665413;
  t263_n80: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t263_n90;
  t263_n81: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t263_n83;
  t263_n82: return 0.055335212498903275;
  t263_n83: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n89;
  t263_n84: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n88;
  t263_n85: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n87;
  t263_n86: return 0.09459211677312851;
  t263_n87: return 0.07227978855371475;
  t263_n88: return 0.03057156316936016;
  t263_n89: return -0.11144591122865677;
  t263_n90: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t263_n98;
  t263_n91: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n97;
  t263_n92: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n94;
  t263_n93: return -0.12411695718765259;
  t263_n94: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n96;
  t263_n95: return 0.09789913892745972;
  t263_n96: return -0.10013438016176224;
  t263_n97: return 0.1287747621536255;
  t263_n98: return 0.06479192525148392;
  t263_n99: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t263_n109;
  t263_n100: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n102;
  t263_n101: return 0.17948542535305023;
  t263_n102: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t263_n104;
  t263_n103: return 0.005848924163728952;
  t263_n104: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n108;
  t263_n105: if (E.getNumReferences() >= 3314549760 /*4608.5*/) goto t263_n107;
  t263_n106: return 0.13462834060192108;
  t263_n107: return 0.032756831496953964;
  t263_n108: return 0.056799959391355515;
  t263_n109: return 0.04895709827542305;
  t263_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t263_n124;
  t263_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t263_n113;
  t263_n112: return -0.060876429080963135;
  t263_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t263_n115;
  t263_n114: return -0.10031954944133759;
  t263_n115: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t263_n123;
  t263_n116: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t263_n122;
  t263_n117: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t263_n119;
  t263_n118: return 0.05266343057155609;
  t263_n119: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n121;
  t263_n120: return 0.11586331576108932;
  t263_n121: return 0.08814885467290878;
  t263_n122: return 0.10560549795627594;
  t263_n123: return -0.035084839910268784;
  t263_n124: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t263_n220;
  t263_n125: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n169;
  t263_n126: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t263_n128;
  t263_n127: return 0.03357893228530884;
  t263_n128: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n168;
  t263_n129: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n167;
  t263_n130: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n160;
  t263_n131: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t263_n143;
  t263_n132: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n142;
  t263_n133: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n137;
  t263_n134: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t263_n136;
  t263_n135: return 0.04440688714385033;
  t263_n136: return 0.06986689567565918;
  t263_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t263_n141;
  t263_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t263_n140;
  t263_n139: return 0.02680877223610878;
  t263_n140: return 0.07680447399616241;
  t263_n141: return 0.11841564625501633;
  t263_n142: return -0.049320418387651443;
  t263_n143: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t263_n159;
  t263_n144: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t263_n152;
  t263_n145: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t263_n151;
  t263_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t263_n148;
  t263_n147: return 0.07256726920604706;
  t263_n148: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n150;
  t263_n149: return 0.11025198549032211;
  t263_n150: return 0.04731715843081474;
  t263_n151: return -0.053121596574783325;
  t263_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t263_n158;
  t263_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n155;
  t263_n154: return 0.012446449138224125;
  t263_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t263_n157;
  t263_n156: return 0.046073392033576965;
  t263_n157: return 0.10717301815748215;
  t263_n158: return 0.14640453457832336;
  t263_n159: return -0.006157289259135723;
  t263_n160: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n164;
  t263_n161: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t263_n163;
  t263_n162: return -0.009171332232654095;
  t263_n163: return 0.09098635613918304;
  t263_n164: if (E.getFileProximityDistance() >= 3254910976 /*32.5*/) goto t263_n166;
  t263_n165: return -0.028231782838702202;
  t263_n166: return -0.1655210554599762;
  t263_n167: return -0.10084109753370285;
  t263_n168: return 0.013560670427978039;
  t263_n169: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t263_n193;
  t263_n170: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t263_n176;
  t263_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t263_n175;
  t263_n172: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t263_n174;
  t263_n173: return 0.042580246925354004;
  t263_n174: return 0.08142878115177155;
  t263_n175: return 0.07321755588054657;
  t263_n176: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n192;
  t263_n177: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n191;
  t263_n178: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t263_n180;
  t263_n179: return 0.04339143633842468;
  t263_n180: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n190;
  t263_n181: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t263_n185;
  t263_n182: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t263_n184;
  t263_n183: return -0.10641635209321976;
  t263_n184: return 0.09505301713943481;
  t263_n185: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t263_n187;
  t263_n186: return -0.04946257546544075;
  t263_n187: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t263_n189;
  t263_n188: return 0.09611184149980545;
  t263_n189: return -0.1288149058818817;
  t263_n190: return -0.10059801489114761;
  t263_n191: return 0.041399359703063965;
  t263_n192: return 0.00016177556244656444;
  t263_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t263_n211;
  t263_n194: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t263_n210;
  t263_n195: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n209;
  t263_n196: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t263_n202;
  t263_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t263_n201;
  t263_n198: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t263_n200;
  t263_n199: return 0.051173366606235504;
  t263_n200: return 0.14252786338329315;
  t263_n201: return 0.11402884870767593;
  t263_n202: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t263_n204;
  t263_n203: return -0.08729677647352219;
  t263_n204: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t263_n208;
  t263_n205: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t263_n207;
  t263_n206: return 0.10076185315847397;
  t263_n207: return 0.10704468190670013;
  t263_n208: return 0.20125707983970642;
  t263_n209: return -0.1006065085530281;
  t263_n210: return 0.04129302129149437;
  t263_n211: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t263_n219;
  t263_n212: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t263_n218;
  t263_n213: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t263_n217;
  t263_n214: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t263_n216;
  t263_n215: return 0.10954506695270538;
  t263_n216: return -0.13016921281814575;
  t263_n217: return -0.10079646110534668;
  t263_n218: return 0.12466908246278763;
  t263_n219: return -0.14461757242679596;
  t263_n220: if (E.getNumReferences() >= 3253469184 /*29.5*/) goto t263_n222;
  t263_n221: return -0.010812586173415184;
  t263_n222: if (E.getSymbolScopeDistance() >= 3247964160 /*19.0*/) goto t263_n224;
  t263_n223: return 0.18467138707637787;
  t263_n224: return 0.05715601146221161;
  t263_n225: if (E.getNumReferences() >= 3282452480 /*332.5*/) goto t263_n227;
  t263_n226: return 0.004416801035404205;
  t263_n227: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t263_n229;
  t263_n228: return 0.029225073754787445;
  t263_n229: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t263_n253;
  t263_n230: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t263_n240;
  t263_n231: if (E.getNumReferences() >= 3291054080 /*678.0*/) goto t263_n233;
  t263_n232: return -0.11192569136619568;
  t263_n233: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t263_n239;
  t263_n234: if (E.getNumReferences() >= 3302932480 /*1782.0*/) goto t263_n236;
  t263_n235: return 0.1872205138206482;
  t263_n236: if (E.getNumReferences() >= 3325197824 /*11423.5*/) goto t263_n238;
  t263_n237: return -0.1027078926563263;
  t263_n238: return 0.08710148185491562;
  t263_n239: return 0.09813757240772247;
  t263_n240: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t263_n242;
  t263_n241: return -0.16304519772529602;
  t263_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t263_n244;
  t263_n243: return -0.1162911206483841;
  t263_n244: if (E.getNumReferences() >= 3321980928 /*8282.0*/) goto t263_n252;
  t263_n245: if (E.getNumReferences() >= 3292160000 /*745.5*/) goto t263_n249;
  t263_n246: if (E.getNumReferences() >= 3283419136 /*362.0*/) goto t263_n248;
  t263_n247: return 0.11921671032905579;
  t263_n248: return -0.28737935423851013;
  t263_n249: if (E.getNumReferences() >= 3306002432 /*2265.5*/) goto t263_n251;
  t263_n250: return 0.10718824714422226;
  t263_n251: return 0.10752546042203903;
  t263_n252: return -0.11077603697776794;
  t263_n253: return 0.023544572293758392;
  t263_n254: return -0.04673806205391884;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree264(const Example& E) {
  t264_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t264_n2;
  t264_n1: return -0.0002530912170186639;
  t264_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t264_n56;
  t264_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n27;
  t264_n4: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t264_n6;
  t264_n5: return 0.10707733780145645;
  t264_n6: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t264_n26;
  t264_n7: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t264_n25;
  t264_n8: if (E.getNumReferences() >= 3327672832 /*13840.5*/) goto t264_n16;
  t264_n9: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t264_n11;
  t264_n10: return -0.09797956049442291;
  t264_n11: if (E.getNumReferences() >= 3324626432 /*10865.5*/) goto t264_n15;
  t264_n12: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t264_n14;
  t264_n13: return -0.14917878806591034;
  t264_n14: return 0.1046484187245369;
  t264_n15: return -0.014194603078067303;
  t264_n16: if (E.getNumReferences() >= 3328148480 /*14305.0*/) goto t264_n20;
  t264_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n19;
  t264_n18: return 0.1365695595741272;
  t264_n19: return 0.10056792199611664;
  t264_n20: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t264_n24;
  t264_n21: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t264_n23;
  t264_n22: return -0.13153555989265442;
  t264_n23: return 0.07514497637748718;
  t264_n24: return 0.01702863909304142;
  t264_n25: return -0.1416569948196411;
  t264_n26: return 0.012360326945781708;
  t264_n27: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t264_n39;
  t264_n28: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t264_n30;
  t264_n29: return -0.003986636642366648;
  t264_n30: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n38;
  t264_n31: if (E.getNumReferences() >= 3359911200 /*200884.5*/) goto t264_n35;
  t264_n32: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t264_n34;
  t264_n33: return -0.18023322522640228;
  t264_n34: return -0.6340731978416443;
  t264_n35: if (E.getNumReferences() >= 3361141760 /*220112.0*/) goto t264_n37;
  t264_n36: return 0.08171653747558594;
  t264_n37: return -0.1100151538848877;
  t264_n38: return 0.014440600760281086;
  t264_n39: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t264_n55;
  t264_n40: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t264_n46;
  t264_n41: if (E.getNumReferences() >= 3321499648 /*8002.0*/) goto t264_n45;
  t264_n42: if (E.getNumReferences() >= 3320885248 /*7702.0*/) goto t264_n44;
  t264_n43: return -0.18418440222740173;
  t264_n44: return 0.4016737937927246;
  t264_n45: return 0.06517153978347778;
  t264_n46: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n48;
  t264_n47: return 0.03501906618475914;
  t264_n48: if (E.getNumReferences() >= 3321825280 /*8161.0*/) goto t264_n54;
  t264_n49: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t264_n53;
  t264_n50: if (E.getNumReferences() >= 3321156608 /*7834.5*/) goto t264_n52;
  t264_n51: return 0.3053189218044281;
  t264_n52: return 0.3541563153266907;
  t264_n53: return 0.04062018170952797;
  t264_n54: return 0.03988879546523094;
  t264_n55: return 0.008027967065572739;
  t264_n56: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t264_n60;
  t264_n57: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t264_n59;
  t264_n58: return -0.02905375324189663;
  t264_n59: return -0.07338821142911911;
  t264_n60: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t264_n240;
  t264_n61: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t264_n219;
  t264_n62: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t264_n184;
  t264_n63: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t264_n65;
  t264_n64: return 0.02275303192436695;
  t264_n65: if (E.getNumReferences() >= 3320185856 /*7360.5*/) goto t264_n73;
  t264_n66: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t264_n68;
  t264_n67: return 0.11685184389352798;
  t264_n68: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n70;
  t264_n69: return -0.2639961540699005;
  t264_n70: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n72;
  t264_n71: return 0.11449114978313446;
  t264_n72: return -0.10700280219316483;
  t264_n73: if (E.getNumReferences() >= 3322624512 /*8910.5*/) goto t264_n163;
  t264_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n76;
  t264_n75: return -0.10703901201486588;
  t264_n76: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t264_n112;
  t264_n77: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n87;
  t264_n78: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n80;
  t264_n79: return -0.15353578329086304;
  t264_n80: if (E.getNumReferences() >= 3321541632 /*8022.5*/) goto t264_n82;
  t264_n81: return -0.021576842293143272;
  t264_n82: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t264_n86;
  t264_n83: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n85;
  t264_n84: return -0.14196035265922546;
  t264_n85: return 0.13572247326374054;
  t264_n86: return -0.11049371212720871;
  t264_n87: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t264_n105;
  t264_n88: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n104;
  t264_n89: if (E.getNumReferences() >= 3322036736 /*8336.5*/) goto t264_n103;
  t264_n90: if (E.getNumReferences() >= 3321878528 /*8187.0*/) goto t264_n102;
  t264_n91: if (E.getNumReferences() >= 3321586688 /*8044.5*/) goto t264_n101;
  t264_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n94;
  t264_n93: return 0.1761539876461029;
  t264_n94: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n98;
  t264_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t264_n97;
  t264_n96: return -0.13397538661956787;
  t264_n97: return 0.6902667880058289;
  t264_n98: if (E.getNumReferences() >= 3320489984 /*7509.0*/) goto t264_n100;
  t264_n99: return 0.14737914502620697;
  t264_n100: return -0.11158844828605652;
  t264_n101: return 0.11582455784082413;
  t264_n102: return 0.12325620651245117;
  t264_n103: return -0.04956893250346184;
  t264_n104: return -0.1410479098558426;
  t264_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t264_n107;
  t264_n106: return 0.012413193471729755;
  t264_n107: if (E.getNumReferences() >= 3321601024 /*8051.5*/) goto t264_n109;
  t264_n108: return 0.04255624860525131;
  t264_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t264_n111;
  t264_n110: return -0.10109062492847443;
  t264_n111: return 0.1134641021490097;
  t264_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t264_n130;
  t264_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n115;
  t264_n114: return -0.0497509129345417;
  t264_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t264_n123;
  t264_n116: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t264_n120;
  t264_n117: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t264_n119;
  t264_n118: return -1.1469184160232544;
  t264_n119: return 0.047611434012651443;
  t264_n120: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n122;
  t264_n121: return 0.052352942526340485;
  t264_n122: return 0.1138836219906807;
  t264_n123: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t264_n129;
  t264_n124: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t264_n128;
  t264_n125: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t264_n127;
  t264_n126: return 0.13063210248947144;
  t264_n127: return -0.04264707490801811;
  t264_n128: return 0.11449922621250153;
  t264_n129: return 0.0407857671380043;
  t264_n130: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t264_n162;
  t264_n131: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n133;
  t264_n132: return -0.7286947965621948;
  t264_n133: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t264_n145;
  t264_n134: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t264_n136;
  t264_n135: return -0.10237197577953339;
  t264_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t264_n144;
  t264_n137: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n139;
  t264_n138: return 0.07714354991912842;
  t264_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n143;
  t264_n140: if (E.getNumReferences() >= 3321156608 /*7834.5*/) goto t264_n142;
  t264_n141: return 0.07630033046007156;
  t264_n142: return 0.10620920360088348;
  t264_n143: return 0.06719394028186798;
  t264_n144: return 0.10172060877084732;
  t264_n145: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t264_n161;
  t264_n146: if (E.getNumReferences() >= 3320403968 /*7467.0*/) goto t264_n150;
  t264_n147: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t264_n149;
  t264_n148: return -0.11138954013586044;
  t264_n149: return 0.11571714282035828;
  t264_n150: if (E.getNumReferences() >= 3320655872 /*7590.0*/) goto t264_n152;
  t264_n151: return -0.109327532351017;
  t264_n152: if (E.getNumReferences() >= 3321151488 /*7832.0*/) goto t264_n158;
  t264_n153: if (E.getNumReferences() >= 3320945664 /*7731.5*/) goto t264_n155;
  t264_n154: return 0.08197680115699768;
  t264_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n157;
  t264_n156: return 0.10938876122236252;
  t264_n157: return 0.0851588100194931;
  t264_n158: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t264_n160;
  t264_n159: return 0.04696061834692955;
  t264_n160: return 0.10493941605091095;
  t264_n161: return -0.12212970107793808;
  t264_n162: return 0.10132923722267151;
  t264_n163: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t264_n183;
  t264_n164: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t264_n180;
  t264_n165: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n179;
  t264_n166: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t264_n168;
  t264_n167: return -0.4876014292240143;
  t264_n168: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n170;
  t264_n169: return 0.12054920941591263;
  t264_n170: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n174;
  t264_n171: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t264_n173;
  t264_n172: return -0.37670332193374634;
  t264_n173: return 0.10709338635206223;
  t264_n174: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t264_n178;
  t264_n175: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n177;
  t264_n176: return -0.24214619398117065;
  t264_n177: return 0.10638914257287979;
  t264_n178: return 0.15195167064666748;
  t264_n179: return -0.3174605965614319;
  t264_n180: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t264_n182;
  t264_n181: return -0.28234386444091797;
  t264_n182: return 0.11073284596204758;
  t264_n183: return 0.09919124096632004;
  t264_n184: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t264_n214;
  t264_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t264_n205;
  t264_n186: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t264_n196;
  t264_n187: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t264_n191;
  t264_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t264_n190;
  t264_n189: return -0.542084276676178;
  t264_n190: return -0.04978398233652115;
  t264_n191: if (E.getNumReferences() >= 3321995264 /*8296.0*/) goto t264_n193;
  t264_n192: return 0.0983557254076004;
  t264_n193: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t264_n195;
  t264_n194: return 0.06299242377281189;
  t264_n195: return -0.1440954953432083;
  t264_n196: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t264_n204;
  t264_n197: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n201;
  t264_n198: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t264_n200;
  t264_n199: return -0.7193828225135803;
  t264_n200: return 0.08207804709672928;
  t264_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t264_n203;
  t264_n202: return 0.09743236750364304;
  t264_n203: return 0.11266063153743744;
  t264_n204: return 0.025277288630604744;
  t264_n205: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t264_n213;
  t264_n206: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t264_n212;
  t264_n207: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t264_n209;
  t264_n208: return 0.09317463636398315;
  t264_n209: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t264_n211;
  t264_n210: return 0.10488531738519669;
  t264_n211: return 0.10686041414737701;
  t264_n212: return 0.006027278024703264;
  t264_n213: return -0.02859637327492237;
  t264_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t264_n218;
  t264_n215: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t264_n217;
  t264_n216: return -0.023889193311333656;
  t264_n217: return 0.10965083539485931;
  t264_n218: return 0.13644054532051086;
  t264_n219: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t264_n227;
  t264_n220: if (E.getNumReferences() >= 3320516608 /*7522.0*/) goto t264_n226;
  t264_n221: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t264_n223;
  t264_n222: return -0.2607899010181427;
  t264_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t264_n225;
  t264_n224: return 0.11279025673866272;
  t264_n225: return 0.14243820309638977;
  t264_n226: return -0.06580764055252075;
  t264_n227: if (E.getNumReferences() >= 3322671104 /*8956.0*/) goto t264_n229;
  t264_n228: return 0.11113855987787247;
  t264_n229: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t264_n231;
  t264_n230: return -0.1581154614686966;
  t264_n231: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t264_n233;
  t264_n232: return 0.07029625028371811;
  t264_n233: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t264_n239;
  t264_n234: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t264_n238;
  t264_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t264_n237;
  t264_n236: return -0.10431382805109024;
  t264_n237: return 0.10504720360040665;
  t264_n238: return 0.10906069725751877;
  t264_n239: return -0.10196453332901001;
  t264_n240: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t264_n246;
  t264_n241: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t264_n245;
  t264_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t264_n244;
  t264_n243: return -0.01334524154663086;
  t264_n244: return 0.11777745187282562;
  t264_n245: return -0.00971667468547821;
  t264_n246: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t264_n248;
  t264_n247: return 0.010011685080826283;
  t264_n248: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t264_n252;
  t264_n249: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t264_n251;
  t264_n250: return 0.11273820698261261;
  t264_n251: return -0.06519660353660583;
  t264_n252: if (E.getNumReferences() >= 3333341184 /*22368.0*/) goto t264_n254;
  t264_n253: return 0.024314939975738525;
  t264_n254: return -0.006078618578612804;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree265(const Example& E) {
  t265_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t265_n232;
  t265_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t265_n3;
  t265_n2: return -0.0001371461694361642;
  t265_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t265_n43;
  t265_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t265_n24;
  t265_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n7;
  t265_n6: return -0.05689384043216705;
  t265_n7: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n11;
  t265_n8: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t265_n10;
  t265_n9: return -0.011340834200382233;
  t265_n10: return 0.01351480558514595;
  t265_n11: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t265_n19;
  t265_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n18;
  t265_n13: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n17;
  t265_n14: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n16;
  t265_n15: return -0.06802206486463547;
  t265_n16: return -1.1481515169143677;
  t265_n17: return -0.0010421437909826636;
  t265_n18: return -0.019771572202444077;
  t265_n19: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t265_n23;
  t265_n20: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t265_n22;
  t265_n21: return 0.0042795455083251;
  t265_n22: return 0.07770003378391266;
  t265_n23: return -0.017406756058335304;
  t265_n24: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n26;
  t265_n25: return -0.01997656747698784;
  t265_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t265_n28;
  t265_n27: return 0.01847931742668152;
  t265_n28: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n42;
  t265_n29: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n41;
  t265_n30: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n36;
  t265_n31: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t265_n33;
  t265_n32: return -0.2328079789876938;
  t265_n33: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n35;
  t265_n34: return 0.0899992287158966;
  t265_n35: return 0.01858898624777794;
  t265_n36: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n40;
  t265_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n39;
  t265_n38: return 0.11347991973161697;
  t265_n39: return -0.3291932940483093;
  t265_n40: return 0.011169728823006153;
  t265_n41: return -0.024112431332468987;
  t265_n42: return 0.06490448117256165;
  t265_n43: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t265_n135;
  t265_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n48;
  t265_n45: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t265_n47;
  t265_n46: return 0.003509857691824436;
  t265_n47: return 0.015494339168071747;
  t265_n48: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n96;
  t265_n49: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t265_n63;
  t265_n50: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n60;
  t265_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t265_n53;
  t265_n52: return -0.00696588447317481;
  t265_n53: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t265_n55;
  t265_n54: return -0.03294484689831734;
  t265_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t265_n57;
  t265_n56: return 0.04851873591542244;
  t265_n57: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t265_n59;
  t265_n58: return -0.1001054123044014;
  t265_n59: return 0.041041478514671326;
  t265_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t265_n62;
  t265_n61: return -0.026277143508195877;
  t265_n62: return 0.004450688604265451;
  t265_n63: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n73;
  t265_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t265_n66;
  t265_n65: return 0.007965834811329842;
  t265_n66: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n68;
  t265_n67: return 0.005791411269456148;
  t265_n68: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t265_n70;
  t265_n69: return 0.0656772181391716;
  t265_n70: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t265_n72;
  t265_n71: return -0.03358175605535507;
  t265_n72: return 0.11125696450471878;
  t265_n73: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t265_n95;
  t265_n74: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n76;
  t265_n75: return -0.018549256026744843;
  t265_n76: if (E.getNumReferences() >= 3324770304 /*11006.0*/) goto t265_n94;
  t265_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t265_n83;
  t265_n78: if (E.getNumReferences() >= 3298770944 /*1274.0*/) goto t265_n80;
  t265_n79: return -0.03080056793987751;
  t265_n80: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n82;
  t265_n81: return 0.09984475374221802;
  t265_n82: return -0.399953693151474;
  t265_n83: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t265_n89;
  t265_n84: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t265_n86;
  t265_n85: return -0.7000288963317871;
  t265_n86: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t265_n88;
  t265_n87: return 0.09750567376613617;
  t265_n88: return 0.11200466752052307;
  t265_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n91;
  t265_n90: return 0.08423177897930145;
  t265_n91: if (E.getSymbolScopeDistance() >= 3246391296 /*16.0*/) goto t265_n93;
  t265_n92: return -0.2014145851135254;
  t265_n93: return 0.05421341210603714;
  t265_n94: return -0.019702879711985588;
  t265_n95: return 0.4224223792552948;
  t265_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t265_n132;
  t265_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n99;
  t265_n98: return -0.024037685245275497;
  t265_n99: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t265_n101;
  t265_n100: return -0.00846597459167242;
  t265_n101: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t265_n103;
  t265_n102: return -0.011128704063594341;
  t265_n103: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t265_n127;
  t265_n104: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n126;
  t265_n105: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t265_n115;
  t265_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n114;
  t265_n107: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t265_n111;
  t265_n108: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t265_n110;
  t265_n109: return 0.08834553509950638;
  t265_n110: return -0.0371847003698349;
  t265_n111: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t265_n113;
  t265_n112: return 0.13235172629356384;
  t265_n113: return 0.01626795157790184;
  t265_n114: return -0.12506616115570068;
  t265_n115: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t265_n119;
  t265_n116: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t265_n118;
  t265_n117: return 0.06157601997256279;
  t265_n118: return 0.09177961945533752;
  t265_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n121;
  t265_n120: return -0.13045144081115723;
  t265_n121: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t265_n125;
  t265_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t265_n124;
  t265_n123: return 0.07351258397102356;
  t265_n124: return 0.11638680845499039;
  t265_n125: return 0.08588734269142151;
  t265_n126: return -0.005817297380417585;
  t265_n127: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n129;
  t265_n128: return -0.05092532932758331;
  t265_n129: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t265_n131;
  t265_n130: return 0.15725819766521454;
  t265_n131: return 0.031086064875125885;
  t265_n132: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t265_n134;
  t265_n133: return 0.0060227252542972565;
  t265_n134: return 0.010161848738789558;
  t265_n135: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t265_n225;
  t265_n136: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t265_n200;
  t265_n137: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t265_n163;
  t265_n138: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n140;
  t265_n139: return 0.00890728086233139;
  t265_n140: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n162;
  t265_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t265_n151;
  t265_n142: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t265_n144;
  t265_n143: return -0.5232328772544861;
  t265_n144: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t265_n150;
  t265_n145: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t265_n149;
  t265_n146: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t265_n148;
  t265_n147: return 0.10144828259944916;
  t265_n148: return -0.08403301984071732;
  t265_n149: return 0.10875600576400757;
  t265_n150: return -0.036639340221881866;
  t265_n151: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n161;
  t265_n152: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n158;
  t265_n153: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t265_n155;
  t265_n154: return -0.16690154373645782;
  t265_n155: if (E.getNumReferences() >= 3238002688 /*8.0*/) goto t265_n157;
  t265_n156: return 0.11948603391647339;
  t265_n157: return 0.1140751764178276;
  t265_n158: if (E.getNumReferences() >= 3265396736 /*81.0*/) goto t265_n160;
  t265_n159: return -0.1453748643398285;
  t265_n160: return 0.09653052687644958;
  t265_n161: return 0.07052335888147354;
  t265_n162: return 0.0512433722615242;
  t265_n163: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t265_n195;
  t265_n164: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t265_n192;
  t265_n165: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t265_n181;
  t265_n166: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t265_n180;
  t265_n167: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n173;
  t265_n168: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n172;
  t265_n169: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t265_n171;
  t265_n170: return 0.04456391930580139;
  t265_n171: return 0.14676479995250702;
  t265_n172: return -0.037125542759895325;
  t265_n173: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t265_n179;
  t265_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n176;
  t265_n175: return -0.11660099774599075;
  t265_n176: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t265_n178;
  t265_n177: return 0.13377757370471954;
  t265_n178: return 0.11255265772342682;
  t265_n179: return 0.07860633730888367;
  t265_n180: return 0.016493454575538635;
  t265_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n187;
  t265_n182: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n186;
  t265_n183: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t265_n185;
  t265_n184: return 0.11140128970146179;
  t265_n185: return 0.10175486654043198;
  t265_n186: return -0.14002302289009094;
  t265_n187: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t265_n189;
  t265_n188: return -0.05833810940384865;
  t265_n189: if (E.getNumReferences() >= 3266707456 /*91.0*/) goto t265_n191;
  t265_n190: return 0.1188209280371666;
  t265_n191: return 0.04657655954360962;
  t265_n192: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t265_n194;
  t265_n193: return 0.15614017844200134;
  t265_n194: return -0.015060569159686565;
  t265_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n199;
  t265_n196: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t265_n198;
  t265_n197: return 0.10530136525630951;
  t265_n198: return 0.11089877784252167;
  t265_n199: return -0.03684954345226288;
  t265_n200: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t265_n206;
  t265_n201: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n203;
  t265_n202: return -0.019737042486667633;
  t265_n203: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n205;
  t265_n204: return 0.016320914030075073;
  t265_n205: return -0.057907834649086;
  t265_n206: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t265_n216;
  t265_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n209;
  t265_n208: return 0.006648062262684107;
  t265_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n211;
  t265_n210: return 0.03154253214597702;
  t265_n211: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t265_n213;
  t265_n212: return -0.024540802463889122;
  t265_n213: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t265_n215;
  t265_n214: return 0.09710372984409332;
  t265_n215: return 0.004924481268972158;
  t265_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n224;
  t265_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t265_n221;
  t265_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n220;
  t265_n219: return 0.047543179243803024;
  t265_n220: return 0.06132834777235985;
  t265_n221: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n223;
  t265_n222: return 0.05143539980053902;
  t265_n223: return 0.012972933240234852;
  t265_n224: return -0.026353677734732628;
  t265_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t265_n227;
  t265_n226: return -0.011894289404153824;
  t265_n227: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t265_n231;
  t265_n228: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t265_n230;
  t265_n229: return 0.051690101623535156;
  t265_n230: return 0.1032603308558464;
  t265_n231: return 0.0018094974802806973;
  t265_n232: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t265_n246;
  t265_n233: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t265_n245;
  t265_n234: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t265_n236;
  t265_n235: return -0.07042880356311798;
  t265_n236: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t265_n238;
  t265_n237: return -0.09875551611185074;
  t265_n238: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t265_n242;
  t265_n239: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t265_n241;
  t265_n240: return -0.13491088151931763;
  t265_n241: return -0.07997286319732666;
  t265_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t265_n244;
  t265_n243: return 0.010814371518790722;
  t265_n244: return -0.2477635145187378;
  t265_n245: return -0.00606003450229764;
  t265_n246: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t265_n248;
  t265_n247: return -0.024556171149015427;
  t265_n248: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t265_n252;
  t265_n249: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t265_n251;
  t265_n250: return 0.03391391411423683;
  t265_n251: return 0.0730263814330101;
  t265_n252: if (E.getNumReferences() >= 3280633856 /*277.0*/) goto t265_n254;
  t265_n253: return -0.02888600528240204;
  t265_n254: return 0.1347033828496933;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree266(const Example& E) {
  t266_n0: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t266_n210;
  t266_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t266_n209;
  t266_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t266_n84;
  t266_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t266_n83;
  t266_n4: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n32;
  t266_n5: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t266_n17;
  t266_n6: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t266_n14;
  t266_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n13;
  t266_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t266_n10;
  t266_n9: return -0.14294709265232086;
  t266_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n12;
  t266_n11: return 0.10088977962732315;
  t266_n12: return 0.013427432626485825;
  t266_n13: return 0.02961147204041481;
  t266_n14: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t266_n16;
  t266_n15: return -0.029730452224612236;
  t266_n16: return 0.11302733421325684;
  t266_n17: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n31;
  t266_n18: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t266_n22;
  t266_n19: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t266_n21;
  t266_n20: return -0.08688316494226456;
  t266_n21: return -0.1637892872095108;
  t266_n22: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n24;
  t266_n23: return -0.016927268356084824;
  t266_n24: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t266_n26;
  t266_n25: return 0.01928785815834999;
  t266_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t266_n30;
  t266_n27: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t266_n29;
  t266_n28: return 0.10991144925355911;
  t266_n29: return 0.09388848394155502;
  t266_n30: return 0.11938928812742233;
  t266_n31: return 0.0020454612094908953;
  t266_n32: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t266_n60;
  t266_n33: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t266_n57;
  t266_n34: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t266_n36;
  t266_n35: return -0.11465691775083542;
  t266_n36: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n42;
  t266_n37: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t266_n39;
  t266_n38: return 0.01716517098248005;
  t266_n39: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n41;
  t266_n40: return 0.5093629360198975;
  t266_n41: return -0.061838164925575256;
  t266_n42: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t266_n56;
  t266_n43: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n47;
  t266_n44: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t266_n46;
  t266_n45: return 0.10999688506126404;
  t266_n46: return 0.1058567464351654;
  t266_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Type))) goto t266_n55;
  t266_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t266_n50;
  t266_n49: return -0.15749487280845642;
  t266_n50: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n54;
  t266_n51: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n53;
  t266_n52: return 0.14928261935710907;
  t266_n53: return 0.09312749654054642;
  t266_n54: return 0.23075444996356964;
  t266_n55: return 0.11347155272960663;
  t266_n56: return -0.07885421812534332;
  t266_n57: if (E.getSymbolScopeDistance() >= 3245342720 /*15.0*/) goto t266_n59;
  t266_n58: return 0.007039055228233337;
  t266_n59: return -0.03522808477282524;
  t266_n60: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n78;
  t266_n61: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t266_n63;
  t266_n62: return -0.034878090023994446;
  t266_n63: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n77;
  t266_n64: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t266_n66;
  t266_n65: return 0.05575264245271683;
  t266_n66: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n76;
  t266_n67: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t266_n75;
  t266_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n72;
  t266_n69: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n71;
  t266_n70: return 0.10779924690723419;
  t266_n71: return 0.100611612200737;
  t266_n72: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t266_n74;
  t266_n73: return 0.07133070379495621;
  t266_n74: return 0.08837002515792847;
  t266_n75: return -0.11478453129529953;
  t266_n76: return 0.04260038584470749;
  t266_n77: return -0.017040370032191277;
  t266_n78: if (E.getNumReferences() >= 3310286848 /*3311.5*/) goto t266_n80;
  t266_n79: return -0.025617072358727455;
  t266_n80: if (E.getNumReferences() >= 3311058944 /*3500.0*/) goto t266_n82;
  t266_n81: return 0.12177680432796478;
  t266_n82: return 0.033024322241544724;
  t266_n83: return -0.03929354250431061;
  t266_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t266_n86;
  t266_n85: return -0.011878753080964088;
  t266_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace))) goto t266_n208;
  t266_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t266_n153;
  t266_n88: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n90;
  t266_n89: return -0.01302577555179596;
  t266_n90: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n136;
  t266_n91: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t266_n135;
  t266_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n110;
  t266_n93: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t266_n109;
  t266_n94: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n108;
  t266_n95: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t266_n99;
  t266_n96: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t266_n98;
  t266_n97: return 0.012964945286512375;
  t266_n98: return 0.07942113280296326;
  t266_n99: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t266_n103;
  t266_n100: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n102;
  t266_n101: return 0.12192396074533463;
  t266_n102: return 0.10331454128026962;
  t266_n103: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t266_n105;
  t266_n104: return 0.11020481586456299;
  t266_n105: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t266_n107;
  t266_n106: return 0.01262042298913002;
  t266_n107: return 0.08793377876281738;
  t266_n108: return 0.005661584436893463;
  t266_n109: return -0.1490388810634613;
  t266_n110: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t266_n126;
  t266_n111: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t266_n125;
  t266_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n124;
  t266_n113: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t266_n117;
  t266_n114: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n116;
  t266_n115: return 0.104563869535923;
  t266_n116: return 0.060001689940690994;
  t266_n117: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t266_n119;
  t266_n118: return 0.02975262887775898;
  t266_n119: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n121;
  t266_n120: return 0.12490660697221756;
  t266_n121: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t266_n123;
  t266_n122: return 0.12677742540836334;
  t266_n123: return 0.060475364327430725;
  t266_n124: return -0.021840736269950867;
  t266_n125: return 0.006797381676733494;
  t266_n126: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t266_n134;
  t266_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t266_n129;
  t266_n128: return 0.09077988564968109;
  t266_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n131;
  t266_n130: return -0.37304773926734924;
  t266_n131: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t266_n133;
  t266_n132: return 0.12652993202209473;
  t266_n133: return -0.10135935246944427;
  t266_n134: return -0.21244792640209198;
  t266_n135: return -0.0031839795410633087;
  t266_n136: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n144;
  t266_n137: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n139;
  t266_n138: return -0.0005539284902624786;
  t266_n139: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n141;
  t266_n140: return 0.0371597483754158;
  t266_n141: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t266_n143;
  t266_n142: return 0.1230822205543518;
  t266_n143: return 0.1046779602766037;
  t266_n144: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n152;
  t266_n145: if (E.getFilterLength() >= 3241672704 /*11.5*/) goto t266_n147;
  t266_n146: return -0.0601884201169014;
  t266_n147: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n151;
  t266_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n150;
  t266_n149: return 0.11954007297754288;
  t266_n150: return -0.10030949860811234;
  t266_n151: return -0.655197024345398;
  t266_n152: return 0.005224030464887619;
  t266_n153: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t266_n187;
  t266_n154: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t266_n176;
  t266_n155: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t266_n165;
  t266_n156: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t266_n164;
  t266_n157: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n159;
  t266_n158: return -0.49875301122665405;
  t266_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t266_n161;
  t266_n160: return 0.14243264496326447;
  t266_n161: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t266_n163;
  t266_n162: return 0.09521451592445374;
  t266_n163: return 0.08396031707525253;
  t266_n164: return -0.0022505908273160458;
  t266_n165: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t266_n167;
  t266_n166: return 0.0945003554224968;
  t266_n167: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t266_n169;
  t266_n168: return -0.04641703888773918;
  t266_n169: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t266_n175;
  t266_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t266_n172;
  t266_n171: return 0.09380719065666199;
  t266_n172: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n174;
  t266_n173: return 0.0831466093659401;
  t266_n174: return -0.31045278906822205;
  t266_n175: return 0.16744115948677063;
  t266_n176: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n178;
  t266_n177: return -0.0011936655500903726;
  t266_n178: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n186;
  t266_n179: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t266_n185;
  t266_n180: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t266_n184;
  t266_n181: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t266_n183;
  t266_n182: return 0.01591135561466217;
  t266_n183: return 0.031789518892765045;
  t266_n184: return 0.07216043025255203;
  t266_n185: return -0.05311813950538635;
  t266_n186: return 0.007313149981200695;
  t266_n187: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t266_n191;
  t266_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t266_n190;
  t266_n189: return -0.57929527759552;
  t266_n190: return -0.12149791419506073;
  t266_n191: if (E.getNumReferences() >= 3333794048 /*23252.5*/) goto t266_n193;
  t266_n192: return -0.004645606502890587;
  t266_n193: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t266_n199;
  t266_n194: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t266_n196;
  t266_n195: return 0.09142494946718216;
  t266_n196: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n198;
  t266_n197: return -0.04152899980545044;
  t266_n198: return 0.1133054792881012;
  t266_n199: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n201;
  t266_n200: return -0.004853356163948774;
  t266_n201: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t266_n205;
  t266_n202: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t266_n204;
  t266_n203: return 0.08177496492862701;
  t266_n204: return -0.05945603922009468;
  t266_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t266_n207;
  t266_n206: return 0.08852601051330566;
  t266_n207: return 0.03886756673455238;
  t266_n208: return 0.06297758966684341;
  t266_n209: return 0.0008832048624753952;
  t266_n210: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t266_n212;
  t266_n211: return -0.0005072267958894372;
  t266_n212: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t266_n216;
  t266_n213: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t266_n215;
  t266_n214: return -0.10533810406923294;
  t266_n215: return 0.003187097841873765;
  t266_n216: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t266_n248;
  t266_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t266_n221;
  t266_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t266_n220;
  t266_n219: return -0.015085973776876926;
  t266_n220: return 0.02133808098733425;
  t266_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t266_n235;
  t266_n222: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n228;
  t266_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t266_n227;
  t266_n224: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t266_n226;
  t266_n225: return -0.018900888040661812;
  t266_n226: return 0.03615214303135872;
  t266_n227: return -0.0067928205244243145;
  t266_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t266_n230;
  t266_n229: return 0.002777441870421171;
  t266_n230: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t266_n232;
  t266_n231: return 0.00033731688745319843;
  t266_n232: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t266_n234;
  t266_n233: return 0.02908875234425068;
  t266_n234: return -0.0044554173946380615;
  t266_n235: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t266_n247;
  t266_n236: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t266_n242;
  t266_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t266_n241;
  t266_n238: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t266_n240;
  t266_n239: return -0.3054511547088623;
  t266_n240: return 0.03397975116968155;
  t266_n241: return 0.029757961630821228;
  t266_n242: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t266_n244;
  t266_n243: return -0.001966611947864294;
  t266_n244: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t266_n246;
  t266_n245: return 0.03163072094321251;
  t266_n246: return 0.05684802681207657;
  t266_n247: return 0.020146099850535393;
  t266_n248: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t266_n254;
  t266_n249: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t266_n253;
  t266_n250: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t266_n252;
  t266_n251: return 0.0755566880106926;
  t266_n252: return 0.0409579761326313;
  t266_n253: return 0.044757578521966934;
  t266_n254: return -0.007000420242547989;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree267(const Example& E) {
  t267_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t267_n24;
  t267_n1: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope))) goto t267_n3;
  t267_n2: return -0.002730569802224636;
  t267_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t267_n13;
  t267_n4: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n12;
  t267_n5: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t267_n9;
  t267_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t267_n8;
  t267_n7: return 0.006117536686360836;
  t267_n8: return -0.003720036707818508;
  t267_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t267_n11;
  t267_n10: return 0.024979455396533012;
  t267_n11: return 0.0031269621104002;
  t267_n12: return -0.014078921638429165;
  t267_n13: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n23;
  t267_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t267_n16;
  t267_n15: return 0.011423279531300068;
  t267_n16: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n22;
  t267_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t267_n19;
  t267_n18: return 0.026948057115077972;
  t267_n19: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n21;
  t267_n20: return 0.09575028717517853;
  t267_n21: return -0.012823281809687614;
  t267_n22: return 0.04519057273864746;
  t267_n23: return -0.05055035278201103;
  t267_n24: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t267_n124;
  t267_n25: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t267_n123;
  t267_n26: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t267_n70;
  t267_n27: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown))) goto t267_n49;
  t267_n28: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t267_n30;
  t267_n29: return -0.00751735782250762;
  t267_n30: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t267_n48;
  t267_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n45;
  t267_n32: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t267_n36;
  t267_n33: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n35;
  t267_n34: return -0.18042980134487152;
  t267_n35: return 0.09404150396585464;
  t267_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t267_n38;
  t267_n37: return 0.10694333910942078;
  t267_n38: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t267_n40;
  t267_n39: return -0.030170345678925514;
  t267_n40: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t267_n42;
  t267_n41: return 0.09568189084529877;
  t267_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n44;
  t267_n43: return -1.5909855365753174;
  t267_n44: return 0.11153572052717209;
  t267_n45: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t267_n47;
  t267_n46: return 0.007441780064254999;
  t267_n47: return 0.10804763436317444;
  t267_n48: return 0.0026016782503575087;
  t267_n49: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t267_n55;
  t267_n50: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n52;
  t267_n51: return -0.09421028196811676;
  t267_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n54;
  t267_n53: return -0.03473619744181633;
  t267_n54: return 0.0020302394405007362;
  t267_n55: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n69;
  t267_n56: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t267_n62;
  t267_n57: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n61;
  t267_n58: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t267_n60;
  t267_n59: return -0.739951491355896;
  t267_n60: return -0.0025486210361123085;
  t267_n61: return 0.022778989747166634;
  t267_n62: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t267_n64;
  t267_n63: return 0.017482386901974678;
  t267_n64: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t267_n66;
  t267_n65: return -0.10475537180900574;
  t267_n66: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t267_n68;
  t267_n67: return 0.07093636691570282;
  t267_n68: return -0.12669728696346283;
  t267_n69: return 0.004511814098805189;
  t267_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t267_n72;
  t267_n71: return -0.06121326982975006;
  t267_n72: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t267_n80;
  t267_n73: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n75;
  t267_n74: return -0.00648330757394433;
  t267_n75: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t267_n77;
  t267_n76: return 0.0012188851833343506;
  t267_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t267_n79;
  t267_n78: return -0.07786449790000916;
  t267_n79: return -0.005256766453385353;
  t267_n80: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t267_n110;
  t267_n81: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t267_n83;
  t267_n82: return -0.015454304404556751;
  t267_n83: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n95;
  t267_n84: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n94;
  t267_n85: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t267_n93;
  t267_n86: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t267_n92;
  t267_n87: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t267_n89;
  t267_n88: return -0.10166620463132858;
  t267_n89: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t267_n91;
  t267_n90: return 0.14712435007095337;
  t267_n91: return 0.08367172628641129;
  t267_n92: return -0.09763524681329727;
  t267_n93: return 0.12748391926288605;
  t267_n94: return 0.04270947352051735;
  t267_n95: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n97;
  t267_n96: return 0.0139304893091321;
  t267_n97: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t267_n105;
  t267_n98: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n100;
  t267_n99: return 0.01747273840010166;
  t267_n100: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t267_n104;
  t267_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_DotMemberAccess))) goto t267_n103;
  t267_n102: return 0.01913519576191902;
  t267_n103: return 0.11421047151088715;
  t267_n104: return 0.00743847107514739;
  t267_n105: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n109;
  t267_n106: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t267_n108;
  t267_n107: return 0.06141616031527519;
  t267_n108: return 0.137796550989151;
  t267_n109: return 0.07819042354822159;
  t267_n110: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::GlobalScope))) goto t267_n112;
  t267_n111: return 0.001149671385064721;
  t267_n112: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n114;
  t267_n113: return -0.008888984099030495;
  t267_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n122;
  t267_n115: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n117;
  t267_n116: return -0.005340272095054388;
  t267_n117: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t267_n119;
  t267_n118: return 0.06973452121019363;
  t267_n119: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t267_n121;
  t267_n120: return 0.1168174296617508;
  t267_n121: return 0.12623755633831024;
  t267_n122: return 0.012326105497777462;
  t267_n123: return 0.0059222010895609856;
  t267_n124: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t267_n192;
  t267_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t267_n127;
  t267_n126: return 0.0014059861423447728;
  t267_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t267_n191;
  t267_n128: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t267_n144;
  t267_n129: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t267_n143;
  t267_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n132;
  t267_n131: return 0.015766004100441933;
  t267_n132: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n142;
  t267_n133: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t267_n139;
  t267_n134: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n138;
  t267_n135: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t267_n137;
  t267_n136: return 0.05822988599538803;
  t267_n137: return 0.008067110553383827;
  t267_n138: return -0.0133872851729393;
  t267_n139: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n141;
  t267_n140: return 0.10918322205543518;
  t267_n141: return 0.018655380234122276;
  t267_n142: return -0.009402510710060596;
  t267_n143: return 0.007118739653378725;
  t267_n144: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t267_n182;
  t267_n145: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t267_n181;
  t267_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n154;
  t267_n147: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t267_n153;
  t267_n148: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n150;
  t267_n149: return 0.006014605052769184;
  t267_n150: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t267_n152;
  t267_n151: return 0.025602729991078377;
  t267_n152: return -0.10169610381126404;
  t267_n153: return -0.2112884372472763;
  t267_n154: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t267_n172;
  t267_n155: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t267_n171;
  t267_n156: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n160;
  t267_n157: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t267_n159;
  t267_n158: return 0.13524498045444489;
  t267_n159: return 0.0389166995882988;
  t267_n160: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n162;
  t267_n161: return -0.010335388593375683;
  t267_n162: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t267_n170;
  t267_n163: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t267_n169;
  t267_n164: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t267_n168;
  t267_n165: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n167;
  t267_n166: return 0.1227855309844017;
  t267_n167: return 0.1252421736717224;
  t267_n168: return 0.07460103929042816;
  t267_n169: return 0.04826226085424423;
  t267_n170: return 0.00745236175134778;
  t267_n171: return 0.11819060146808624;
  t267_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t267_n180;
  t267_n173: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t267_n179;
  t267_n174: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t267_n176;
  t267_n175: return -0.022660044953227043;
  t267_n176: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t267_n178;
  t267_n177: return -0.19346536695957184;
  t267_n178: return -0.2893243730068207;
  t267_n179: return -0.02203275077044964;
  t267_n180: return -0.005770217161625624;
  t267_n181: return -0.03246968984603882;
  t267_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n188;
  t267_n183: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n185;
  t267_n184: return 0.0516987070441246;
  t267_n185: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n187;
  t267_n186: return -0.040929120033979416;
  t267_n187: return 0.04275303706526756;
  t267_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n190;
  t267_n189: return 0.04152324050664902;
  t267_n190: return 0.014024495147168636;
  t267_n191: return 0.02364920638501644;
  t267_n192: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t267_n246;
  t267_n193: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t267_n243;
  t267_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t267_n214;
  t267_n195: if (E.getNumReferences() >= 3269918720 /*115.5*/) goto t267_n213;
  t267_n196: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t267_n210;
  t267_n197: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t267_n203;
  t267_n198: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t267_n200;
  t267_n199: return -0.01013268157839775;
  t267_n200: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t267_n202;
  t267_n201: return -0.08562622964382172;
  t267_n202: return -0.010732363909482956;
  t267_n203: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n209;
  t267_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n208;
  t267_n205: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t267_n207;
  t267_n206: return -0.05327858775854111;
  t267_n207: return -0.19704501330852509;
  t267_n208: return 0.011282887309789658;
  t267_n209: return 0.028765013441443443;
  t267_n210: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t267_n212;
  t267_n211: return 0.03440432250499725;
  t267_n212: return 0.11004232615232468;
  t267_n213: return -0.02932683378458023;
  t267_n214: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t267_n216;
  t267_n215: return 0.04292680695652962;
  t267_n216: if (E.getFileProximityDistance() >= 3252420608 /*27.5*/) goto t267_n242;
  t267_n217: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t267_n225;
  t267_n218: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t267_n224;
  t267_n219: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t267_n221;
  t267_n220: return -0.10767380148172379;
  t267_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t267_n223;
  t267_n222: return 0.1373744159936905;
  t267_n223: return -0.10859548300504684;
  t267_n224: return 0.15752655267715454;
  t267_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t267_n241;
  t267_n226: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t267_n236;
  t267_n227: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t267_n229;
  t267_n228: return -0.2525063753128052;
  t267_n229: if (E.getNumReferences() >= 3294322688 /*877.5*/) goto t267_n235;
  t267_n230: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t267_n232;
  t267_n231: return 0.05846020206809044;
  t267_n232: if (E.getNumReferences() >= 3276865536 /*209.0*/) goto t267_n234;
  t267_n233: return 0.05861712992191315;
  t267_n234: return 0.09737909585237503;
  t267_n235: return 0.19841724634170532;
  t267_n236: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t267_n238;
  t267_n237: return 0.09201841801404953;
  t267_n238: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t267_n240;
  t267_n239: return -0.6524826288223267;
  t267_n240: return 0.08837790787220001;
  t267_n241: return 0.02202451415359974;
  t267_n242: return 0.11856492608785629;
  t267_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t267_n245;
  t267_n244: return 0.008546704426407814;
  t267_n245: return -0.01784767396748066;
  t267_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t267_n248;
  t267_n247: return -0.013879799284040928;
  t267_n248: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t267_n250;
  t267_n249: return 0.03150663524866104;
  t267_n250: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t267_n252;
  t267_n251: return -0.013382741250097752;
  t267_n252: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t267_n254;
  t267_n253: return 0.22632654011249542;
  t267_n254: return 0.16827067732810974;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree268(const Example& E) {
  t268_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t268_n2;
  t268_n1: return -0.00032464246032759547;
  t268_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t268_n70;
  t268_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t268_n41;
  t268_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t268_n6;
  t268_n5: return 0.0031567257829010487;
  t268_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t268_n28;
  t268_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t268_n17;
  t268_n8: if (E.getNumReferences() >= 3284926464 /*408.0*/) goto t268_n10;
  t268_n9: return -0.6578812003135681;
  t268_n10: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n12;
  t268_n11: return -0.03878534585237503;
  t268_n12: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t268_n16;
  t268_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t268_n15;
  t268_n14: return 0.07608432322740555;
  t268_n15: return -0.027123969048261642;
  t268_n16: return 0.09240173548460007;
  t268_n17: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t268_n25;
  t268_n18: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t268_n20;
  t268_n19: return 0.019269365817308426;
  t268_n20: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t268_n22;
  t268_n21: return 0.11535605043172836;
  t268_n22: if (E.getNumReferences() >= 3295059968 /*922.5*/) goto t268_n24;
  t268_n23: return -0.22041882574558258;
  t268_n24: return 0.09410280734300613;
  t268_n25: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t268_n27;
  t268_n26: return 0.12250266224145889;
  t268_n27: return 0.28383252024650574;
  t268_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t268_n32;
  t268_n29: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t268_n31;
  t268_n30: return 0.014463038183748722;
  t268_n31: return -0.14452964067459106;
  t268_n32: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t268_n38;
  t268_n33: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t268_n35;
  t268_n34: return -0.23244693875312805;
  t268_n35: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t268_n37;
  t268_n36: return 0.011674950830638409;
  t268_n37: return 0.07604878395795822;
  t268_n38: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t268_n40;
  t268_n39: return 0.09336821734905243;
  t268_n40: return 0.0707482174038887;
  t268_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t268_n69;
  t268_n42: if (E.getNumReferences() >= 3297431552 /*1110.5*/) goto t268_n68;
  t268_n43: if (E.getNumReferences() >= 3297333248 /*1098.5*/) goto t268_n67;
  t268_n44: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n60;
  t268_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t268_n47;
  t268_n46: return 0.01179643627256155;
  t268_n47: if (E.getNumReferences() >= 3285057536 /*412.0*/) goto t268_n49;
  t268_n48: return -0.19174805283546448;
  t268_n49: if (E.getNumReferences() >= 3286433792 /*454.0*/) goto t268_n53;
  t268_n50: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t268_n52;
  t268_n51: return 0.11552780866622925;
  t268_n52: return 0.08842921257019043;
  t268_n53: if (E.getNumReferences() >= 3292299264 /*754.0*/) goto t268_n55;
  t268_n54: return 0.03138609975576401;
  t268_n55: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t268_n59;
  t268_n56: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t268_n58;
  t268_n57: return 0.10328803956508636;
  t268_n58: return 0.12684151530265808;
  t268_n59: return -0.008324316702783108;
  t268_n60: if (E.getNumReferences() >= 3291217920 /*688.0*/) goto t268_n64;
  t268_n61: if (E.getNumReferences() >= 3285794816 /*434.5*/) goto t268_n63;
  t268_n62: return 0.09802622348070145;
  t268_n63: return -0.04859844595193863;
  t268_n64: if (E.getNumReferences() >= 3292962816 /*794.5*/) goto t268_n66;
  t268_n65: return 0.10428232699632645;
  t268_n66: return 0.056869298219680786;
  t268_n67: return 0.10201174765825272;
  t268_n68: return -0.035544198006391525;
  t268_n69: return 0.09714686125516891;
  t268_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t268_n124;
  t268_n71: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t268_n75;
  t268_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n74;
  t268_n73: return -0.06509137898683548;
  t268_n74: return -0.011312219314277172;
  t268_n75: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t268_n77;
  t268_n76: return 0.0018927183700725436;
  t268_n77: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t268_n87;
  t268_n78: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t268_n80;
  t268_n79: return 0.13695821166038513;
  t268_n80: if (E.getNumReferences() >= 3287154688 /*476.0*/) goto t268_n82;
  t268_n81: return 0.13538393378257751;
  t268_n82: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t268_n84;
  t268_n83: return 0.1187051311135292;
  t268_n84: if (E.getNumReferences() >= 3304493056 /*1972.5*/) goto t268_n86;
  t268_n85: return -0.143084317445755;
  t268_n86: return 0.10483860969543457;
  t268_n87: if (E.getNumReferences() >= 3325700096 /*11914.0*/) goto t268_n105;
  t268_n88: if (E.getNumReferences() >= 3315857408 /*5247.0*/) goto t268_n104;
  t268_n89: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t268_n91;
  t268_n90: return 0.005088873207569122;
  t268_n91: if (E.getNumReferences() >= 3307923456 /*2734.5*/) goto t268_n95;
  t268_n92: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n94;
  t268_n93: return 0.030952295288443565;
  t268_n94: return 0.08931917697191238;
  t268_n95: if (E.getNumReferences() >= 3308326912 /*2833.0*/) goto t268_n97;
  t268_n96: return 0.10859324038028717;
  t268_n97: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t268_n103;
  t268_n98: if (E.getNumReferences() >= 3313381376 /*4067.0*/) goto t268_n102;
  t268_n99: if (E.getNumReferences() >= 3310929920 /*3468.5*/) goto t268_n101;
  t268_n100: return 0.10300324857234955;
  t268_n101: return 0.11049765348434448;
  t268_n102: return 0.08218292146921158;
  t268_n103: return 0.05913146957755089;
  t268_n104: return -0.03755826875567436;
  t268_n105: if (E.getNumReferences() >= 3327105024 /*13286.0*/) goto t268_n121;
  t268_n106: if (E.getNumReferences() >= 3327053312 /*13235.5*/) goto t268_n116;
  t268_n107: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t268_n111;
  t268_n108: if (E.getNumReferences() >= 3325825536 /*12036.5*/) goto t268_n110;
  t268_n109: return 0.31848445534706116;
  t268_n110: return 0.010723716579377651;
  t268_n111: if (E.getNumReferences() >= 3326541312 /*12735.5*/) goto t268_n113;
  t268_n112: return -0.08969324082136154;
  t268_n113: if (E.getNumReferences() >= 3326876672 /*13063.0*/) goto t268_n115;
  t268_n114: return 0.09309361129999161;
  t268_n115: return 0.047620609402656555;
  t268_n116: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t268_n118;
  t268_n117: return 0.37172871828079224;
  t268_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t268_n120;
  t268_n119: return 0.11438488215208054;
  t268_n120: return 0.009297979064285755;
  t268_n121: if (E.getFileProximityDistance() >= 3251896320 /*26.5*/) goto t268_n123;
  t268_n122: return 0.018634820356965065;
  t268_n123: return 0.10009732842445374;
  t268_n124: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t268_n128;
  t268_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n127;
  t268_n126: return -0.20185315608978271;
  t268_n127: return 0.10417396575212479;
  t268_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t268_n130;
  t268_n129: return 0.005523754749447107;
  t268_n130: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t268_n254;
  t268_n131: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t268_n145;
  t268_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t268_n136;
  t268_n133: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n135;
  t268_n134: return -0.29011911153793335;
  t268_n135: return -0.10366718471050262;
  t268_n136: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t268_n144;
  t268_n137: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t268_n139;
  t268_n138: return 0.12702856957912445;
  t268_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n143;
  t268_n140: if (E.getNumReferences() >= 3285663744 /*430.5*/) goto t268_n142;
  t268_n141: return 0.08045675605535507;
  t268_n142: return -0.6512492299079895;
  t268_n143: return 0.07674819231033325;
  t268_n144: return -0.4537450671195984;
  t268_n145: if (E.getNumReferences() >= 3286712320 /*462.5*/) goto t268_n147;
  t268_n146: return 0.10219712555408478;
  t268_n147: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t268_n237;
  t268_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t268_n208;
  t268_n149: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t268_n207;
  t268_n150: if (E.getNumReferences() >= 3299819520 /*1402.0*/) goto t268_n204;
  t268_n151: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t268_n175;
  t268_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t268_n166;
  t268_n153: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t268_n161;
  t268_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t268_n156;
  t268_n155: return -1.0112189054489136;
  t268_n156: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n158;
  t268_n157: return 0.04783685877919197;
  t268_n158: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t268_n160;
  t268_n159: return -0.7479925155639648;
  t268_n160: return -0.12785771489143372;
  t268_n161: if (E.getNumReferences() >= 3288473600 /*520.5*/) goto t268_n163;
  t268_n162: return 0.10037891566753387;
  t268_n163: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t268_n165;
  t268_n164: return -0.09889526665210724;
  t268_n165: return 0.08101922273635864;
  t268_n166: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n168;
  t268_n167: return -0.1054157093167305;
  t268_n168: if (E.getNumReferences() >= 3291308032 /*693.5*/) goto t268_n170;
  t268_n169: return -0.31096163392066956;
  t268_n170: if (E.getNumReferences() >= 3294150656 /*867.0*/) goto t268_n172;
  t268_n171: return 0.11556235700845718;
  t268_n172: if (E.getNumReferences() >= 3297222656 /*1085.0*/) goto t268_n174;
  t268_n173: return -0.0024039228446781635;
  t268_n174: return 0.13142022490501404;
  t268_n175: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t268_n191;
  t268_n176: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t268_n188;
  t268_n177: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t268_n179;
  t268_n178: return 0.09385652840137482;
  t268_n179: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t268_n187;
  t268_n180: if (E.getNumReferences() >= 3290759168 /*660.0*/) goto t268_n184;
  t268_n181: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t268_n183;
  t268_n182: return -1.4555426836013794;
  t268_n183: return -0.5778682231903076;
  t268_n184: if (E.getNumReferences() >= 3292045312 /*738.5*/) goto t268_n186;
  t268_n185: return 0.11436174064874649;
  t268_n186: return -0.09089936316013336;
  t268_n187: return 0.06500755250453949;
  t268_n188: if (E.getNumReferences() >= 3289456640 /*580.5*/) goto t268_n190;
  t268_n189: return 0.0861348956823349;
  t268_n190: return 0.04384274780750275;
  t268_n191: if (E.getNumReferences() >= 3296256000 /*995.5*/) goto t268_n195;
  t268_n192: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t268_n194;
  t268_n193: return 0.14407701790332794;
  t268_n194: return -0.06092308461666107;
  t268_n195: if (E.getNumReferences() >= 3299012608 /*1303.5*/) goto t268_n203;
  t268_n196: if (E.getNumReferences() >= 3298086912 /*1190.5*/) goto t268_n200;
  t268_n197: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t268_n199;
  t268_n198: return -0.08434034883975983;
  t268_n199: return 0.07405632734298706;
  t268_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t268_n202;
  t268_n201: return 0.060237180441617966;
  t268_n202: return 0.11272060126066208;
  t268_n203: return -0.8447687029838562;
  t268_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t268_n206;
  t268_n205: return -0.18846282362937927;
  t268_n206: return 0.11502334475517273;
  t268_n207: return 0.027011973783373833;
  t268_n208: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t268_n212;
  t268_n209: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t268_n211;
  t268_n210: return -0.28904688358306885;
  t268_n211: return 0.12228931486606598;
  t268_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t268_n218;
  t268_n213: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t268_n217;
  t268_n214: if (E.getNumReferences() >= 3293315072 /*816.0*/) goto t268_n216;
  t268_n215: return 0.07909034192562103;
  t268_n216: return 0.00168310955632478;
  t268_n217: return 0.009982336312532425;
  t268_n218: if (E.getNumReferences() >= 3365715136 /*320998.0*/) goto t268_n236;
  t268_n219: if (E.getNumReferences() >= 3319939072 /*7240.0*/) goto t268_n235;
  t268_n220: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t268_n224;
  t268_n221: if (E.getNumReferences() >= 3316105216 /*5368.0*/) goto t268_n223;
  t268_n222: return -0.055297333747148514;
  t268_n223: return -0.36092275381088257;
  t268_n224: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t268_n232;
  t268_n225: if (E.getNumReferences() >= 3309293568 /*3069.0*/) goto t268_n227;
  t268_n226: return -0.08625443279743195;
  t268_n227: if (E.getNumReferences() >= 3311069184 /*3502.5*/) goto t268_n229;
  t268_n228: return 0.1162247285246849;
  t268_n229: if (E.getNumReferences() >= 3315866624 /*5251.5*/) goto t268_n231;
  t268_n230: return -0.10190063714981079;
  t268_n231: return 0.07531154155731201;
  t268_n232: if (E.getNumReferences() >= 3290120192 /*621.0*/) goto t268_n234;
  t268_n233: return 0.07162890583276749;
  t268_n234: return 0.0017244991613551974;
  t268_n235: return 0.00568772666156292;
  t268_n236: return 0.09786694496870041;
  t268_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t268_n249;
  t268_n238: if (E.getNumReferences() >= 3297067008 /*1066.0*/) goto t268_n246;
  t268_n239: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t268_n243;
  t268_n240: if (E.getNumReferences() >= 3294601216 /*894.5*/) goto t268_n242;
  t268_n241: return -0.24455250799655914;
  t268_n242: return -3.696253538131714;
  t268_n243: if (E.getNumReferences() >= 3296575488 /*1015.0*/) goto t268_n245;
  t268_n244: return -0.07872742414474487;
  t268_n245: return -1.4604294300079346;
  t268_n246: if (E.getNumReferences() >= 3297263616 /*1090.0*/) goto t268_n248;
  t268_n247: return 0.09459394961595535;
  t268_n248: return 0.0019574682228267193;
  t268_n249: if (E.getNumReferences() >= 3289088000 /*558.0*/) goto t268_n253;
  t268_n250: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t268_n252;
  t268_n251: return 0.0973275750875473;
  t268_n252: return 0.1468123346567154;
  t268_n253: return 0.022298011928796768;
  t268_n254: return 0.10968631505966187;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree269(const Example& E) {
  t269_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t269_n2;
  t269_n1: return -0.00024920282885432243;
  t269_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t269_n20;
  t269_n3: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n7;
  t269_n4: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t269_n6;
  t269_n5: return 0.10481611639261246;
  t269_n6: return 0.01041041873395443;
  t269_n7: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t269_n9;
  t269_n8: return -0.0057387156412005424;
  t269_n9: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t269_n19;
  t269_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t269_n18;
  t269_n11: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t269_n13;
  t269_n12: return -0.202397882938385;
  t269_n13: if (E.getNumReferences() >= 3338025472 /*31517.0*/) goto t269_n17;
  t269_n14: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n16;
  t269_n15: return 0.14676102995872498;
  t269_n16: return -0.04379652440547943;
  t269_n17: return -0.06081049516797066;
  t269_n18: return 0.037269238382577896;
  t269_n19: return 0.008097292855381966;
  t269_n20: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t269_n32;
  t269_n21: if (E.getNumReferences() >= 3376956888 /*820317.5*/) goto t269_n23;
  t269_n22: return -0.032231781631708145;
  t269_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t269_n25;
  t269_n24: return 0.08527535945177078;
  t269_n25: if (E.getNumReferences() >= 3382768696 /*1318535.0*/) goto t269_n31;
  t269_n26: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t269_n30;
  t269_n27: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t269_n29;
  t269_n28: return 0.0669204592704773;
  t269_n29: return 0.02943088486790657;
  t269_n30: return 0.08245760947465897;
  t269_n31: return 0.01469360664486885;
  t269_n32: if (E.getNumReferences() >= 3322934784 /*9213.5*/) goto t269_n180;
  t269_n33: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t269_n159;
  t269_n34: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t269_n120;
  t269_n35: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t269_n37;
  t269_n36: return 0.02016156166791916;
  t269_n37: if (E.getNumReferences() >= 3320185856 /*7360.5*/) goto t269_n45;
  t269_n38: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t269_n40;
  t269_n39: return 0.11493047326803207;
  t269_n40: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n42;
  t269_n41: return -0.25572407245635986;
  t269_n42: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n44;
  t269_n43: return 0.11299459636211395;
  t269_n44: return -0.10653692483901978;
  t269_n45: if (E.getNumReferences() >= 3322624512 /*8910.5*/) goto t269_n99;
  t269_n46: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n48;
  t269_n47: return -0.08077273517847061;
  t269_n48: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t269_n74;
  t269_n49: if (E.getNumReferences() >= 3321606144 /*8054.0*/) goto t269_n51;
  t269_n50: return -0.00395452044904232;
  t269_n51: if (E.getNumReferences() >= 3321819136 /*8158.0*/) goto t269_n63;
  t269_n52: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n58;
  t269_n53: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t269_n55;
  t269_n54: return 0.03612349554896355;
  t269_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n57;
  t269_n56: return -0.525761067867279;
  t269_n57: return 0.11624304950237274;
  t269_n58: if (E.getNumReferences() >= 3321802752 /*8150.0*/) goto t269_n60;
  t269_n59: return 0.10944489389657974;
  t269_n60: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t269_n62;
  t269_n61: return 0.08546657860279083;
  t269_n62: return 0.12477309256792068;
  t269_n63: if (E.getNumReferences() >= 3322180096 /*8476.5*/) goto t269_n73;
  t269_n64: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n66;
  t269_n65: return -0.16081589460372925;
  t269_n66: if (E.getNumReferences() >= 3322118656 /*8416.5*/) goto t269_n70;
  t269_n67: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t269_n69;
  t269_n68: return 0.07359102368354797;
  t269_n69: return 0.1104322150349617;
  t269_n70: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n72;
  t269_n71: return -0.4267744719982147;
  t269_n72: return 0.1087404116988182;
  t269_n73: return -0.12682819366455078;
  t269_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t269_n86;
  t269_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n77;
  t269_n76: return -0.04390530288219452;
  t269_n77: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t269_n79;
  t269_n78: return 0.044691264629364014;
  t269_n79: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n85;
  t269_n80: if (E.getNumReferences() >= 3321240576 /*7875.5*/) goto t269_n84;
  t269_n81: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t269_n83;
  t269_n82: return 0.12561248242855072;
  t269_n83: return -0.03623289242386818;
  t269_n84: return 0.11312159895896912;
  t269_n85: return 0.04247593507170677;
  t269_n86: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t269_n98;
  t269_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t269_n95;
  t269_n88: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t269_n90;
  t269_n89: return -0.10210646688938141;
  t269_n90: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t269_n92;
  t269_n91: return 0.08063752204179764;
  t269_n92: if (E.getNumReferences() >= 3321615360 /*8058.5*/) goto t269_n94;
  t269_n93: return 0.10834277421236038;
  t269_n94: return 0.05417369678616524;
  t269_n95: if (E.getNumReferences() >= 3321964032 /*8265.5*/) goto t269_n97;
  t269_n96: return 0.06986264884471893;
  t269_n97: return -0.14314283430576324;
  t269_n98: return 0.09467247873544693;
  t269_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t269_n119;
  t269_n100: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n118;
  t269_n101: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t269_n115;
  t269_n102: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t269_n104;
  t269_n103: return -0.3125990331172943;
  t269_n104: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n106;
  t269_n105: return 0.10873671621084213;
  t269_n106: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n110;
  t269_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t269_n109;
  t269_n108: return -0.10377661138772964;
  t269_n109: return 0.10464361310005188;
  t269_n110: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t269_n114;
  t269_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n113;
  t269_n112: return -0.23176667094230652;
  t269_n113: return 0.10742440819740295;
  t269_n114: return 0.15072087943553925;
  t269_n115: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t269_n117;
  t269_n116: return -0.00396140618249774;
  t269_n117: return 0.11009763181209564;
  t269_n118: return -0.35631972551345825;
  t269_n119: return 0.09747283160686493;
  t269_n120: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t269_n154;
  t269_n121: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t269_n145;
  t269_n122: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t269_n136;
  t269_n123: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n131;
  t269_n124: if (E.getNumReferences() >= 3322376704 /*8668.5*/) goto t269_n126;
  t269_n125: return -0.1053377240896225;
  t269_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t269_n128;
  t269_n127: return -0.36983662843704224;
  t269_n128: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t269_n130;
  t269_n129: return 0.058038871735334396;
  t269_n130: return 0.10688057541847229;
  t269_n131: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n133;
  t269_n132: return 0.038481418043375015;
  t269_n133: if (E.getNumReferences() >= 3321910784 /*8213.5*/) goto t269_n135;
  t269_n134: return -0.015877947211265564;
  t269_n135: return 0.10999692231416702;
  t269_n136: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t269_n144;
  t269_n137: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t269_n141;
  t269_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t269_n140;
  t269_n139: return -0.4432945251464844;
  t269_n140: return 0.07914714515209198;
  t269_n141: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t269_n143;
  t269_n142: return 0.0949820801615715;
  t269_n143: return 0.11157681047916412;
  t269_n144: return 0.01961546018719673;
  t269_n145: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n153;
  t269_n146: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t269_n152;
  t269_n147: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t269_n149;
  t269_n148: return 0.09566408395767212;
  t269_n149: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t269_n151;
  t269_n150: return 0.10343826562166214;
  t269_n151: return 0.10265152156352997;
  t269_n152: return 0.005065077915787697;
  t269_n153: return -0.02814542129635811;
  t269_n154: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel))) goto t269_n158;
  t269_n155: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t269_n157;
  t269_n156: return -0.026470046490430832;
  t269_n157: return 0.10772862285375595;
  t269_n158: return 0.12811419367790222;
  t269_n159: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t269_n167;
  t269_n160: if (E.getNumReferences() >= 3320516608 /*7522.0*/) goto t269_n166;
  t269_n161: if (E.getNumReferences() >= 3320203264 /*7369.0*/) goto t269_n163;
  t269_n162: return -0.17477181553840637;
  t269_n163: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t269_n165;
  t269_n164: return 0.11135481297969818;
  t269_n165: return 0.1415833979845047;
  t269_n166: return -0.06036657467484474;
  t269_n167: if (E.getNumReferences() >= 3322671104 /*8956.0*/) goto t269_n169;
  t269_n168: return 0.10980775952339172;
  t269_n169: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t269_n171;
  t269_n170: return -0.15356415510177612;
  t269_n171: if (E.getNumReferences() >= 3322782208 /*9064.5*/) goto t269_n173;
  t269_n172: return 0.0700712725520134;
  t269_n173: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t269_n179;
  t269_n174: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t269_n178;
  t269_n175: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t269_n177;
  t269_n176: return -0.1036488264799118;
  t269_n177: return 0.09195108711719513;
  t269_n178: return 0.10711608827114105;
  t269_n179: return -0.10181281715631485;
  t269_n180: if (E.getNumReferences() >= 3331449088 /*18672.5*/) goto t269_n182;
  t269_n181: return -0.00810197088867426;
  t269_n182: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t269_n184;
  t269_n183: return 0.00878005288541317;
  t269_n184: if (E.getNumReferences() >= 3331720960 /*19203.5*/) goto t269_n192;
  t269_n185: if (E.getNumReferences() >= 3331634688 /*19035.0*/) goto t269_n191;
  t269_n186: if (E.getNumReferences() >= 3331489536 /*18751.5*/) goto t269_n190;
  t269_n187: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n189;
  t269_n188: return 0.11074569076299667;
  t269_n189: return -0.060026995837688446;
  t269_n190: return -0.0044226557947695255;
  t269_n191: return 0.13109977543354034;
  t269_n192: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t269_n196;
  t269_n193: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t269_n195;
  t269_n194: return -0.008088726550340652;
  t269_n195: return 0.13435347378253937;
  t269_n196: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t269_n198;
  t269_n197: return 0.0372607596218586;
  t269_n198: if (E.getNumReferences() >= 3333877760 /*23416.0*/) goto t269_n214;
  t269_n199: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t269_n207;
  t269_n200: if (E.getNumReferences() >= 3332307456 /*20349.0*/) goto t269_n206;
  t269_n201: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t269_n205;
  t269_n202: if (E.getNumReferences() >= 3332209408 /*20157.5*/) goto t269_n204;
  t269_n203: return 0.06293146312236786;
  t269_n204: return 0.11953003704547882;
  t269_n205: return -0.05634760484099388;
  t269_n206: return -0.1885685920715332;
  t269_n207: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t269_n213;
  t269_n208: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t269_n212;
  t269_n209: if (E.getNumReferences() >= 3333234688 /*22160.0*/) goto t269_n211;
  t269_n210: return 0.08840467035770416;
  t269_n211: return 0.10878154635429382;
  t269_n212: return 0.013067732565104961;
  t269_n213: return 0.10403764247894287;
  t269_n214: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t269_n248;
  t269_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t269_n239;
  t269_n216: if (E.getNumReferences() >= 3372373568 /*533860.0*/) goto t269_n238;
  t269_n217: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t269_n231;
  t269_n218: if (E.getNumReferences() >= 3367337376 /*371693.0*/) goto t269_n226;
  t269_n219: if (E.getNumReferences() >= 3364664960 /*288180.0*/) goto t269_n221;
  t269_n220: return -0.010720081627368927;
  t269_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t269_n223;
  t269_n222: return -0.2019246518611908;
  t269_n223: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t269_n225;
  t269_n224: return -0.11611029505729675;
  t269_n225: return 0.06602200120687485;
  t269_n226: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n228;
  t269_n227: return 0.1074037104845047;
  t269_n228: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t269_n230;
  t269_n229: return -0.5038248896598816;
  t269_n230: return 0.044653672724962234;
  t269_n231: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t269_n233;
  t269_n232: return 0.06555846333503723;
  t269_n233: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t269_n237;
  t269_n234: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t269_n236;
  t269_n235: return -0.20008179545402527;
  t269_n236: return -1.8823069334030151;
  t269_n237: return -0.11609134078025818;
  t269_n238: return 0.0663256049156189;
  t269_n239: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t269_n241;
  t269_n240: return 0.022385617718100548;
  t269_n241: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t269_n247;
  t269_n242: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t269_n244;
  t269_n243: return -0.04980979487299919;
  t269_n244: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t269_n246;
  t269_n245: return 0.11086565256118774;
  t269_n246: return 0.10347672551870346;
  t269_n247: return 0.020071007311344147;
  t269_n248: if (E.getNumReferences() >= 3336586496 /*28706.5*/) goto t269_n250;
  t269_n249: return -0.056564874947071075;
  t269_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t269_n254;
  t269_n251: if (E.getNumReferences() >= 3336821248 /*29165.0*/) goto t269_n253;
  t269_n252: return 0.07213837653398514;
  t269_n253: return 0.022259263321757317;
  t269_n254: return 0.09045996516942978;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree270(const Example& E) {
  t270_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t270_n2;
  t270_n1: return -0.0004046738613396883;
  t270_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t270_n226;
  t270_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t270_n109;
  t270_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t270_n6;
  t270_n5: return 0.003015809925273061;
  t270_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t270_n24;
  t270_n7: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Namespace))) goto t270_n9;
  t270_n8: return -0.04511398822069168;
  t270_n9: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t270_n19;
  t270_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t270_n18;
  t270_n11: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t270_n17;
  t270_n12: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t270_n14;
  t270_n13: return -0.13820281624794006;
  t270_n14: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t270_n16;
  t270_n15: return 0.10864213854074478;
  t270_n16: return -0.23625360429286957;
  t270_n17: return -0.11304944008588791;
  t270_n18: return 0.09218358248472214;
  t270_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t270_n21;
  t270_n20: return -0.27923649549484253;
  t270_n21: if (E.getNumReferences() >= 3277389824 /*217.0*/) goto t270_n23;
  t270_n22: return -0.1776786744594574;
  t270_n23: return 0.11759188771247864;
  t270_n24: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n100;
  t270_n25: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t270_n31;
  t270_n26: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t270_n28;
  t270_n27: return -0.10995344072580338;
  t270_n28: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t270_n30;
  t270_n29: return 0.14099016785621643;
  t270_n30: return 0.08231177181005478;
  t270_n31: if (E.getNumReferences() >= 3281698816 /*309.5*/) goto t270_n85;
  t270_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t270_n50;
  t270_n33: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t270_n49;
  t270_n34: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t270_n44;
  t270_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t270_n39;
  t270_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t270_n38;
  t270_n37: return -0.4792892634868622;
  t270_n38: return -0.02726178988814354;
  t270_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t270_n41;
  t270_n40: return 0.04722153767943382;
  t270_n41: if (E.getNumReferences() >= 3262382080 /*61.0*/) goto t270_n43;
  t270_n42: return -0.15613850951194763;
  t270_n43: return 0.1820254772901535;
  t270_n44: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t270_n46;
  t270_n45: return 0.12833741307258606;
  t270_n46: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t270_n48;
  t270_n47: return -0.17518490552902222;
  t270_n48: return 0.10784265398979187;
  t270_n49: return -0.07202153652906418;
  t270_n50: if (E.getNumReferences() >= 3272966144 /*149.5*/) goto t270_n76;
  t270_n51: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t270_n65;
  t270_n52: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n60;
  t270_n53: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t270_n55;
  t270_n54: return -0.12553906440734863;
  t270_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t270_n57;
  t270_n56: return -0.13464371860027313;
  t270_n57: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t270_n59;
  t270_n58: return 0.10403859615325928;
  t270_n59: return 0.06020870432257652;
  t270_n60: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t270_n62;
  t270_n61: return -0.1692117601633072;
  t270_n62: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t270_n64;
  t270_n63: return 0.1358531266450882;
  t270_n64: return 0.12117015570402145;
  t270_n65: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t270_n71;
  t270_n66: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t270_n70;
  t270_n67: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t270_n69;
  t270_n68: return -0.02611038275063038;
  t270_n69: return -0.6828874349594116;
  t270_n70: return 0.07252669334411621;
  t270_n71: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t270_n73;
  t270_n72: return -0.3332127332687378;
  t270_n73: if (E.getNumReferences() >= 3272769536 /*146.5*/) goto t270_n75;
  t270_n74: return -0.0586981475353241;
  t270_n75: return 0.09524156153202057;
  t270_n76: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t270_n84;
  t270_n77: if (E.getNumReferences() >= 3274604544 /*174.5*/) goto t270_n83;
  t270_n78: if (E.getNumReferences() >= 3273097216 /*151.5*/) goto t270_n80;
  t270_n79: return 0.09223390370607376;
  t270_n80: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t270_n82;
  t270_n81: return 0.004982424434274435;
  t270_n82: return 0.11562962830066681;
  t270_n83: return 0.11603476107120514;
  t270_n84: return -0.01571737229824066;
  t270_n85: if (E.getNumReferences() >= 3281813504 /*313.0*/) goto t270_n87;
  t270_n86: return 0.1172361969947815;
  t270_n87: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t270_n89;
  t270_n88: return 0.020488504320383072;
  t270_n89: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t270_n91;
  t270_n90: return 0.03133267164230347;
  t270_n91: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n97;
  t270_n92: if (E.getNumReferences() >= 3288088576 /*504.5*/) goto t270_n94;
  t270_n93: return 0.10360242426395416;
  t270_n94: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t270_n96;
  t270_n95: return -0.2264346033334732;
  t270_n96: return 0.09886380285024643;
  t270_n97: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t270_n99;
  t270_n98: return 0.12029504776000977;
  t270_n99: return 0.08500952273607254;
  t270_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t270_n102;
  t270_n101: return 0.012239346280694008;
  t270_n102: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t270_n104;
  t270_n103: return 0.024848802015185356;
  t270_n104: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t270_n106;
  t270_n105: return -0.14521068334579468;
  t270_n106: if (E.getNumReferences() >= 3286859776 /*467.0*/) goto t270_n108;
  t270_n107: return 0.11565160006284714;
  t270_n108: return -0.06428588181734085;
  t270_n109: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t270_n189;
  t270_n110: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t270_n186;
  t270_n111: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t270_n185;
  t270_n112: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t270_n126;
  t270_n113: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t270_n125;
  t270_n114: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t270_n116;
  t270_n115: return -0.0009360757539980114;
  t270_n116: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n122;
  t270_n117: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n121;
  t270_n118: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t270_n120;
  t270_n119: return -0.036090027540922165;
  t270_n120: return 0.11503175646066666;
  t270_n121: return 0.13476347923278809;
  t270_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t270_n124;
  t270_n123: return -0.20946455001831055;
  t270_n124: return 0.09393060952425003;
  t270_n125: return -0.03329605609178543;
  t270_n126: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t270_n130;
  t270_n127: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t270_n129;
  t270_n128: return 0.11234263330698013;
  t270_n129: return -0.10818123072385788;
  t270_n130: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t270_n142;
  t270_n131: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n139;
  t270_n132: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t270_n138;
  t270_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t270_n135;
  t270_n134: return 0.020960431545972824;
  t270_n135: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t270_n137;
  t270_n136: return 0.13259878754615784;
  t270_n137: return -0.04893101006746292;
  t270_n138: return 0.10998613387346268;
  t270_n139: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t270_n141;
  t270_n140: return 0.01591462641954422;
  t270_n141: return 0.3234180212020874;
  t270_n142: if (E.getNumReferences() >= 3281534976 /*304.5*/) goto t270_n148;
  t270_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t270_n145;
  t270_n144: return -0.008069631643593311;
  t270_n145: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t270_n147;
  t270_n146: return -0.12139546871185303;
  t270_n147: return 0.08886607736349106;
  t270_n148: if (E.getNumReferences() >= 3281600512 /*306.5*/) goto t270_n150;
  t270_n149: return 0.12036052346229553;
  t270_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t270_n152;
  t270_n151: return -0.005602053366601467;
  t270_n152: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t270_n154;
  t270_n153: return -0.24207821488380432;
  t270_n154: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t270_n184;
  t270_n155: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n157;
  t270_n156: return -0.08008144795894623;
  t270_n157: if (E.getNumReferences() >= 3302694912 /*1753.0*/) goto t270_n183;
  t270_n158: if (E.getNumReferences() >= 3292364800 /*758.0*/) goto t270_n172;
  t270_n159: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t270_n171;
  t270_n160: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t270_n168;
  t270_n161: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t270_n163;
  t270_n162: return -0.023201214149594307;
  t270_n163: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t270_n167;
  t270_n164: if (E.getNumReferences() >= 3283501056 /*364.5*/) goto t270_n166;
  t270_n165: return 0.22820498049259186;
  t270_n166: return 0.031228404492139816;
  t270_n167: return -0.018946249037981033;
  t270_n168: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t270_n170;
  t270_n169: return 0.09646381437778473;
  t270_n170: return -0.12511998414993286;
  t270_n171: return -0.016144651919603348;
  t270_n172: if (E.getNumReferences() >= 3294167040 /*868.0*/) goto t270_n176;
  t270_n173: if (E.getNumReferences() >= 3293421568 /*822.5*/) goto t270_n175;
  t270_n174: return 0.1069672554731369;
  t270_n175: return 0.1251228153705597;
  t270_n176: if (E.getNumReferences() >= 3297796096 /*1155.0*/) goto t270_n180;
  t270_n177: if (E.getNumReferences() >= 3295977472 /*978.5*/) goto t270_n179;
  t270_n178: return 0.019251257181167603;
  t270_n179: return 0.1092950701713562;
  t270_n180: if (E.getNumReferences() >= 3301625856 /*1622.5*/) goto t270_n182;
  t270_n181: return -0.0867585688829422;
  t270_n182: return 0.105888232588768;
  t270_n183: return 0.0016553750028833747;
  t270_n184: return -0.12800295650959015;
  t270_n185: return 0.09490302205085754;
  t270_n186: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t270_n188;
  t270_n187: return -0.020859787240624428;
  t270_n188: return 0.1066020205616951;
  t270_n189: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t270_n211;
  t270_n190: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t270_n210;
  t270_n191: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t270_n195;
  t270_n192: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t270_n194;
  t270_n193: return -0.20338734984397888;
  t270_n194: return 0.10844169557094574;
  t270_n195: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t270_n197;
  t270_n196: return -0.038223668932914734;
  t270_n197: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t270_n209;
  t270_n198: if (E.getNumReferences() >= 3259891712 /*51.5*/) goto t270_n200;
  t270_n199: return -0.020992251113057137;
  t270_n200: if (E.getNumReferences() >= 3261464576 /*57.5*/) goto t270_n204;
  t270_n201: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t270_n203;
  t270_n202: return 0.09082090854644775;
  t270_n203: return 0.11485632508993149;
  t270_n204: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n206;
  t270_n205: return 0.003642786294221878;
  t270_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t270_n208;
  t270_n207: return 0.08905868232250214;
  t270_n208: return -0.2617889642715454;
  t270_n209: return -0.08042021840810776;
  t270_n210: return 0.10845710337162018;
  t270_n211: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t270_n221;
  t270_n212: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t270_n220;
  t270_n213: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t270_n215;
  t270_n214: return -0.09670703858137131;
  t270_n215: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t270_n219;
  t270_n216: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n218;
  t270_n217: return 0.09614437818527222;
  t270_n218: return 0.062202099710702896;
  t270_n219: return -0.009076130576431751;
  t270_n220: return 0.0968737006187439;
  t270_n221: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t270_n223;
  t270_n222: return -0.06830690801143646;
  t270_n223: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t270_n225;
  t270_n224: return -0.033064406365156174;
  t270_n225: return 0.10236728936433792;
  t270_n226: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t270_n228;
  t270_n227: return -0.0016605686396360397;
  t270_n228: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t270_n250;
  t270_n229: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t270_n249;
  t270_n230: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t270_n246;
  t270_n231: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t270_n233;
  t270_n232: return -0.08682970702648163;
  t270_n233: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t270_n235;
  t270_n234: return 0.14423689246177673;
  t270_n235: if (E.getNumReferences() >= 3272998912 /*150.0*/) goto t270_n241;
  t270_n236: if (E.getNumReferences() >= 3267166208 /*94.5*/) goto t270_n240;
  t270_n237: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t270_n239;
  t270_n238: return -0.4302901029586792;
  t270_n239: return 0.23725222051143646;
  t270_n240: return -0.2888478934764862;
  t270_n241: if (E.getNumReferences() >= 3273490432 /*157.5*/) goto t270_n243;
  t270_n242: return 0.10343969613313675;
  t270_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t270_n245;
  t270_n244: return -1.0634597539901733;
  t270_n245: return 0.08870965987443924;
  t270_n246: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t270_n248;
  t270_n247: return 0.10372588783502579;
  t270_n248: return 0.0634690597653389;
  t270_n249: return 0.015296237543225288;
  t270_n250: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t270_n254;
  t270_n251: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t270_n253;
  t270_n252: return -0.18874359130859375;
  t270_n253: return 0.006398837082087994;
  t270_n254: return 0.028705457225441933;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree271(const Example& E) {
  t271_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t271_n254;
  t271_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t271_n3;
  t271_n2: return -0.00017012325406540185;
  t271_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t271_n59;
  t271_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t271_n14;
  t271_n5: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n13;
  t271_n6: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n12;
  t271_n7: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t271_n11;
  t271_n8: if (E.getNumReferences() >= 3212836864 /*1.0*/) goto t271_n10;
  t271_n9: return 0.09321700781583786;
  t271_n10: return -0.0266172643750906;
  t271_n11: return -0.018331680446863174;
  t271_n12: return 0.009801347739994526;
  t271_n13: return -0.021170098334550858;
  t271_n14: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n34;
  t271_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t271_n17;
  t271_n16: return -0.0459512397646904;
  t271_n17: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t271_n33;
  t271_n18: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t271_n20;
  t271_n19: return 0.00806854385882616;
  t271_n20: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n32;
  t271_n21: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t271_n25;
  t271_n22: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t271_n24;
  t271_n23: return 0.1011657863855362;
  t271_n24: return -0.07490447908639908;
  t271_n25: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t271_n29;
  t271_n26: if (E.getNumReferences() >= 3271229440 /*125.5*/) goto t271_n28;
  t271_n27: return -0.05587886646389961;
  t271_n28: return 0.07133892178535461;
  t271_n29: if (E.getNumReferences() >= 3260284928 /*53.0*/) goto t271_n31;
  t271_n30: return 0.10513119399547577;
  t271_n31: return -0.01041154470294714;
  t271_n32: return -0.21573716402053833;
  t271_n33: return -0.030110886320471764;
  t271_n34: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t271_n36;
  t271_n35: return 0.01246523018926382;
  t271_n36: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t271_n38;
  t271_n37: return 0.008403596468269825;
  t271_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n58;
  t271_n39: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n49;
  t271_n40: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t271_n48;
  t271_n41: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t271_n45;
  t271_n42: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n44;
  t271_n43: return 0.10852646827697754;
  t271_n44: return -0.5230382680892944;
  t271_n45: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t271_n47;
  t271_n46: return 0.1168011948466301;
  t271_n47: return 0.10766423493623734;
  t271_n48: return -0.007373692933470011;
  t271_n49: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t271_n53;
  t271_n50: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t271_n52;
  t271_n51: return 0.07584003359079361;
  t271_n52: return 0.10776817053556442;
  t271_n53: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t271_n55;
  t271_n54: return -0.6404602527618408;
  t271_n55: if (E.getNumReferences() >= 3326113792 /*12318.0*/) goto t271_n57;
  t271_n56: return 0.05327229201793671;
  t271_n57: return -1.2747036218643188;
  t271_n58: return 0.04051947966217995;
  t271_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t271_n137;
  t271_n60: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t271_n108;
  t271_n61: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t271_n69;
  t271_n62: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n64;
  t271_n63: return -0.003014660906046629;
  t271_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t271_n68;
  t271_n65: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n67;
  t271_n66: return -0.02957906946539879;
  t271_n67: return -0.005468500312417746;
  t271_n68: return 0.009462008252739906;
  t271_n69: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n91;
  t271_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t271_n72;
  t271_n71: return -0.013818695209920406;
  t271_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n74;
  t271_n73: return 0.03225648030638695;
  t271_n74: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t271_n84;
  t271_n75: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n77;
  t271_n76: return -0.032105572521686554;
  t271_n77: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t271_n79;
  t271_n78: return 0.08889096975326538;
  t271_n79: if (E.getNumReferences() >= 3257270272 /*41.5*/) goto t271_n81;
  t271_n80: return 0.021256355568766594;
  t271_n81: if (E.getNumReferences() >= 3259236352 /*49.0*/) goto t271_n83;
  t271_n82: return 0.10790538787841797;
  t271_n83: return 0.12137055397033691;
  t271_n84: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t271_n86;
  t271_n85: return 0.026929106563329697;
  t271_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n88;
  t271_n87: return -0.020562658086419106;
  t271_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t271_n90;
  t271_n89: return -0.24703416228294373;
  t271_n90: return 0.06372739374637604;
  t271_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t271_n97;
  t271_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n96;
  t271_n93: if (E.getNumReferences() >= 3361088608 /*219281.5*/) goto t271_n95;
  t271_n94: return -0.020339567214250565;
  t271_n95: return 0.07612890750169754;
  t271_n96: return -0.0014395592734217644;
  t271_n97: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t271_n99;
  t271_n98: return 0.0030240293126553297;
  t271_n99: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n105;
  t271_n100: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t271_n104;
  t271_n101: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t271_n103;
  t271_n102: return 0.2594850957393646;
  t271_n103: return 0.13763058185577393;
  t271_n104: return 0.060969822108745575;
  t271_n105: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t271_n107;
  t271_n106: return 0.026929957792162895;
  t271_n107: return -1.2733756303787231;
  t271_n108: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n124;
  t271_n109: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t271_n117;
  t271_n110: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n116;
  t271_n111: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t271_n115;
  t271_n112: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n114;
  t271_n113: return -0.03318848833441734;
  t271_n114: return -0.06991801410913467;
  t271_n115: return -0.10133962333202362;
  t271_n116: return 0.019674312323331833;
  t271_n117: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n119;
  t271_n118: return 0.011312730610370636;
  t271_n119: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n123;
  t271_n120: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t271_n122;
  t271_n121: return -0.0788494199514389;
  t271_n122: return 0.04209822043776512;
  t271_n123: return 0.0005073270876891911;
  t271_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t271_n126;
  t271_n125: return -0.0165246594697237;
  t271_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t271_n128;
  t271_n127: return -0.027478624135255814;
  t271_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n136;
  t271_n129: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n135;
  t271_n130: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t271_n134;
  t271_n131: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t271_n133;
  t271_n132: return -0.10512267798185349;
  t271_n133: return 0.0955759659409523;
  t271_n134: return -0.12774740159511566;
  t271_n135: return -0.13359639048576355;
  t271_n136: return 0.024121101945638657;
  t271_n137: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t271_n247;
  t271_n138: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t271_n216;
  t271_n139: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n215;
  t271_n140: if (E.getNumReferences() >= 3268739072 /*106.5*/) goto t271_n210;
  t271_n141: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t271_n161;
  t271_n142: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t271_n160;
  t271_n143: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n145;
  t271_n144: return 0.06358561664819717;
  t271_n145: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t271_n157;
  t271_n146: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n150;
  t271_n147: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t271_n149;
  t271_n148: return 0.1518419235944748;
  t271_n149: return -0.012959827668964863;
  t271_n150: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n152;
  t271_n151: return 0.06602144986391068;
  t271_n152: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t271_n156;
  t271_n153: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n155;
  t271_n154: return 0.39014506340026855;
  t271_n155: return 0.11429958790540695;
  t271_n156: return 0.09869582951068878;
  t271_n157: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t271_n159;
  t271_n158: return 0.10843289643526077;
  t271_n159: return -0.08479895442724228;
  t271_n160: return 0.0037141749635338783;
  t271_n161: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t271_n185;
  t271_n162: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n178;
  t271_n163: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t271_n173;
  t271_n164: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n166;
  t271_n165: return -0.11448338627815247;
  t271_n166: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t271_n170;
  t271_n167: if (E.getNumReferences() >= 3229614080 /*4.0*/) goto t271_n169;
  t271_n168: return 0.17104984819889069;
  t271_n169: return 0.1260748654603958;
  t271_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n172;
  t271_n171: return -0.7378110885620117;
  t271_n172: return 0.07541455328464508;
  t271_n173: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n175;
  t271_n174: return 0.028019307181239128;
  t271_n175: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t271_n177;
  t271_n176: return 0.11483011394739151;
  t271_n177: return 0.12591588497161865;
  t271_n178: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t271_n184;
  t271_n179: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n181;
  t271_n180: return 0.11509500443935394;
  t271_n181: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t271_n183;
  t271_n182: return 0.0030251541174948215;
  t271_n183: return 0.11088072508573532;
  t271_n184: return 0.05240800976753235;
  t271_n185: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t271_n189;
  t271_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n188;
  t271_n187: return -0.01442849449813366;
  t271_n188: return 0.15494567155838013;
  t271_n189: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n199;
  t271_n190: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t271_n192;
  t271_n191: return 0.04683058708906174;
  t271_n192: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t271_n198;
  t271_n193: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n195;
  t271_n194: return 0.1156356930732727;
  t271_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t271_n197;
  t271_n196: return 0.09068930894136429;
  t271_n197: return 0.09962036460638046;
  t271_n198: return 0.10284503549337387;
  t271_n199: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t271_n209;
  t271_n200: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t271_n202;
  t271_n201: return -0.12473326176404953;
  t271_n202: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t271_n206;
  t271_n203: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t271_n205;
  t271_n204: return 0.12025943398475647;
  t271_n205: return 0.1385803371667862;
  t271_n206: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t271_n208;
  t271_n207: return -0.45377781987190247;
  t271_n208: return 0.0537690706551075;
  t271_n209: return 0.1075885072350502;
  t271_n210: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t271_n212;
  t271_n211: return -0.07522863894701004;
  t271_n212: if (E.getNumReferences() >= 3290939392 /*671.0*/) goto t271_n214;
  t271_n213: return 0.13549020886421204;
  t271_n214: return -0.0817590057849884;
  t271_n215: return 0.04107268899679184;
  t271_n216: if (E.getScope() & (BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t271_n218;
  t271_n217: return -0.003804483450949192;
  t271_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Statement))) goto t271_n240;
  t271_n219: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t271_n223;
  t271_n220: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n222;
  t271_n221: return 0.008519905619323254;
  t271_n222: return 0.020435338839888573;
  t271_n223: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n225;
  t271_n224: return 0.02407318353652954;
  t271_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t271_n239;
  t271_n226: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t271_n238;
  t271_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t271_n229;
  t271_n228: return 0.016266725957393646;
  t271_n229: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n231;
  t271_n230: return 0.06902388483285904;
  t271_n231: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n233;
  t271_n232: return -0.07212293893098831;
  t271_n233: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t271_n237;
  t271_n234: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t271_n236;
  t271_n235: return 0.06465831398963928;
  t271_n236: return 0.11881187558174133;
  t271_n237: return 0.08546748012304306;
  t271_n238: return 0.012839671224355698;
  t271_n239: return 0.04562067240476608;
  t271_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t271_n246;
  t271_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t271_n245;
  t271_n242: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n244;
  t271_n243: return 0.032606206834316254;
  t271_n244: return 0.057841334491968155;
  t271_n245: return 0.03673667833209038;
  t271_n246: return -0.01348403561860323;
  t271_n247: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t271_n249;
  t271_n248: return -0.011111805215477943;
  t271_n249: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t271_n253;
  t271_n250: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t271_n252;
  t271_n251: return 0.05979118123650551;
  t271_n252: return 0.09970255941152573;
  t271_n253: return 0.0013206922449171543;
  t271_n254: return -0.009460430592298508;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree272(const Example& E) {
  t272_n0: if (E.getNumReferences() >= 3320122368 /*7329.5*/) goto t272_n210;
  t272_n1: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t272_n3;
  t272_n2: return 0.0022675246000289917;
  t272_n3: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t272_n173;
  t272_n4: if (E.getSymbolScopeDistance() >= 3246915584 /*17.0*/) goto t272_n30;
  t272_n5: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t272_n29;
  t272_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t272_n8;
  t272_n7: return -0.01264221128076315;
  t272_n8: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t272_n10;
  t272_n9: return 0.023399455472826958;
  t272_n10: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n22;
  t272_n11: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t272_n13;
  t272_n12: return 0.008639214560389519;
  t272_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n15;
  t272_n14: return 0.03609349951148033;
  t272_n15: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t272_n17;
  t272_n16: return 0.06596704572439194;
  t272_n17: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t272_n21;
  t272_n18: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t272_n20;
  t272_n19: return 0.12582221627235413;
  t272_n20: return 0.1351318657398224;
  t272_n21: return 0.08391793072223663;
  t272_n22: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n28;
  t272_n23: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t272_n27;
  t272_n24: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n26;
  t272_n25: return 0.10804705321788788;
  t272_n26: return 0.1397029608488083;
  t272_n27: return 0.056800372898578644;
  t272_n28: return 0.036074113100767136;
  t272_n29: return 0.00018523613107390702;
  t272_n30: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t272_n32;
  t272_n31: return -0.0063846176490187645;
  t272_n32: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t272_n34;
  t272_n33: return 0.0029971993062645197;
  t272_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t272_n36;
  t272_n35: return -0.006992395967245102;
  t272_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t272_n84;
  t272_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t272_n43;
  t272_n38: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n42;
  t272_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t272_n41;
  t272_n40: return -0.01625852845609188;
  t272_n41: return 0.04437035694718361;
  t272_n42: return -0.04257486015558243;
  t272_n43: if (E.getSymbolScopeDistance() >= 3249012736 /*21.0*/) goto t272_n47;
  t272_n44: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t272_n46;
  t272_n45: return 0.12433672696352005;
  t272_n46: return -0.3053397536277771;
  t272_n47: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t272_n69;
  t272_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t272_n58;
  t272_n49: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n51;
  t272_n50: return 0.01774229109287262;
  t272_n51: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t272_n53;
  t272_n52: return 0.1329420953989029;
  t272_n53: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t272_n57;
  t272_n54: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n56;
  t272_n55: return 0.061699219048023224;
  t272_n56: return 0.0864289402961731;
  t272_n57: return -0.11282815039157867;
  t272_n58: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n68;
  t272_n59: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n61;
  t272_n60: return 0.20743407309055328;
  t272_n61: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t272_n63;
  t272_n62: return -0.075736865401268;
  t272_n63: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t272_n65;
  t272_n64: return -0.10013201832771301;
  t272_n65: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t272_n67;
  t272_n66: return 0.13145746290683746;
  t272_n67: return 0.057311076670885086;
  t272_n68: return 0.08735332638025284;
  t272_n69: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t272_n81;
  t272_n70: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t272_n72;
  t272_n71: return 0.008989043533802032;
  t272_n72: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t272_n80;
  t272_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n79;
  t272_n74: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t272_n78;
  t272_n75: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n77;
  t272_n76: return 0.14250285923480988;
  t272_n77: return 0.19262754917144775;
  t272_n78: return 0.08999203145503998;
  t272_n79: return 0.12706084549427032;
  t272_n80: return 0.03326508030295372;
  t272_n81: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n83;
  t272_n82: return 0.036719389259815216;
  t272_n83: return -0.004660372156649828;
  t272_n84: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t272_n88;
  t272_n85: if (E.getSemaFileProximityScore() >= 3204448256 /*0.5*/) goto t272_n87;
  t272_n86: return -0.031645823270082474;
  t272_n87: return -0.22924166917800903;
  t272_n88: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n98;
  t272_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t272_n91;
  t272_n90: return 0.025602800771594048;
  t272_n91: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t272_n93;
  t272_n92: return 0.036635711789131165;
  t272_n93: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n95;
  t272_n94: return -0.04914555698633194;
  t272_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t272_n97;
  t272_n96: return -0.10148368030786514;
  t272_n97: return 0.10571535676717758;
  t272_n98: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t272_n172;
  t272_n99: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n169;
  t272_n100: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t272_n122;
  t272_n101: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t272_n115;
  t272_n102: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t272_n108;
  t272_n103: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n105;
  t272_n104: return 0.06827963143587112;
  t272_n105: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n107;
  t272_n106: return -0.045165229588747025;
  t272_n107: return 0.052785418927669525;
  t272_n108: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t272_n114;
  t272_n109: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t272_n111;
  t272_n110: return 0.13310931622982025;
  t272_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n113;
  t272_n112: return 0.06289325654506683;
  t272_n113: return 0.14745934307575226;
  t272_n114: return -0.04093904048204422;
  t272_n115: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n119;
  t272_n116: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n118;
  t272_n117: return 0.07634971290826797;
  t272_n118: return -0.038101449608802795;
  t272_n119: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t272_n121;
  t272_n120: return 0.08268275856971741;
  t272_n121: return 0.07121023535728455;
  t272_n122: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t272_n168;
  t272_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t272_n141;
  t272_n124: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n128;
  t272_n125: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n127;
  t272_n126: return 0.056837018579244614;
  t272_n127: return -0.022822683677077293;
  t272_n128: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t272_n132;
  t272_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n131;
  t272_n130: return 0.026860956102609634;
  t272_n131: return 0.08495038002729416;
  t272_n132: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t272_n134;
  t272_n133: return 0.05027230083942413;
  t272_n134: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t272_n140;
  t272_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t272_n139;
  t272_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n138;
  t272_n137: return 0.04109268635511398;
  t272_n138: return 0.11782949417829514;
  t272_n139: return 0.10621823370456696;
  t272_n140: return 0.04116327315568924;
  t272_n141: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t272_n143;
  t272_n142: return 0.05266723409295082;
  t272_n143: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t272_n167;
  t272_n144: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t272_n164;
  t272_n145: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t272_n155;
  t272_n146: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t272_n148;
  t272_n147: return 0.0541829951107502;
  t272_n148: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t272_n150;
  t272_n149: return 0.08839435130357742;
  t272_n150: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t272_n152;
  t272_n151: return -0.02570757456123829;
  t272_n152: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t272_n154;
  t272_n153: return 0.09228207170963287;
  t272_n154: return -0.12831901013851166;
  t272_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t272_n161;
  t272_n156: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t272_n160;
  t272_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t272_n159;
  t272_n158: return 0.07459262013435364;
  t272_n159: return 0.10575567185878754;
  t272_n160: return -0.1336333006620407;
  t272_n161: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t272_n163;
  t272_n162: return 0.10894696414470673;
  t272_n163: return -0.13209538161754608;
  t272_n164: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t272_n166;
  t272_n165: return 0.09108821302652359;
  t272_n166: return 0.11980102956295013;
  t272_n167: return -0.07895655930042267;
  t272_n168: return 0.020851654931902885;
  t272_n169: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t272_n171;
  t272_n170: return 0.029215797781944275;
  t272_n171: return -0.08014735579490662;
  t272_n172: return -0.10199395567178726;
  t272_n173: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t272_n175;
  t272_n174: return 0.008589616045355797;
  t272_n175: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t272_n177;
  t272_n176: return -0.0277081448584795;
  t272_n177: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n203;
  t272_n178: if (E.getNumReferences() >= 3316691968 /*5654.5*/) goto t272_n192;
  t272_n179: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t272_n181;
  t272_n180: return 0.01531133521348238;
  t272_n181: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t272_n183;
  t272_n182: return -0.03430768474936485;
  t272_n183: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t272_n191;
  t272_n184: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n190;
  t272_n185: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t272_n189;
  t272_n186: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t272_n188;
  t272_n187: return 0.1541374921798706;
  t272_n188: return -0.025971582159399986;
  t272_n189: return 0.15017573535442352;
  t272_n190: return -0.05994337424635887;
  t272_n191: return 0.04028250277042389;
  t272_n192: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t272_n194;
  t272_n193: return -0.24702033400535583;
  t272_n194: if (E.getNumReferences() >= 3319669760 /*7108.5*/) goto t272_n202;
  t272_n195: if (E.getNumReferences() >= 3319385088 /*6969.5*/) goto t272_n201;
  t272_n196: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t272_n198;
  t272_n197: return 0.13455452024936676;
  t272_n198: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t272_n200;
  t272_n199: return -0.05629127845168114;
  t272_n200: return 0.09050492942333221;
  t272_n201: return 0.12765946984291077;
  t272_n202: return -0.21160122752189636;
  t272_n203: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t272_n205;
  t272_n204: return -0.059765323996543884;
  t272_n205: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t272_n207;
  t272_n206: return -0.015415072441101074;
  t272_n207: if (E.getNumReferences() >= 3276865536 /*209.0*/) goto t272_n209;
  t272_n208: return 0.16754034161567688;
  t272_n209: return 0.0672769844532013;
  t272_n210: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t272_n252;
  t272_n211: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t272_n245;
  t272_n212: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t272_n214;
  t272_n213: return 0.10251887887716293;
  t272_n214: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t272_n244;
  t272_n215: if (E.getNumReferences() >= 3348085888 /*73593.0*/) goto t272_n229;
  t272_n216: if (E.getNumReferences() >= 3339097344 /*34453.0*/) goto t272_n218;
  t272_n217: return -0.02022102102637291;
  t272_n218: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t272_n228;
  t272_n219: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t272_n221;
  t272_n220: return -0.2741563022136688;
  t272_n221: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t272_n227;
  t272_n222: if (E.getNumReferences() >= 3345471616 /*59352.5*/) goto t272_n224;
  t272_n223: return 0.025091204792261124;
  t272_n224: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t272_n226;
  t272_n225: return 0.03773108497262001;
  t272_n226: return 0.08976670354604721;
  t272_n227: return 0.0988512709736824;
  t272_n228: return -0.06011049821972847;
  t272_n229: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t272_n243;
  t272_n230: if (E.getNumReferences() >= 3349315712 /*83201.0*/) goto t272_n236;
  t272_n231: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t272_n233;
  t272_n232: return -2.759380578994751;
  t272_n233: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t272_n235;
  t272_n234: return -0.008589637465775013;
  t272_n235: return -0.13245181739330292;
  t272_n236: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t272_n238;
  t272_n237: return 0.01883835531771183;
  t272_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t272_n242;
  t272_n239: if (E.getNumReferences() >= 3359666304 /*197058.0*/) goto t272_n241;
  t272_n240: return -0.2317870408296585;
  t272_n241: return -0.11055287718772888;
  t272_n242: return 0.0435432605445385;
  t272_n243: return 0.08752705901861191;
  t272_n244: return 0.011080209165811539;
  t272_n245: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t272_n247;
  t272_n246: return 0.0009819614933803678;
  t272_n247: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t272_n249;
  t272_n248: return 0.016466841101646423;
  t272_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t272_n251;
  t272_n250: return 0.0981258824467659;
  t272_n251: return -0.044042594730854034;
  t272_n252: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t272_n254;
  t272_n253: return -0.026343777775764465;
  t272_n254: return 0.0046780845150351524;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree273(const Example& E) {
  t273_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t273_n2;
  t273_n1: return -0.00031622109236195683;
  t273_n2: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t273_n86;
  t273_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t273_n7;
  t273_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t273_n6;
  t273_n5: return -0.21177783608436584;
  t273_n6: return 0.003154624719172716;
  t273_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t273_n31;
  t273_n8: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t273_n30;
  t273_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t273_n11;
  t273_n10: return 0.000418495706981048;
  t273_n11: if (E.getNumReferences() >= 3290529792 /*646.0*/) goto t273_n21;
  t273_n12: if (E.getNumReferences() >= 3289440256 /*579.5*/) goto t273_n20;
  t273_n13: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t273_n15;
  t273_n14: return -0.18330809473991394;
  t273_n15: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t273_n17;
  t273_n16: return -0.34679844975471497;
  t273_n17: if (E.getNumReferences() >= 3288375296 /*514.5*/) goto t273_n19;
  t273_n18: return 0.10578006505966187;
  t273_n19: return -0.20934343338012695;
  t273_n20: return 0.13260087370872498;
  t273_n21: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t273_n23;
  t273_n22: return -0.36665117740631104;
  t273_n23: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t273_n29;
  t273_n24: if (E.getNumReferences() >= 3302469632 /*1725.5*/) goto t273_n28;
  t273_n25: if (E.getNumReferences() >= 3298672640 /*1262.0*/) goto t273_n27;
  t273_n26: return 0.10687698423862457;
  t273_n27: return 0.12787170708179474;
  t273_n28: return -0.7502469420433044;
  t273_n29: return -0.004112012684345245;
  t273_n30: return 0.012726353481411934;
  t273_n31: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t273_n83;
  t273_n32: if (E.getNumReferences() >= 3314761728 /*4712.0*/) goto t273_n68;
  t273_n33: if (E.getNumReferences() >= 3289620480 /*590.5*/) goto t273_n67;
  t273_n34: if (E.getNumReferences() >= 3289538560 /*585.5*/) goto t273_n66;
  t273_n35: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t273_n57;
  t273_n36: if (E.getNumReferences() >= 3286384640 /*452.5*/) goto t273_n48;
  t273_n37: if (E.getNumReferences() >= 3286089728 /*443.5*/) goto t273_n45;
  t273_n38: if (E.getNumReferences() >= 3285598208 /*428.5*/) goto t273_n44;
  t273_n39: if (E.getNumReferences() >= 3285467136 /*424.5*/) goto t273_n41;
  t273_n40: return 0.052434779703617096;
  t273_n41: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t273_n43;
  t273_n42: return 0.11015193164348602;
  t273_n43: return -0.1614500731229782;
  t273_n44: return -0.20996235311031342;
  t273_n45: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t273_n47;
  t273_n46: return 0.04369568079710007;
  t273_n47: return 0.11223895102739334;
  t273_n48: if (E.getNumReferences() >= 3288580096 /*527.0*/) goto t273_n50;
  t273_n49: return -0.07223992049694061;
  t273_n50: if (E.getNumReferences() >= 3288678400 /*533.0*/) goto t273_n52;
  t273_n51: return 0.10755637288093567;
  t273_n52: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n54;
  t273_n53: return -0.39761948585510254;
  t273_n54: if (E.getNumReferences() >= 3289128960 /*560.5*/) goto t273_n56;
  t273_n55: return -0.003162436420097947;
  t273_n56: return 0.11339423805475235;
  t273_n57: if (E.getNumReferences() >= 3286024192 /*441.5*/) goto t273_n59;
  t273_n58: return -0.09724900871515274;
  t273_n59: if (E.getNumReferences() >= 3286368256 /*452.0*/) goto t273_n61;
  t273_n60: return 0.0985201969742775;
  t273_n61: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t273_n63;
  t273_n62: return -0.11641903966665268;
  t273_n63: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t273_n65;
  t273_n64: return 0.167011559009552;
  t273_n65: return -0.11663062125444412;
  t273_n66: return 0.1486562341451645;
  t273_n67: return 0.00871626939624548;
  t273_n68: if (E.getNumReferences() >= 3318413312 /*6495.0*/) goto t273_n82;
  t273_n69: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t273_n77;
  t273_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t273_n72;
  t273_n71: return -0.27521684765815735;
  t273_n72: if (E.getNumReferences() >= 3317001216 /*5805.5*/) goto t273_n74;
  t273_n73: return 0.03631414473056793;
  t273_n74: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t273_n76;
  t273_n75: return 0.10276547074317932;
  t273_n76: return 0.13469047844409943;
  t273_n77: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t273_n79;
  t273_n78: return 0.08939363062381744;
  t273_n79: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t273_n81;
  t273_n80: return 0.12987728416919708;
  t273_n81: return 0.1398271769285202;
  t273_n82: return -0.001562589081004262;
  t273_n83: if (E.getNumReferences() >= 3298271232 /*1213.0*/) goto t273_n85;
  t273_n84: return 0.11373718827962875;
  t273_n85: return -1.4637610912322998;
  t273_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t273_n88;
  t273_n87: return -0.00046386371832340956;
  t273_n88: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t273_n90;
  t273_n89: return 0.00560372369363904;
  t273_n90: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t273_n254;
  t273_n91: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t273_n101;
  t273_n92: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t273_n98;
  t273_n93: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t273_n95;
  t273_n94: return -0.45036134123802185;
  t273_n95: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t273_n97;
  t273_n96: return -0.17215275764465332;
  t273_n97: return -0.008461110293865204;
  t273_n98: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t273_n100;
  t273_n99: return -0.18822382390499115;
  t273_n100: return 0.12325061112642288;
  t273_n101: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t273_n103;
  t273_n102: return 0.09653985500335693;
  t273_n103: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t273_n217;
  t273_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t273_n148;
  t273_n105: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t273_n147;
  t273_n106: if (E.getNumReferences() >= 3300237312 /*1453.0*/) goto t273_n146;
  t273_n107: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t273_n129;
  t273_n108: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t273_n116;
  t273_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Expression))) goto t273_n113;
  t273_n110: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t273_n112;
  t273_n111: return -0.46035632491111755;
  t273_n112: return 0.14869174361228943;
  t273_n113: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t273_n115;
  t273_n114: return 0.02425779215991497;
  t273_n115: return 0.12286421656608582;
  t273_n116: if (E.getNumReferences() >= 3299237888 /*1331.0*/) goto t273_n128;
  t273_n117: if (E.getNumReferences() >= 3294543872 /*891.0*/) goto t273_n121;
  t273_n118: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t273_n120;
  t273_n119: return -0.1590830385684967;
  t273_n120: return 0.05591215193271637;
  t273_n121: if (E.getNumReferences() >= 3295584256 /*954.5*/) goto t273_n123;
  t273_n122: return 0.10527046769857407;
  t273_n123: if (E.getNumReferences() >= 3298086912 /*1190.5*/) goto t273_n125;
  t273_n124: return -0.10650062561035156;
  t273_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement))) goto t273_n127;
  t273_n126: return 0.0028732072096318007;
  t273_n127: return 0.09726721793413162;
  t273_n128: return -1.2171803712844849;
  t273_n129: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t273_n137;
  t273_n130: if (E.getNumReferences() >= 3299737600 /*1392.0*/) goto t273_n136;
  t273_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t273_n135;
  t273_n132: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n134;
  t273_n133: return -0.2631862163543701;
  t273_n134: return 0.08062144368886948;
  t273_n135: return 0.08895644545555115;
  t273_n136: return 0.09462673962116241;
  t273_n137: if (E.getNumReferences() >= 3291422720 /*700.5*/) goto t273_n139;
  t273_n138: return -0.4278988540172577;
  t273_n139: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t273_n143;
  t273_n140: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t273_n142;
  t273_n141: return 0.12373102456331253;
  t273_n142: return 0.059694379568099976;
  t273_n143: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t273_n145;
  t273_n144: return -0.1169477105140686;
  t273_n145: return 0.12536601722240448;
  t273_n146: return 0.11783809959888458;
  t273_n147: return 0.02349073812365532;
  t273_n148: if (E.getNumReferences() >= 3287089152 /*474.0*/) goto t273_n152;
  t273_n149: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t273_n151;
  t273_n150: return -0.2524101436138153;
  t273_n151: return 0.10783607512712479;
  t273_n152: if (E.getNumReferences() >= 3289980928 /*612.5*/) goto t273_n156;
  t273_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Type))) goto t273_n155;
  t273_n154: return -0.15750941634178162;
  t273_n155: return 0.12324083596467972;
  t273_n156: if (E.getNumReferences() >= 3290718208 /*657.5*/) goto t273_n168;
  t273_n157: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t273_n165;
  t273_n158: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t273_n164;
  t273_n159: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t273_n163;
  t273_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t273_n162;
  t273_n161: return -0.27426910400390625;
  t273_n162: return 0.060777463018894196;
  t273_n163: return 0.07307519763708115;
  t273_n164: return 0.11683496832847595;
  t273_n165: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t273_n167;
  t273_n166: return 0.1133643388748169;
  t273_n167: return -0.09855208545923233;
  t273_n168: if (E.getNumReferences() >= 3312013312 /*3733.0*/) goto t273_n202;
  t273_n169: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t273_n189;
  t273_n170: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t273_n172;
  t273_n171: return 0.08516591787338257;
  t273_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t273_n176;
  t273_n173: if (E.getNumReferences() >= 3294429184 /*884.0*/) goto t273_n175;
  t273_n174: return -0.8568227291107178;
  t273_n175: return -0.10086403042078018;
  t273_n176: if (E.getNumReferences() >= 3291193344 /*686.5*/) goto t273_n180;
  t273_n177: if (E.getNumReferences() >= 3290963968 /*672.5*/) goto t273_n179;
  t273_n178: return -0.010616296902298927;
  t273_n179: return -0.5300487279891968;
  t273_n180: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t273_n186;
  t273_n181: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t273_n185;
  t273_n182: if (E.getNumReferences() >= 3310272512 /*3308.0*/) goto t273_n184;
  t273_n183: return -0.014238185249269009;
  t273_n184: return 0.10111494362354279;
  t273_n185: return 0.09259900450706482;
  t273_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n188;
  t273_n187: return -0.2239830642938614;
  t273_n188: return -0.06312979757785797;
  t273_n189: if (E.getNumReferences() >= 3307843584 /*2715.0*/) goto t273_n201;
  t273_n190: if (E.getNumReferences() >= 3296665600 /*1020.5*/) goto t273_n192;
  t273_n191: return -0.08804783225059509;
  t273_n192: if (E.getNumReferences() >= 3296931840 /*1049.5*/) goto t273_n194;
  t273_n193: return 0.10611032694578171;
  t273_n194: if (E.getNumReferences() >= 3303219200 /*1817.0*/) goto t273_n196;
  t273_n195: return 0.0010310913203284144;
  t273_n196: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t273_n198;
  t273_n197: return 0.12382940202951431;
  t273_n198: if (E.getNumReferences() >= 3305670656 /*2184.5*/) goto t273_n200;
  t273_n199: return -0.02572430670261383;
  t273_n200: return 0.1302795559167862;
  t273_n201: return -0.48674771189689636;
  t273_n202: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t273_n204;
  t273_n203: return -0.19084139168262482;
  t273_n204: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t273_n208;
  t273_n205: if (E.getNumReferences() >= 3313082368 /*3994.0*/) goto t273_n207;
  t273_n206: return 0.061208467930555344;
  t273_n207: return 0.00582013139501214;
  t273_n208: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t273_n210;
  t273_n209: return 0.10530727356672287;
  t273_n210: if (E.getNumReferences() >= 3319742464 /*7144.0*/) goto t273_n214;
  t273_n211: if (E.getNumReferences() >= 3315684352 /*5162.5*/) goto t273_n213;
  t273_n212: return -0.028774376958608627;
  t273_n213: return 0.11124803870916367;
  t273_n214: if (E.getNumReferences() >= 3364045296 /*268815.5*/) goto t273_n216;
  t273_n215: return -0.025387294590473175;
  t273_n216: return 0.07468394935131073;
  t273_n217: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t273_n219;
  t273_n218: return -0.011669783852994442;
  t273_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t273_n237;
  t273_n220: if (E.getNumReferences() >= 3289956352 /*611.0*/) goto t273_n224;
  t273_n221: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n223;
  t273_n222: return -0.34453830122947693;
  t273_n223: return 0.08636423945426941;
  t273_n224: if (E.getNumReferences() >= 3369637072 /*443558.5*/) goto t273_n232;
  t273_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t273_n229;
  t273_n226: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t273_n228;
  t273_n227: return -0.4054372310638428;
  t273_n228: return 0.032595645636320114;
  t273_n229: if (E.getNumReferences() >= 3290333184 /*634.0*/) goto t273_n231;
  t273_n230: return 0.1747329980134964;
  t273_n231: return 0.010365399532020092;
  t273_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Expression))) goto t273_n234;
  t273_n233: return 0.10018978267908096;
  t273_n234: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t273_n236;
  t273_n235: return 0.08112356811761856;
  t273_n236: return 0.009757503867149353;
  t273_n237: if (E.getNumReferences() >= 3289088000 /*558.0*/) goto t273_n239;
  t273_n238: return 0.09777652472257614;
  t273_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t273_n253;
  t273_n240: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t273_n250;
  t273_n241: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t273_n243;
  t273_n242: return -0.004836652893573046;
  t273_n243: if (E.getNumReferences() >= 3347567040 /*69539.5*/) goto t273_n249;
  t273_n244: if (E.getNumReferences() >= 3319671808 /*7109.5*/) goto t273_n246;
  t273_n245: return 0.06208343803882599;
  t273_n246: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t273_n248;
  t273_n247: return 0.11411050707101822;
  t273_n248: return 0.10144314914941788;
  t273_n249: return -0.02167423814535141;
  t273_n250: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t273_n252;
  t273_n251: return 0.0943528264760971;
  t273_n252: return 0.11468975245952606;
  t273_n253: return -0.004111388232558966;
  t273_n254: return 0.10833494365215302;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree274(const Example& E) {
  t274_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t274_n2;
  t274_n1: return -0.00031513572321273386;
  t274_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t274_n178;
  t274_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t274_n157;
  t274_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t274_n28;
  t274_n5: if (E.getNumReferences() >= 3310407680 /*3341.0*/) goto t274_n7;
  t274_n6: return -0.012307364493608475;
  t274_n7: if (E.getNumReferences() >= 3311495168 /*3606.5*/) goto t274_n27;
  t274_n8: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t274_n24;
  t274_n9: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n19;
  t274_n10: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t274_n18;
  t274_n11: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t274_n13;
  t274_n12: return 0.1462482362985611;
  t274_n13: if (E.getNumReferences() >= 3311011840 /*3488.5*/) goto t274_n15;
  t274_n14: return -0.10254786908626556;
  t274_n15: if (E.getNumReferences() >= 3311206400 /*3536.0*/) goto t274_n17;
  t274_n16: return 0.20058684051036835;
  t274_n17: return -0.10313844680786133;
  t274_n18: return -0.10591036826372147;
  t274_n19: if (E.getNumReferences() >= 3310528512 /*3370.5*/) goto t274_n21;
  t274_n20: return 0.17454001307487488;
  t274_n21: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t274_n23;
  t274_n22: return 0.08369076997041702;
  t274_n23: return -0.2896454930305481;
  t274_n24: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t274_n26;
  t274_n25: return 0.09843171387910843;
  t274_n26: return -0.10676586627960205;
  t274_n27: return 0.005820554215461016;
  t274_n28: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t274_n58;
  t274_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t274_n43;
  t274_n30: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t274_n34;
  t274_n31: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t274_n33;
  t274_n32: return 0.05782734230160713;
  t274_n33: return -0.144953653216362;
  t274_n34: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t274_n38;
  t274_n35: if (E.getNumReferences() >= 3318000640 /*6293.5*/) goto t274_n37;
  t274_n36: return -0.08002349734306335;
  t274_n37: return 0.12429457157850266;
  t274_n38: if (E.getNumReferences() >= 3291176960 /*685.5*/) goto t274_n40;
  t274_n39: return -0.28907883167266846;
  t274_n40: if (E.getNumReferences() >= 3294339072 /*878.5*/) goto t274_n42;
  t274_n41: return 0.10457852482795715;
  t274_n42: return 0.07050852477550507;
  t274_n43: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t274_n55;
  t274_n44: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t274_n54;
  t274_n45: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t274_n47;
  t274_n46: return -0.1060740202665329;
  t274_n47: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t274_n49;
  t274_n48: return 0.11460157483816147;
  t274_n49: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t274_n51;
  t274_n50: return -0.1405637264251709;
  t274_n51: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t274_n53;
  t274_n52: return 0.107828289270401;
  t274_n53: return 0.09103654325008392;
  t274_n54: return -0.25040504336357117;
  t274_n55: if (E.getNumReferences() >= 3291029504 /*676.5*/) goto t274_n57;
  t274_n56: return 0.1155184656381607;
  t274_n57: return 0.07387030869722366;
  t274_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t274_n152;
  t274_n59: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t274_n151;
  t274_n60: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t274_n136;
  t274_n61: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t274_n117;
  t274_n62: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t274_n86;
  t274_n63: if (E.getNumReferences() >= 3288662016 /*532.0*/) goto t274_n67;
  t274_n64: if (E.getNumReferences() >= 3288432640 /*518.0*/) goto t274_n66;
  t274_n65: return -0.039172712713479996;
  t274_n66: return 0.1097930446267128;
  t274_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t274_n85;
  t274_n68: if (E.getNumReferences() >= 3314260992 /*4467.5*/) goto t274_n84;
  t274_n69: if (E.getNumReferences() >= 3302797312 /*1765.5*/) goto t274_n79;
  t274_n70: if (E.getNumReferences() >= 3291463680 /*703.0*/) goto t274_n74;
  t274_n71: if (E.getNumReferences() >= 3290890240 /*668.0*/) goto t274_n73;
  t274_n72: return -0.038761384785175323;
  t274_n73: return 0.10047018527984619;
  t274_n74: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t274_n78;
  t274_n75: if (E.getNumReferences() >= 3292356608 /*757.5*/) goto t274_n77;
  t274_n76: return -0.8249486684799194;
  t274_n77: return -0.10975154489278793;
  t274_n78: return 0.07384754717350006;
  t274_n79: if (E.getNumReferences() >= 3303575552 /*1860.5*/) goto t274_n81;
  t274_n80: return 0.10796822607517242;
  t274_n81: if (E.getNumReferences() >= 3310970880 /*3478.5*/) goto t274_n83;
  t274_n82: return -0.09591950476169586;
  t274_n83: return 0.10681251436471939;
  t274_n84: return -0.15707632899284363;
  t274_n85: return -0.35336020588874817;
  t274_n86: if (E.getNumReferences() >= 3317244928 /*5924.5*/) goto t274_n114;
  t274_n87: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t274_n105;
  t274_n88: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t274_n100;
  t274_n89: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t274_n95;
  t274_n90: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t274_n94;
  t274_n91: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t274_n93;
  t274_n92: return -0.16465380787849426;
  t274_n93: return -0.6644179224967957;
  t274_n94: return -0.0456058643758297;
  t274_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t274_n97;
  t274_n96: return -0.5159109830856323;
  t274_n97: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t274_n99;
  t274_n98: return -0.5195292830467224;
  t274_n99: return -0.050112638622522354;
  t274_n100: if (E.getNumReferences() >= 3284992000 /*410.0*/) goto t274_n104;
  t274_n101: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t274_n103;
  t274_n102: return -0.26288366317749023;
  t274_n103: return 0.12123597413301468;
  t274_n104: return -0.02834898792207241;
  t274_n105: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t274_n107;
  t274_n106: return -0.043857622891664505;
  t274_n107: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t274_n109;
  t274_n108: return 0.005949351005256176;
  t274_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n113;
  t274_n110: if (E.getNumReferences() >= 3289448448 /*580.0*/) goto t274_n112;
  t274_n111: return 0.18747399747371674;
  t274_n112: return -0.08202183246612549;
  t274_n113: return 0.10791762918233871;
  t274_n114: if (E.getNumReferences() >= 3321911808 /*8214.5*/) goto t274_n116;
  t274_n115: return 0.09593097865581512;
  t274_n116: return -0.2397880256175995;
  t274_n117: if (E.getNumReferences() >= 3291791360 /*723.0*/) goto t274_n131;
  t274_n118: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t274_n126;
  t274_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t274_n123;
  t274_n120: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t274_n122;
  t274_n121: return -0.1340940296649933;
  t274_n122: return 0.08379355072975159;
  t274_n123: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n125;
  t274_n124: return 0.11072813719511032;
  t274_n125: return 0.045977529138326645;
  t274_n126: if (E.getNumReferences() >= 3286204416 /*447.0*/) goto t274_n130;
  t274_n127: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t274_n129;
  t274_n128: return -3.1444900035858154;
  t274_n129: return -0.15584196150302887;
  t274_n130: return -0.07107935100793839;
  t274_n131: if (E.getNumReferences() >= 3292323840 /*755.5*/) goto t274_n133;
  t274_n132: return -0.9795028567314148;
  t274_n133: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t274_n135;
  t274_n134: return -0.10861244052648544;
  t274_n135: return 0.046681102365255356;
  t274_n136: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t274_n148;
  t274_n137: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t274_n139;
  t274_n138: return 0.01917448081076145;
  t274_n139: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t274_n147;
  t274_n140: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t274_n142;
  t274_n141: return -0.13273443281650543;
  t274_n142: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t274_n144;
  t274_n143: return 0.3092496693134308;
  t274_n144: if (E.getNumReferences() >= 3302293504 /*1704.0*/) goto t274_n146;
  t274_n145: return 0.06781362742185593;
  t274_n146: return 0.1431487649679184;
  t274_n147: return 0.155690535902977;
  t274_n148: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t274_n150;
  t274_n149: return 0.003256283700466156;
  t274_n150: return 0.05846068635582924;
  t274_n151: return -0.13849978148937225;
  t274_n152: if (E.getNumReferences() >= 3286122496 /*444.5*/) goto t274_n156;
  t274_n153: if (E.getNumReferences() >= 3285368832 /*421.5*/) goto t274_n155;
  t274_n154: return 0.02675841562449932;
  t274_n155: return 0.10389867424964905;
  t274_n156: return 0.009261944331228733;
  t274_n157: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t274_n177;
  t274_n158: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t274_n162;
  t274_n159: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n161;
  t274_n160: return -0.03821224346756935;
  t274_n161: return 0.065894715487957;
  t274_n162: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t274_n164;
  t274_n163: return -0.07305784523487091;
  t274_n164: if (E.getNumReferences() >= 3286761472 /*464.0*/) goto t274_n172;
  t274_n165: if (E.getNumReferences() >= 3286269952 /*449.0*/) goto t274_n171;
  t274_n166: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t274_n168;
  t274_n167: return 0.015135345980525017;
  t274_n168: if (E.getNumReferences() >= 3285696512 /*431.5*/) goto t274_n170;
  t274_n169: return 0.09394926577806473;
  t274_n170: return -0.12014550715684891;
  t274_n171: return 0.08132800459861755;
  t274_n172: if (E.getNumReferences() >= 3288186880 /*507.5*/) goto t274_n174;
  t274_n173: return -0.4069157540798187;
  t274_n174: if (E.getNumReferences() >= 3288334336 /*512.0*/) goto t274_n176;
  t274_n175: return 0.09508407115936279;
  t274_n176: return 0.04415477439761162;
  t274_n177: return 0.08685418963432312;
  t274_n178: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t274_n208;
  t274_n179: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t274_n183;
  t274_n180: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t274_n182;
  t274_n181: return -0.10590801388025284;
  t274_n182: return 0.09796811640262604;
  t274_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t274_n185;
  t274_n184: return 0.021726883947849274;
  t274_n185: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t274_n195;
  t274_n186: if (E.getNumReferences() >= 3289677824 /*594.0*/) goto t274_n194;
  t274_n187: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t274_n193;
  t274_n188: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t274_n190;
  t274_n189: return -0.15515990555286407;
  t274_n190: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t274_n192;
  t274_n191: return 0.10188545286655426;
  t274_n192: return 0.02985912188887596;
  t274_n193: return 0.11490967869758606;
  t274_n194: return 0.10546955466270447;
  t274_n195: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n205;
  t274_n196: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t274_n198;
  t274_n197: return -0.06709950417280197;
  t274_n198: if (E.getNumReferences() >= 3297423360 /*1109.5*/) goto t274_n202;
  t274_n199: if (E.getNumReferences() >= 3292889088 /*790.0*/) goto t274_n201;
  t274_n200: return 0.06956489384174347;
  t274_n201: return 0.10668207705020905;
  t274_n202: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t274_n204;
  t274_n203: return -0.4154883325099945;
  t274_n204: return 0.07684171199798584;
  t274_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t274_n207;
  t274_n206: return 0.08683925867080688;
  t274_n207: return 0.016123943030834198;
  t274_n208: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t274_n210;
  t274_n209: return -0.0007037675241008401;
  t274_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t274_n212;
  t274_n211: return 0.004664168227463961;
  t274_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t274_n254;
  t274_n213: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t274_n219;
  t274_n214: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t274_n216;
  t274_n215: return -0.09436514228582382;
  t274_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t274_n218;
  t274_n217: return -0.1510152518749237;
  t274_n218: return 0.12522973120212555;
  t274_n219: if (E.getNumReferences() >= 3286712320 /*462.5*/) goto t274_n221;
  t274_n220: return 0.09039585292339325;
  t274_n221: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t274_n225;
  t274_n222: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t274_n224;
  t274_n223: return 0.014905460178852081;
  t274_n224: return 0.08665014803409576;
  t274_n225: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t274_n253;
  t274_n226: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t274_n252;
  t274_n227: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t274_n251;
  t274_n228: if (E.getNumReferences() >= 3299819520 /*1402.0*/) goto t274_n248;
  t274_n229: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t274_n231;
  t274_n230: return -0.053078893572092056;
  t274_n231: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t274_n233;
  t274_n232: return 0.04102148488163948;
  t274_n233: if (E.getNumReferences() >= 3291422720 /*700.5*/) goto t274_n235;
  t274_n234: return 0.0114559605717659;
  t274_n235: if (E.getNumReferences() >= 3292069888 /*740.0*/) goto t274_n237;
  t274_n236: return 0.10972021520137787;
  t274_n237: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t274_n247;
  t274_n238: if (E.getNumReferences() >= 3292553216 /*769.5*/) goto t274_n240;
  t274_n239: return 0.006627675611525774;
  t274_n240: if (E.getNumReferences() >= 3296256000 /*995.5*/) goto t274_n244;
  t274_n241: if (E.getNumReferences() >= 3293970432 /*856.0*/) goto t274_n243;
  t274_n242: return 0.12347692251205444;
  t274_n243: return 0.1762036234140396;
  t274_n244: if (E.getNumReferences() >= 3298041856 /*1185.0*/) goto t274_n246;
  t274_n245: return -0.07242642343044281;
  t274_n246: return 0.09745687246322632;
  t274_n247: return 0.047273870557546616;
  t274_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t274_n250;
  t274_n249: return -0.09569644927978516;
  t274_n250: return 0.11578826606273651;
  t274_n251: return 0.022681105881929398;
  t274_n252: return 0.003968062344938517;
  t274_n253: return 0.005084900185465813;
  t274_n254: return 0.1065460592508316;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree275(const Example& E) {
  t275_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t275_n2;
  t275_n1: return -0.0008722601924091578;
  t275_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t275_n254;
  t275_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t275_n101;
  t275_n4: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t275_n58;
  t275_n5: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n29;
  t275_n6: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t275_n10;
  t275_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t275_n9;
  t275_n8: return -0.008663583546876907;
  t275_n9: return -0.047370120882987976;
  t275_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t275_n12;
  t275_n11: return -0.0020269076339900494;
  t275_n12: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n28;
  t275_n13: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t275_n15;
  t275_n14: return 0.03154369816184044;
  t275_n15: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t275_n17;
  t275_n16: return -0.016758600249886513;
  t275_n17: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t275_n19;
  t275_n18: return 0.10127152502536774;
  t275_n19: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t275_n23;
  t275_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t275_n22;
  t275_n21: return 0.08830726891756058;
  t275_n22: return 0.09962349385023117;
  t275_n23: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n25;
  t275_n24: return 0.04499959200620651;
  t275_n25: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t275_n27;
  t275_n26: return 0.045987486839294434;
  t275_n27: return 0.146021768450737;
  t275_n28: return -0.006261436268687248;
  t275_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t275_n31;
  t275_n30: return -0.05167798697948456;
  t275_n31: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t275_n33;
  t275_n32: return -0.013474998064339161;
  t275_n33: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t275_n55;
  t275_n34: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Function))) goto t275_n36;
  t275_n35: return -0.018524151295423508;
  t275_n36: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t275_n52;
  t275_n37: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t275_n47;
  t275_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n46;
  t275_n39: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t275_n41;
  t275_n40: return 0.14523963630199432;
  t275_n41: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t275_n45;
  t275_n42: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n44;
  t275_n43: return -0.2835027873516083;
  t275_n44: return 0.0943041443824768;
  t275_n45: return -0.05267103761434555;
  t275_n46: return -0.0029191740322858095;
  t275_n47: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n51;
  t275_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n50;
  t275_n49: return 0.11555762588977814;
  t275_n50: return 0.17253223061561584;
  t275_n51: return 0.08421199768781662;
  t275_n52: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n54;
  t275_n53: return 0.037993814796209335;
  t275_n54: return -0.0008709885296411812;
  t275_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t275_n57;
  t275_n56: return -0.07846345007419586;
  t275_n57: return 0.004556549247354269;
  t275_n58: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t275_n86;
  t275_n59: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n61;
  t275_n60: return -0.005107522010803223;
  t275_n61: if (E.getNumReferences() >= 3363951184 /*265874.5*/) goto t275_n85;
  t275_n62: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t275_n84;
  t275_n63: if (E.getNumReferences() >= 3278602240 /*235.5*/) goto t275_n81;
  t275_n64: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n80;
  t275_n65: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t275_n79;
  t275_n66: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t275_n76;
  t275_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n75;
  t275_n68: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t275_n74;
  t275_n69: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t275_n73;
  t275_n70: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t275_n72;
  t275_n71: return 0.07645659893751144;
  t275_n72: return 0.09063903987407684;
  t275_n73: return -0.010063815861940384;
  t275_n74: return 0.0400347039103508;
  t275_n75: return -0.0687028244137764;
  t275_n76: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t275_n78;
  t275_n77: return 0.08716040849685669;
  t275_n78: return -0.12668852508068085;
  t275_n79: return -0.019646788015961647;
  t275_n80: return 0.005008689593523741;
  t275_n81: if (E.getNumReferences() >= 3280486400 /*272.5*/) goto t275_n83;
  t275_n82: return 0.12059945613145828;
  t275_n83: return 0.034664954990148544;
  t275_n84: return 0.0056219156831502914;
  t275_n85: return 0.04521685093641281;
  t275_n86: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t275_n100;
  t275_n87: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t275_n89;
  t275_n88: return 0.09012136608362198;
  t275_n89: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t275_n91;
  t275_n90: return -0.0058025033213198185;
  t275_n91: if (E.getNumReferences() >= 3352044608 /*104520.5*/) goto t275_n99;
  t275_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n98;
  t275_n93: if (E.getNumReferences() >= 3328268288 /*14422.0*/) goto t275_n97;
  t275_n94: if (E.getNumReferences() >= 3286122496 /*444.5*/) goto t275_n96;
  t275_n95: return 0.09408626705408096;
  t275_n96: return -0.09007740765810013;
  t275_n97: return 0.09637477248907089;
  t275_n98: return 0.008084351196885109;
  t275_n99: return 0.018687045201659203;
  t275_n100: return 0.10605646669864655;
  t275_n101: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t275_n107;
  t275_n102: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t275_n106;
  t275_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n105;
  t275_n104: return 0.11599228531122208;
  t275_n105: return -0.005865557584911585;
  t275_n106: return -0.11258076876401901;
  t275_n107: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t275_n253;
  t275_n108: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t275_n110;
  t275_n109: return -0.09162381291389465;
  t275_n110: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t275_n132;
  t275_n111: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t275_n131;
  t275_n112: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t275_n116;
  t275_n113: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n115;
  t275_n114: return 0.02536049671471119;
  t275_n115: return -0.7156781554222107;
  t275_n116: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n122;
  t275_n117: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n121;
  t275_n118: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t275_n120;
  t275_n119: return 0.09407306462526321;
  t275_n120: return -0.09522237628698349;
  t275_n121: return 0.037848662585020065;
  t275_n122: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t275_n128;
  t275_n123: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t275_n125;
  t275_n124: return -0.031044354662299156;
  t275_n125: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t275_n127;
  t275_n126: return 0.04601030796766281;
  t275_n127: return -0.13223804533481598;
  t275_n128: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t275_n130;
  t275_n129: return 0.10476183146238327;
  t275_n130: return 0.003144137328490615;
  t275_n131: return -0.07529082149267197;
  t275_n132: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t275_n142;
  t275_n133: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n141;
  t275_n134: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t275_n136;
  t275_n135: return 0.02270866185426712;
  t275_n136: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t275_n138;
  t275_n137: return -0.1012941300868988;
  t275_n138: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t275_n140;
  t275_n139: return 0.06824079155921936;
  t275_n140: return -0.07915277034044266;
  t275_n141: return 0.0035976364742964506;
  t275_n142: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t275_n144;
  t275_n143: return -0.0017296049045398831;
  t275_n144: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t275_n232;
  t275_n145: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t275_n231;
  t275_n146: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t275_n228;
  t275_n147: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t275_n205;
  t275_n148: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t275_n176;
  t275_n149: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t275_n175;
  t275_n150: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t275_n160;
  t275_n151: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n157;
  t275_n152: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t275_n156;
  t275_n153: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t275_n155;
  t275_n154: return 0.10862696170806885;
  t275_n155: return 0.11138025671243668;
  t275_n156: return -0.15992499887943268;
  t275_n157: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t275_n159;
  t275_n158: return 0.01820412091910839;
  t275_n159: return 0.4351242482662201;
  t275_n160: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n170;
  t275_n161: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t275_n163;
  t275_n162: return 0.06381212919950485;
  t275_n163: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t275_n169;
  t275_n164: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t275_n168;
  t275_n165: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t275_n167;
  t275_n166: return 0.06443388015031815;
  t275_n167: return 0.11222435534000397;
  t275_n168: return 0.10452774167060852;
  t275_n169: return -0.07500752061605453;
  t275_n170: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t275_n172;
  t275_n171: return 0.08865290135145187;
  t275_n172: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t275_n174;
  t275_n173: return 0.11314556747674942;
  t275_n174: return -0.06215394660830498;
  t275_n175: return 0.02374875918030739;
  t275_n176: if (E.getNumReferences() >= 3270705152 /*121.5*/) goto t275_n182;
  t275_n177: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t275_n179;
  t275_n178: return -0.0434330478310585;
  t275_n179: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t275_n181;
  t275_n180: return 0.13269400596618652;
  t275_n181: return -0.0015244574751704931;
  t275_n182: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t275_n188;
  t275_n183: if (E.getNumReferences() >= 3271655424 /*129.5*/) goto t275_n187;
  t275_n184: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t275_n186;
  t275_n185: return -0.30553948879241943;
  t275_n186: return 0.10670294612646103;
  t275_n187: return 0.11332403868436813;
  t275_n188: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t275_n190;
  t275_n189: return -0.060239527374506;
  t275_n190: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t275_n204;
  t275_n191: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t275_n193;
  t275_n192: return -0.19659768044948578;
  t275_n193: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t275_n201;
  t275_n194: if (E.getNumReferences() >= 3277324288 /*216.0*/) goto t275_n200;
  t275_n195: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n199;
  t275_n196: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t275_n198;
  t275_n197: return 0.1160767674446106;
  t275_n198: return 0.03374063968658447;
  t275_n199: return 0.040521398186683655;
  t275_n200: return 0.12691707909107208;
  t275_n201: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t275_n203;
  t275_n202: return 0.09311804920434952;
  t275_n203: return 0.013689029030501842;
  t275_n204: return -0.7233436107635498;
  t275_n205: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t275_n225;
  t275_n206: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t275_n218;
  t275_n207: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t275_n217;
  t275_n208: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n216;
  t275_n209: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t275_n215;
  t275_n210: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t275_n214;
  t275_n211: if (E.getFilterLength() >= 3221225472 /*2.0*/) goto t275_n213;
  t275_n212: return 0.4249661862850189;
  t275_n213: return 0.15138623118400574;
  t275_n214: return -0.10099916905164719;
  t275_n215: return -0.10516338795423508;
  t275_n216: return 0.11067048460245132;
  t275_n217: return -0.11863266676664352;
  t275_n218: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t275_n220;
  t275_n219: return 0.10855823010206223;
  t275_n220: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t275_n222;
  t275_n221: return 0.047502052038908005;
  t275_n222: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t275_n224;
  t275_n223: return -0.6311695575714111;
  t275_n224: return 0.11465905606746674;
  t275_n225: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t275_n227;
  t275_n226: return -0.0040567428804934025;
  t275_n227: return -0.9014007449150085;
  t275_n228: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t275_n230;
  t275_n229: return -0.11935442686080933;
  t275_n230: return 0.11028289794921875;
  t275_n231: return -0.07176971435546875;
  t275_n232: if (E.getNumReferences() >= 3251896320 /*26.5*/) goto t275_n242;
  t275_n233: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t275_n241;
  t275_n234: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t275_n240;
  t275_n235: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t275_n237;
  t275_n236: return -0.06745336204767227;
  t275_n237: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t275_n239;
  t275_n238: return 0.16501787304878235;
  t275_n239: return 0.09229850769042969;
  t275_n240: return -0.36736860871315;
  t275_n241: return -0.1700281798839569;
  t275_n242: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t275_n252;
  t275_n243: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t275_n247;
  t275_n244: if (E.getNumReferences() >= 3261595648 /*58.0*/) goto t275_n246;
  t275_n245: return -0.2984693944454193;
  t275_n246: return 0.08501418679952621;
  t275_n247: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t275_n249;
  t275_n248: return 0.11048675328493118;
  t275_n249: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t275_n251;
  t275_n250: return 0.11604470014572144;
  t275_n251: return -0.21796652674674988;
  t275_n252: return -0.14478494226932526;
  t275_n253: return 0.02250482514500618;
  t275_n254: return 0.002231793710961938;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree276(const Example& E) {
  t276_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t276_n2;
  t276_n1: return -0.0008145553874783218;
  t276_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t276_n254;
  t276_n3: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t276_n97;
  t276_n4: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t276_n32;
  t276_n5: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t276_n17;
  t276_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n10;
  t276_n7: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t276_n9;
  t276_n8: return 0.09254157543182373;
  t276_n9: return -0.568488597869873;
  t276_n10: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n14;
  t276_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n13;
  t276_n12: return -0.13387079536914825;
  t276_n13: return 0.06771028786897659;
  t276_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n16;
  t276_n15: return -0.08661295473575592;
  t276_n16: return 0.05034294351935387;
  t276_n17: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t276_n27;
  t276_n18: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n22;
  t276_n19: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t276_n21;
  t276_n20: return -0.022226279601454735;
  t276_n21: return -0.44313979148864746;
  t276_n22: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t276_n26;
  t276_n23: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t276_n25;
  t276_n24: return -0.3222096264362335;
  t276_n25: return 0.11247611790895462;
  t276_n26: return -0.11332527548074722;
  t276_n27: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t276_n31;
  t276_n28: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n30;
  t276_n29: return 0.1595979630947113;
  t276_n30: return 0.03062356449663639;
  t276_n31: return -0.0018395435763522983;
  t276_n32: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t276_n34;
  t276_n33: return 0.000948573462665081;
  t276_n34: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t276_n78;
  t276_n35: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t276_n45;
  t276_n36: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t276_n38;
  t276_n37: return 0.0002136744005838409;
  t276_n38: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t276_n44;
  t276_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n43;
  t276_n40: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n42;
  t276_n41: return -0.9506571292877197;
  t276_n42: return -0.33095210790634155;
  t276_n43: return 0.1633283942937851;
  t276_n44: return -0.06493102759122849;
  t276_n45: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t276_n47;
  t276_n46: return -0.0844401940703392;
  t276_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t276_n77;
  t276_n48: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n50;
  t276_n49: return -0.011761737987399101;
  t276_n50: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t276_n72;
  t276_n51: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t276_n55;
  t276_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n54;
  t276_n53: return 0.07154294103384018;
  t276_n54: return 0.009901142679154873;
  t276_n55: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t276_n65;
  t276_n56: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t276_n58;
  t276_n57: return 0.016924137249588966;
  t276_n58: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t276_n64;
  t276_n59: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t276_n61;
  t276_n60: return 0.13333268463611603;
  t276_n61: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t276_n63;
  t276_n62: return -0.5302838087081909;
  t276_n63: return 0.047753434628248215;
  t276_n64: return 0.13352929055690765;
  t276_n65: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n69;
  t276_n66: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t276_n68;
  t276_n67: return 0.12388481944799423;
  t276_n68: return 0.11050965636968613;
  t276_n69: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t276_n71;
  t276_n70: return 0.11945166438817978;
  t276_n71: return 0.04941356182098389;
  t276_n72: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t276_n74;
  t276_n73: return -0.009173017926514149;
  t276_n74: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t276_n76;
  t276_n75: return -0.025244932621717453;
  t276_n76: return 0.045596279203891754;
  t276_n77: return -0.00632650637999177;
  t276_n78: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t276_n82;
  t276_n79: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t276_n81;
  t276_n80: return -0.0034023935440927744;
  t276_n81: return -0.10912660509347916;
  t276_n82: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t276_n96;
  t276_n83: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t276_n85;
  t276_n84: return 0.009951922111213207;
  t276_n85: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n95;
  t276_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t276_n94;
  t276_n87: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t276_n91;
  t276_n88: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t276_n90;
  t276_n89: return 0.09377508610486984;
  t276_n90: return 0.08194159716367722;
  t276_n91: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t276_n93;
  t276_n92: return 0.12663032114505768;
  t276_n93: return -0.017725767567753792;
  t276_n94: return 0.05299096181988716;
  t276_n95: return 0.06244586035609245;
  t276_n96: return 0.004561457317322493;
  t276_n97: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t276_n173;
  t276_n98: if (E.getNumReferences() >= 3364597360 /*286067.5*/) goto t276_n160;
  t276_n99: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t276_n139;
  t276_n100: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t276_n102;
  t276_n101: return -0.0014812814770266414;
  t276_n102: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t276_n110;
  t276_n103: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t276_n105;
  t276_n104: return -0.04611366614699364;
  t276_n105: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t276_n109;
  t276_n106: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t276_n108;
  t276_n107: return 0.10052650421857834;
  t276_n108: return -0.10134756565093994;
  t276_n109: return 0.004307464696466923;
  t276_n110: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t276_n114;
  t276_n111: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t276_n113;
  t276_n112: return -0.004769459832459688;
  t276_n113: return -0.08493735641241074;
  t276_n114: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t276_n122;
  t276_n115: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n117;
  t276_n116: return -0.2744795083999634;
  t276_n117: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t276_n119;
  t276_n118: return -0.04199528321623802;
  t276_n119: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t276_n121;
  t276_n120: return 0.13132813572883606;
  t276_n121: return -0.21182721853256226;
  t276_n122: if (E.getNumReferences() >= 3251372032 /*25.5*/) goto t276_n126;
  t276_n123: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t276_n125;
  t276_n124: return 0.10543529689311981;
  t276_n125: return -0.037685416638851166;
  t276_n126: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t276_n136;
  t276_n127: if (E.getNumReferences() >= 3259760640 /*51.0*/) goto t276_n133;
  t276_n128: if (E.getNumReferences() >= 3254910976 /*32.5*/) goto t276_n132;
  t276_n129: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n131;
  t276_n130: return 0.010238615795969963;
  t276_n131: return 0.11535916477441788;
  t276_n132: return -0.041779737919569016;
  t276_n133: if (E.getNumReferences() >= 3260940288 /*55.5*/) goto t276_n135;
  t276_n134: return 0.1129855290055275;
  t276_n135: return 0.045268114656209946;
  t276_n136: if (E.getNumReferences() >= 3283222528 /*356.0*/) goto t276_n138;
  t276_n137: return 0.09476260840892792;
  t276_n138: return -0.04411202669143677;
  t276_n139: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t276_n149;
  t276_n140: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t276_n148;
  t276_n141: if (E.getNumReferences() >= 3298136064 /*1196.5*/) goto t276_n147;
  t276_n142: if (E.getNumReferences() >= 3298004992 /*1180.5*/) goto t276_n144;
  t276_n143: return 0.014901559799909592;
  t276_n144: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t276_n146;
  t276_n145: return 0.05071108788251877;
  t276_n146: return 0.21760733425617218;
  t276_n147: return -0.020383575931191444;
  t276_n148: return 0.020402662456035614;
  t276_n149: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t276_n153;
  t276_n150: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t276_n152;
  t276_n151: return -0.009219027124345303;
  t276_n152: return 0.11266562342643738;
  t276_n153: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t276_n155;
  t276_n154: return -0.11545895040035248;
  t276_n155: if (E.getNumReferences() >= 3303305216 /*1827.5*/) goto t276_n157;
  t276_n156: return -0.025262773036956787;
  t276_n157: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t276_n159;
  t276_n158: return -0.47082167863845825;
  t276_n159: return 0.10628953576087952;
  t276_n160: if (E.getNumReferences() >= 3364952880 /*297177.5*/) goto t276_n170;
  t276_n161: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n167;
  t276_n162: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t276_n164;
  t276_n163: return 0.009217003360390663;
  t276_n164: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t276_n166;
  t276_n165: return 0.09093209356069565;
  t276_n166: return 0.05771917849779129;
  t276_n167: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n169;
  t276_n168: return -0.08506546169519424;
  t276_n169: return 0.035114310681819916;
  t276_n170: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t276_n172;
  t276_n171: return -0.03034280054271221;
  t276_n172: return 0.06167708337306976;
  t276_n173: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t276_n231;
  t276_n174: if (E.getNumReferences() >= 3247177728 /*17.5*/) goto t276_n204;
  t276_n175: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t276_n183;
  t276_n176: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t276_n178;
  t276_n177: return 0.022505803033709526;
  t276_n178: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n180;
  t276_n179: return -0.23944847285747528;
  t276_n180: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t276_n182;
  t276_n181: return -0.0400911383330822;
  t276_n182: return 0.03421967476606369;
  t276_n183: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t276_n185;
  t276_n184: return -0.00870082713663578;
  t276_n185: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n203;
  t276_n186: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t276_n202;
  t276_n187: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n201;
  t276_n188: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t276_n196;
  t276_n189: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t276_n191;
  t276_n190: return 0.11486293375492096;
  t276_n191: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n193;
  t276_n192: return -0.10487306118011475;
  t276_n193: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t276_n195;
  t276_n194: return 0.025673897936940193;
  t276_n195: return 0.11352366954088211;
  t276_n196: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t276_n198;
  t276_n197: return -0.26029884815216064;
  t276_n198: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t276_n200;
  t276_n199: return 0.11694282293319702;
  t276_n200: return 0.22467753291130066;
  t276_n201: return -0.1283019632101059;
  t276_n202: return -0.08124514669179916;
  t276_n203: return 0.03596383333206177;
  t276_n204: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t276_n224;
  t276_n205: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t276_n215;
  t276_n206: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t276_n214;
  t276_n207: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t276_n209;
  t276_n208: return -0.08327562361955643;
  t276_n209: if (E.getNumReferences() >= 3255173120 /*33.5*/) goto t276_n211;
  t276_n210: return -0.27566131949424744;
  t276_n211: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t276_n213;
  t276_n212: return 0.10910122096538544;
  t276_n213: return -0.36417892575263977;
  t276_n214: return -0.01623273268342018;
  t276_n215: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t276_n217;
  t276_n216: return 0.009580983780324459;
  t276_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n223;
  t276_n218: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t276_n222;
  t276_n219: if (E.getNumReferences() >= 3255828480 /*36.0*/) goto t276_n221;
  t276_n220: return -0.4561728239059448;
  t276_n221: return 0.11236035078763962;
  t276_n222: return 0.10166065394878387;
  t276_n223: return -0.0763779729604721;
  t276_n224: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t276_n230;
  t276_n225: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t276_n227;
  t276_n226: return -0.17645609378814697;
  t276_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t276_n229;
  t276_n228: return 0.1155596524477005;
  t276_n229: return -0.13412757217884064;
  t276_n230: return 0.010755171068012714;
  t276_n231: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t276_n235;
  t276_n232: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n234;
  t276_n233: return -0.007967577315866947;
  t276_n234: return 0.011455468833446503;
  t276_n235: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t276_n253;
  t276_n236: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t276_n238;
  t276_n237: return 0.10206539928913116;
  t276_n238: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t276_n250;
  t276_n239: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t276_n249;
  t276_n240: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t276_n246;
  t276_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t276_n245;
  t276_n242: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t276_n244;
  t276_n243: return -0.2014504224061966;
  t276_n244: return 0.10624305158853531;
  t276_n245: return -0.07621145993471146;
  t276_n246: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t276_n248;
  t276_n247: return 0.11326075345277786;
  t276_n248: return 0.07792454212903976;
  t276_n249: return -0.0626896545290947;
  t276_n250: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t276_n252;
  t276_n251: return -0.026279151439666748;
  t276_n252: return 0.10984189063310623;
  t276_n253: return 0.012021641246974468;
  t276_n254: return 0.0023225729819387197;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree277(const Example& E) {
  t277_n0: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t277_n252;
  t277_n1: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t277_n3;
  t277_n2: return -2.4026456230785698e-05;
  t277_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t277_n29;
  t277_n4: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t277_n20;
  t277_n5: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t277_n13;
  t277_n6: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t277_n10;
  t277_n7: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t277_n9;
  t277_n8: return -0.019127285107970238;
  t277_n9: return 0.08167087286710739;
  t277_n10: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n12;
  t277_n11: return -0.0859576016664505;
  t277_n12: return 0.04395516961812973;
  t277_n13: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n15;
  t277_n14: return -0.18170765042304993;
  t277_n15: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t277_n19;
  t277_n16: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t277_n18;
  t277_n17: return -0.12895174324512482;
  t277_n18: return -0.11364448070526123;
  t277_n19: return -0.001933826133608818;
  t277_n20: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t277_n22;
  t277_n21: return 0.10331084579229355;
  t277_n22: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t277_n24;
  t277_n23: return -0.0007746167830191553;
  t277_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n26;
  t277_n25: return -0.07154730707406998;
  t277_n26: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n28;
  t277_n27: return 0.0631183311343193;
  t277_n28: return -0.07234769314527512;
  t277_n29: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t277_n251;
  t277_n30: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t277_n248;
  t277_n31: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t277_n241;
  t277_n32: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t277_n124;
  t277_n33: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t277_n35;
  t277_n34: return 0.020581314340233803;
  t277_n35: if (E.getNumReferences() >= 3242721280 /*12.5*/) goto t277_n109;
  t277_n36: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t277_n62;
  t277_n37: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t277_n41;
  t277_n38: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t277_n40;
  t277_n39: return -0.007858586497604847;
  t277_n40: return -0.05109884962439537;
  t277_n41: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t277_n53;
  t277_n42: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n48;
  t277_n43: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n45;
  t277_n44: return -0.004184836987406015;
  t277_n45: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n47;
  t277_n46: return 0.14172956347465515;
  t277_n47: return 0.029200134798884392;
  t277_n48: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n52;
  t277_n49: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t277_n51;
  t277_n50: return -0.3230268359184265;
  t277_n51: return 0.1367480605840683;
  t277_n52: return -0.016394976526498795;
  t277_n53: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n57;
  t277_n54: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t277_n56;
  t277_n55: return 0.11156845092773438;
  t277_n56: return 0.0889589935541153;
  t277_n57: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t277_n61;
  t277_n58: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t277_n60;
  t277_n59: return 0.10703549534082413;
  t277_n60: return -0.12077067792415619;
  t277_n61: return -0.07284963876008987;
  t277_n62: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t277_n80;
  t277_n63: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t277_n75;
  t277_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t277_n66;
  t277_n65: return 0.03496309369802475;
  t277_n66: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t277_n68;
  t277_n67: return -0.0965641513466835;
  t277_n68: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t277_n74;
  t277_n69: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t277_n71;
  t277_n70: return 0.0179100651293993;
  t277_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n73;
  t277_n72: return 0.010525195859372616;
  t277_n73: return 0.18215247988700867;
  t277_n74: return 0.08789321035146713;
  t277_n75: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t277_n79;
  t277_n76: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n78;
  t277_n77: return 0.15267761051654816;
  t277_n78: return 0.14861907064914703;
  t277_n79: return 0.0065987748093903065;
  t277_n80: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n82;
  t277_n81: return -0.15007257461547852;
  t277_n82: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t277_n108;
  t277_n83: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t277_n105;
  t277_n84: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t277_n92;
  t277_n85: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t277_n87;
  t277_n86: return 0.0015976623399183154;
  t277_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t277_n89;
  t277_n88: return -0.10795020312070847;
  t277_n89: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t277_n91;
  t277_n90: return 0.12019115686416626;
  t277_n91: return -0.4050194025039673;
  t277_n92: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t277_n104;
  t277_n93: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t277_n101;
  t277_n94: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n98;
  t277_n95: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n97;
  t277_n96: return -0.6340553760528564;
  t277_n97: return 0.08949548751115799;
  t277_n98: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n100;
  t277_n99: return 0.1402163803577423;
  t277_n100: return 0.016808252781629562;
  t277_n101: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n103;
  t277_n102: return 0.07903818786144257;
  t277_n103: return -0.12486311048269272;
  t277_n104: return -0.020631110295653343;
  t277_n105: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t277_n107;
  t277_n106: return -0.19403177499771118;
  t277_n107: return 0.04772607609629631;
  t277_n108: return 0.053861103951931;
  t277_n109: if (E.getNumReferences() >= 3243769856 /*13.5*/) goto t277_n113;
  t277_n110: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n112;
  t277_n111: return -0.30428245663642883;
  t277_n112: return 0.11050862073898315;
  t277_n113: if (E.getNumReferences() >= 3293675520 /*838.0*/) goto t277_n119;
  t277_n114: if (E.getNumReferences() >= 3291987968 /*735.0*/) goto t277_n118;
  t277_n115: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t277_n117;
  t277_n116: return -0.05789916589856148;
  t277_n117: return 0.028061265125870705;
  t277_n118: return 0.08889203518629074;
  t277_n119: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t277_n123;
  t277_n120: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t277_n122;
  t277_n121: return -0.33596494793891907;
  t277_n122: return 0.05269069969654083;
  t277_n123: return -0.013300331309437752;
  t277_n124: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t277_n136;
  t277_n125: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n133;
  t277_n126: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t277_n132;
  t277_n127: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t277_n131;
  t277_n128: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n130;
  t277_n129: return -0.05812111124396324;
  t277_n130: return 0.009404129348695278;
  t277_n131: return 0.023849720135331154;
  t277_n132: return 0.1409132033586502;
  t277_n133: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t277_n135;
  t277_n134: return -0.03519997000694275;
  t277_n135: return -0.29445481300354004;
  t277_n136: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t277_n186;
  t277_n137: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t277_n147;
  t277_n138: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n144;
  t277_n139: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t277_n143;
  t277_n140: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t277_n142;
  t277_n141: return -0.0281053576618433;
  t277_n142: return -0.08390699326992035;
  t277_n143: return 0.006180633790791035;
  t277_n144: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t277_n146;
  t277_n145: return 0.0026562537532299757;
  t277_n146: return -0.10415098816156387;
  t277_n147: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t277_n153;
  t277_n148: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n152;
  t277_n149: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t277_n151;
  t277_n150: return 0.10429756343364716;
  t277_n151: return -0.11956058442592621;
  t277_n152: return -0.15207135677337646;
  t277_n153: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t277_n179;
  t277_n154: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n166;
  t277_n155: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t277_n159;
  t277_n156: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t277_n158;
  t277_n157: return -0.10130380094051361;
  t277_n158: return -0.46254271268844604;
  t277_n159: if (E.getNumReferences() >= 3246653440 /*16.5*/) goto t277_n165;
  t277_n160: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t277_n162;
  t277_n161: return 0.0;
  t277_n162: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t277_n164;
  t277_n163: return 0.0973525419831276;
  t277_n164: return -0.05910249799489975;
  t277_n165: return 0.024800816550850868;
  t277_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t277_n170;
  t277_n167: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t277_n169;
  t277_n168: return 0.06696678698062897;
  t277_n169: return 0.3085139989852905;
  t277_n170: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t277_n176;
  t277_n171: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t277_n175;
  t277_n172: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n174;
  t277_n173: return -0.10121184587478638;
  t277_n174: return 0.10034927725791931;
  t277_n175: return 0.11460010707378387;
  t277_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n178;
  t277_n177: return -0.505709707736969;
  t277_n178: return 0.1666792780160904;
  t277_n179: if (E.getNumReferences() >= 3301568512 /*1615.5*/) goto t277_n181;
  t277_n180: return -0.04031198099255562;
  t277_n181: if (E.getNumReferences() >= 3301761024 /*1639.0*/) goto t277_n185;
  t277_n182: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t277_n184;
  t277_n183: return 0.19545257091522217;
  t277_n184: return -0.03496947139501572;
  t277_n185: return 0.0356200747191906;
  t277_n186: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t277_n192;
  t277_n187: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t277_n189;
  t277_n188: return 0.005557127296924591;
  t277_n189: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t277_n191;
  t277_n190: return -0.031324855983257294;
  t277_n191: return 0.1300443708896637;
  t277_n192: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t277_n204;
  t277_n193: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t277_n197;
  t277_n194: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t277_n196;
  t277_n195: return -0.3596130907535553;
  t277_n196: return -0.4932118058204651;
  t277_n197: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t277_n199;
  t277_n198: return 0.05478818342089653;
  t277_n199: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t277_n201;
  t277_n200: return 0.021915633231401443;
  t277_n201: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t277_n203;
  t277_n202: return -0.114412322640419;
  t277_n203: return 0.08576854318380356;
  t277_n204: if (E.getNumReferences() >= 3270115328 /*117.0*/) goto t277_n230;
  t277_n205: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t277_n229;
  t277_n206: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t277_n216;
  t277_n207: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t277_n215;
  t277_n208: if (E.getNumReferences() >= 3255959552 /*36.5*/) goto t277_n214;
  t277_n209: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t277_n213;
  t277_n210: if (E.getNumReferences() >= 3250847744 /*24.5*/) goto t277_n212;
  t277_n211: return -0.3590363562107086;
  t277_n212: return -0.9596304893493652;
  t277_n213: return -0.06697729974985123;
  t277_n214: return 0.010264805518090725;
  t277_n215: return -0.056049346923828125;
  t277_n216: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t277_n218;
  t277_n217: return -0.060561783611774445;
  t277_n218: if (E.getNumReferences() >= 3250323456 /*23.5*/) goto t277_n224;
  t277_n219: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t277_n221;
  t277_n220: return -0.047572407871484756;
  t277_n221: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t277_n223;
  t277_n222: return -0.11462529748678207;
  t277_n223: return 0.10930949449539185;
  t277_n224: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t277_n226;
  t277_n225: return 0.10212986916303635;
  t277_n226: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t277_n228;
  t277_n227: return -0.2931008040904999;
  t277_n228: return 0.0916864201426506;
  t277_n229: return -0.6947469711303711;
  t277_n230: if (E.getNumReferences() >= 3282960384 /*348.0*/) goto t277_n240;
  t277_n231: if (E.getNumReferences() >= 3281829888 /*313.5*/) goto t277_n239;
  t277_n232: if (E.getNumReferences() >= 3278209024 /*229.5*/) goto t277_n238;
  t277_n233: if (E.getNumReferences() >= 3274997760 /*180.5*/) goto t277_n237;
  t277_n234: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t277_n236;
  t277_n235: return 0.09538327902555466;
  t277_n236: return -0.15063126385211945;
  t277_n237: return 0.11651613563299179;
  t277_n238: return -0.02316010184586048;
  t277_n239: return 0.09407202899456024;
  t277_n240: return -0.018603401258587837;
  t277_n241: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t277_n247;
  t277_n242: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t277_n244;
  t277_n243: return 0.04633164778351784;
  t277_n244: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t277_n246;
  t277_n245: return 0.10419701784849167;
  t277_n246: return -0.20093318819999695;
  t277_n247: return 0.012158913537859917;
  t277_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t277_n250;
  t277_n249: return -0.10573960840702057;
  t277_n250: return 0.007717037573456764;
  t277_n251: return -0.00010794147237902507;
  t277_n252: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t277_n254;
  t277_n253: return -0.11297336220741272;
  t277_n254: return -0.06378210335969925;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree278(const Example& E) {
  t278_n0: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t278_n250;
  t278_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t278_n95;
  t278_n2: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t278_n94;
  t278_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t278_n39;
  t278_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t278_n6;
  t278_n5: return 0.006579677574336529;
  t278_n6: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t278_n36;
  t278_n7: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t278_n11;
  t278_n8: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t278_n10;
  t278_n9: return 0.026580005884170532;
  t278_n10: return -0.07025980949401855;
  t278_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n23;
  t278_n12: if (E.getNumReferences() >= 3234856960 /*6.5*/) goto t278_n22;
  t278_n13: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t278_n17;
  t278_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n16;
  t278_n15: return -0.0066936686635017395;
  t278_n16: return 0.07400637120008469;
  t278_n17: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t278_n19;
  t278_n18: return 0.05557025969028473;
  t278_n19: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t278_n21;
  t278_n20: return 0.10778338462114334;
  t278_n21: return 0.09238967299461365;
  t278_n22: return 0.023426571860909462;
  t278_n23: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n29;
  t278_n24: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n28;
  t278_n25: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t278_n27;
  t278_n26: return -0.003556353272870183;
  t278_n27: return 0.08835957944393158;
  t278_n28: return -0.21954023838043213;
  t278_n29: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t278_n31;
  t278_n30: return 0.015202966518700123;
  t278_n31: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t278_n35;
  t278_n32: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t278_n34;
  t278_n33: return 0.05423160269856453;
  t278_n34: return 0.1366138607263565;
  t278_n35: return -0.30136480927467346;
  t278_n36: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t278_n38;
  t278_n37: return -0.25438231229782104;
  t278_n38: return 0.11763054877519608;
  t278_n39: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t278_n83;
  t278_n40: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n44;
  t278_n41: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t278_n43;
  t278_n42: return -0.06391981989145279;
  t278_n43: return 0.06255032867193222;
  t278_n44: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n70;
  t278_n45: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t278_n51;
  t278_n46: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t278_n50;
  t278_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t278_n49;
  t278_n48: return -0.40926867723464966;
  t278_n49: return 0.012848610989749432;
  t278_n50: return -0.2588683068752289;
  t278_n51: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t278_n57;
  t278_n52: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t278_n56;
  t278_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n55;
  t278_n54: return -0.3274013102054596;
  t278_n55: return 0.09739644080400467;
  t278_n56: return 0.1255979686975479;
  t278_n57: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n61;
  t278_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t278_n60;
  t278_n59: return -0.26963353157043457;
  t278_n60: return 0.08280761539936066;
  t278_n61: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n67;
  t278_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n64;
  t278_n63: return -0.033642515540122986;
  t278_n64: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n66;
  t278_n65: return 0.08967249095439911;
  t278_n66: return 0.016386142000555992;
  t278_n67: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t278_n69;
  t278_n68: return -0.18699730932712555;
  t278_n69: return 0.04037795588374138;
  t278_n70: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t278_n78;
  t278_n71: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t278_n73;
  t278_n72: return 0.03705926612019539;
  t278_n73: if (E.getNumReferences() >= 3241672704 /*11.5*/) goto t278_n75;
  t278_n74: return 0.07424243539571762;
  t278_n75: if (E.getNumReferences() >= 3251634176 /*26.0*/) goto t278_n77;
  t278_n76: return 0.11924582719802856;
  t278_n77: return -0.1063745990395546;
  t278_n78: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t278_n82;
  t278_n79: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n81;
  t278_n80: return 0.11862460523843765;
  t278_n81: return 0.0825238972902298;
  t278_n82: return 0.034361060708761215;
  t278_n83: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n93;
  t278_n84: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t278_n92;
  t278_n85: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t278_n91;
  t278_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n88;
  t278_n87: return -0.10239730030298233;
  t278_n88: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n90;
  t278_n89: return 0.09877005964517593;
  t278_n90: return 0.10707342624664307;
  t278_n91: return 0.0399295836687088;
  t278_n92: return 0.05084504559636116;
  t278_n93: return 0.04461078345775604;
  t278_n94: return -0.002275702776387334;
  t278_n95: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t278_n175;
  t278_n96: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t278_n166;
  t278_n97: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t278_n107;
  t278_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t278_n102;
  t278_n99: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t278_n101;
  t278_n100: return 0.05478822439908981;
  t278_n101: return -0.21616092324256897;
  t278_n102: if (E.getNumReferences() >= 3243245568 /*13.0*/) goto t278_n106;
  t278_n103: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n105;
  t278_n104: return 0.10778061300516129;
  t278_n105: return 0.03317462280392647;
  t278_n106: return 0.01501523982733488;
  t278_n107: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t278_n155;
  t278_n108: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t278_n148;
  t278_n109: if (E.getSymbolScopeDistance() >= 3243245568 /*13.0*/) goto t278_n125;
  t278_n110: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t278_n118;
  t278_n111: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t278_n113;
  t278_n112: return -0.004975901450961828;
  t278_n113: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t278_n117;
  t278_n114: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n116;
  t278_n115: return -0.23428353667259216;
  t278_n116: return 0.2123987227678299;
  t278_n117: return 0.085941843688488;
  t278_n118: if (E.getNumReferences() >= 3309711360 /*3171.0*/) goto t278_n124;
  t278_n119: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n123;
  t278_n120: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t278_n122;
  t278_n121: return -0.12498242408037186;
  t278_n122: return -0.39826324582099915;
  t278_n123: return -0.022720549255609512;
  t278_n124: return 0.02799614891409874;
  t278_n125: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n131;
  t278_n126: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t278_n128;
  t278_n127: return 0.0629810318350792;
  t278_n128: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n130;
  t278_n129: return 0.10797899961471558;
  t278_n130: return 0.08317450433969498;
  t278_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t278_n137;
  t278_n132: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t278_n134;
  t278_n133: return 0.024648120626807213;
  t278_n134: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n136;
  t278_n135: return -0.5210446715354919;
  t278_n136: return -0.01677219569683075;
  t278_n137: if (E.getNumReferences() >= 3248226304 /*19.5*/) goto t278_n141;
  t278_n138: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n140;
  t278_n139: return -0.3233487010002136;
  t278_n140: return 0.0438089482486248;
  t278_n141: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t278_n143;
  t278_n142: return 0.119831882417202;
  t278_n143: if (E.getNumReferences() >= 3281666048 /*308.5*/) goto t278_n145;
  t278_n144: return -0.14588484168052673;
  t278_n145: if (E.getNumReferences() >= 3332881408 /*21470.0*/) goto t278_n147;
  t278_n146: return 0.11355443298816681;
  t278_n147: return 0.05040978640317917;
  t278_n148: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n150;
  t278_n149: return -0.05858014151453972;
  t278_n150: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t278_n154;
  t278_n151: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t278_n153;
  t278_n152: return -1.5396077632904053;
  t278_n153: return -0.19381938874721527;
  t278_n154: return -0.2044840157032013;
  t278_n155: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n157;
  t278_n156: return -0.038913603872060776;
  t278_n157: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t278_n165;
  t278_n158: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t278_n164;
  t278_n159: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n161;
  t278_n160: return -0.13123507797718048;
  t278_n161: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n163;
  t278_n162: return 0.09906835108995438;
  t278_n163: return 0.018838685005903244;
  t278_n164: return 0.08557764440774918;
  t278_n165: return 0.022593140602111816;
  t278_n166: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n174;
  t278_n167: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t278_n173;
  t278_n168: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n172;
  t278_n169: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t278_n171;
  t278_n170: return -0.14938940107822418;
  t278_n171: return -0.10148649662733078;
  t278_n172: return 0.008581782691180706;
  t278_n173: return -0.018482277169823647;
  t278_n174: return -0.0204616691917181;
  t278_n175: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t278_n235;
  t278_n176: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t278_n234;
  t278_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t278_n179;
  t278_n178: return -0.012829042971134186;
  t278_n179: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t278_n233;
  t278_n180: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t278_n182;
  t278_n181: return 0.00037265062564983964;
  t278_n182: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t278_n200;
  t278_n183: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t278_n185;
  t278_n184: return 0.0033682279754430056;
  t278_n185: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n197;
  t278_n186: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n188;
  t278_n187: return 0.04880242422223091;
  t278_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t278_n196;
  t278_n189: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t278_n195;
  t278_n190: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t278_n194;
  t278_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t278_n193;
  t278_n192: return 0.01110877189785242;
  t278_n193: return 0.1136757954955101;
  t278_n194: return 0.13795356452465057;
  t278_n195: return 0.0382830873131752;
  t278_n196: return 0.04444018006324768;
  t278_n197: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Namespace))) goto t278_n199;
  t278_n198: return 0.007782378233969212;
  t278_n199: return 0.05431767925620079;
  t278_n200: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t278_n216;
  t278_n201: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t278_n215;
  t278_n202: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t278_n208;
  t278_n203: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t278_n207;
  t278_n204: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t278_n206;
  t278_n205: return -0.12641742825508118;
  t278_n206: return 0.019299160689115524;
  t278_n207: return 0.09784293919801712;
  t278_n208: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n210;
  t278_n209: return -0.07543954998254776;
  t278_n210: if (E.getNumReferences() >= 3327834624 /*13998.5*/) goto t278_n214;
  t278_n211: if (E.getFileProximityDistance() >= 3247439872 /*18.0*/) goto t278_n213;
  t278_n212: return 0.11744139343500137;
  t278_n213: return 0.09751220047473907;
  t278_n214: return 0.03399742767214775;
  t278_n215: return -0.0005937851965427399;
  t278_n216: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t278_n232;
  t278_n217: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t278_n219;
  t278_n218: return 0.012826112098991871;
  t278_n219: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t278_n229;
  t278_n220: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t278_n224;
  t278_n221: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t278_n223;
  t278_n222: return 0.1238420382142067;
  t278_n223: return -0.01052157487720251;
  t278_n224: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t278_n228;
  t278_n225: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t278_n227;
  t278_n226: return 0.08712541311979294;
  t278_n227: return 0.20407168567180634;
  t278_n228: return 0.11198756843805313;
  t278_n229: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t278_n231;
  t278_n230: return 0.07680962979793549;
  t278_n231: return 0.10109599679708481;
  t278_n232: return -0.2204572707414627;
  t278_n233: return -0.021252118051052094;
  t278_n234: return -0.007489602081477642;
  t278_n235: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t278_n237;
  t278_n236: return 0.011025740765035152;
  t278_n237: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t278_n241;
  t278_n238: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n240;
  t278_n239: return 0.06772234290838242;
  t278_n240: return -0.06750716269016266;
  t278_n241: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t278_n243;
  t278_n242: return -0.06930069625377655;
  t278_n243: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t278_n249;
  t278_n244: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t278_n248;
  t278_n245: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t278_n247;
  t278_n246: return -0.10480455309152603;
  t278_n247: return 0.09536249935626984;
  t278_n248: return -0.12427201867103577;
  t278_n249: return 0.0048832339234650135;
  t278_n250: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t278_n254;
  t278_n251: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t278_n253;
  t278_n252: return -0.007099279668182135;
  t278_n253: return 0.005538186524063349;
  t278_n254: return 0.0018399425316601992;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree279(const Example& E) {
  t279_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t279_n2;
  t279_n1: return -0.00041070388397201896;
  t279_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t279_n120;
  t279_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t279_n45;
  t279_n4: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t279_n6;
  t279_n5: return 0.0028706334996968508;
  t279_n6: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t279_n32;
  t279_n7: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n25;
  t279_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t279_n18;
  t279_n9: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n11;
  t279_n10: return -0.025562645867466927;
  t279_n11: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t279_n13;
  t279_n12: return -0.12811101973056793;
  t279_n13: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t279_n17;
  t279_n14: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t279_n16;
  t279_n15: return 0.12120804190635681;
  t279_n16: return 0.13811521232128143;
  t279_n17: return 0.11940986663103104;
  t279_n18: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t279_n24;
  t279_n19: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t279_n21;
  t279_n20: return 0.13516798615455627;
  t279_n21: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t279_n23;
  t279_n22: return 0.11546877026557922;
  t279_n23: return -0.4414885640144348;
  t279_n24: return -0.2296466827392578;
  t279_n25: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t279_n27;
  t279_n26: return -0.08911667764186859;
  t279_n27: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t279_n29;
  t279_n28: return 0.04086155816912651;
  t279_n29: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t279_n31;
  t279_n30: return 0.11291202902793884;
  t279_n31: return -0.007698480971157551;
  t279_n32: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t279_n40;
  t279_n33: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t279_n35;
  t279_n34: return 0.011158653534948826;
  t279_n35: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t279_n37;
  t279_n36: return 0.018469203263521194;
  t279_n37: if (E.getNumReferences() >= 3266838528 /*92.0*/) goto t279_n39;
  t279_n38: return -0.1370045244693756;
  t279_n39: return 0.11472474783658981;
  t279_n40: if (E.getNumReferences() >= 3263365120 /*65.5*/) goto t279_n44;
  t279_n41: if (E.getNumReferences() >= 3261988864 /*59.5*/) goto t279_n43;
  t279_n42: return -0.07399626076221466;
  t279_n43: return 0.11813758313655853;
  t279_n44: return -0.15220382809638977;
  t279_n45: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t279_n83;
  t279_n46: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t279_n80;
  t279_n47: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t279_n59;
  t279_n48: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t279_n50;
  t279_n49: return 0.0059743463061749935;
  t279_n50: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n56;
  t279_n51: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n55;
  t279_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t279_n54;
  t279_n53: return -0.02957492507994175;
  t279_n54: return 0.11931413412094116;
  t279_n55: return 0.12704749405384064;
  t279_n56: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t279_n58;
  t279_n57: return -0.20117832720279694;
  t279_n58: return 0.09224028140306473;
  t279_n59: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t279_n61;
  t279_n60: return -0.031893737614154816;
  t279_n61: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t279_n65;
  t279_n62: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t279_n64;
  t279_n63: return 0.10965141654014587;
  t279_n64: return -0.10571538656949997;
  t279_n65: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t279_n77;
  t279_n66: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t279_n74;
  t279_n67: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n73;
  t279_n68: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t279_n70;
  t279_n69: return 0.014163524843752384;
  t279_n70: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t279_n72;
  t279_n71: return 0.11986090242862701;
  t279_n72: return -0.02234531007707119;
  t279_n73: return 0.020692288875579834;
  t279_n74: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t279_n76;
  t279_n75: return 0.10612775385379791;
  t279_n76: return 0.056885603815317154;
  t279_n77: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t279_n79;
  t279_n78: return 0.009515030309557915;
  t279_n79: return 0.09516891837120056;
  t279_n80: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t279_n82;
  t279_n81: return -0.012966156005859375;
  t279_n82: return 0.10312318801879883;
  t279_n83: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t279_n107;
  t279_n84: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t279_n106;
  t279_n85: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t279_n89;
  t279_n86: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t279_n88;
  t279_n87: return -0.16940733790397644;
  t279_n88: return 0.10689855366945267;
  t279_n89: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t279_n91;
  t279_n90: return -0.036611005663871765;
  t279_n91: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t279_n105;
  t279_n92: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t279_n98;
  t279_n93: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t279_n95;
  t279_n94: return -0.2737055718898773;
  t279_n95: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t279_n97;
  t279_n96: return -0.3950292766094208;
  t279_n97: return 0.10915199667215347;
  t279_n98: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t279_n100;
  t279_n99: return 0.09139709174633026;
  t279_n100: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t279_n102;
  t279_n101: return -0.010173331014811993;
  t279_n102: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t279_n104;
  t279_n103: return 0.08864784240722656;
  t279_n104: return 0.16225554049015045;
  t279_n105: return -0.07029896229505539;
  t279_n106: return 0.10630036145448685;
  t279_n107: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t279_n117;
  t279_n108: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t279_n116;
  t279_n109: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t279_n111;
  t279_n110: return -0.08841422945261002;
  t279_n111: if (E.getNumReferences() >= 3269722112 /*114.0*/) goto t279_n115;
  t279_n112: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n114;
  t279_n113: return 0.09437920153141022;
  t279_n114: return 0.058476462960243225;
  t279_n115: return -0.013833433389663696;
  t279_n116: return 0.09483952075242996;
  t279_n117: if (E.getNumReferences() >= 3275128832 /*182.5*/) goto t279_n119;
  t279_n118: return -0.43834787607192993;
  t279_n119: return -0.0312344990670681;
  t279_n120: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t279_n122;
  t279_n121: return -0.0014009708538651466;
  t279_n122: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t279_n166;
  t279_n123: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n139;
  t279_n124: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t279_n136;
  t279_n125: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t279_n127;
  t279_n126: return -0.0841573178768158;
  t279_n127: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t279_n129;
  t279_n128: return 0.1332920640707016;
  t279_n129: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t279_n135;
  t279_n130: if (E.getNumReferences() >= 3272867840 /*148.0*/) goto t279_n132;
  t279_n131: return -0.000826087431050837;
  t279_n132: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t279_n134;
  t279_n133: return 0.06809946149587631;
  t279_n134: return 0.10692090541124344;
  t279_n135: return -0.11957315355539322;
  t279_n136: if (E.getNumReferences() >= 3264741376 /*76.0*/) goto t279_n138;
  t279_n137: return 0.1004827693104744;
  t279_n138: return 0.06019216403365135;
  t279_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t279_n145;
  t279_n140: if (E.getNumReferences() >= 3301228544 /*1574.0*/) goto t279_n142;
  t279_n141: return -0.04709358513355255;
  t279_n142: if (E.getNumReferences() >= 3301416960 /*1597.0*/) goto t279_n144;
  t279_n143: return 0.1065712422132492;
  t279_n144: return 0.01478119008243084;
  t279_n145: if (E.getNumReferences() >= 3301847040 /*1649.5*/) goto t279_n165;
  t279_n146: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t279_n148;
  t279_n147: return 0.024988213554024696;
  t279_n148: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t279_n154;
  t279_n149: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t279_n153;
  t279_n150: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t279_n152;
  t279_n151: return -0.10249660164117813;
  t279_n152: return 3.0883753299713135;
  t279_n153: return 0.1250436156988144;
  t279_n154: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t279_n164;
  t279_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t279_n157;
  t279_n156: return 0.028168847784399986;
  t279_n157: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t279_n159;
  t279_n158: return 0.03284112364053726;
  t279_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t279_n161;
  t279_n160: return 0.07514990121126175;
  t279_n161: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t279_n163;
  t279_n162: return 0.1122707650065422;
  t279_n163: return 0.10367385298013687;
  t279_n164: return 0.03175930306315422;
  t279_n165: return -0.009090682491660118;
  t279_n166: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t279_n174;
  t279_n167: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t279_n173;
  t279_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Expression))) goto t279_n170;
  t279_n169: return -0.11036514490842819;
  t279_n170: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t279_n172;
  t279_n171: return 0.10533293336629868;
  t279_n172: return -0.021434737369418144;
  t279_n173: return -0.5050637722015381;
  t279_n174: if (E.getFilterLength() >= 3243769856 /*13.5*/) goto t279_n240;
  t279_n175: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t279_n235;
  t279_n176: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t279_n234;
  t279_n177: if (E.getNumReferences() >= 3313941504 /*4311.5*/) goto t279_n225;
  t279_n178: if (E.getNumReferences() >= 3290079232 /*618.5*/) goto t279_n222;
  t279_n179: if (E.getNumReferences() >= 3290038272 /*616.0*/) goto t279_n221;
  t279_n180: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t279_n212;
  t279_n181: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t279_n211;
  t279_n182: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t279_n188;
  t279_n183: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t279_n185;
  t279_n184: return -0.1886570304632187;
  t279_n185: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t279_n187;
  t279_n186: return 0.09638898819684982;
  t279_n187: return 0.04529581964015961;
  t279_n188: if (E.getNumReferences() >= 3272507392 /*142.5*/) goto t279_n210;
  t279_n189: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t279_n191;
  t279_n190: return 0.10879827290773392;
  t279_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t279_n193;
  t279_n192: return -0.13615921139717102;
  t279_n193: if (E.getNumReferences() >= 3267297280 /*95.5*/) goto t279_n209;
  t279_n194: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t279_n208;
  t279_n195: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t279_n207;
  t279_n196: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t279_n198;
  t279_n197: return 0.06414943188428879;
  t279_n198: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t279_n202;
  t279_n199: if (E.getNumReferences() >= 3263430656 /*66.0*/) goto t279_n201;
  t279_n200: return 0.12767459452152252;
  t279_n201: return 0.08235250413417816;
  t279_n202: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t279_n206;
  t279_n203: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t279_n205;
  t279_n204: return -0.11826609820127487;
  t279_n205: return 0.12195166200399399;
  t279_n206: return -0.11061357706785202;
  t279_n207: return -0.04760150983929634;
  t279_n208: return 0.11583667248487473;
  t279_n209: return 0.011872630566358566;
  t279_n210: return 0.10727618634700775;
  t279_n211: return -0.015980374068021774;
  t279_n212: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t279_n218;
  t279_n213: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t279_n215;
  t279_n214: return -0.4144437909126282;
  t279_n215: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t279_n217;
  t279_n216: return -0.3078831136226654;
  t279_n217: return 0.08859140425920486;
  t279_n218: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t279_n220;
  t279_n219: return 0.010320114903151989;
  t279_n220: return -0.09380321204662323;
  t279_n221: return 0.09463086724281311;
  t279_n222: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t279_n224;
  t279_n223: return -0.08319052308797836;
  t279_n224: return 0.010520048439502716;
  t279_n225: if (E.getNumReferences() >= 3326809600 /*12997.5*/) goto t279_n233;
  t279_n226: if (E.getNumReferences() >= 3318675456 /*6623.0*/) goto t279_n228;
  t279_n227: return 0.0356840081512928;
  t279_n228: if (E.getNumReferences() >= 3319357440 /*6956.0*/) goto t279_n230;
  t279_n229: return 0.1247696653008461;
  t279_n230: if (E.getNumReferences() >= 3323836416 /*10094.0*/) goto t279_n232;
  t279_n231: return 0.06104579567909241;
  t279_n232: return 0.1699139028787613;
  t279_n233: return 0.018617823719978333;
  t279_n234: return 0.041300948709249496;
  t279_n235: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t279_n239;
  t279_n236: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t279_n238;
  t279_n237: return -0.007685762830078602;
  t279_n238: return 0.11943908780813217;
  t279_n239: return 0.004379970952868462;
  t279_n240: if (E.getFilterLength() >= 3244818432 /*14.5*/) goto t279_n254;
  t279_n241: if (E.getNumReferences() >= 3261726720 /*58.5*/) goto t279_n245;
  t279_n242: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t279_n244;
  t279_n243: return -0.0833214819431305;
  t279_n244: return 0.12587890028953552;
  t279_n245: if (E.getNumReferences() >= 3288948736 /*549.5*/) goto t279_n247;
  t279_n246: return 0.05426182225346565;
  t279_n247: if (E.getNumReferences() >= 3291684864 /*716.5*/) goto t279_n249;
  t279_n248: return 0.12309571355581284;
  t279_n249: if (E.getNumReferences() >= 3308023808 /*2759.0*/) goto t279_n251;
  t279_n250: return -0.09291550517082214;
  t279_n251: if (E.getNumReferences() >= 3308718080 /*2928.5*/) goto t279_n253;
  t279_n252: return 0.12465312331914902;
  t279_n253: return 0.043974872678518295;
  t279_n254: return 0.03759480267763138;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree280(const Example& E) {
  t280_n0: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t280_n8;
  t280_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t280_n3;
  t280_n2: return -0.029486989602446556;
  t280_n3: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t280_n7;
  t280_n4: if (E.getNumReferences() >= 3245867008 /*15.5*/) goto t280_n6;
  t280_n5: return 5.004979175282642e-05;
  t280_n6: return 0.007476980332285166;
  t280_n7: return -0.016226043924689293;
  t280_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t280_n176;
  t280_n9: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t280_n11;
  t280_n10: return -0.005926317069679499;
  t280_n11: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n13;
  t280_n12: return -0.003956463187932968;
  t280_n13: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t280_n175;
  t280_n14: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Type))) goto t280_n88;
  t280_n15: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t280_n53;
  t280_n16: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t280_n18;
  t280_n17: return 0.002162389224395156;
  t280_n18: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t280_n24;
  t280_n19: if (E.getNumReferences() >= 3297677312 /*1140.5*/) goto t280_n21;
  t280_n20: return 0.012434015981853008;
  t280_n21: if (E.getNumReferences() >= 3297751040 /*1149.5*/) goto t280_n23;
  t280_n22: return 0.18161848187446594;
  t280_n23: return 0.050924111157655716;
  t280_n24: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n52;
  t280_n25: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n27;
  t280_n26: return 0.04647967219352722;
  t280_n27: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n51;
  t280_n28: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n50;
  t280_n29: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n49;
  t280_n30: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n40;
  t280_n31: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t280_n33;
  t280_n32: return -0.13138209283351898;
  t280_n33: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n37;
  t280_n34: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t280_n36;
  t280_n35: return 0.0775982066988945;
  t280_n36: return -0.06718258559703827;
  t280_n37: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n39;
  t280_n38: return 0.08223174512386322;
  t280_n39: return 0.08023722469806671;
  t280_n40: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t280_n42;
  t280_n41: return 0.07151814550161362;
  t280_n42: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n48;
  t280_n43: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n47;
  t280_n44: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t280_n46;
  t280_n45: return 0.08599992841482162;
  t280_n46: return -0.03290094435214996;
  t280_n47: return 0.0942540392279625;
  t280_n48: return 0.08468686789274216;
  t280_n49: return 0.07014783471822739;
  t280_n50: return -0.10135223716497421;
  t280_n51: return -0.0016945742536336184;
  t280_n52: return -0.04762644320726395;
  t280_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t280_n55;
  t280_n54: return -0.020080694928765297;
  t280_n55: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t280_n73;
  t280_n56: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n72;
  t280_n57: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t280_n59;
  t280_n58: return 0.05378985032439232;
  t280_n59: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t280_n61;
  t280_n60: return 0.05716373771429062;
  t280_n61: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n63;
  t280_n62: return 0.11329077929258347;
  t280_n63: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n71;
  t280_n64: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n70;
  t280_n65: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n67;
  t280_n66: return 0.08379708230495453;
  t280_n67: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n69;
  t280_n68: return 0.11314165592193604;
  t280_n69: return 0.06455749273300171;
  t280_n70: return 0.06810175627470016;
  t280_n71: return 0.030460244044661522;
  t280_n72: return -0.11048706620931625;
  t280_n73: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t280_n75;
  t280_n74: return 0.013632889837026596;
  t280_n75: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n87;
  t280_n76: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t280_n86;
  t280_n77: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n79;
  t280_n78: return 0.13668292760849;
  t280_n79: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n85;
  t280_n80: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n82;
  t280_n81: return -0.11837286502122879;
  t280_n82: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n84;
  t280_n83: return 0.09794830530881882;
  t280_n84: return -0.10012048482894897;
  t280_n85: return 0.132518008351326;
  t280_n86: return -0.10089657455682755;
  t280_n87: return -0.1197030246257782;
  t280_n88: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t280_n102;
  t280_n89: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t280_n91;
  t280_n90: return -0.061696361750364304;
  t280_n91: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t280_n93;
  t280_n92: return -0.10020677000284195;
  t280_n93: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n97;
  t280_n94: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t280_n96;
  t280_n95: return 0.10431259870529175;
  t280_n96: return 0.04475861042737961;
  t280_n97: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n101;
  t280_n98: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t280_n100;
  t280_n99: return 0.013619810342788696;
  t280_n100: return 0.11767552047967911;
  t280_n101: return 0.024843985214829445;
  t280_n102: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t280_n132;
  t280_n103: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n127;
  t280_n104: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t280_n126;
  t280_n105: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t280_n125;
  t280_n106: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t280_n114;
  t280_n107: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t280_n109;
  t280_n108: return 0.032526761293411255;
  t280_n109: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n111;
  t280_n110: return -0.13233156502246857;
  t280_n111: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t280_n113;
  t280_n112: return -0.10135441273450851;
  t280_n113: return 0.10286998748779297;
  t280_n114: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n124;
  t280_n115: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t280_n121;
  t280_n116: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n118;
  t280_n117: return 0.02187078446149826;
  t280_n118: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n120;
  t280_n119: return 0.05739439278841019;
  t280_n120: return -0.009527924470603466;
  t280_n121: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n123;
  t280_n122: return 0.08740795403718948;
  t280_n123: return 0.03545296564698219;
  t280_n124: return -0.10179953277111053;
  t280_n125: return -0.009994595311582088;
  t280_n126: return -0.03194443881511688;
  t280_n127: if (E.getNumReferences() >= 3319326720 /*6941.0*/) goto t280_n129;
  t280_n128: return -0.03117164969444275;
  t280_n129: if (E.getNumReferences() >= 3320337408 /*7434.5*/) goto t280_n131;
  t280_n130: return 0.11004376411437988;
  t280_n131: return 0.04425974562764168;
  t280_n132: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n170;
  t280_n133: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n169;
  t280_n134: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t280_n168;
  t280_n135: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t280_n143;
  t280_n136: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t280_n138;
  t280_n137: return 0.01437500398606062;
  t280_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n140;
  t280_n139: return 0.06442292034626007;
  t280_n140: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n142;
  t280_n141: return 0.08192253112792969;
  t280_n142: return 0.02443879283964634;
  t280_n143: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t280_n147;
  t280_n144: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n146;
  t280_n145: return 0.07806071639060974;
  t280_n146: return 0.02560274302959442;
  t280_n147: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t280_n149;
  t280_n148: return -0.002004520036280155;
  t280_n149: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t280_n167;
  t280_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n152;
  t280_n151: return 0.08443323522806168;
  t280_n152: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t280_n160;
  t280_n153: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t280_n155;
  t280_n154: return 0.04866684228181839;
  t280_n155: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t280_n159;
  t280_n156: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t280_n158;
  t280_n157: return 0.11509627848863602;
  t280_n158: return -0.16110585629940033;
  t280_n159: return -0.07156551629304886;
  t280_n160: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t280_n166;
  t280_n161: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t280_n165;
  t280_n162: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t280_n164;
  t280_n163: return 0.10541979223489761;
  t280_n164: return -0.1249484121799469;
  t280_n165: return 0.08546347171068192;
  t280_n166: return 0.10966214537620544;
  t280_n167: return -0.004537058062851429;
  t280_n168: return -0.10114482790231705;
  t280_n169: return 0.009672742336988449;
  t280_n170: if (E.getNumReferences() >= 3312433152 /*3835.5*/) goto t280_n172;
  t280_n171: return 0.020607220008969307;
  t280_n172: if (E.getNumReferences() >= 3312914432 /*3953.0*/) goto t280_n174;
  t280_n173: return 0.11765507608652115;
  t280_n174: return 0.07783288508653641;
  t280_n175: return 0.0012712248135358095;
  t280_n176: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t280_n210;
  t280_n177: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t280_n199;
  t280_n178: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t280_n180;
  t280_n179: return 0.018805084750056267;
  t280_n180: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t280_n182;
  t280_n181: return 0.12002699077129364;
  t280_n182: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n198;
  t280_n183: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t280_n193;
  t280_n184: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n186;
  t280_n185: return 0.03334978595376015;
  t280_n186: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n192;
  t280_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n191;
  t280_n188: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n190;
  t280_n189: return 0.11955961585044861;
  t280_n190: return 0.09670330584049225;
  t280_n191: return 0.06842679530382156;
  t280_n192: return 0.0905766636133194;
  t280_n193: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n197;
  t280_n194: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t280_n196;
  t280_n195: return 0.11741691827774048;
  t280_n196: return -0.4104191064834595;
  t280_n197: return -0.10856659710407257;
  t280_n198: return -0.030331268906593323;
  t280_n199: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t280_n201;
  t280_n200: return 0.009383467957377434;
  t280_n201: if (E.getNumReferences() >= 3325825536 /*12036.5*/) goto t280_n209;
  t280_n202: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n208;
  t280_n203: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t280_n207;
  t280_n204: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t280_n206;
  t280_n205: return -0.10746349394321442;
  t280_n206: return 0.1331801861524582;
  t280_n207: return 0.13641153275966644;
  t280_n208: return 0.0375695638358593;
  t280_n209: return 0.020366154611110687;
  t280_n210: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t280_n228;
  t280_n211: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t280_n225;
  t280_n212: if (E.getNumReferences() >= 3300126720 /*1439.5*/) goto t280_n224;
  t280_n213: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t280_n223;
  t280_n214: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n216;
  t280_n215: return 0.013027466833591461;
  t280_n216: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t280_n222;
  t280_n217: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n221;
  t280_n218: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t280_n220;
  t280_n219: return 0.12468820065259933;
  t280_n220: return 0.10663352906703949;
  t280_n221: return 0.09578870981931686;
  t280_n222: return -0.06803147494792938;
  t280_n223: return -0.06196935102343559;
  t280_n224: return 0.1072305291891098;
  t280_n225: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n227;
  t280_n226: return -0.000640469545032829;
  t280_n227: return 0.11490827798843384;
  t280_n228: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t280_n232;
  t280_n229: if (E.getNumReferences() >= 3352866240 /*110939.5*/) goto t280_n231;
  t280_n230: return 0.0052414159290492535;
  t280_n231: return 0.07266800105571747;
  t280_n232: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t280_n250;
  t280_n233: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t280_n249;
  t280_n234: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t280_n248;
  t280_n235: if (E.getNumReferences() >= 3270770688 /*122.0*/) goto t280_n247;
  t280_n236: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t280_n238;
  t280_n237: return 0.02570560947060585;
  t280_n238: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t280_n246;
  t280_n239: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t280_n241;
  t280_n240: return 0.01501394435763359;
  t280_n241: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t280_n243;
  t280_n242: return 0.07787970453500748;
  t280_n243: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t280_n245;
  t280_n244: return 0.03878089040517807;
  t280_n245: return 0.07440101355314255;
  t280_n246: return 0.01500410120934248;
  t280_n247: return 0.12649790942668915;
  t280_n248: return -0.05850684270262718;
  t280_n249: return 0.022168787196278572;
  t280_n250: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t280_n254;
  t280_n251: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t280_n253;
  t280_n252: return -0.1017247810959816;
  t280_n253: return 0.10207352787256241;
  t280_n254: return 0.01443571224808693;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree281(const Example& E) {
  t281_n0: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t281_n228;
  t281_n1: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t281_n103;
  t281_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t281_n4;
  t281_n3: return -0.012700523249804974;
  t281_n4: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t281_n6;
  t281_n5: return -0.0006640683277510107;
  t281_n6: if (E.getFileProximityDistance() >= 3223322624 /*2.5*/) goto t281_n16;
  t281_n7: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t281_n15;
  t281_n8: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n10;
  t281_n9: return 0.1723327338695526;
  t281_n10: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n14;
  t281_n11: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Symbol))) goto t281_n13;
  t281_n12: return 0.11399044096469879;
  t281_n13: return 0.12915624678134918;
  t281_n14: return 0.033884335309267044;
  t281_n15: return -0.01339950505644083;
  t281_n16: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t281_n18;
  t281_n17: return 0.01862248219549656;
  t281_n18: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t281_n20;
  t281_n19: return 0.02072897180914879;
  t281_n20: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t281_n30;
  t281_n21: if (E.getNumReferences() >= 3341265408 /*42922.0*/) goto t281_n23;
  t281_n22: return -0.011889494955539703;
  t281_n23: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t281_n25;
  t281_n24: return 0.01100369542837143;
  t281_n25: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n29;
  t281_n26: if (E.getNumReferences() >= 3347831872 /*71608.5*/) goto t281_n28;
  t281_n27: return 0.08305090665817261;
  t281_n28: return 0.12311321496963501;
  t281_n29: return 0.02111985720694065;
  t281_n30: if (E.getNumReferences() >= 3346496384 /*63355.5*/) goto t281_n102;
  t281_n31: if (E.getNumReferences() >= 3336210176 /*27971.5*/) goto t281_n101;
  t281_n32: if (E.getNumReferences() >= 3256221696 /*37.5*/) goto t281_n52;
  t281_n33: if (E.getNumReferences() >= 3249274880 /*21.5*/) goto t281_n51;
  t281_n34: if (E.getNumReferences() >= 3248750592 /*20.5*/) goto t281_n46;
  t281_n35: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t281_n37;
  t281_n36: return 0.015282108448445797;
  t281_n37: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t281_n45;
  t281_n38: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t281_n42;
  t281_n39: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t281_n41;
  t281_n40: return 0.07827883958816528;
  t281_n41: return 0.13148722052574158;
  t281_n42: if (E.getNumReferences() >= 3247702016 /*18.5*/) goto t281_n44;
  t281_n43: return -0.15150600671768188;
  t281_n44: return 0.09903234243392944;
  t281_n45: return 0.02439621277153492;
  t281_n46: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t281_n50;
  t281_n47: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t281_n49;
  t281_n48: return 0.11405625939369202;
  t281_n49: return 0.1224369928240776;
  t281_n50: return -0.06595123559236526;
  t281_n51: return -0.1511070877313614;
  t281_n52: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t281_n62;
  t281_n53: if (E.getNumReferences() >= 3257532416 /*42.5*/) goto t281_n57;
  t281_n54: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n56;
  t281_n55: return 0.15763022005558014;
  t281_n56: return -0.11516313254833221;
  t281_n57: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t281_n59;
  t281_n58: return -0.6969040036201477;
  t281_n59: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t281_n61;
  t281_n60: return 0.11318834871053696;
  t281_n61: return 0.16247455775737762;
  t281_n62: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t281_n64;
  t281_n63: return -0.012062741443514824;
  t281_n64: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t281_n76;
  t281_n65: if (E.getNumReferences() >= 3263561728 /*67.0*/) goto t281_n67;
  t281_n66: return 0.11053037643432617;
  t281_n67: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n69;
  t281_n68: return 0.09356073290109634;
  t281_n69: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t281_n73;
  t281_n70: if (E.getNumReferences() >= 3272114176 /*136.5*/) goto t281_n72;
  t281_n71: return -0.29788702726364136;
  t281_n72: return 0.026089457795023918;
  t281_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n75;
  t281_n74: return 0.07044129818677902;
  t281_n75: return 0.10091779381036758;
  t281_n76: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t281_n98;
  t281_n77: if (E.getNumReferences() >= 3290374144 /*636.5*/) goto t281_n97;
  t281_n78: if (E.getNumReferences() >= 3289194496 /*564.5*/) goto t281_n96;
  t281_n79: if (E.getNumReferences() >= 3280404480 /*270.0*/) goto t281_n95;
  t281_n80: if (E.getNumReferences() >= 3278602240 /*235.5*/) goto t281_n94;
  t281_n81: if (E.getNumReferences() >= 3267821568 /*99.5*/) goto t281_n87;
  t281_n82: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n86;
  t281_n83: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t281_n85;
  t281_n84: return -0.07303221523761749;
  t281_n85: return 0.10416959226131439;
  t281_n86: return -0.011179433204233646;
  t281_n87: if (E.getNumReferences() >= 3272441856 /*141.5*/) goto t281_n93;
  t281_n88: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t281_n92;
  t281_n89: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t281_n91;
  t281_n90: return -0.11567626148462296;
  t281_n91: return 0.11929811537265778;
  t281_n92: return 0.116038016974926;
  t281_n93: return -0.022458795458078384;
  t281_n94: return 0.13445919752120972;
  t281_n95: return -0.08988867700099945;
  t281_n96: return 0.11514178663492203;
  t281_n97: return -0.18632927536964417;
  t281_n98: if (E.getNumReferences() >= 3272343552 /*140.0*/) goto t281_n100;
  t281_n99: return -0.33402907848358154;
  t281_n100: return 0.011084908619523048;
  t281_n101: return -0.07023199647665024;
  t281_n102: return 0.09357163310050964;
  t281_n103: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t281_n225;
  t281_n104: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t281_n112;
  t281_n105: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n109;
  t281_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t281_n108;
  t281_n107: return 0.000738635309971869;
  t281_n108: return 0.007765098940581083;
  t281_n109: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t281_n111;
  t281_n110: return -0.03458790108561516;
  t281_n111: return -0.024100830778479576;
  t281_n112: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t281_n216;
  t281_n113: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t281_n119;
  t281_n114: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n118;
  t281_n115: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t281_n117;
  t281_n116: return -0.012186783365905285;
  t281_n117: return 0.005886073689907789;
  t281_n118: return -0.00508407736197114;
  t281_n119: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t281_n163;
  t281_n120: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t281_n122;
  t281_n121: return 0.029455194249749184;
  t281_n122: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t281_n148;
  t281_n123: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t281_n125;
  t281_n124: return 0.01636177860200405;
  t281_n125: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t281_n127;
  t281_n126: return -0.00397774251177907;
  t281_n127: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t281_n147;
  t281_n128: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t281_n142;
  t281_n129: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t281_n131;
  t281_n130: return 0.02877935767173767;
  t281_n131: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t281_n135;
  t281_n132: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t281_n134;
  t281_n133: return 0.1120477020740509;
  t281_n134: return 0.07965286076068878;
  t281_n135: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t281_n137;
  t281_n136: return -0.015569481067359447;
  t281_n137: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t281_n139;
  t281_n138: return 0.09297607839107513;
  t281_n139: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t281_n141;
  t281_n140: return -0.10865511745214462;
  t281_n141: return 0.08002417534589767;
  t281_n142: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t281_n146;
  t281_n143: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t281_n145;
  t281_n144: return 0.06773559004068375;
  t281_n145: return 0.10544226318597794;
  t281_n146: return 0.0046228691935539246;
  t281_n147: return 0.013058406300842762;
  t281_n148: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t281_n152;
  t281_n149: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t281_n151;
  t281_n150: return -0.01789100095629692;
  t281_n151: return 0.12237437069416046;
  t281_n152: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t281_n162;
  t281_n153: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t281_n161;
  t281_n154: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t281_n156;
  t281_n155: return 0.07158965617418289;
  t281_n156: if (E.getFileProximityDistance() >= 3253469184 /*29.5*/) goto t281_n160;
  t281_n157: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n159;
  t281_n158: return 0.09015171229839325;
  t281_n159: return 0.13385838270187378;
  t281_n160: return -0.1019558236002922;
  t281_n161: return 0.02697301283478737;
  t281_n162: return -0.10739953070878983;
  t281_n163: if (E.getFileProximityDistance() >= 3252944896 /*28.5*/) goto t281_n193;
  t281_n164: if (E.getNumReferences() >= 3331802112 /*19362.0*/) goto t281_n174;
  t281_n165: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t281_n167;
  t281_n166: return -0.03550180047750473;
  t281_n167: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t281_n169;
  t281_n168: return 0.0400882251560688;
  t281_n169: if (E.getNumReferences() >= 3320975360 /*7746.0*/) goto t281_n171;
  t281_n170: return 0.03722105547785759;
  t281_n171: if (E.getNumReferences() >= 3323093504 /*9368.5*/) goto t281_n173;
  t281_n172: return 0.13185074925422668;
  t281_n173: return -0.17985674738883972;
  t281_n174: if (E.getNumReferences() >= 3331859712 /*19474.5*/) goto t281_n182;
  t281_n175: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t281_n181;
  t281_n176: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t281_n178;
  t281_n177: return -0.15363731980323792;
  t281_n178: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t281_n180;
  t281_n179: return 0.10023397207260132;
  t281_n180: return 0.08332086354494095;
  t281_n181: return 0.001963825663551688;
  t281_n182: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n188;
  t281_n183: if (E.getNumReferences() >= 3340106752 /*38396.0*/) goto t281_n185;
  t281_n184: return 0.005698068533092737;
  t281_n185: if (E.getNumReferences() >= 3345865600 /*60891.5*/) goto t281_n187;
  t281_n186: return 0.06546005606651306;
  t281_n187: return -0.0011127329198643565;
  t281_n188: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t281_n192;
  t281_n189: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t281_n191;
  t281_n190: return 0.049940235912799835;
  t281_n191: return 0.09497156739234924;
  t281_n192: return 0.05072060972452164;
  t281_n193: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t281_n205;
  t281_n194: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n196;
  t281_n195: return 0.055292241275310516;
  t281_n196: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t281_n204;
  t281_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Symbol))) goto t281_n199;
  t281_n198: return 0.0181468166410923;
  t281_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t281_n201;
  t281_n200: return 0.003505914006382227;
  t281_n201: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t281_n203;
  t281_n202: return 0.039903730154037476;
  t281_n203: return 0.13337358832359314;
  t281_n204: return -2.006385326385498;
  t281_n205: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t281_n207;
  t281_n206: return 0.04339172691106796;
  t281_n207: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t281_n209;
  t281_n208: return -0.07610895484685898;
  t281_n209: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t281_n211;
  t281_n210: return 0.18864630162715912;
  t281_n211: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t281_n213;
  t281_n212: return 0.001122408895753324;
  t281_n213: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t281_n215;
  t281_n214: return 0.13828223943710327;
  t281_n215: return 0.06394296139478683;
  t281_n216: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n218;
  t281_n217: return 0.006406643893569708;
  t281_n218: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t281_n224;
  t281_n219: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t281_n221;
  t281_n220: return 0.03417575731873512;
  t281_n221: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t281_n223;
  t281_n222: return 0.10062868893146515;
  t281_n223: return 0.019787432625889778;
  t281_n224: return 0.009088727645576;
  t281_n225: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t281_n227;
  t281_n226: return -0.1088654100894928;
  t281_n227: return -0.0005170971853658557;
  t281_n228: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t281_n254;
  t281_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t281_n231;
  t281_n230: return 0.021403390914201736;
  t281_n231: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t281_n247;
  t281_n232: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t281_n234;
  t281_n233: return 0.10667290538549423;
  t281_n234: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t281_n246;
  t281_n235: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t281_n241;
  t281_n236: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t281_n240;
  t281_n237: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n239;
  t281_n238: return -0.10560537129640579;
  t281_n239: return 2.178177833557129;
  t281_n240: return -0.06853631883859634;
  t281_n241: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t281_n243;
  t281_n242: return 0.7834787964820862;
  t281_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t281_n245;
  t281_n244: return -0.46267056465148926;
  t281_n245: return 0.1550350934267044;
  t281_n246: return 1.5666284561157227;
  t281_n247: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t281_n253;
  t281_n248: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t281_n252;
  t281_n249: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t281_n251;
  t281_n250: return -0.1363552361726761;
  t281_n251: return 0.47757571935653687;
  t281_n252: return -0.10085843503475189;
  t281_n253: return 0.18796013295650482;
  t281_n254: return -0.042712029069662094;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree282(const Example& E) {
  t282_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t282_n2;
  t282_n1: return -0.00031202565878629684;
  t282_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t282_n38;
  t282_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t282_n5;
  t282_n4: return 0.00735994940623641;
  t282_n5: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t282_n37;
  t282_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t282_n10;
  t282_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n9;
  t282_n8: return -0.028485801070928574;
  t282_n9: return 0.06474091857671738;
  t282_n10: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t282_n36;
  t282_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t282_n13;
  t282_n12: return -0.09474875777959824;
  t282_n13: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t282_n27;
  t282_n14: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t282_n26;
  t282_n15: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n25;
  t282_n16: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t282_n18;
  t282_n17: return 0.011412503197789192;
  t282_n18: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n24;
  t282_n19: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t282_n21;
  t282_n20: return 0.11019165813922882;
  t282_n21: if (E.getNumReferences() >= 3286204416 /*447.0*/) goto t282_n23;
  t282_n22: return 0.10615319758653641;
  t282_n23: return 0.0007531600422225893;
  t282_n24: return -0.07378876209259033;
  t282_n25: return -0.1341540813446045;
  t282_n26: return 0.005361767020076513;
  t282_n27: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t282_n35;
  t282_n28: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t282_n34;
  t282_n29: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t282_n33;
  t282_n30: if (E.getNumReferences() >= 3293782016 /*844.5*/) goto t282_n32;
  t282_n31: return 0.11284732073545456;
  t282_n32: return 0.11957701295614243;
  t282_n33: return 0.0722745954990387;
  t282_n34: return 0.0614035464823246;
  t282_n35: return -0.10397736728191376;
  t282_n36: return 0.010373012162744999;
  t282_n37: return 0.07786449044942856;
  t282_n38: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t282_n40;
  t282_n39: return -0.0002560199936851859;
  t282_n40: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t282_n168;
  t282_n41: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t282_n45;
  t282_n42: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t282_n44;
  t282_n43: return 0.10776519775390625;
  t282_n44: return -0.3021254241466522;
  t282_n45: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t282_n157;
  t282_n46: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t282_n134;
  t282_n47: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t282_n57;
  t282_n48: if (E.getNumReferences() >= 3285467136 /*424.5*/) goto t282_n56;
  t282_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n51;
  t282_n50: return -0.029527295380830765;
  t282_n51: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t282_n53;
  t282_n52: return -0.018154608085751534;
  t282_n53: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t282_n55;
  t282_n54: return 0.11058391630649567;
  t282_n55: return 0.029482614248991013;
  t282_n56: return -0.004134549759328365;
  t282_n57: if (E.getNumReferences() >= 3290079232 /*618.5*/) goto t282_n67;
  t282_n58: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n60;
  t282_n59: return -0.45641398429870605;
  t282_n60: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t282_n66;
  t282_n61: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t282_n63;
  t282_n62: return -0.02207343839108944;
  t282_n63: if (E.getNumReferences() >= 3290030080 /*615.5*/) goto t282_n65;
  t282_n64: return -0.26651790738105774;
  t282_n65: return -0.9000018239021301;
  t282_n66: return 0.10369117558002472;
  t282_n67: if (E.getNumReferences() >= 3290128384 /*621.5*/) goto t282_n69;
  t282_n68: return 0.09388293325901031;
  t282_n69: if (E.getNumReferences() >= 3310512128 /*3366.5*/) goto t282_n117;
  t282_n70: if (E.getNumReferences() >= 3309832192 /*3200.5*/) goto t282_n114;
  t282_n71: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t282_n113;
  t282_n72: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n96;
  t282_n73: if (E.getNumReferences() >= 3292413952 /*761.0*/) goto t282_n75;
  t282_n74: return -0.17456009984016418;
  t282_n75: if (E.getNumReferences() >= 3293192192 /*808.5*/) goto t282_n79;
  t282_n76: if (E.getNumReferences() >= 3292733440 /*780.5*/) goto t282_n78;
  t282_n77: return -0.10469823330640793;
  t282_n78: return 0.11037324368953705;
  t282_n79: if (E.getNumReferences() >= 3301113856 /*1560.0*/) goto t282_n85;
  t282_n80: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t282_n84;
  t282_n81: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t282_n83;
  t282_n82: return -0.6032833456993103;
  t282_n83: return -0.07125187665224075;
  t282_n84: return 0.008763240650296211;
  t282_n85: if (E.getNumReferences() >= 3301826560 /*1647.0*/) goto t282_n89;
  t282_n86: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n88;
  t282_n87: return -0.10638564079999924;
  t282_n88: return 0.15810033679008484;
  t282_n89: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t282_n91;
  t282_n90: return -0.06223641708493233;
  t282_n91: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n93;
  t282_n92: return -0.016875866800546646;
  t282_n93: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t282_n95;
  t282_n94: return 0.14615598320960999;
  t282_n95: return -0.02092980593442917;
  t282_n96: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t282_n102;
  t282_n97: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t282_n101;
  t282_n98: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Type))) goto t282_n100;
  t282_n99: return -0.035651061683893204;
  t282_n100: return 0.1199006512761116;
  t282_n101: return 0.0881437212228775;
  t282_n102: if (E.getNumReferences() >= 3292987392 /*796.0*/) goto t282_n106;
  t282_n103: if (E.getNumReferences() >= 3292233728 /*750.0*/) goto t282_n105;
  t282_n104: return 0.06308086961507797;
  t282_n105: return 0.0893397405743599;
  t282_n106: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t282_n110;
  t282_n107: if (E.getNumReferences() >= 3299438592 /*1355.5*/) goto t282_n109;
  t282_n108: return 0.10095422714948654;
  t282_n109: return -0.11985193938016891;
  t282_n110: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t282_n112;
  t282_n111: return -0.33466246724128723;
  t282_n112: return 0.08879651874303818;
  t282_n113: return 0.8031365275382996;
  t282_n114: if (E.getNumReferences() >= 3310073856 /*3259.5*/) goto t282_n116;
  t282_n115: return 0.10907955467700958;
  t282_n116: return 0.08588362485170364;
  t282_n117: if (E.getNumReferences() >= 3320595456 /*7560.5*/) goto t282_n121;
  t282_n118: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n120;
  t282_n119: return -0.028635285794734955;
  t282_n120: return -0.15169639885425568;
  t282_n121: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t282_n131;
  t282_n122: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t282_n130;
  t282_n123: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t282_n127;
  t282_n124: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n126;
  t282_n125: return -0.003018096787855029;
  t282_n126: return 0.08939948678016663;
  t282_n127: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t282_n129;
  t282_n128: return 0.04856889694929123;
  t282_n129: return 0.10409124195575714;
  t282_n130: return 0.13476526737213135;
  t282_n131: if (E.getNumReferences() >= 3324368896 /*10614.0*/) goto t282_n133;
  t282_n132: return 0.07263099402189255;
  t282_n133: return 0.013853252865374088;
  t282_n134: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t282_n148;
  t282_n135: if (E.getNumReferences() >= 3317536768 /*6067.0*/) goto t282_n137;
  t282_n136: return -0.15526048839092255;
  t282_n137: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t282_n139;
  t282_n138: return -0.12488272786140442;
  t282_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t282_n141;
  t282_n140: return -0.2925182580947876;
  t282_n141: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t282_n147;
  t282_n142: if (E.getNumReferences() >= 3324282368 /*10529.5*/) goto t282_n144;
  t282_n143: return 0.10220542550086975;
  t282_n144: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n146;
  t282_n145: return 0.07308447360992432;
  t282_n146: return 0.11491239070892334;
  t282_n147: return 0.06854967772960663;
  t282_n148: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n150;
  t282_n149: return 0.056265901774168015;
  t282_n150: if (E.getNumReferences() >= 3303497728 /*1851.0*/) goto t282_n152;
  t282_n151: return -0.554100751876831;
  t282_n152: if (E.getNumReferences() >= 3318012928 /*6299.5*/) goto t282_n156;
  t282_n153: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t282_n155;
  t282_n154: return -0.507710874080658;
  t282_n155: return 0.1379278302192688;
  t282_n156: return -0.21954381465911865;
  t282_n157: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n167;
  t282_n158: if (E.getNumReferences() >= 3285516288 /*426.0*/) goto t282_n162;
  t282_n159: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t282_n161;
  t282_n160: return -0.02286510355770588;
  t282_n161: return 0.09803476184606552;
  t282_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n164;
  t282_n163: return -0.04443231597542763;
  t282_n164: if (E.getNumReferences() >= 3358754656 /*182813.5*/) goto t282_n166;
  t282_n165: return -0.2202959656715393;
  t282_n166: return 0.07741034030914307;
  t282_n167: return -0.0017174313543364406;
  t282_n168: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t282_n254;
  t282_n169: if (E.getNumReferences() >= 3286614016 /*459.5*/) goto t282_n181;
  t282_n170: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t282_n176;
  t282_n171: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t282_n175;
  t282_n172: if (E.getNumReferences() >= 3286106112 /*444.0*/) goto t282_n174;
  t282_n173: return -0.12760530412197113;
  t282_n174: return -0.914707601070404;
  t282_n175: return -0.04538167268037796;
  t282_n176: if (E.getNumReferences() >= 3285729280 /*432.5*/) goto t282_n180;
  t282_n177: if (E.getNumReferences() >= 3285499904 /*425.5*/) goto t282_n179;
  t282_n178: return 0.08282921463251114;
  t282_n179: return -0.7961204648017883;
  t282_n180: return 0.0944669172167778;
  t282_n181: if (E.getNumReferences() >= 3286679552 /*461.5*/) goto t282_n183;
  t282_n182: return 0.10593020170927048;
  t282_n183: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t282_n245;
  t282_n184: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t282_n188;
  t282_n185: if (E.getNumReferences() >= 3286990848 /*471.0*/) goto t282_n187;
  t282_n186: return 0.0057714395225048065;
  t282_n187: return 0.09317020326852798;
  t282_n188: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t282_n240;
  t282_n189: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t282_n239;
  t282_n190: if (E.getNumReferences() >= 3300237312 /*1453.0*/) goto t282_n238;
  t282_n191: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Type))) goto t282_n203;
  t282_n192: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t282_n202;
  t282_n193: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t282_n199;
  t282_n194: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t282_n196;
  t282_n195: return -0.08832657337188721;
  t282_n196: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t282_n198;
  t282_n197: return 0.1090681254863739;
  t282_n198: return 0.023913446813821793;
  t282_n199: if (E.getNumReferences() >= 3297816576 /*1157.5*/) goto t282_n201;
  t282_n200: return -0.07927755266427994;
  t282_n201: return 0.1328626275062561;
  t282_n202: return 0.0885762944817543;
  t282_n203: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t282_n227;
  t282_n204: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t282_n206;
  t282_n205: return 0.10213784873485565;
  t282_n206: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t282_n224;
  t282_n207: if (E.getNumReferences() >= 3289161728 /*562.5*/) goto t282_n209;
  t282_n208: return -0.15548548102378845;
  t282_n209: if (E.getNumReferences() >= 3293110272 /*803.5*/) goto t282_n223;
  t282_n210: if (E.getNumReferences() >= 3292405760 /*760.5*/) goto t282_n220;
  t282_n211: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t282_n215;
  t282_n212: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t282_n214;
  t282_n213: return 0.07911912351846695;
  t282_n214: return 0.09806487709283829;
  t282_n215: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t282_n217;
  t282_n216: return -0.13492989540100098;
  t282_n217: if (E.getNumReferences() >= 3289972736 /*612.0*/) goto t282_n219;
  t282_n218: return 0.1342683583498001;
  t282_n219: return -0.11564911156892776;
  t282_n220: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Expression))) goto t282_n222;
  t282_n221: return 0.04289800673723221;
  t282_n222: return 0.15287430584430695;
  t282_n223: return -0.12104400992393494;
  t282_n224: if (E.getNumReferences() >= 3289456640 /*580.5*/) goto t282_n226;
  t282_n225: return 0.08510316908359528;
  t282_n226: return 0.018843382596969604;
  t282_n227: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t282_n233;
  t282_n228: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t282_n232;
  t282_n229: if (E.getNumReferences() >= 3298021376 /*1182.5*/) goto t282_n231;
  t282_n230: return -0.23863543570041656;
  t282_n231: return 0.10735326260328293;
  t282_n232: return 0.11444789171218872;
  t282_n233: if (E.getNumReferences() >= 3295780864 /*966.5*/) goto t282_n237;
  t282_n234: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t282_n236;
  t282_n235: return 0.16641341149806976;
  t282_n236: return -0.05195186287164688;
  t282_n237: return 0.0017575661186128855;
  t282_n238: return 0.11654186993837357;
  t282_n239: return 0.02009027823805809;
  t282_n240: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t282_n242;
  t282_n241: return 0.015019840560853481;
  t282_n242: if (E.getNumReferences() >= 3365715136 /*320998.0*/) goto t282_n244;
  t282_n243: return -0.018412631005048752;
  t282_n244: return 0.09269475936889648;
  t282_n245: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t282_n249;
  t282_n246: if (E.getNumReferences() >= 3287924736 /*499.5*/) goto t282_n248;
  t282_n247: return -1.365025281906128;
  t282_n248: return -0.0019108009291812778;
  t282_n249: if (E.getNumReferences() >= 3289088000 /*558.0*/) goto t282_n253;
  t282_n250: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t282_n252;
  t282_n251: return 0.09206531196832657;
  t282_n252: return 0.15011011064052582;
  t282_n253: return 0.020402971655130386;
  t282_n254: return 0.10190942138433456;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree283(const Example& E) {
  t283_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t283_n2;
  t283_n1: return -0.0003101542533840984;
  t283_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t283_n26;
  t283_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t283_n5;
  t283_n4: return 0.00732892332598567;
  t283_n5: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t283_n25;
  t283_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t283_n10;
  t283_n7: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n9;
  t283_n8: return -0.029541384428739548;
  t283_n9: return 0.06265883147716522;
  t283_n10: if (E.getNumReferences() >= 3297521664 /*1121.5*/) goto t283_n24;
  t283_n11: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t283_n13;
  t283_n12: return -0.08519589900970459;
  t283_n13: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t283_n17;
  t283_n14: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t283_n16;
  t283_n15: return 0.06410686671733856;
  t283_n16: return 0.004721513018012047;
  t283_n17: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t283_n23;
  t283_n18: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t283_n22;
  t283_n19: if (E.getFilterLength() >= 3235905536 /*7.0*/) goto t283_n21;
  t283_n20: return 0.11452153325080872;
  t283_n21: return 0.07052841782569885;
  t283_n22: return 0.057397544384002686;
  t283_n23: return -0.08607739955186844;
  t283_n24: return 0.006078975275158882;
  t283_n25: return 0.07338003814220428;
  t283_n26: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t283_n28;
  t283_n27: return -0.0002326584217371419;
  t283_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t283_n30;
  t283_n29: return 0.0036472519859671593;
  t283_n30: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t283_n34;
  t283_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t283_n33;
  t283_n32: return -0.40184375643730164;
  t283_n33: return 0.09920252859592438;
  t283_n34: if (E.getNumReferences() >= 3312803840 /*3926.0*/) goto t283_n178;
  t283_n35: if (E.getNumReferences() >= 3290095616 /*619.5*/) goto t283_n41;
  t283_n36: if (E.getNumReferences() >= 3286384640 /*452.5*/) goto t283_n40;
  t283_n37: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n39;
  t283_n38: return 0.06136306747794151;
  t283_n39: return -0.15349651873111725;
  t283_n40: return -0.07278098911046982;
  t283_n41: if (E.getNumReferences() >= 3290112000 /*620.5*/) goto t283_n43;
  t283_n42: return 0.10134243965148926;
  t283_n43: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t283_n161;
  t283_n44: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t283_n50;
  t283_n45: if (E.getNumReferences() >= 3310151680 /*3278.5*/) goto t283_n47;
  t283_n46: return -0.12186361849308014;
  t283_n47: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n49;
  t283_n48: return -0.10564660280942917;
  t283_n49: return 0.11117827147245407;
  t283_n50: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t283_n78;
  t283_n51: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t283_n75;
  t283_n52: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t283_n74;
  t283_n53: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t283_n63;
  t283_n54: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n56;
  t283_n55: return -0.18744848668575287;
  t283_n56: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t283_n60;
  t283_n57: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t283_n59;
  t283_n58: return 0.0846262276172638;
  t283_n59: return -0.9456624388694763;
  t283_n60: if (E.getNumReferences() >= 3298697216 /*1265.0*/) goto t283_n62;
  t283_n61: return -0.1473608762025833;
  t283_n62: return 0.10524153709411621;
  t283_n63: if (E.getNumReferences() >= 3292495872 /*766.0*/) goto t283_n65;
  t283_n64: return -0.3167036175727844;
  t283_n65: if (E.getNumReferences() >= 3301003264 /*1546.5*/) goto t283_n71;
  t283_n66: if (E.getNumReferences() >= 3297775616 /*1152.5*/) goto t283_n70;
  t283_n67: if (E.getNumReferences() >= 3295903744 /*974.0*/) goto t283_n69;
  t283_n68: return 0.10514377802610397;
  t283_n69: return -0.1421108841896057;
  t283_n70: return 0.15548968315124512;
  t283_n71: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n73;
  t283_n72: return 0.10708440095186234;
  t283_n73: return -0.18594631552696228;
  t283_n74: return 0.11418169736862183;
  t283_n75: if (E.getNumReferences() >= 3294584832 /*893.5*/) goto t283_n77;
  t283_n76: return 0.10621892660856247;
  t283_n77: return 0.11539904028177261;
  t283_n78: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_Namespace))) goto t283_n160;
  t283_n79: if (E.getNumReferences() >= 3292815360 /*785.5*/) goto t283_n97;
  t283_n80: if (E.getNumReferences() >= 3292684288 /*777.5*/) goto t283_n94;
  t283_n81: if (E.getNumReferences() >= 3291439104 /*701.5*/) goto t283_n93;
  t283_n82: if (E.getNumReferences() >= 3291381760 /*698.0*/) goto t283_n92;
  t283_n83: if (E.getNumReferences() >= 3291021312 /*676.0*/) goto t283_n91;
  t283_n84: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n86;
  t283_n85: return -0.006084693595767021;
  t283_n86: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t283_n90;
  t283_n87: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t283_n89;
  t283_n88: return 0.11452538520097733;
  t283_n89: return 0.10131309181451797;
  t283_n90: return -0.05314777418971062;
  t283_n91: return -0.27748537063598633;
  t283_n92: return 0.11148838698863983;
  t283_n93: return -0.061663318425416946;
  t283_n94: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n96;
  t283_n95: return 0.09349852800369263;
  t283_n96: return 0.09846266359090805;
  t283_n97: if (E.getNumReferences() >= 3306727424 /*2442.5*/) goto t283_n139;
  t283_n98: if (E.getNumReferences() >= 3304943616 /*2027.5*/) goto t283_n136;
  t283_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t283_n103;
  t283_n100: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t283_n102;
  t283_n101: return -0.49843624234199524;
  t283_n102: return 0.0027054008096456528;
  t283_n103: if (E.getNumReferences() >= 3295387648 /*942.5*/) goto t283_n105;
  t283_n104: return -0.059421345591545105;
  t283_n105: if (E.getNumReferences() >= 3295576064 /*954.0*/) goto t283_n107;
  t283_n106: return 0.12354796379804611;
  t283_n107: if (E.getNumReferences() >= 3296780288 /*1031.0*/) goto t283_n117;
  t283_n108: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n116;
  t283_n109: if (E.getNumReferences() >= 3296256000 /*995.5*/) goto t283_n113;
  t283_n110: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t283_n112;
  t283_n111: return 0.12204813212156296;
  t283_n112: return 0.014302672818303108;
  t283_n113: if (E.getNumReferences() >= 3296403456 /*1004.5*/) goto t283_n115;
  t283_n114: return 0.009332239627838135;
  t283_n115: return 0.10819090902805328;
  t283_n116: return -0.03571275994181633;
  t283_n117: if (E.getNumReferences() >= 3303219200 /*1817.0*/) goto t283_n133;
  t283_n118: if (E.getNumReferences() >= 3302764544 /*1761.5*/) goto t283_n132;
  t283_n119: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t283_n125;
  t283_n120: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n124;
  t283_n121: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t283_n123;
  t283_n122: return 0.08520802110433578;
  t283_n123: return -0.20183517038822174;
  t283_n124: return -0.037017155438661575;
  t283_n125: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t283_n131;
  t283_n126: if (E.getNumReferences() >= 3298189312 /*1203.0*/) goto t283_n128;
  t283_n127: return -0.0640546903014183;
  t283_n128: if (E.getNumReferences() >= 3299315712 /*1340.5*/) goto t283_n130;
  t283_n129: return 0.09964964538812637;
  t283_n130: return 0.10302131623029709;
  t283_n131: return -0.03322002664208412;
  t283_n132: return -1.50899338722229;
  t283_n133: if (E.getNumReferences() >= 3303272448 /*1823.5*/) goto t283_n135;
  t283_n134: return 0.3126637935638428;
  t283_n135: return 0.020875919610261917;
  t283_n136: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t283_n138;
  t283_n137: return -0.2211223691701889;
  t283_n138: return 0.075968436896801;
  t283_n139: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t283_n155;
  t283_n140: if (E.getNumReferences() >= 3307331584 /*2590.0*/) goto t283_n144;
  t283_n141: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t283_n143;
  t283_n142: return 0.1054188460111618;
  t283_n143: return -0.02897805906832218;
  t283_n144: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t283_n146;
  t283_n145: return -0.022660180926322937;
  t283_n146: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t283_n154;
  t283_n147: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t283_n151;
  t283_n148: if (E.getNumReferences() >= 3309703168 /*3169.0*/) goto t283_n150;
  t283_n149: return 0.11715209484100342;
  t283_n150: return 0.09845355898141861;
  t283_n151: if (E.getNumReferences() >= 3310755840 /*3426.0*/) goto t283_n153;
  t283_n152: return 0.10749383270740509;
  t283_n153: return -0.28054389357566833;
  t283_n154: return -0.10203531384468079;
  t283_n155: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n157;
  t283_n156: return 0.03704938665032387;
  t283_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t283_n159;
  t283_n158: return 0.10725852847099304;
  t283_n159: return 0.10456854850053787;
  t283_n160: return 0.10422050207853317;
  t283_n161: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t283_n165;
  t283_n162: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n164;
  t283_n163: return -0.22911109030246735;
  t283_n164: return 0.08638889342546463;
  t283_n165: if (E.getNumReferences() >= 3291561984 /*709.0*/) goto t283_n169;
  t283_n166: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t283_n168;
  t283_n167: return -0.012004882097244263;
  t283_n168: return 0.11787456274032593;
  t283_n169: if (E.getNumReferences() >= 3298562048 /*1248.5*/) goto t283_n171;
  t283_n170: return -0.13467158377170563;
  t283_n171: if (E.getNumReferences() >= 3298725888 /*1268.5*/) goto t283_n173;
  t283_n172: return 0.09647692739963531;
  t283_n173: if (E.getNumReferences() >= 3301179392 /*1568.0*/) goto t283_n175;
  t283_n174: return -0.07241597026586533;
  t283_n175: if (E.getFilterLength() >= 3212836864 /*1.0*/) goto t283_n177;
  t283_n176: return 0.17474548518657684;
  t283_n177: return 0.034753475338220596;
  t283_n178: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t283_n250;
  t283_n179: if (E.getScope() & (BIT(Scope_type::GlobalScope))) goto t283_n205;
  t283_n180: if (E.getNumReferences() >= 3340753024 /*40920.5*/) goto t283_n182;
  t283_n181: return -0.03918677195906639;
  t283_n182: if (E.getNumReferences() >= 3365173872 /*304083.5*/) goto t283_n204;
  t283_n183: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t283_n195;
  t283_n184: if (E.getNumReferences() >= 3354468928 /*123460.5*/) goto t283_n186;
  t283_n185: return 0.01035374216735363;
  t283_n186: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t283_n192;
  t283_n187: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t283_n191;
  t283_n188: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t283_n190;
  t283_n189: return 0.053106147795915604;
  t283_n190: return 0.040708281099796295;
  t283_n191: return 1.2266260385513306;
  t283_n192: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t283_n194;
  t283_n193: return 0.01615307852625847;
  t283_n194: return 0.09853420406579971;
  t283_n195: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t283_n203;
  t283_n196: if (E.getNumReferences() >= 3343861504 /*53063.0*/) goto t283_n198;
  t283_n197: return 0.09127653390169144;
  t283_n198: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t283_n202;
  t283_n199: if (E.getNumReferences() >= 3358206848 /*174254.0*/) goto t283_n201;
  t283_n200: return 0.007093564607203007;
  t283_n201: return 0.10060176253318787;
  t283_n202: return -0.013052895665168762;
  t283_n203: return 0.1000613197684288;
  t283_n204: return -0.027184071019291878;
  t283_n205: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t283_n237;
  t283_n206: if (E.getNumReferences() >= 3315707904 /*5174.0*/) goto t283_n214;
  t283_n207: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n213;
  t283_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t283_n212;
  t283_n209: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t283_n211;
  t283_n210: return -0.7449407577514648;
  t283_n211: return -0.10577821731567383;
  t283_n212: return -0.07674729079008102;
  t283_n213: return -0.035810958594083786;
  t283_n214: if (E.getNumReferences() >= 3315832832 /*5235.0*/) goto t283_n218;
  t283_n215: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t283_n217;
  t283_n216: return 0.10876250267028809;
  t283_n217: return -0.8215135931968689;
  t283_n218: if (E.getNumReferences() >= 3333532160 /*22741.0*/) goto t283_n236;
  t283_n219: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t283_n227;
  t283_n220: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t283_n226;
  t283_n221: if (E.getNumReferences() >= 3332340992 /*20414.5*/) goto t283_n223;
  t283_n222: return -0.06297680735588074;
  t283_n223: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t283_n225;
  t283_n224: return 0.11398537456989288;
  t283_n225: return -0.10535013675689697;
  t283_n226: return 0.03292534500360489;
  t283_n227: if (E.getNumReferences() >= 3322279424 /*8573.5*/) goto t283_n229;
  t283_n228: return -0.05821837857365608;
  t283_n229: if (E.getNumReferences() >= 3322461184 /*8751.0*/) goto t283_n231;
  t283_n230: return 0.10199764370918274;
  t283_n231: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t283_n233;
  t283_n232: return -0.14517387747764587;
  t283_n233: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t283_n235;
  t283_n234: return 0.11197619885206223;
  t283_n235: return 0.07863756269216537;
  t283_n236: return 0.006068825721740723;
  t283_n237: if (E.getNumReferences() >= 3329272320 /*15402.5*/) goto t283_n249;
  t283_n238: if (E.getNumReferences() >= 3318817792 /*6692.5*/) goto t283_n240;
  t283_n239: return -0.060661930590867996;
  t283_n240: if (E.getNumReferences() >= 3322330112 /*8623.0*/) goto t283_n244;
  t283_n241: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t283_n243;
  t283_n242: return -0.06507992744445801;
  t283_n243: return 0.12244711816310883;
  t283_n244: if (E.getNumReferences() >= 3325912064 /*12121.0*/) goto t283_n246;
  t283_n245: return -0.07987646758556366;
  t283_n246: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t283_n248;
  t283_n247: return 0.7541830539703369;
  t283_n248: return 0.139249786734581;
  t283_n249: return 0.0401856005191803;
  t283_n250: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t283_n252;
  t283_n251: return -0.05724320188164711;
  t283_n252: if (E.getNumReferences() >= 3314238464 /*4456.5*/) goto t283_n254;
  t283_n253: return -0.4270537793636322;
  t283_n254: return 0.03688452020287514;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree284(const Example& E) {
  t284_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t284_n2;
  t284_n1: return -0.000293208344373852;
  t284_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t284_n98;
  t284_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t284_n7;
  t284_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t284_n6;
  t284_n5: return -0.11580107361078262;
  t284_n6: return 0.004421899560838938;
  t284_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t284_n51;
  t284_n8: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t284_n36;
  t284_n9: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t284_n21;
  t284_n10: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t284_n14;
  t284_n11: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n13;
  t284_n12: return 0.05231141299009323;
  t284_n13: return -0.12960867583751678;
  t284_n14: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t284_n16;
  t284_n15: return -0.010776110924780369;
  t284_n16: if (E.getNumReferences() >= 3291176960 /*685.5*/) goto t284_n18;
  t284_n17: return -0.2406335175037384;
  t284_n18: if (E.getNumReferences() >= 3294339072 /*878.5*/) goto t284_n20;
  t284_n19: return 0.1001439169049263;
  t284_n20: return 0.05841011181473732;
  t284_n21: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t284_n31;
  t284_n22: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t284_n30;
  t284_n23: if (E.getNumReferences() >= 3286171648 /*446.0*/) goto t284_n25;
  t284_n24: return -0.1049758791923523;
  t284_n25: if (E.getNumReferences() >= 3289227264 /*566.5*/) goto t284_n27;
  t284_n26: return 0.11441770195960999;
  t284_n27: if (E.getNumReferences() >= 3295690752 /*961.0*/) goto t284_n29;
  t284_n28: return -0.13594281673431396;
  t284_n29: return 0.09117726236581802;
  t284_n30: return -0.24916715919971466;
  t284_n31: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t284_n33;
  t284_n32: return -0.22909773886203766;
  t284_n33: if (E.getNumReferences() >= 3291889664 /*729.0*/) goto t284_n35;
  t284_n34: return 0.1133754700422287;
  t284_n35: return 0.08200542628765106;
  t284_n36: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t284_n50;
  t284_n37: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t284_n47;
  t284_n38: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t284_n40;
  t284_n39: return 0.01672496646642685;
  t284_n40: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t284_n46;
  t284_n41: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n43;
  t284_n42: return -0.1308351308107376;
  t284_n43: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n45;
  t284_n44: return 0.15408658981323242;
  t284_n45: return 0.08870281279087067;
  t284_n46: return 0.154104545712471;
  t284_n47: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t284_n49;
  t284_n48: return 0.0020276394207030535;
  t284_n49: return 0.05660704895853996;
  t284_n50: return -0.12898777425289154;
  t284_n51: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t284_n67;
  t284_n52: if (E.getNumReferences() >= 3287891968 /*498.5*/) goto t284_n66;
  t284_n53: if (E.getNumReferences() >= 3285139456 /*414.5*/) goto t284_n55;
  t284_n54: return -0.04358537867665291;
  t284_n55: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t284_n65;
  t284_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t284_n64;
  t284_n57: if (E.getNumReferences() >= 3285549056 /*427.0*/) goto t284_n59;
  t284_n58: return 0.09292998909950256;
  t284_n59: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n63;
  t284_n60: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t284_n62;
  t284_n61: return 0.07983754575252533;
  t284_n62: return -0.2835056483745575;
  t284_n63: return 0.1132078468799591;
  t284_n64: return -0.026648813858628273;
  t284_n65: return 0.09115895628929138;
  t284_n66: return 0.10571198910474777;
  t284_n67: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n69;
  t284_n68: return -0.028748370707035065;
  t284_n69: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t284_n97;
  t284_n70: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t284_n96;
  t284_n71: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t284_n77;
  t284_n72: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t284_n74;
  t284_n73: return -0.052326750010252;
  t284_n74: if (E.getNumReferences() >= 3290718208 /*657.5*/) goto t284_n76;
  t284_n75: return 0.01697167195379734;
  t284_n76: return 0.09106671810150146;
  t284_n77: if (E.getNumReferences() >= 3294314496 /*877.0*/) goto t284_n81;
  t284_n78: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t284_n80;
  t284_n79: return 0.11237639933824539;
  t284_n80: return 0.014332742430269718;
  t284_n81: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t284_n91;
  t284_n82: if (E.getNumReferences() >= 3301900288 /*1656.0*/) goto t284_n86;
  t284_n83: if (E.getNumReferences() >= 3296133120 /*988.0*/) goto t284_n85;
  t284_n84: return 0.10036862641572952;
  t284_n85: return -0.2852354943752289;
  t284_n86: if (E.getFileProximityDistance() >= 3235905536 /*7.0*/) goto t284_n90;
  t284_n87: if (E.getNumReferences() >= 3312216064 /*3782.5*/) goto t284_n89;
  t284_n88: return 0.10809610784053802;
  t284_n89: return 0.06849242001771927;
  t284_n90: return -0.059140171855688095;
  t284_n91: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t284_n95;
  t284_n92: if (E.getNumReferences() >= 3316801536 /*5708.0*/) goto t284_n94;
  t284_n93: return -0.028209418058395386;
  t284_n94: return 0.10275864601135254;
  t284_n95: return -0.26587679982185364;
  t284_n96: return 0.10109678655862808;
  t284_n97: return 0.10423307120800018;
  t284_n98: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t284_n132;
  t284_n99: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t284_n103;
  t284_n100: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t284_n102;
  t284_n101: return -0.10540840029716492;
  t284_n102: return 0.09166263788938522;
  t284_n103: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Namespace))) goto t284_n105;
  t284_n104: return 0.023109493777155876;
  t284_n105: if (E.getNumReferences() >= 3311517696 /*3612.0*/) goto t284_n127;
  t284_n106: if (E.getNumReferences() >= 3306639360 /*2421.0*/) goto t284_n124;
  t284_n107: if (E.getNumReferences() >= 3289849856 /*604.5*/) goto t284_n117;
  t284_n108: if (E.getNumReferences() >= 3289677824 /*594.0*/) goto t284_n116;
  t284_n109: if (E.getNumReferences() >= 3288891392 /*546.0*/) goto t284_n115;
  t284_n110: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t284_n112;
  t284_n111: return -0.12513430416584015;
  t284_n112: if (E.getNumReferences() >= 3285975040 /*440.0*/) goto t284_n114;
  t284_n113: return 0.10247643291950226;
  t284_n114: return 0.025807388126850128;
  t284_n115: return 0.11034126579761505;
  t284_n116: return 0.10499070584774017;
  t284_n117: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t284_n119;
  t284_n118: return -0.21788667142391205;
  t284_n119: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t284_n123;
  t284_n120: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t284_n122;
  t284_n121: return 0.10109201818704605;
  t284_n122: return 0.056976884603500366;
  t284_n123: return 0.03337981924414635;
  t284_n124: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t284_n126;
  t284_n125: return 0.050350889563560486;
  t284_n126: return 0.11054517328739166;
  t284_n127: if (E.getNumReferences() >= 3341172352 /*42558.5*/) goto t284_n131;
  t284_n128: if (E.getNumReferences() >= 3338888448 /*33637.0*/) goto t284_n130;
  t284_n129: return -0.054677367210388184;
  t284_n130: return -1.1913989782333374;
  t284_n131: return 0.10304208844900131;
  t284_n132: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t284_n134;
  t284_n133: return -0.0007236163364723325;
  t284_n134: if (E.getNumReferences() >= 3319569408 /*7059.5*/) goto t284_n254;
  t284_n135: if (E.getNumReferences() >= 3319397376 /*6975.5*/) goto t284_n253;
  t284_n136: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t284_n252;
  t284_n137: if (E.getNumReferences() >= 3318611968 /*6592.0*/) goto t284_n241;
  t284_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Type))) goto t284_n160;
  t284_n139: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t284_n141;
  t284_n140: return -0.00044029977289028466;
  t284_n141: if (E.getNumReferences() >= 3287498752 /*486.5*/) goto t284_n153;
  t284_n142: if (E.getNumReferences() >= 3286581248 /*458.5*/) goto t284_n148;
  t284_n143: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t284_n145;
  t284_n144: return -0.17104382812976837;
  t284_n145: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t284_n147;
  t284_n146: return 0.06531007587909698;
  t284_n147: return -0.09447276592254639;
  t284_n148: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n150;
  t284_n149: return -0.113828644156456;
  t284_n150: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t284_n152;
  t284_n151: return 0.09685694426298141;
  t284_n152: return -0.07454726845026016;
  t284_n153: if (E.getNumReferences() >= 3296690176 /*1022.0*/) goto t284_n157;
  t284_n154: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n156;
  t284_n155: return -0.12367873638868332;
  t284_n156: return 0.04243375360965729;
  t284_n157: if (E.getNumReferences() >= 3297062912 /*1065.5*/) goto t284_n159;
  t284_n158: return 0.10560819506645203;
  t284_n159: return 0.03779331594705582;
  t284_n160: if (E.getNumReferences() >= 3290365952 /*636.0*/) goto t284_n174;
  t284_n161: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t284_n173;
  t284_n162: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t284_n164;
  t284_n163: return -0.035955414175987244;
  t284_n164: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t284_n168;
  t284_n165: if (E.getNumReferences() >= 3285549056 /*427.0*/) goto t284_n167;
  t284_n166: return 0.110667385160923;
  t284_n167: return -0.2874946892261505;
  t284_n168: if (E.getNumReferences() >= 3289071616 /*557.0*/) goto t284_n172;
  t284_n169: if (E.getNumReferences() >= 3288506368 /*522.5*/) goto t284_n171;
  t284_n170: return 0.07902505993843079;
  t284_n171: return 0.15036581456661224;
  t284_n172: return -0.14462575316429138;
  t284_n173: return -0.9662525057792664;
  t284_n174: if (E.getNumReferences() >= 3293151232 /*806.0*/) goto t284_n198;
  t284_n175: if (E.getNumReferences() >= 3292684288 /*777.5*/) goto t284_n189;
  t284_n176: if (E.getNumReferences() >= 3291660288 /*715.0*/) goto t284_n188;
  t284_n177: if (E.getNumReferences() >= 3291521024 /*706.5*/) goto t284_n187;
  t284_n178: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t284_n184;
  t284_n179: if (E.getNumReferences() >= 3290972160 /*673.0*/) goto t284_n183;
  t284_n180: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t284_n182;
  t284_n181: return 0.029001938179135323;
  t284_n182: return 0.09638265520334244;
  t284_n183: return -0.2363768219947815;
  t284_n184: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t284_n186;
  t284_n185: return 0.08599825948476791;
  t284_n186: return 0.014685327187180519;
  t284_n187: return 0.12714150547981262;
  t284_n188: return -0.08907788246870041;
  t284_n189: if (E.getNumReferences() >= 3292782592 /*783.5*/) goto t284_n193;
  t284_n190: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t284_n192;
  t284_n191: return 0.09831973165273666;
  t284_n192: return 0.1013672798871994;
  t284_n193: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t284_n197;
  t284_n194: if (E.getNumReferences() >= 3292880896 /*789.5*/) goto t284_n196;
  t284_n195: return -0.037148136645555496;
  t284_n196: return 0.10868088901042938;
  t284_n197: return -0.48110005259513855;
  t284_n198: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n232;
  t284_n199: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t284_n201;
  t284_n200: return -0.34481531381607056;
  t284_n201: if (E.getNumReferences() >= 3295535104 /*951.5*/) goto t284_n203;
  t284_n202: return -0.2005741447210312;
  t284_n203: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t284_n205;
  t284_n204: return 0.01711219735443592;
  t284_n205: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t284_n213;
  t284_n206: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t284_n212;
  t284_n207: if (E.getNumReferences() >= 3297787904 /*1154.0*/) goto t284_n211;
  t284_n208: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t284_n210;
  t284_n209: return -0.12012318521738052;
  t284_n210: return 0.8177352547645569;
  t284_n211: return -0.17224536836147308;
  t284_n212: return 0.17005771398544312;
  t284_n213: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n227;
  t284_n214: if (E.getNumReferences() >= 3300458496 /*1480.0*/) goto t284_n220;
  t284_n215: if (E.getNumReferences() >= 3297886208 /*1166.0*/) goto t284_n219;
  t284_n216: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t284_n218;
  t284_n217: return 0.0837307870388031;
  t284_n218: return -0.1545955240726471;
  t284_n219: return 0.12898553907871246;
  t284_n220: if (E.getNumReferences() >= 3306293248 /*2336.5*/) goto t284_n222;
  t284_n221: return -0.1571582853794098;
  t284_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t284_n224;
  t284_n223: return -0.15441571176052094;
  t284_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t284_n226;
  t284_n225: return 0.08601412922143936;
  t284_n226: return 0.14660537242889404;
  t284_n227: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Symbol))) goto t284_n231;
  t284_n228: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t284_n230;
  t284_n229: return -0.046445202082395554;
  t284_n230: return 0.09809103608131409;
  t284_n231: return 0.10120803117752075;
  t284_n232: if (E.getNumReferences() >= 3318055936 /*6320.5*/) goto t284_n236;
  t284_n233: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t284_n235;
  t284_n234: return -0.02186264656484127;
  t284_n235: return 0.02779659815132618;
  t284_n236: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t284_n238;
  t284_n237: return -0.013022946193814278;
  t284_n238: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t284_n240;
  t284_n239: return -1.217344045639038;
  t284_n240: return -0.3018433749675751;
  t284_n241: if (E.getNumReferences() >= 3318784000 /*6676.0*/) goto t284_n251;
  t284_n242: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t284_n246;
  t284_n243: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t284_n245;
  t284_n244: return -0.28168749809265137;
  t284_n245: return 0.12059376388788223;
  t284_n246: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t284_n250;
  t284_n247: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t284_n249;
  t284_n248: return 0.10045457631349564;
  t284_n249: return 0.06603001803159714;
  t284_n250: return -0.14248716831207275;
  t284_n251: return 0.018570873886346817;
  t284_n252: return 0.09975786507129669;
  t284_n253: return 0.10914259403944016;
  t284_n254: return 0.0037214960902929306;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree285(const Example& E) {
  t285_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t285_n2;
  t285_n1: return -0.00027685044915415347;
  t285_n2: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t285_n34;
  t285_n3: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::FileScope))) goto t285_n15;
  t285_n4: if (E.getNumReferences() >= 3317489664 /*6044.0*/) goto t285_n14;
  t285_n5: if (E.getNumReferences() >= 3300917248 /*1536.0*/) goto t285_n7;
  t285_n6: return -0.004306808114051819;
  t285_n7: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n9;
  t285_n8: return 0.1360553652048111;
  t285_n9: if (E.getNumReferences() >= 3301826560 /*1647.0*/) goto t285_n11;
  t285_n10: return 0.15802070498466492;
  t285_n11: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t285_n13;
  t285_n12: return 0.012312822043895721;
  t285_n13: return 0.1065576896071434;
  t285_n14: return -0.11739646643400192;
  t285_n15: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t285_n17;
  t285_n16: return 0.09608727693557739;
  t285_n17: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n29;
  t285_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t285_n20;
  t285_n19: return -0.025843998417258263;
  t285_n20: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t285_n26;
  t285_n21: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t285_n23;
  t285_n22: return -0.10510219633579254;
  t285_n23: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t285_n25;
  t285_n24: return -0.0018059361027553678;
  t285_n25: return 0.08998598903417587;
  t285_n26: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t285_n28;
  t285_n27: return -0.013504080474376678;
  t285_n28: return -0.25199639797210693;
  t285_n29: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t285_n31;
  t285_n30: return 0.009207721799612045;
  t285_n31: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t285_n33;
  t285_n32: return 0.056249864399433136;
  t285_n33: return -0.0653035044670105;
  t285_n34: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t285_n254;
  t285_n35: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t285_n37;
  t285_n36: return 0.007049051579087973;
  t285_n37: if (E.getNumReferences() >= 3290374144 /*636.5*/) goto t285_n199;
  t285_n38: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t285_n86;
  t285_n39: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n73;
  t285_n40: if (E.getNumReferences() >= 3289948160 /*610.5*/) goto t285_n72;
  t285_n41: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t285_n61;
  t285_n42: if (E.getNumReferences() >= 3266248704 /*87.5*/) goto t285_n46;
  t285_n43: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n45;
  t285_n44: return 0.044115811586380005;
  t285_n45: return -0.7690717577934265;
  t285_n46: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t285_n48;
  t285_n47: return 0.05730368196964264;
  t285_n48: if (E.getNumReferences() >= 3280601088 /*276.0*/) goto t285_n60;
  t285_n49: if (E.getNumReferences() >= 3277357056 /*216.5*/) goto t285_n59;
  t285_n50: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t285_n56;
  t285_n51: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n55;
  t285_n52: if (E.getNumReferences() >= 3268608000 /*105.5*/) goto t285_n54;
  t285_n53: return 0.1387208253145218;
  t285_n54: return 0.07770140469074249;
  t285_n55: return -0.005552884191274643;
  t285_n56: if (E.getNumReferences() >= 3272900608 /*148.5*/) goto t285_n58;
  t285_n57: return -0.07524048537015915;
  t285_n58: return 0.11294630169868469;
  t285_n59: return 0.15435722470283508;
  t285_n60: return -0.08354903012514114;
  t285_n61: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n69;
  t285_n62: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n66;
  t285_n63: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t285_n65;
  t285_n64: return 0.14267420768737793;
  t285_n65: return -0.0010256090899929404;
  t285_n66: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t285_n68;
  t285_n67: return 0.12618765234947205;
  t285_n68: return 0.43126416206359863;
  t285_n69: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t285_n71;
  t285_n70: return 0.040497925132513046;
  t285_n71: return -0.8257911801338196;
  t285_n72: return 0.11646075546741486;
  t285_n73: if (E.getNumReferences() >= 3276308480 /*200.5*/) goto t285_n83;
  t285_n74: if (E.getNumReferences() >= 3275522048 /*188.5*/) goto t285_n82;
  t285_n75: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t285_n81;
  t285_n76: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t285_n80;
  t285_n77: if (E.getNumReferences() >= 3272048640 /*135.5*/) goto t285_n79;
  t285_n78: return -0.7015922665596008;
  t285_n79: return 0.13757175207138062;
  t285_n80: return 0.10803738981485367;
  t285_n81: return -0.08436799049377441;
  t285_n82: return 0.1321702003479004;
  t285_n83: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t285_n85;
  t285_n84: return -0.15047450363636017;
  t285_n85: return 0.9602012038230896;
  t285_n86: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t285_n196;
  t285_n87: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t285_n123;
  t285_n88: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t285_n118;
  t285_n89: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t285_n101;
  t285_n90: if (E.getNumReferences() >= 3264937984 /*77.5*/) goto t285_n96;
  t285_n91: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t285_n93;
  t285_n92: return -1.0605086088180542;
  t285_n93: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n95;
  t285_n94: return 0.25906750559806824;
  t285_n95: return -0.10972587019205093;
  t285_n96: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n100;
  t285_n97: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n99;
  t285_n98: return 0.10066276043653488;
  t285_n99: return 0.10184939950704575;
  t285_n100: return -0.10185706615447998;
  t285_n101: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n111;
  t285_n102: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t285_n110;
  t285_n103: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n107;
  t285_n104: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n106;
  t285_n105: return -0.879972517490387;
  t285_n106: return -0.15921558439731598;
  t285_n107: if (E.getNumReferences() >= 3278045184 /*227.0*/) goto t285_n109;
  t285_n108: return -0.13296951353549957;
  t285_n109: return 0.11055203527212143;
  t285_n110: return 0.0582372285425663;
  t285_n111: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t285_n117;
  t285_n112: if (E.getNumReferences() >= 3281616896 /*307.0*/) goto t285_n116;
  t285_n113: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t285_n115;
  t285_n114: return -0.08876724541187286;
  t285_n115: return 0.08191868662834167;
  t285_n116: return 0.10602972656488419;
  t285_n117: return 0.025963537395000458;
  t285_n118: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t285_n120;
  t285_n119: return -0.027201607823371887;
  t285_n120: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t285_n122;
  t285_n121: return 0.12823866307735443;
  t285_n122: return 0.02314002998173237;
  t285_n123: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t285_n193;
  t285_n124: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t285_n184;
  t285_n125: if (E.getNumReferences() >= 3279683584 /*252.0*/) goto t285_n183;
  t285_n126: if (E.getNumReferences() >= 3270049792 /*116.5*/) goto t285_n140;
  t285_n127: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t285_n129;
  t285_n128: return -0.09178753942251205;
  t285_n129: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t285_n139;
  t285_n130: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t285_n138;
  t285_n131: if (E.getFilterLength() >= 3239575552 /*9.5*/) goto t285_n137;
  t285_n132: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n136;
  t285_n133: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n135;
  t285_n134: return -0.1644829362630844;
  t285_n135: return 0.12376817315816879;
  t285_n136: return -0.375501811504364;
  t285_n137: return 0.12216120958328247;
  t285_n138: return 0.07481014728546143;
  t285_n139: return -0.040564537048339844;
  t285_n140: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t285_n180;
  t285_n141: if (E.getNumReferences() >= 3271786496 /*131.5*/) goto t285_n149;
  t285_n142: if (E.getNumReferences() >= 3271720960 /*130.5*/) goto t285_n148;
  t285_n143: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t285_n145;
  t285_n144: return 0.05229447782039642;
  t285_n145: if (E.getNumReferences() >= 3270639616 /*121.0*/) goto t285_n147;
  t285_n146: return -0.12270668148994446;
  t285_n147: return 0.21200445294380188;
  t285_n148: return 0.1072971299290657;
  t285_n149: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t285_n159;
  t285_n150: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t285_n152;
  t285_n151: return -0.03189234063029289;
  t285_n152: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t285_n158;
  t285_n153: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t285_n157;
  t285_n154: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t285_n156;
  t285_n155: return -0.10342882573604584;
  t285_n156: return 0.12823888659477234;
  t285_n157: return -0.3105246126651764;
  t285_n158: return 0.09155721217393875;
  t285_n159: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t285_n165;
  t285_n160: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t285_n164;
  t285_n161: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t285_n163;
  t285_n162: return 0.20706842839717865;
  t285_n163: return -0.1597525030374527;
  t285_n164: return 0.1043190136551857;
  t285_n165: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t285_n167;
  t285_n166: return -0.0019793843384832144;
  t285_n167: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t285_n175;
  t285_n168: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t285_n172;
  t285_n169: if (E.getNumReferences() >= 3275554816 /*189.0*/) goto t285_n171;
  t285_n170: return 0.11328506469726562;
  t285_n171: return -0.028953013941645622;
  t285_n172: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t285_n174;
  t285_n173: return 0.16564035415649414;
  t285_n174: return -0.10044564306735992;
  t285_n175: if (E.getNumReferences() >= 3278667776 /*236.5*/) goto t285_n177;
  t285_n176: return -0.15675204992294312;
  t285_n177: if (E.getNumReferences() >= 3278864384 /*239.5*/) goto t285_n179;
  t285_n178: return 0.10889805108308792;
  t285_n179: return -0.11091241985559464;
  t285_n180: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t285_n182;
  t285_n181: return 0.12532341480255127;
  t285_n182: return 0.13569827377796173;
  t285_n183: return 0.10914907604455948;
  t285_n184: if (E.getNumReferences() >= 3287662592 /*491.5*/) goto t285_n190;
  t285_n185: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t285_n187;
  t285_n186: return -0.14398494362831116;
  t285_n187: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t285_n189;
  t285_n188: return -0.08701593428850174;
  t285_n189: return 0.0376657173037529;
  t285_n190: if (E.getNumReferences() >= 3287924736 /*499.5*/) goto t285_n192;
  t285_n191: return 0.08070552349090576;
  t285_n192: return 0.03728087246417999;
  t285_n193: if (E.getNumReferences() >= 3266379776 /*88.5*/) goto t285_n195;
  t285_n194: return 0.10914114862680435;
  t285_n195: return 0.09649910032749176;
  t285_n196: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t285_n198;
  t285_n197: return 0.10048885643482208;
  t285_n198: return -0.126892551779747;
  t285_n199: if (E.getNumReferences() >= 3293290496 /*814.5*/) goto t285_n205;
  t285_n200: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t285_n202;
  t285_n201: return -0.07722406834363937;
  t285_n202: if (E.getFileProximityDistance() >= 3246391296 /*16.0*/) goto t285_n204;
  t285_n203: return -0.13375425338745117;
  t285_n204: return -1.3035396337509155;
  t285_n205: if (E.getNumReferences() >= 3293315072 /*816.0*/) goto t285_n207;
  t285_n206: return 0.08472920209169388;
  t285_n207: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t285_n215;
  t285_n208: if (E.getNumReferences() >= 3319490560 /*7021.0*/) goto t285_n212;
  t285_n209: if (E.getNumReferences() >= 3293913088 /*852.5*/) goto t285_n211;
  t285_n210: return 0.0987725630402565;
  t285_n211: return -0.09313010424375534;
  t285_n212: if (E.getNumReferences() >= 3319629824 /*7089.0*/) goto t285_n214;
  t285_n213: return 0.11110108345746994;
  t285_n214: return -0.006799082737416029;
  t285_n215: if (E.getNumReferences() >= 3293495296 /*827.0*/) goto t285_n221;
  t285_n216: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t285_n218;
  t285_n217: return -0.13074567914009094;
  t285_n218: if (E.getFilterLength() >= 3233808384 /*6.0*/) goto t285_n220;
  t285_n219: return 0.15179823338985443;
  t285_n220: return -0.12967830896377563;
  t285_n221: if (E.getNumReferences() >= 3295453184 /*946.5*/) goto t285_n223;
  t285_n222: return -0.13924144208431244;
  t285_n223: if (E.getNumReferences() >= 3295698944 /*961.5*/) goto t285_n227;
  t285_n224: if (E.getFileProximityDistance() >= 3244294144 /*14.0*/) goto t285_n226;
  t285_n225: return 0.11375366896390915;
  t285_n226: return 0.0597112812101841;
  t285_n227: if (E.getFileProximityDistance() >= 3231711232 /*5.0*/) goto t285_n229;
  t285_n228: return 0.09970507770776749;
  t285_n229: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t285_n231;
  t285_n230: return -0.47748181223869324;
  t285_n231: if (E.getNumReferences() >= 3362781216 /*245728.5*/) goto t285_n253;
  t285_n232: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t285_n240;
  t285_n233: if (E.getNumReferences() >= 3347438016 /*68531.5*/) goto t285_n239;
  t285_n234: if (E.getNumReferences() >= 3343006592 /*49723.5*/) goto t285_n238;
  t285_n235: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t285_n237;
  t285_n236: return 0.007808004040271044;
  t285_n237: return 0.034993983805179596;
  t285_n238: return -0.06027071177959442;
  t285_n239: return -0.6127010583877563;
  t285_n240: if (E.getNumReferences() >= 3352414592 /*107411.0*/) goto t285_n252;
  t285_n241: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t285_n251;
  t285_n242: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t285_n250;
  t285_n243: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t285_n245;
  t285_n244: return 0.07338724285364151;
  t285_n245: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t285_n247;
  t285_n246: return 0.09835419058799744;
  t285_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t285_n249;
  t285_n248: return 0.03691338747739792;
  t285_n249: return 0.10791032761335373;
  t285_n250: return 0.13360120356082916;
  t285_n251: return 0.04714198410511017;
  t285_n252: return 0.0026158231776207685;
  t285_n253: return -0.25632941722869873;
  t285_n254: return -1.2111814612580929e-05;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree286(const Example& E) {
  t286_n0: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t286_n26;
  t286_n1: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t286_n3;
  t286_n2: return -0.027640795335173607;
  t286_n3: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t286_n5;
  t286_n4: return 0.0037766355089843273;
  t286_n5: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t286_n7;
  t286_n6: return -0.000159332063049078;
  t286_n7: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t286_n11;
  t286_n8: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t286_n10;
  t286_n9: return -0.020967500284314156;
  t286_n10: return -0.05218067765235901;
  t286_n11: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n13;
  t286_n12: return 0.02793486788868904;
  t286_n13: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t286_n19;
  t286_n14: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t286_n18;
  t286_n15: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t286_n17;
  t286_n16: return 0.013917871750891209;
  t286_n17: return 0.08833912760019302;
  t286_n18: return 0.14382237195968628;
  t286_n19: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t286_n21;
  t286_n20: return 0.061350543051958084;
  t286_n21: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t286_n23;
  t286_n22: return 0.11011804640293121;
  t286_n23: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t286_n25;
  t286_n24: return -0.28885096311569214;
  t286_n25: return 0.1254620999097824;
  t286_n26: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t286_n254;
  t286_n27: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t286_n97;
  t286_n28: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName))) goto t286_n62;
  t286_n29: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t286_n61;
  t286_n30: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t286_n52;
  t286_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t286_n33;
  t286_n32: return 0.0011279820464551449;
  t286_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n35;
  t286_n34: return 0.07844597101211548;
  t286_n35: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t286_n45;
  t286_n36: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t286_n38;
  t286_n37: return 0.03274885565042496;
  t286_n38: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t286_n44;
  t286_n39: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t286_n41;
  t286_n40: return 0.06416144967079163;
  t286_n41: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t286_n43;
  t286_n42: return 0.09739222377538681;
  t286_n43: return 0.06273659318685532;
  t286_n44: return 0.0003498863079585135;
  t286_n45: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t286_n49;
  t286_n46: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t286_n48;
  t286_n47: return 0.13868224620819092;
  t286_n48: return -0.010730862617492676;
  t286_n49: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t286_n51;
  t286_n50: return 0.12056254595518112;
  t286_n51: return -0.18404386937618256;
  t286_n52: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n54;
  t286_n53: return 0.10353568941354752;
  t286_n54: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t286_n56;
  t286_n55: return 0.046095412224531174;
  t286_n56: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n58;
  t286_n57: return 0.050532400608062744;
  t286_n58: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t286_n60;
  t286_n59: return 0.11808845400810242;
  t286_n60: return -0.06193391978740692;
  t286_n61: return -0.003245669649913907;
  t286_n62: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t286_n96;
  t286_n63: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t286_n87;
  t286_n64: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t286_n66;
  t286_n65: return 0.017559293657541275;
  t286_n66: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t286_n68;
  t286_n67: return 0.08762554079294205;
  t286_n68: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n86;
  t286_n69: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t286_n81;
  t286_n70: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t286_n78;
  t286_n71: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n73;
  t286_n72: return 0.05994492024183273;
  t286_n73: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n77;
  t286_n74: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t286_n76;
  t286_n75: return 0.11547673493623734;
  t286_n76: return 0.09376700967550278;
  t286_n77: return 0.0662200003862381;
  t286_n78: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n80;
  t286_n79: return -0.21107839047908783;
  t286_n80: return 0.08109308034181595;
  t286_n81: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n85;
  t286_n82: if (E.getNumReferences() >= 3230662656 /*4.5*/) goto t286_n84;
  t286_n83: return 0.11395778506994247;
  t286_n84: return -0.12081696093082428;
  t286_n85: return -0.09101632982492447;
  t286_n86: return -0.017043383792042732;
  t286_n87: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t286_n95;
  t286_n88: if (E.getNumReferences() >= 3325698048 /*11912.0*/) goto t286_n90;
  t286_n89: return 0.013889669440686703;
  t286_n90: if (E.getNumReferences() >= 3325825536 /*12036.5*/) goto t286_n94;
  t286_n91: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t286_n93;
  t286_n92: return 0.12657904624938965;
  t286_n93: return -0.055555764585733414;
  t286_n94: return 0.020419107750058174;
  t286_n95: return -0.19928662478923798;
  t286_n96: return 0.013433392159640789;
  t286_n97: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t286_n105;
  t286_n98: if (E.getScope() & (BIT(Scope_type::ClassScope))) goto t286_n100;
  t286_n99: return 0.001141635701060295;
  t286_n100: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t286_n102;
  t286_n101: return 0.0064758858643472195;
  t286_n102: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t286_n104;
  t286_n103: return 0.02488834224641323;
  t286_n104: return -0.12950974702835083;
  t286_n105: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t286_n253;
  t286_n106: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t286_n146;
  t286_n107: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t286_n119;
  t286_n108: if (E.getScope() & (BIT(Scope_type::FileScope))) goto t286_n112;
  t286_n109: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t286_n111;
  t286_n110: return 0.023344721645116806;
  t286_n111: return -0.03974998742341995;
  t286_n112: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n116;
  t286_n113: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n115;
  t286_n114: return -0.15785697102546692;
  t286_n115: return 0.09330374747514725;
  t286_n116: if (E.getFileProximityDistance() >= 3472883712 /*2147483648.0*/) goto t286_n118;
  t286_n117: return 0.14863519370555878;
  t286_n118: return -0.01598377153277397;
  t286_n119: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t286_n127;
  t286_n120: if (E.getSymbolScopeDistance() >= 3241148416 /*11.0*/) goto t286_n122;
  t286_n121: return 0.10876227915287018;
  t286_n122: if (E.getIsDeprecated() >= 3204448256 /*0.5*/) goto t286_n126;
  t286_n123: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t286_n125;
  t286_n124: return 0.024586116895079613;
  t286_n125: return -0.020505497232079506;
  t286_n126: return 0.15445604920387268;
  t286_n127: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t286_n145;
  t286_n128: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t286_n144;
  t286_n129: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t286_n143;
  t286_n130: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t286_n134;
  t286_n131: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t286_n133;
  t286_n132: return -0.00813473854213953;
  t286_n133: return 0.07639884948730469;
  t286_n134: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n142;
  t286_n135: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n137;
  t286_n136: return 0.09765497595071793;
  t286_n137: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t286_n139;
  t286_n138: return 0.08840020000934601;
  t286_n139: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n141;
  t286_n140: return -0.31973445415496826;
  t286_n141: return 0.1202089786529541;
  t286_n142: return 0.02543638087809086;
  t286_n143: return 0.05545240640640259;
  t286_n144: return 0.02818628028035164;
  t286_n145: return -0.10659874975681305;
  t286_n146: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t286_n148;
  t286_n147: return -0.06020186096429825;
  t286_n148: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t286_n238;
  t286_n149: if (E.getIsReservedName() >= 3204448256 /*0.5*/) goto t286_n237;
  t286_n150: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t286_n220;
  t286_n151: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t286_n179;
  t286_n152: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t286_n164;
  t286_n153: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t286_n163;
  t286_n154: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n156;
  t286_n155: return 0.05034222826361656;
  t286_n156: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t286_n160;
  t286_n157: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n159;
  t286_n158: return 0.05291450023651123;
  t286_n159: return 0.006963761989027262;
  t286_n160: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n162;
  t286_n161: return 0.0755922868847847;
  t286_n162: return 0.08720005303621292;
  t286_n163: return -0.020525451749563217;
  t286_n164: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t286_n166;
  t286_n165: return -0.011126159690320492;
  t286_n166: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t286_n178;
  t286_n167: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n177;
  t286_n168: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n172;
  t286_n169: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t286_n171;
  t286_n170: return 0.036479294300079346;
  t286_n171: return 0.06612168252468109;
  t286_n172: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t286_n174;
  t286_n173: return 0.027157247066497803;
  t286_n174: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n176;
  t286_n175: return 0.08544675260782242;
  t286_n176: return 0.08967353403568268;
  t286_n177: return 0.024487411603331566;
  t286_n178: return -0.012018010020256042;
  t286_n179: if (E.getFileProximityDistance() >= 3251372032 /*25.5*/) goto t286_n219;
  t286_n180: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t286_n196;
  t286_n181: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t286_n195;
  t286_n182: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n194;
  t286_n183: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n189;
  t286_n184: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n188;
  t286_n185: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t286_n187;
  t286_n186: return 0.08503039926290512;
  t286_n187: return 0.09935874491930008;
  t286_n188: return 0.046408649533987045;
  t286_n189: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t286_n191;
  t286_n190: return -0.0016361649613827467;
  t286_n191: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t286_n193;
  t286_n192: return 0.08593548834323883;
  t286_n193: return 0.10961548238992691;
  t286_n194: return 0.011310802772641182;
  t286_n195: return -0.043197132647037506;
  t286_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Type))) goto t286_n206;
  t286_n197: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n199;
  t286_n198: return 0.002056750236079097;
  t286_n199: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t286_n201;
  t286_n200: return 0.04266922548413277;
  t286_n201: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n205;
  t286_n202: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n204;
  t286_n203: return 0.0806875005364418;
  t286_n204: return 0.09688523411750793;
  t286_n205: return -0.17715948820114136;
  t286_n206: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n218;
  t286_n207: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n211;
  t286_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t286_n210;
  t286_n209: return 0.12150898575782776;
  t286_n210: return 0.1517508327960968;
  t286_n211: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t286_n215;
  t286_n212: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n214;
  t286_n213: return 0.12907689809799194;
  t286_n214: return 0.08277402818202972;
  t286_n215: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n217;
  t286_n216: return 0.08863648772239685;
  t286_n217: return 0.09920220822095871;
  t286_n218: return -0.0013987226411700249;
  t286_n219: return 0.0456383153796196;
  t286_n220: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n236;
  t286_n221: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t286_n227;
  t286_n222: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t286_n226;
  t286_n223: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t286_n225;
  t286_n224: return 0.013566164299845695;
  t286_n225: return 0.07266387343406677;
  t286_n226: return -0.06387076526880264;
  t286_n227: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t286_n231;
  t286_n228: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t286_n230;
  t286_n229: return 0.06866560131311417;
  t286_n230: return -0.0223728995770216;
  t286_n231: if (E.getFileProximityDistance() >= 3250323456 /*23.5*/) goto t286_n235;
  t286_n232: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t286_n234;
  t286_n233: return 0.09904742985963821;
  t286_n234: return 0.11758437007665634;
  t286_n235: return 0.01828927733004093;
  t286_n236: return -0.07853634655475616;
  t286_n237: return -0.10109958797693253;
  t286_n238: if (E.getNumReferences() >= 3312652288 /*3889.0*/) goto t286_n240;
  t286_n239: return -0.021888338029384613;
  t286_n240: if (E.getNumReferences() >= 3312812032 /*3928.0*/) goto t286_n242;
  t286_n241: return 0.1058933436870575;
  t286_n242: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t286_n244;
  t286_n243: return -0.053474050015211105;
  t286_n244: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t286_n252;
  t286_n245: if (E.getNumReferences() >= 3331624192 /*19014.5*/) goto t286_n251;
  t286_n246: if (E.getNumReferences() >= 3316534272 /*5577.5*/) goto t286_n248;
  t286_n247: return -0.2022964507341385;
  t286_n248: if (E.getFileProximityDistance() >= 3249012736 /*21.0*/) goto t286_n250;
  t286_n249: return 0.09019777178764343;
  t286_n250: return 0.11286123096942902;
  t286_n251: return 0.0844651535153389;
  t286_n252: return 0.041705306619405746;
  t286_n253: return -0.006200931500643492;
  t286_n254: return -0.04460381343960762;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree287(const Example& E) {
  t287_n0: if (E.getNumReferences() >= 3257794560 /*43.5*/) goto t287_n2;
  t287_n1: return -0.0004134258779231459;
  t287_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t287_n190;
  t287_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_TopLevel))) goto t287_n121;
  t287_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t287_n30;
  t287_n5: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t287_n15;
  t287_n6: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n8;
  t287_n7: return -0.02655639313161373;
  t287_n8: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t287_n12;
  t287_n9: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t287_n11;
  t287_n10: return 0.03750964626669884;
  t287_n11: return 0.1297018676996231;
  t287_n12: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n14;
  t287_n13: return 0.11096359044313431;
  t287_n14: return -0.29158496856689453;
  t287_n15: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n17;
  t287_n16: return -0.014811288565397263;
  t287_n17: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t287_n19;
  t287_n18: return -0.037391871213912964;
  t287_n19: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t287_n21;
  t287_n20: return -0.1440250426530838;
  t287_n21: if (E.getNumReferences() >= 3263234048 /*64.5*/) goto t287_n23;
  t287_n22: return -0.2455744594335556;
  t287_n23: if (E.getNumReferences() >= 3280568320 /*275.0*/) goto t287_n29;
  t287_n24: if (E.getNumReferences() >= 3273424896 /*156.5*/) goto t287_n28;
  t287_n25: if (E.getNumReferences() >= 3267887104 /*100.0*/) goto t287_n27;
  t287_n26: return 0.15728843212127686;
  t287_n27: return -0.08770938217639923;
  t287_n28: return 0.11379610747098923;
  t287_n29: return 0.039345528930425644;
  t287_n30: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n32;
  t287_n31: return 0.003781162900850177;
  t287_n32: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n102;
  t287_n33: if (E.getNumReferences() >= 3281027072 /*289.0*/) goto t287_n81;
  t287_n34: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t287_n46;
  t287_n35: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t287_n41;
  t287_n36: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n38;
  t287_n37: return -0.06550656259059906;
  t287_n38: if (E.getNumReferences() >= 3258318848 /*45.5*/) goto t287_n40;
  t287_n39: return 0.07084105908870697;
  t287_n40: return 0.1065715029835701;
  t287_n41: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t287_n43;
  t287_n42: return -0.12095960974693298;
  t287_n43: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n45;
  t287_n44: return 0.12269030511379242;
  t287_n45: return 0.11232214421033859;
  t287_n46: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t287_n80;
  t287_n47: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t287_n57;
  t287_n48: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n50;
  t287_n49: return -0.11289287358522415;
  t287_n50: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t287_n52;
  t287_n51: return -0.1859954446554184;
  t287_n52: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t287_n54;
  t287_n53: return -0.0709809884428978;
  t287_n54: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t287_n56;
  t287_n55: return 0.057397905737161636;
  t287_n56: return -0.09166199713945389;
  t287_n57: if (E.getNumReferences() >= 3266117632 /*86.5*/) goto t287_n67;
  t287_n58: if (E.getNumReferences() >= 3265986560 /*85.5*/) goto t287_n64;
  t287_n59: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t287_n61;
  t287_n60: return -0.03838469460606575;
  t287_n61: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t287_n63;
  t287_n62: return 0.12016778439283371;
  t287_n63: return 0.012968306429684162;
  t287_n64: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n66;
  t287_n65: return -0.27685439586639404;
  t287_n66: return 0.12629280984401703;
  t287_n67: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n69;
  t287_n68: return -0.03568573296070099;
  t287_n69: if (E.getNumReferences() >= 3268214784 /*102.5*/) goto t287_n79;
  t287_n70: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n76;
  t287_n71: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t287_n75;
  t287_n72: if (E.getNumReferences() >= 3267362816 /*96.0*/) goto t287_n74;
  t287_n73: return 0.11408285796642303;
  t287_n74: return 0.08927181363105774;
  t287_n75: return 0.04760312661528587;
  t287_n76: if (E.getNumReferences() >= 3267756032 /*99.0*/) goto t287_n78;
  t287_n77: return -0.18046027421951294;
  t287_n78: return 0.09312333166599274;
  t287_n79: return 0.01294466108083725;
  t287_n80: return -0.036308594048023224;
  t287_n81: if (E.getNumReferences() >= 3281747968 /*311.0*/) goto t287_n85;
  t287_n82: if (E.getFileProximityDistance() >= 3229614080 /*4.0*/) goto t287_n84;
  t287_n83: return 0.08723147213459015;
  t287_n84: return 0.12016530334949493;
  t287_n85: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t287_n87;
  t287_n86: return 0.010422907769680023;
  t287_n87: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n99;
  t287_n88: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t287_n90;
  t287_n89: return 0.055432237684726715;
  t287_n90: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t287_n98;
  t287_n91: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t287_n95;
  t287_n92: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n94;
  t287_n93: return 0.10957035422325134;
  t287_n94: return -0.107404924929142;
  t287_n95: if (E.getNumReferences() >= 3294699520 /*900.5*/) goto t287_n97;
  t287_n96: return 0.11229591071605682;
  t287_n97: return 0.09847649931907654;
  t287_n98: return 0.020680274814367294;
  t287_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t287_n101;
  t287_n100: return -0.09571971744298935;
  t287_n101: return 0.057889629155397415;
  t287_n102: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n112;
  t287_n103: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t287_n105;
  t287_n104: return 0.016176914796233177;
  t287_n105: if (E.getFileProximityDistance() >= 3250847744 /*24.5*/) goto t287_n109;
  t287_n106: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t287_n108;
  t287_n107: return -0.39031797647476196;
  t287_n108: return 0.035451166331768036;
  t287_n109: if (E.getNumReferences() >= 3266314240 /*88.0*/) goto t287_n111;
  t287_n110: return -0.131337508559227;
  t287_n111: return 0.11081799119710922;
  t287_n112: if (E.getNumReferences() >= 3364942528 /*296854.0*/) goto t287_n120;
  t287_n113: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t287_n115;
  t287_n114: return -0.004038703162223101;
  t287_n115: if (E.getNumReferences() >= 3258056704 /*44.5*/) goto t287_n119;
  t287_n116: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t287_n118;
  t287_n117: return 0.10590590536594391;
  t287_n118: return -0.05624571442604065;
  t287_n119: return 0.016914140433073044;
  t287_n120: return 0.05345524474978447;
  t287_n121: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t287_n161;
  t287_n122: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t287_n158;
  t287_n123: if (E.getNumReferences() >= 3362180128 /*236336.5*/) goto t287_n157;
  t287_n124: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t287_n136;
  t287_n125: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassStructUnion))) goto t287_n127;
  t287_n126: return 0.009126214310526848;
  t287_n127: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n133;
  t287_n128: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t287_n132;
  t287_n129: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t287_n131;
  t287_n130: return -0.039548151195049286;
  t287_n131: return 0.09815295785665512;
  t287_n132: return 0.12371478229761124;
  t287_n133: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t287_n135;
  t287_n134: return -0.18709465861320496;
  t287_n135: return 0.08894715458154678;
  t287_n136: if (E.getNumReferences() >= 3269263360 /*110.5*/) goto t287_n138;
  t287_n137: return -0.02642485685646534;
  t287_n138: if (E.getNumReferences() >= 3269394432 /*111.5*/) goto t287_n142;
  t287_n139: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n141;
  t287_n140: return 0.107771135866642;
  t287_n141: return -0.26030850410461426;
  t287_n142: if (E.getNumReferences() >= 3271917568 /*133.5*/) goto t287_n156;
  t287_n143: if (E.getNumReferences() >= 3271852032 /*132.5*/) goto t287_n153;
  t287_n144: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n152;
  t287_n145: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n151;
  t287_n146: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n148;
  t287_n147: return 0.13226905465126038;
  t287_n148: if (E.getNumReferences() >= 3271098368 /*124.5*/) goto t287_n150;
  t287_n149: return 0.1159411147236824;
  t287_n150: return -0.13012631237506866;
  t287_n151: return 0.056612495332956314;
  t287_n152: return -0.13106408715248108;
  t287_n153: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n155;
  t287_n154: return 0.10771477222442627;
  t287_n155: return 0.045900896191596985;
  t287_n156: return 0.006253836676478386;
  t287_n157: return 0.09378720819950104;
  t287_n158: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t287_n160;
  t287_n159: return 0.0077407206408679485;
  t287_n160: return 0.1011209487915039;
  t287_n161: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t287_n185;
  t287_n162: if (E.getNumReferences() >= 3264806912 /*76.5*/) goto t287_n184;
  t287_n163: if (E.getNumReferences() >= 3258843136 /*47.5*/) goto t287_n167;
  t287_n164: if (E.getNumReferences() >= 3258580992 /*46.5*/) goto t287_n166;
  t287_n165: return -0.16276311874389648;
  t287_n166: return 0.10467150807380676;
  t287_n167: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t287_n169;
  t287_n168: return -0.025194693356752396;
  t287_n169: if (E.getNumReferences() >= 3263889408 /*69.5*/) goto t287_n183;
  t287_n170: if (E.getNumReferences() >= 3261202432 /*56.5*/) goto t287_n176;
  t287_n171: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t287_n173;
  t287_n172: return -0.24486178159713745;
  t287_n173: if (E.getNumReferences() >= 3259629568 /*50.5*/) goto t287_n175;
  t287_n174: return -0.4019053280353546;
  t287_n175: return 0.10758465528488159;
  t287_n176: if (E.getNumReferences() >= 3262251008 /*60.5*/) goto t287_n178;
  t287_n177: return 0.08964934200048447;
  t287_n178: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t287_n180;
  t287_n179: return 0.003019560594111681;
  t287_n180: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n182;
  t287_n181: return 0.08273269981145859;
  t287_n182: return 0.16581952571868896;
  t287_n183: return -0.06082620844244957;
  t287_n184: return 0.10426879674196243;
  t287_n185: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t287_n189;
  t287_n186: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t287_n188;
  t287_n187: return 0.021087199449539185;
  t287_n188: return 0.08528076857328415;
  t287_n189: return -0.04121294245123863;
  t287_n190: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t287_n252;
  t287_n191: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t287_n193;
  t287_n192: return -0.0024592748377472162;
  t287_n193: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t287_n233;
  t287_n194: if (E.getNumReferences() >= 3266772992 /*91.5*/) goto t287_n232;
  t287_n195: if (E.getNumReferences() >= 3264282624 /*72.5*/) goto t287_n203;
  t287_n196: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t287_n200;
  t287_n197: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t287_n199;
  t287_n198: return -0.1038866713643074;
  t287_n199: return -0.00047307030763477087;
  t287_n200: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t287_n202;
  t287_n201: return 0.0791323259472847;
  t287_n202: return 0.10440223664045334;
  t287_n203: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t287_n207;
  t287_n204: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t287_n206;
  t287_n205: return 0.11460692435503006;
  t287_n206: return -0.014477663673460484;
  t287_n207: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t287_n223;
  t287_n208: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t287_n210;
  t287_n209: return -0.06694120913743973;
  t287_n210: if (E.getNumReferences() >= 3265724416 /*83.5*/) goto t287_n222;
  t287_n211: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t287_n221;
  t287_n212: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t287_n214;
  t287_n213: return -0.2635612189769745;
  t287_n214: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t287_n218;
  t287_n215: if (E.getNumReferences() >= 3264872448 /*77.0*/) goto t287_n217;
  t287_n216: return -0.1380675584077835;
  t287_n217: return 0.108941949903965;
  t287_n218: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function))) goto t287_n220;
  t287_n219: return -0.44273510575294495;
  t287_n220: return 0.08268345147371292;
  t287_n221: return 0.1183377355337143;
  t287_n222: return -0.059417497366666794;
  t287_n223: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t287_n231;
  t287_n224: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t287_n230;
  t287_n225: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t287_n229;
  t287_n226: if (E.getNumReferences() >= 3265462272 /*81.5*/) goto t287_n228;
  t287_n227: return 0.15823817253112793;
  t287_n228: return -0.00967510137706995;
  t287_n229: return 0.12193107604980469;
  t287_n230: return 0.06837449967861176;
  t287_n231: return -0.006598532199859619;
  t287_n232: return 0.0041308170184493065;
  t287_n233: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t287_n235;
  t287_n234: return -0.0064896452240645885;
  t287_n235: if (E.getNumReferences() >= 3276242944 /*199.5*/) goto t287_n239;
  t287_n236: if (E.getNumReferences() >= 3275030528 /*181.0*/) goto t287_n238;
  t287_n237: return -0.009193282574415207;
  t287_n238: return 0.12743543088436127;
  t287_n239: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t287_n245;
  t287_n240: if (E.getNumReferences() >= 3294609408 /*895.0*/) goto t287_n242;
  t287_n241: return -0.1564009189605713;
  t287_n242: if (E.getNumReferences() >= 3318227968 /*6404.5*/) goto t287_n244;
  t287_n243: return 0.11329237371683121;
  t287_n244: return -0.09562452137470245;
  t287_n245: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t287_n247;
  t287_n246: return 0.025860393419861794;
  t287_n247: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t287_n251;
  t287_n248: if (E.getNumReferences() >= 3280650240 /*277.5*/) goto t287_n250;
  t287_n249: return 0.09657605737447739;
  t287_n250: return 0.01566111482679844;
  t287_n251: return 0.10842527449131012;
  t287_n252: if (E.getFilterLength() >= 3238526976 /*8.5*/) goto t287_n254;
  t287_n253: return 0.015237560495734215;
  t287_n254: return 0.025560559704899788;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree288(const Example& E) {
  t288_n0: if (E.getNumReferences() >= 3284385792 /*391.5*/) goto t288_n2;
  t288_n1: return -0.0003132911224383861;
  t288_n2: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t288_n64;
  t288_n3: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t288_n5;
  t288_n4: return 0.002919575432315469;
  t288_n5: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t288_n33;
  t288_n6: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t288_n32;
  t288_n7: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t288_n19;
  t288_n8: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n10;
  t288_n9: return -0.05074351653456688;
  t288_n10: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t288_n12;
  t288_n11: return -0.04457610845565796;
  t288_n12: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n16;
  t288_n13: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Expression))) goto t288_n15;
  t288_n14: return 0.04811244085431099;
  t288_n15: return 0.10016925632953644;
  t288_n16: if (E.getNumReferences() >= 3298197504 /*1204.0*/) goto t288_n18;
  t288_n17: return -0.1308092325925827;
  t288_n18: return 0.08573022484779358;
  t288_n19: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t288_n27;
  t288_n20: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t288_n22;
  t288_n21: return -0.0010911333374679089;
  t288_n22: if (E.getNumReferences() >= 3295059968 /*922.5*/) goto t288_n26;
  t288_n23: if (E.getNumReferences() >= 3288489984 /*521.5*/) goto t288_n25;
  t288_n24: return 0.11264708638191223;
  t288_n25: return -0.1326747089624405;
  t288_n26: return 0.08705134689807892;
  t288_n27: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t288_n29;
  t288_n28: return -0.20437796413898468;
  t288_n29: if (E.getNumReferences() >= 3291889664 /*729.0*/) goto t288_n31;
  t288_n30: return 0.10963127017021179;
  t288_n31: return 0.08430742472410202;
  t288_n32: return 0.012081116437911987;
  t288_n33: if (E.getNumReferences() >= 3288252416 /*509.5*/) goto t288_n43;
  t288_n34: if (E.getNumReferences() >= 3287891968 /*498.5*/) goto t288_n42;
  t288_n35: if (E.getNumReferences() >= 3285073920 /*412.5*/) goto t288_n37;
  t288_n36: return -0.04650748893618584;
  t288_n37: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t288_n41;
  t288_n38: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n40;
  t288_n39: return 0.07133546471595764;
  t288_n40: return -0.02451709657907486;
  t288_n41: return 0.08616013079881668;
  t288_n42: return 0.10256737470626831;
  t288_n43: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t288_n45;
  t288_n44: return -0.024533092975616455;
  t288_n45: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t288_n63;
  t288_n46: if (E.getNumReferences() >= 3292340224 /*756.5*/) goto t288_n48;
  t288_n47: return -0.011429209262132645;
  t288_n48: if (E.getNumReferences() >= 3294167040 /*868.0*/) goto t288_n52;
  t288_n49: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n51;
  t288_n50: return 0.10649380832910538;
  t288_n51: return 0.04679858684539795;
  t288_n52: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t288_n60;
  t288_n53: if (E.getNumReferences() >= 3301900288 /*1656.0*/) goto t288_n55;
  t288_n54: return -0.00011701409675879404;
  t288_n55: if (E.getFileProximityDistance() >= 3239051264 /*9.0*/) goto t288_n59;
  t288_n56: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t288_n58;
  t288_n57: return -0.19563470780849457;
  t288_n58: return 0.0960947722196579;
  t288_n59: return -0.07813651859760284;
  t288_n60: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t288_n62;
  t288_n61: return -0.2376917004585266;
  t288_n62: return 0.08308116346597672;
  t288_n63: return 0.09493547677993774;
  t288_n64: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t288_n66;
  t288_n65: return 0.00018143832858186215;
  t288_n66: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t288_n72;
  t288_n67: if (E.getNumReferences() >= 3284516864 /*395.5*/) goto t288_n71;
  t288_n68: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t288_n70;
  t288_n69: return 0.10597789287567139;
  t288_n70: return -0.19465714693069458;
  t288_n71: return 0.004652274306863546;
  t288_n72: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t288_n254;
  t288_n73: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t288_n209;
  t288_n74: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n150;
  t288_n75: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n103;
  t288_n76: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t288_n86;
  t288_n77: if (E.getNumReferences() >= 3297996800 /*1179.5*/) goto t288_n79;
  t288_n78: return -0.1930975764989853;
  t288_n79: if (E.getNumReferences() >= 3298541568 /*1246.0*/) goto t288_n81;
  t288_n80: return 0.09595560282468796;
  t288_n81: if (E.getNumReferences() >= 3345564672 /*59716.0*/) goto t288_n85;
  t288_n82: if (E.getNumReferences() >= 3330556416 /*16929.0*/) goto t288_n84;
  t288_n83: return -0.015515612438321114;
  t288_n84: return 0.0880889743566513;
  t288_n85: return -3.1118528842926025;
  t288_n86: if (E.getNumReferences() >= 3288539136 /*524.5*/) goto t288_n96;
  t288_n87: if (E.getNumReferences() >= 3287695360 /*492.5*/) goto t288_n95;
  t288_n88: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n90;
  t288_n89: return -0.43039628863334656;
  t288_n90: if (E.getNumReferences() >= 3286155264 /*445.5*/) goto t288_n94;
  t288_n91: if (E.getNumReferences() >= 3285155840 /*415.0*/) goto t288_n93;
  t288_n92: return 0.11305121332406998;
  t288_n93: return -0.3642145097255707;
  t288_n94: return 0.10846338421106339;
  t288_n95: return 0.09740510582923889;
  t288_n96: if (E.getNumReferences() >= 3331719680 /*19201.0*/) goto t288_n102;
  t288_n97: if (E.getNumReferences() >= 3323767808 /*10027.0*/) goto t288_n99;
  t288_n98: return -0.005213716067373753;
  t288_n99: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n101;
  t288_n100: return -0.9408723711967468;
  t288_n101: return 0.03224997967481613;
  t288_n102: return 0.07674149423837662;
  t288_n103: if (E.getNumReferences() >= 3300311040 /*1462.0*/) goto t288_n129;
  t288_n104: if (E.getNumReferences() >= 3299737600 /*1392.0*/) goto t288_n128;
  t288_n105: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Type))) goto t288_n113;
  t288_n106: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t288_n112;
  t288_n107: if (E.getNumReferences() >= 3294748672 /*903.5*/) goto t288_n109;
  t288_n108: return -0.12064561992883682;
  t288_n109: if (E.getNumReferences() >= 3296817152 /*1035.5*/) goto t288_n111;
  t288_n110: return 0.09610350430011749;
  t288_n111: return 0.011242326349020004;
  t288_n112: return 0.07463329285383224;
  t288_n113: if (E.getNumReferences() >= 3291308032 /*693.5*/) goto t288_n117;
  t288_n114: if (E.getNumReferences() >= 3285532672 /*426.5*/) goto t288_n116;
  t288_n115: return 0.22299738228321075;
  t288_n116: return -0.027171533554792404;
  t288_n117: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t288_n121;
  t288_n118: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t288_n120;
  t288_n119: return -0.10116846114397049;
  t288_n120: return 0.1456785649061203;
  t288_n121: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n123;
  t288_n122: return 0.1156134083867073;
  t288_n123: if (E.getNumReferences() >= 3292880896 /*789.5*/) goto t288_n125;
  t288_n124: return 0.04449556767940521;
  t288_n125: if (E.getNumReferences() >= 3295805440 /*968.0*/) goto t288_n127;
  t288_n126: return 0.2920297682285309;
  t288_n127: return 0.12289079278707504;
  t288_n128: return 0.10413013398647308;
  t288_n129: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t288_n131;
  t288_n130: return 0.014544793404638767;
  t288_n131: if (E.getNumReferences() >= 3330181632 /*16290.5*/) goto t288_n141;
  t288_n132: if (E.getNumReferences() >= 3305365504 /*2110.0*/) goto t288_n134;
  t288_n133: return -0.27944415807724;
  t288_n134: if (E.getNumReferences() >= 3307837440 /*2713.5*/) goto t288_n136;
  t288_n135: return 0.1097777709364891;
  t288_n136: if (E.getNumReferences() >= 3319662592 /*7105.0*/) goto t288_n138;
  t288_n137: return 0.022564779967069626;
  t288_n138: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t288_n140;
  t288_n139: return 0.0916372537612915;
  t288_n140: return 0.023473143577575684;
  t288_n141: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t288_n143;
  t288_n142: return 0.02945922128856182;
  t288_n143: if (E.getNumReferences() >= 3366670560 /*350855.0*/) goto t288_n149;
  t288_n144: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t288_n148;
  t288_n145: if (E.getNumReferences() >= 3343170304 /*50363.0*/) goto t288_n147;
  t288_n146: return -0.16909213364124298;
  t288_n147: return 0.050878025591373444;
  t288_n148: return -0.4178772568702698;
  t288_n149: return 0.09163392335176468;
  t288_n150: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t288_n206;
  t288_n151: if (E.getNumReferences() >= 3287056384 /*473.0*/) goto t288_n155;
  t288_n152: if (E.getNumReferences() >= 3286646784 /*460.5*/) goto t288_n154;
  t288_n153: return -0.16580475866794586;
  t288_n154: return 0.0991806909441948;
  t288_n155: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n163;
  t288_n156: if (E.getNumReferences() >= 3348635904 /*77890.0*/) goto t288_n162;
  t288_n157: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n159;
  t288_n158: return 0.0813322439789772;
  t288_n159: if (E.getNumReferences() >= 3330147328 /*16257.0*/) goto t288_n161;
  t288_n160: return -0.31147778034210205;
  t288_n161: return 0.0719214677810669;
  t288_n162: return -1.7902312278747559;
  t288_n163: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t288_n165;
  t288_n164: return -0.08960284292697906;
  t288_n165: if (E.getNumReferences() >= 3290718208 /*657.5*/) goto t288_n169;
  t288_n166: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t288_n168;
  t288_n167: return 0.00991644524037838;
  t288_n168: return 0.11301405727863312;
  t288_n169: if (E.getNumReferences() >= 3313736704 /*4211.5*/) goto t288_n175;
  t288_n170: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t288_n172;
  t288_n171: return -0.03942946344614029;
  t288_n172: if (E.getNumReferences() >= 3296833536 /*1037.5*/) goto t288_n174;
  t288_n173: return 0.0878203809261322;
  t288_n174: return 0.025587575510144234;
  t288_n175: if (E.getNumReferences() >= 3315866624 /*5251.5*/) goto t288_n181;
  t288_n176: if (E.getNumReferences() >= 3315571712 /*5107.5*/) goto t288_n180;
  t288_n177: if (E.getFileProximityDistance() >= 3242196992 /*12.0*/) goto t288_n179;
  t288_n178: return -0.2668737471103668;
  t288_n179: return 0.11986664682626724;
  t288_n180: return 0.10675318539142609;
  t288_n181: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t288_n195;
  t288_n182: if (E.getNumReferences() >= 3330498816 /*16816.5*/) goto t288_n186;
  t288_n183: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n185;
  t288_n184: return -0.08687996864318848;
  t288_n185: return 0.09912408143281937;
  t288_n186: if (E.getNumReferences() >= 3339076992 /*34373.5*/) goto t288_n190;
  t288_n187: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t288_n189;
  t288_n188: return 0.0017612994415685534;
  t288_n189: return -0.560341477394104;
  t288_n190: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n192;
  t288_n191: return 0.08981620520353317;
  t288_n192: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t288_n194;
  t288_n193: return -0.5044015645980835;
  t288_n194: return -0.00901057105511427;
  t288_n195: if (E.getNumReferences() >= 3336247808 /*28045.0*/) goto t288_n205;
  t288_n196: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t288_n198;
  t288_n197: return -0.5618304014205933;
  t288_n198: if (E.getNumReferences() >= 3329812480 /*15930.0*/) goto t288_n204;
  t288_n199: if (E.getNumReferences() >= 3324910592 /*11143.0*/) goto t288_n203;
  t288_n200: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t288_n202;
  t288_n201: return -0.07351113855838776;
  t288_n202: return 0.11252646893262863;
  t288_n203: return 0.1084408164024353;
  t288_n204: return -0.11194998770952225;
  t288_n205: return 0.07224563509225845;
  t288_n206: if (E.getNumReferences() >= 3359314816 /*191566.0*/) goto t288_n208;
  t288_n207: return -0.020894482731819153;
  t288_n208: return 0.09595518559217453;
  t288_n209: if (E.getNumReferences() >= 3286286336 /*449.5*/) goto t288_n211;
  t288_n210: return -0.17878711223602295;
  t288_n211: if (E.getNumReferences() >= 3286417408 /*453.5*/) goto t288_n213;
  t288_n212: return 0.086934894323349;
  t288_n213: if (E.getNumReferences() >= 3287990272 /*501.5*/) goto t288_n215;
  t288_n214: return -0.26529887318611145;
  t288_n215: if (E.getNumReferences() >= 3291062272 /*678.5*/) goto t288_n233;
  t288_n216: if (E.getNumReferences() >= 3290906624 /*669.0*/) goto t288_n232;
  t288_n217: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Statement))) goto t288_n225;
  t288_n218: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t288_n224;
  t288_n219: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t288_n223;
  t288_n220: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t288_n222;
  t288_n221: return 0.0983564555644989;
  t288_n222: return -0.017832353711128235;
  t288_n223: return 0.08631705492734909;
  t288_n224: return -0.07509146630764008;
  t288_n225: if (E.getNumReferences() >= 3289063424 /*556.5*/) goto t288_n229;
  t288_n226: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t288_n228;
  t288_n227: return 0.04340744763612747;
  t288_n228: return 0.1551373451948166;
  t288_n229: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Namespace))) goto t288_n231;
  t288_n230: return -0.17158547043800354;
  t288_n231: return 0.11021605879068375;
  t288_n232: return 0.11915798485279083;
  t288_n233: if (E.getNumReferences() >= 3319629824 /*7089.0*/) goto t288_n251;
  t288_n234: if (E.getNumReferences() >= 3311720448 /*3661.5*/) goto t288_n248;
  t288_n235: if (E.getNumReferences() >= 3311081472 /*3505.5*/) goto t288_n245;
  t288_n236: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t288_n238;
  t288_n237: return -0.0037791819777339697;
  t288_n238: if (E.getNumReferences() >= 3309152256 /*3034.5*/) goto t288_n244;
  t288_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t288_n243;
  t288_n240: if (E.getNumReferences() >= 3298500608 /*1241.0*/) goto t288_n242;
  t288_n241: return -0.028492985293269157;
  t288_n242: return 0.09736252576112747;
  t288_n243: return -0.13905680179595947;
  t288_n244: return 0.10415805876255035;
  t288_n245: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t288_n247;
  t288_n246: return 0.12017494440078735;
  t288_n247: return 0.02087404392659664;
  t288_n248: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Type))) goto t288_n250;
  t288_n249: return -0.10208377987146378;
  t288_n250: return 0.04515538364648819;
  t288_n251: if (E.getNumReferences() >= 3319669760 /*7108.5*/) goto t288_n253;
  t288_n252: return 0.11247412115335464;
  t288_n253: return 0.014366996474564075;
  t288_n254: return 0.10082046687602997;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree289(const Example& E) {
  t289_n0: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t289_n2;
  t289_n1: return -0.00027510637301020324;
  t289_n2: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t289_n4;
  t289_n3: return 0.0018796513322740793;
  t289_n4: if (E.getNumReferences() >= 3290374144 /*636.5*/) goto t289_n100;
  t289_n5: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n45;
  t289_n6: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t289_n36;
  t289_n7: if (E.getNumReferences() >= 3289948160 /*610.5*/) goto t289_n35;
  t289_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t289_n12;
  t289_n9: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t289_n11;
  t289_n10: return 0.12354940921068192;
  t289_n11: return 0.0027867748867720366;
  t289_n12: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t289_n14;
  t289_n13: return -0.013259944505989552;
  t289_n14: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t289_n22;
  t289_n15: if (E.getNumReferences() >= 3273228288 /*153.5*/) goto t289_n21;
  t289_n16: if (E.getNumReferences() >= 3272704000 /*145.5*/) goto t289_n20;
  t289_n17: if (E.getNumReferences() >= 3272179712 /*137.5*/) goto t289_n19;
  t289_n18: return 0.07546305656433105;
  t289_n19: return -0.42607197165489197;
  t289_n20: return 0.10737130790948868;
  t289_n21: return -0.16086989641189575;
  t289_n22: if (E.getNumReferences() >= 3275096064 /*182.0*/) goto t289_n24;
  t289_n23: return 0.18700164556503296;
  t289_n24: if (E.getNumReferences() >= 3283042304 /*350.5*/) goto t289_n34;
  t289_n25: if (E.getNumReferences() >= 3278438400 /*233.0*/) goto t289_n27;
  t289_n26: return 0.04346504807472229;
  t289_n27: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t289_n33;
  t289_n28: if (E.getNumReferences() >= 3280502784 /*273.0*/) goto t289_n30;
  t289_n29: return 0.14826257526874542;
  t289_n30: if (E.getNumReferences() >= 3281371136 /*299.5*/) goto t289_n32;
  t289_n31: return -0.10242854058742523;
  t289_n32: return 0.39577871561050415;
  t289_n33: return -0.6376256346702576;
  t289_n34: return -0.10692444443702698;
  t289_n35: return 0.11153948307037354;
  t289_n36: if (E.getNumReferences() >= 3276308480 /*200.5*/) goto t289_n42;
  t289_n37: if (E.getNumReferences() >= 3274833920 /*178.0*/) goto t289_n41;
  t289_n38: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t289_n40;
  t289_n39: return 0.11207876354455948;
  t289_n40: return -0.03289482370018959;
  t289_n41: return 0.12166319042444229;
  t289_n42: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t289_n44;
  t289_n43: return -0.1428653597831726;
  t289_n44: return 0.38592007756233215;
  t289_n45: if (E.getNumReferences() >= 3290267648 /*630.0*/) goto t289_n97;
  t289_n46: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t289_n62;
  t289_n47: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t289_n51;
  t289_n48: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t289_n50;
  t289_n49: return 0.12400101125240326;
  t289_n50: return 0.0007481181528419256;
  t289_n51: if (E.getNumReferences() >= 3277750272 /*222.5*/) goto t289_n53;
  t289_n52: return -0.01932513527572155;
  t289_n53: if (E.getNumReferences() >= 3277815808 /*223.5*/) goto t289_n55;
  t289_n54: return 0.1841798573732376;
  t289_n55: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t289_n61;
  t289_n56: if (E.getNumReferences() >= 3281616896 /*307.0*/) goto t289_n58;
  t289_n57: return -0.011186775751411915;
  t289_n58: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t289_n60;
  t289_n59: return 0.11381349712610245;
  t289_n60: return 0.04450225457549095;
  t289_n61: return 0.016367992386221886;
  t289_n62: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t289_n94;
  t289_n63: if (E.getNumReferences() >= 3279994880 /*257.5*/) goto t289_n89;
  t289_n64: if (E.getNumReferences() >= 3274735616 /*176.5*/) goto t289_n66;
  t289_n65: return 0.028929712250828743;
  t289_n66: if (E.getNumReferences() >= 3274801152 /*177.5*/) goto t289_n68;
  t289_n67: return 0.13267108798027039;
  t289_n68: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t289_n72;
  t289_n69: if (E.getNumReferences() >= 3279224832 /*245.0*/) goto t289_n71;
  t289_n70: return -0.1299150437116623;
  t289_n71: return 0.13002042472362518;
  t289_n72: if (E.getNumReferences() >= 3275063296 /*181.5*/) goto t289_n76;
  t289_n73: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t289_n75;
  t289_n74: return -0.16080453991889954;
  t289_n75: return 0.10668914020061493;
  t289_n76: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t289_n86;
  t289_n77: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression))) goto t289_n81;
  t289_n78: if (E.getNumReferences() >= 3275390976 /*186.5*/) goto t289_n80;
  t289_n79: return 0.10782270133495331;
  t289_n80: return -0.053348615765571594;
  t289_n81: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t289_n83;
  t289_n82: return 0.14638495445251465;
  t289_n83: if (E.getNumReferences() >= 3278307328 /*231.0*/) goto t289_n85;
  t289_n84: return -0.5711079239845276;
  t289_n85: return 0.11064489185810089;
  t289_n86: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t289_n88;
  t289_n87: return 0.028625058010220528;
  t289_n88: return 0.10306449979543686;
  t289_n89: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t289_n91;
  t289_n90: return -0.011279995553195477;
  t289_n91: if (E.getNumReferences() >= 3283877888 /*376.0*/) goto t289_n93;
  t289_n92: return -0.15671876072883606;
  t289_n93: return 0.12699569761753082;
  t289_n94: if (E.getNumReferences() >= 3265921024 /*85.0*/) goto t289_n96;
  t289_n95: return 0.10836495459079742;
  t289_n96: return 0.0709943026304245;
  t289_n97: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t289_n99;
  t289_n98: return 0.09655823558568954;
  t289_n99: return -0.1135186105966568;
  t289_n100: if (E.getFileProximityDistance() >= 3249274880 /*21.5*/) goto t289_n254;
  t289_n101: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t289_n103;
  t289_n102: return -0.012246442027390003;
  t289_n103: if (E.getNumReferences() >= 3300196352 /*1448.0*/) goto t289_n105;
  t289_n104: return -0.03214314952492714;
  t289_n105: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t289_n235;
  t289_n106: if (E.getNumReferences() >= 3328776192 /*14918.0*/) goto t289_n160;
  t289_n107: if (E.getNumReferences() >= 3323748864 /*10008.5*/) goto t289_n153;
  t289_n108: if (E.getNumReferences() >= 3322603520 /*8890.0*/) goto t289_n134;
  t289_n109: if (E.getNumReferences() >= 3307966464 /*2745.0*/) goto t289_n125;
  t289_n110: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t289_n116;
  t289_n111: if (E.getNumReferences() >= 3306926080 /*2491.0*/) goto t289_n113;
  t289_n112: return -0.008130716159939766;
  t289_n113: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n115;
  t289_n114: return 0.09892742335796356;
  t289_n115: return 0.15533828735351562;
  t289_n116: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t289_n124;
  t289_n117: if (E.getNumReferences() >= 3300925440 /*1537.0*/) goto t289_n119;
  t289_n118: return 0.13048657774925232;
  t289_n119: if (E.getNumReferences() >= 3305877504 /*2235.0*/) goto t289_n123;
  t289_n120: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t289_n122;
  t289_n121: return 0.10294357687234879;
  t289_n122: return -0.4637068212032318;
  t289_n123: return 0.11216627061367035;
  t289_n124: return 0.12664629518985748;
  t289_n125: if (E.getNumReferences() >= 3309840384 /*3202.5*/) goto t289_n129;
  t289_n126: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t289_n128;
  t289_n127: return 0.0843270942568779;
  t289_n128: return -0.20153436064720154;
  t289_n129: if (E.getNumReferences() >= 3313057792 /*3988.0*/) goto t289_n133;
  t289_n130: if (E.getNumReferences() >= 3312498688 /*3851.5*/) goto t289_n132;
  t289_n131: return 0.011364971287548542;
  t289_n132: return 0.10597792267799377;
  t289_n133: return -0.02888667583465576;
  t289_n134: if (E.getNumReferences() >= 3322671104 /*8956.0*/) goto t289_n136;
  t289_n135: return 0.10611758381128311;
  t289_n136: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t289_n138;
  t289_n137: return -0.015315935015678406;
  t289_n138: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n140;
  t289_n139: return -0.10560082644224167;
  t289_n140: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t289_n152;
  t289_n141: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t289_n151;
  t289_n142: if (E.getNumReferences() >= 3323686912 /*9948.0*/) goto t289_n148;
  t289_n143: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n145;
  t289_n144: return -0.1178637146949768;
  t289_n145: if (E.getNumReferences() >= 3322915840 /*9195.0*/) goto t289_n147;
  t289_n146: return 0.09186505526304245;
  t289_n147: return 0.05868442729115486;
  t289_n148: if (E.getNumReferences() >= 3323708928 /*9969.5*/) goto t289_n150;
  t289_n149: return 0.1090879887342453;
  t289_n150: return -0.1243891716003418;
  t289_n151: return 0.10475564002990723;
  t289_n152: return 0.041863422840833664;
  t289_n153: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t289_n155;
  t289_n154: return -0.08100289851427078;
  t289_n155: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t289_n157;
  t289_n156: return -0.06754998117685318;
  t289_n157: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n159;
  t289_n158: return 0.13532845675945282;
  t289_n159: return 0.12628333270549774;
  t289_n160: if (E.getNumReferences() >= 3330413056 /*16649.0*/) goto t289_n164;
  t289_n161: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t289_n163;
  t289_n162: return -0.3960946500301361;
  t289_n163: return 0.11719752848148346;
  t289_n164: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t289_n232;
  t289_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t289_n167;
  t289_n166: return -0.2263496071100235;
  t289_n167: if (E.getNumReferences() >= 3338447872 /*32342.0*/) goto t289_n203;
  t289_n168: if (E.getNumReferences() >= 3336347136 /*28239.0*/) goto t289_n190;
  t289_n169: if (E.getFileProximityDistance() >= 3248226304 /*19.5*/) goto t289_n189;
  t289_n170: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t289_n186;
  t289_n171: if (E.getNumReferences() >= 3334924800 /*25461.0*/) goto t289_n177;
  t289_n172: if (E.getNumReferences() >= 3333992192 /*23639.5*/) goto t289_n174;
  t289_n173: return -0.0002586705959402025;
  t289_n174: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n176;
  t289_n175: return -0.05397212877869606;
  t289_n176: return -1.1952238082885742;
  t289_n177: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t289_n179;
  t289_n178: return 0.1032504141330719;
  t289_n179: if (E.getNumReferences() >= 3335315200 /*26223.5*/) goto t289_n183;
  t289_n180: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n182;
  t289_n181: return 0.10250832885503769;
  t289_n182: return 0.06813456118106842;
  t289_n183: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t289_n185;
  t289_n184: return -0.3354724943637848;
  t289_n185: return 0.08801015466451645;
  t289_n186: if (E.getNumReferences() >= 3331945984 /*19643.0*/) goto t289_n188;
  t289_n187: return 0.120332732796669;
  t289_n188: return -0.0376567617058754;
  t289_n189: return -0.41635778546333313;
  t289_n190: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t289_n192;
  t289_n191: return -0.07014243304729462;
  t289_n192: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n194;
  t289_n193: return 0.01990444026887417;
  t289_n194: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t289_n200;
  t289_n195: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t289_n197;
  t289_n196: return 0.06643463671207428;
  t289_n197: if (E.getNumReferences() >= 3337883136 /*31239.0*/) goto t289_n199;
  t289_n198: return 0.09741741418838501;
  t289_n199: return 0.07233966141939163;
  t289_n200: if (E.getNumReferences() >= 3338210816 /*31879.0*/) goto t289_n202;
  t289_n201: return 0.07794549316167831;
  t289_n202: return -0.4676990807056427;
  t289_n203: if (E.getNumReferences() >= 3348712704 /*78490.0*/) goto t289_n215;
  t289_n204: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t289_n212;
  t289_n205: if (E.getNumReferences() >= 3340675072 /*40616.0*/) goto t289_n211;
  t289_n206: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n208;
  t289_n207: return -0.11226267367601395;
  t289_n208: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t289_n210;
  t289_n209: return 0.11892321705818176;
  t289_n210: return 0.13651143014431;
  t289_n211: return -0.07098108530044556;
  t289_n212: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n214;
  t289_n213: return 0.03260913863778114;
  t289_n214: return -0.07004256546497345;
  t289_n215: if (E.getNumReferences() >= 3350072960 /*89117.0*/) goto t289_n231;
  t289_n216: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t289_n228;
  t289_n217: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t289_n227;
  t289_n218: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t289_n220;
  t289_n219: return 0.0955287292599678;
  t289_n220: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t289_n222;
  t289_n221: return -0.024689797312021255;
  t289_n222: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t289_n224;
  t289_n223: return -0.11634846031665802;
  t289_n224: if (E.getNumReferences() >= 3350016768 /*88678.0*/) goto t289_n226;
  t289_n225: return 0.12338106334209442;
  t289_n226: return 0.10640160739421844;
  t289_n227: return -0.07471296191215515;
  t289_n228: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t289_n230;
  t289_n229: return 0.05706724151968956;
  t289_n230: return 0.1253245621919632;
  t289_n231: return 0.0003374289080966264;
  t289_n232: if (E.getNumReferences() >= 3335962112 /*27487.0*/) goto t289_n234;
  t289_n233: return -1.3280909061431885;
  t289_n234: return -0.021539997309446335;
  t289_n235: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t289_n249;
  t289_n236: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t289_n238;
  t289_n237: return -0.3475241959095001;
  t289_n238: if (E.getNumReferences() >= 3330446592 /*16714.5*/) goto t289_n248;
  t289_n239: if (E.getNumReferences() >= 3327475712 /*13648.0*/) goto t289_n241;
  t289_n240: return 0.029453538358211517;
  t289_n241: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t289_n247;
  t289_n242: if (E.getNumReferences() >= 3328385536 /*14536.5*/) goto t289_n246;
  t289_n243: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t289_n245;
  t289_n244: return -0.1913495510816574;
  t289_n245: return 0.10785527527332306;
  t289_n246: return 0.12398608773946762;
  t289_n247: return 0.05192354694008827;
  t289_n248: return 0.010750741697847843;
  t289_n249: if (E.getNumReferences() >= 3311716352 /*3660.5*/) goto t289_n251;
  t289_n250: return -0.18607006967067719;
  t289_n251: if (E.getNumReferences() >= 3315241984 /*4946.5*/) goto t289_n253;
  t289_n252: return 0.11119701713323593;
  t289_n253: return -0.014623434282839298;
  t289_n254: return -0.10681876540184021;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree290(const Example& E) {
  t290_n0: if (E.getNumReferences() >= 3264151552 /*71.5*/) goto t290_n2;
  t290_n1: return -0.0003758746897801757;
  t290_n2: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t290_n254;
  t290_n3: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Function))) goto t290_n149;
  t290_n4: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag))) goto t290_n40;
  t290_n5: if (E.getNumReferences() >= 3264675840 /*75.5*/) goto t290_n39;
  t290_n6: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t290_n24;
  t290_n7: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess))) goto t290_n9;
  t290_n8: return -0.05049802362918854;
  t290_n9: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t290_n23;
  t290_n10: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t290_n12;
  t290_n11: return 0.04599408060312271;
  t290_n12: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t290_n14;
  t290_n13: return 0.05740176513791084;
  t290_n14: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t290_n18;
  t290_n15: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n17;
  t290_n16: return 0.07672283053398132;
  t290_n17: return 0.12331335991621017;
  t290_n18: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t290_n22;
  t290_n19: if (E.getNumReferences() >= 3264544768 /*74.5*/) goto t290_n21;
  t290_n20: return -0.17073792219161987;
  t290_n21: return 0.10402515530586243;
  t290_n22: return -0.09665005654096603;
  t290_n23: return 0.003406872507184744;
  t290_n24: if (E.getFileProximityDistance() >= 3246915584 /*17.0*/) goto t290_n38;
  t290_n25: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t290_n29;
  t290_n26: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t290_n28;
  t290_n27: return 0.04973358288407326;
  t290_n28: return -0.3226686716079712;
  t290_n29: if (E.getFileProximityDistance() >= 3234856960 /*6.5*/) goto t290_n37;
  t290_n30: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n34;
  t290_n31: if (E.getNumReferences() >= 3264413696 /*73.5*/) goto t290_n33;
  t290_n32: return 0.11611749976873398;
  t290_n33: return -0.41952845454216003;
  t290_n34: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t290_n36;
  t290_n35: return -0.03798479214310646;
  t290_n36: return 0.1066734567284584;
  t290_n37: return -0.19943587481975555;
  t290_n38: return 0.10114555060863495;
  t290_n39: return -0.001652680803090334;
  t290_n40: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t290_n64;
  t290_n41: if (E.getFileProximityDistance() >= 3249799168 /*22.5*/) goto t290_n61;
  t290_n42: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n44;
  t290_n43: return 0.023166973143815994;
  t290_n44: if (E.getNumReferences() >= 3265069056 /*78.5*/) goto t290_n48;
  t290_n45: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t290_n47;
  t290_n46: return 0.10901664942502975;
  t290_n47: return -0.8027737140655518;
  t290_n48: if (E.getNumReferences() >= 3274407936 /*171.5*/) goto t290_n52;
  t290_n49: if (E.getNumReferences() >= 3273883648 /*163.5*/) goto t290_n51;
  t290_n50: return 0.03505120053887367;
  t290_n51: return 0.08347970992326736;
  t290_n52: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t290_n58;
  t290_n53: if (E.getNumReferences() >= 3280519168 /*273.5*/) goto t290_n55;
  t290_n54: return -0.311857134103775;
  t290_n55: if (E.getNumReferences() >= 3281174528 /*293.5*/) goto t290_n57;
  t290_n56: return 0.09245357662439346;
  t290_n57: return -0.03966231271624565;
  t290_n58: if (E.getNumReferences() >= 3281731584 /*310.5*/) goto t290_n60;
  t290_n59: return 0.09001092612743378;
  t290_n60: return -0.007049118168652058;
  t290_n61: if (E.getNumReferences() >= 3280306176 /*267.0*/) goto t290_n63;
  t290_n62: return -0.09704254567623138;
  t290_n63: return 0.09405358135700226;
  t290_n64: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t290_n76;
  t290_n65: if (E.getNumReferences() >= 3275980800 /*195.5*/) goto t290_n67;
  t290_n66: return -0.10489563643932343;
  t290_n67: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t290_n75;
  t290_n68: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t290_n74;
  t290_n69: if (E.getNumReferences() >= 3284746240 /*402.5*/) goto t290_n73;
  t290_n70: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n72;
  t290_n71: return 0.07320809364318848;
  t290_n72: return 0.10720673948526382;
  t290_n73: return -0.32160428166389465;
  t290_n74: return 0.09699583053588867;
  t290_n75: return 0.004766733385622501;
  t290_n76: if (E.getNumReferences() >= 3267690496 /*98.5*/) goto t290_n100;
  t290_n77: if (E.getNumReferences() >= 3267559424 /*97.5*/) goto t290_n97;
  t290_n78: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t290_n96;
  t290_n79: if (E.getNumReferences() >= 3265200128 /*79.5*/) goto t290_n81;
  t290_n80: return 0.0028896171133965254;
  t290_n81: if (E.getNumReferences() >= 3265331200 /*80.5*/) goto t290_n83;
  t290_n82: return 0.13443557918071747;
  t290_n83: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n95;
  t290_n84: if (E.getNumReferences() >= 3266904064 /*92.5*/) goto t290_n90;
  t290_n85: if (E.getNumReferences() >= 3265855488 /*84.5*/) goto t290_n89;
  t290_n86: if (E.getNumReferences() >= 3265593344 /*82.5*/) goto t290_n88;
  t290_n87: return -0.33114394545555115;
  t290_n88: return 0.1446443349123001;
  t290_n89: return -0.07533645629882812;
  t290_n90: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t290_n94;
  t290_n91: if (E.getNumReferences() >= 3267297280 /*95.5*/) goto t290_n93;
  t290_n92: return 0.11599748581647873;
  t290_n93: return -0.12538479268550873;
  t290_n94: return 0.2008715271949768;
  t290_n95: return -0.11972928792238235;
  t290_n96: return -0.12260166555643082;
  t290_n97: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t290_n99;
  t290_n98: return 0.10790261626243591;
  t290_n99: return -0.13314348459243774;
  t290_n100: if (E.getNumReferences() >= 3282305024 /*328.0*/) goto t290_n102;
  t290_n101: return -0.0162455216050148;
  t290_n102: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t290_n114;
  t290_n103: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t290_n107;
  t290_n104: if (E.getNumReferences() >= 3293462528 /*825.0*/) goto t290_n106;
  t290_n105: return -0.04712297394871712;
  t290_n106: return 0.1867280900478363;
  t290_n107: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n113;
  t290_n108: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t290_n110;
  t290_n109: return -0.125138059258461;
  t290_n110: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t290_n112;
  t290_n111: return 0.09987690299749374;
  t290_n112: return 0.01093680877238512;
  t290_n113: return -0.04189309477806091;
  t290_n114: if (E.getNumReferences() >= 3282567168 /*336.0*/) goto t290_n116;
  t290_n115: return 0.1255251169204712;
  t290_n116: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t290_n120;
  t290_n117: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n119;
  t290_n118: return -0.15616559982299805;
  t290_n119: return 0.0624343603849411;
  t290_n120: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t290_n138;
  t290_n121: if (E.getNumReferences() >= 3312984064 /*3970.0*/) goto t290_n137;
  t290_n122: if (E.getNumReferences() >= 3309117440 /*3026.0*/) goto t290_n136;
  t290_n123: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t290_n135;
  t290_n124: if (E.getNumReferences() >= 3288530944 /*524.0*/) goto t290_n132;
  t290_n125: if (E.getNumReferences() >= 3288203264 /*508.0*/) goto t290_n131;
  t290_n126: if (E.getFileProximityDistance() >= 3242721280 /*12.5*/) goto t290_n128;
  t290_n127: return 0.0569983646273613;
  t290_n128: if (E.getNumReferences() >= 3283795968 /*373.5*/) goto t290_n130;
  t290_n129: return -0.10067674517631531;
  t290_n130: return 0.23707441985607147;
  t290_n131: return 0.11349070817232132;
  t290_n132: if (E.getFileProximityDistance() >= 3240624128 /*10.5*/) goto t290_n134;
  t290_n133: return 0.08844281733036041;
  t290_n134: return 0.021830523386597633;
  t290_n135: return 0.09385515749454498;
  t290_n136: return 0.11362159997224808;
  t290_n137: return 0.012716706842184067;
  t290_n138: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag))) goto t290_n146;
  t290_n139: if (E.getNumReferences() >= 3324868096 /*11101.5*/) goto t290_n141;
  t290_n140: return -0.0605824738740921;
  t290_n141: if (E.getNumReferences() >= 3333739264 /*23145.5*/) goto t290_n145;
  t290_n142: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t290_n144;
  t290_n143: return 0.11503738164901733;
  t290_n144: return -0.04729185625910759;
  t290_n145: return 0.0067432476207613945;
  t290_n146: if (E.getNumReferences() >= 3293175808 /*807.5*/) goto t290_n148;
  t290_n147: return -0.026720041409134865;
  t290_n148: return 0.12275461107492447;
  t290_n149: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t290_n167;
  t290_n150: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::GlobalScope))) goto t290_n166;
  t290_n151: if (E.getNumReferences() >= 3285319680 /*420.0*/) goto t290_n159;
  t290_n152: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t290_n158;
  t290_n153: if (E.getNumReferences() >= 3276898304 /*209.5*/) goto t290_n157;
  t290_n154: if (E.getNumReferences() >= 3275653120 /*190.5*/) goto t290_n156;
  t290_n155: return -0.2556565999984741;
  t290_n156: return 0.11475642770528793;
  t290_n157: return -0.4600152373313904;
  t290_n158: return -0.04402404651045799;
  t290_n159: if (E.getNumReferences() >= 3287465984 /*485.5*/) goto t290_n165;
  t290_n160: if (E.getNumReferences() >= 3286941696 /*469.5*/) goto t290_n162;
  t290_n161: return 0.02182997763156891;
  t290_n162: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t290_n164;
  t290_n163: return 0.08554001152515411;
  t290_n164: return -0.5063996911048889;
  t290_n165: return -0.03576888144016266;
  t290_n166: return 0.01639370433986187;
  t290_n167: if (E.getNumReferences() >= 3353595776 /*116639.0*/) goto t290_n239;
  t290_n168: if (E.getNumReferences() >= 3282223104 /*325.5*/) goto t290_n170;
  t290_n169: return 0.019620178267359734;
  t290_n170: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t290_n174;
  t290_n171: if (E.getNumReferences() >= 3282321408 /*328.5*/) goto t290_n173;
  t290_n172: return 0.26385998725891113;
  t290_n173: return 0.02000170759856701;
  t290_n174: if (E.getNumReferences() >= 3297275904 /*1091.5*/) goto t290_n196;
  t290_n175: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t290_n185;
  t290_n176: if (E.getNumReferences() >= 3282419712 /*331.5*/) goto t290_n182;
  t290_n177: if (E.getNumReferences() >= 3282386944 /*330.5*/) goto t290_n179;
  t290_n178: return -0.05552729591727257;
  t290_n179: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t290_n181;
  t290_n180: return -0.10022664070129395;
  t290_n181: return 0.15996935963630676;
  t290_n182: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t290_n184;
  t290_n183: return 0.05623670667409897;
  t290_n184: return 0.06677538901567459;
  t290_n185: if (E.getFileProximityDistance() >= 3244818432 /*14.5*/) goto t290_n187;
  t290_n186: return 0.04446323588490486;
  t290_n187: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t290_n193;
  t290_n188: if (E.getNumReferences() >= 3289186304 /*564.0*/) goto t290_n190;
  t290_n189: return -0.1041627749800682;
  t290_n190: if (E.getNumReferences() >= 3291136000 /*683.0*/) goto t290_n192;
  t290_n191: return 0.10107025504112244;
  t290_n192: return 0.09642034024000168;
  t290_n193: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t290_n195;
  t290_n194: return 0.10886148363351822;
  t290_n195: return 0.11521400511264801;
  t290_n196: if (E.getNumReferences() >= 3299151872 /*1320.5*/) goto t290_n218;
  t290_n197: if (E.getFileProximityDistance() >= 3245867008 /*15.5*/) goto t290_n207;
  t290_n198: if (E.getNumReferences() >= 3299106816 /*1315.0*/) goto t290_n206;
  t290_n199: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t290_n201;
  t290_n200: return -0.16536463797092438;
  t290_n201: if (E.getNumReferences() >= 3298168832 /*1200.5*/) goto t290_n205;
  t290_n202: if (E.getNumReferences() >= 3297943552 /*1173.0*/) goto t290_n204;
  t290_n203: return -0.10223404318094254;
  t290_n204: return 0.13851742446422577;
  t290_n205: return 0.03494250029325485;
  t290_n206: return 0.117310531437397;
  t290_n207: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t290_n217;
  t290_n208: if (E.getNumReferences() >= 3298639872 /*1258.0*/) goto t290_n216;
  t290_n209: if (E.getNumReferences() >= 3298324480 /*1219.5*/) goto t290_n213;
  t290_n210: if (E.getNumReferences() >= 3297902592 /*1168.0*/) goto t290_n212;
  t290_n211: return 0.10739216208457947;
  t290_n212: return -0.10190899670124054;
  t290_n213: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t290_n215;
  t290_n214: return 0.12147931009531021;
  t290_n215: return -0.10016652196645737;
  t290_n216: return -0.1135624572634697;
  t290_n217: return -0.10880928486585617;
  t290_n218: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t290_n238;
  t290_n219: if (E.getNumReferences() >= 3313839104 /*4261.5*/) goto t290_n221;
  t290_n220: return 0.06175487861037254;
  t290_n221: if (E.getNumReferences() >= 3313898496 /*4290.5*/) goto t290_n223;
  t290_n222: return 0.14519108831882477;
  t290_n223: if (E.getNumReferences() >= 3317490688 /*6044.5*/) goto t290_n225;
  t290_n224: return -0.04215676710009575;
  t290_n225: if (E.getNumReferences() >= 3317757952 /*6175.0*/) goto t290_n227;
  t290_n226: return 0.11443211883306503;
  t290_n227: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t290_n237;
  t290_n228: if (E.getNumReferences() >= 3322947584 /*9226.0*/) goto t290_n230;
  t290_n229: return 0.056423626840114594;
  t290_n230: if (E.getNumReferences() >= 3324085248 /*10337.0*/) goto t290_n232;
  t290_n231: return 0.12380901724100113;
  t290_n232: if (E.getNumReferences() >= 3328163328 /*14319.5*/) goto t290_n236;
  t290_n233: if (E.getNumReferences() >= 3326885888 /*13072.0*/) goto t290_n235;
  t290_n234: return -0.027981910854578018;
  t290_n235: return 0.1140306144952774;
  t290_n236: return -0.11132889240980148;
  t290_n237: return -0.07558123022317886;
  t290_n238: return -0.10021202266216278;
  t290_n239: if (E.getFileProximityDistance() >= 3246653440 /*16.5*/) goto t290_n253;
  t290_n240: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t290_n252;
  t290_n241: if (E.getNumReferences() >= 3356586400 /*148934.5*/) goto t290_n251;
  t290_n242: if (E.getSemaSaysInScope() >= 3204448256 /*0.5*/) goto t290_n250;
  t290_n243: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t290_n245;
  t290_n244: return 0.08465901017189026;
  t290_n245: if (E.getFileProximityDistance() >= 3243245568 /*13.0*/) goto t290_n247;
  t290_n246: return 0.11695220321416855;
  t290_n247: if (E.getFileProximityDistance() >= 3245342720 /*15.0*/) goto t290_n249;
  t290_n248: return 0.10688968747854233;
  t290_n249: return 0.10934565216302872;
  t290_n250: return -0.4023343026638031;
  t290_n251: return 0.0907929539680481;
  t290_n252: return 0.020408596843481064;
  t290_n253: return -0.006540196947753429;
  t290_n254: return -0.0005379684153012931;
}

LLVM_ATTRIBUTE_NOINLINE float EvaluateTree291(const Example& E) {
  t291_n0: if (E.getIsImplementationDetail() >= 3204448256 /*0.5*/) goto t291_n206;
  t291_n1: if (E.getSemaFileProximityScore() >= 3209481421 /*0.800000011920929*/) goto t291_n3;
  t291_n2: return -9.381832205690444e-05;
  t291_n3: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression))) goto t291_n17;
  t291_n4: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Namespace))) goto t291_n6;
  t291_n5: return -0.013474937528371811;
  t291_n6: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n8;
  t291_n7: return -0.018641190603375435;
  t291_n8: if (E.getContextKind() & (BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_Type))) goto t291_n10;
  t291_n9: return 0.012510438449680805;
  t291_n10: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t291_n12;
  t291_n11: return 0.004396921955049038;
  t291_n12: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n16;
  t291_n13: if (E.getNumReferences() >= 3322085376 /*8384.0*/) goto t291_n15;
  t291_n14: return 0.0703975260257721;
  t291_n15: return -0.2107551097869873;
  t291_n16: return 0.03427647054195404;
  t291_n17: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Type))) goto t291_n163;
  t291_n18: if (E.getScope() & (BIT(Scope_type::GlobalScope)|BIT(Scope_type::FileScope))) goto t291_n46;
  t291_n19: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n41;
  t291_n20: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n22;
  t291_n21: return -0.0038289958611130714;
  t291_n22: if (E.getIsInBaseClass() >= 3204448256 /*0.5*/) goto t291_n24;
  t291_n23: return 0.0006883793976157904;
  t291_n24: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Function))) goto t291_n28;
  t291_n25: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n27;
  t291_n26: return -0.05213822424411774;
  t291_n27: return 0.02935420349240303;
  t291_n28: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n40;
  t291_n29: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n31;
  t291_n30: return 0.04694046452641487;
  t291_n31: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t291_n33;
  t291_n32: return 0.062120962888002396;
  t291_n33: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n39;
  t291_n34: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t291_n38;
  t291_n35: if (E.getIsInstanceMember() >= 3204448256 /*0.5*/) goto t291_n37;
  t291_n36: return -0.1044471263885498;
  t291_n37: return 0.08697892725467682;
  t291_n38: return -0.12165842950344086;
  t291_n39: return 0.013998414389789104;
  t291_n40: return 0.007093135733157396;
  t291_n41: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t291_n45;
  t291_n42: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n44;
  t291_n43: return -0.02991998754441738;
  t291_n44: return -0.00857355073094368;
  t291_n45: return 0.007957075722515583;
  t291_n46: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n50;
  t291_n47: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Function))) goto t291_n49;
  t291_n48: return -0.012319260276854038;
  t291_n49: return 0.02449943497776985;
  t291_n50: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t291_n162;
  t291_n51: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n65;
  t291_n52: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n54;
  t291_n53: return 0.007462368346750736;
  t291_n54: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type))) goto t291_n62;
  t291_n55: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n61;
  t291_n56: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t291_n60;
  t291_n57: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t291_n59;
  t291_n58: return -0.025752069428563118;
  t291_n59: return -0.14532820880413055;
  t291_n60: return 0.0008486551814712584;
  t291_n61: return -0.014614921994507313;
  t291_n62: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n64;
  t291_n63: return -0.0013415239518508315;
  t291_n64: return 0.05546329915523529;
  t291_n65: if (E.getSymbolScopeDistance() >= 3225419776 /*3.0*/) goto t291_n85;
  t291_n66: if (E.getScope() & (BIT(Scope_type::FunctionScope)|BIT(Scope_type::ClassScope)|BIT(Scope_type::FileScope))) goto t291_n70;
  t291_n67: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Function)|BIT(SymbolCategory_type::Type))) goto t291_n69;
  t291_n68: return -0.11501562595367432;
  t291_n69: return -0.03132624924182892;
  t291_n70: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n84;
  t291_n71: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n73;
  t291_n72: return -0.01514025405049324;
  t291_n73: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Statement)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n75;
  t291_n74: return -0.009807078167796135;
  t291_n75: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Variable)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n77;
  t291_n76: return -0.008678650483489037;
  t291_n77: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t291_n83;
  t291_n78: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n80;
  t291_n79: return 0.029170794412493706;
  t291_n80: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t291_n82;
  t291_n81: return 0.07262790203094482;
  t291_n82: return 0.03584323078393936;
  t291_n83: return -0.003367809811607003;
  t291_n84: return 0.060701627284288406;
  t291_n85: if (E.getFileProximityDistance() >= 3247702016 /*18.5*/) goto t291_n157;
  t291_n86: if (E.getNumReferences() >= 3217031168 /*1.5*/) goto t291_n110;
  t291_n87: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t291_n109;
  t291_n88: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t291_n96;
  t291_n89: if (E.getHadSymbolType() >= 3204448256 /*0.5*/) goto t291_n91;
  t291_n90: return -0.132868230342865;
  t291_n91: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ParenthesizedExpression))) goto t291_n95;
  t291_n92: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n94;
  t291_n93: return 0.07100047171115875;
  t291_n94: return 0.007504635490477085;
  t291_n95: return 0.10686545073986053;
  t291_n96: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Namespace))) goto t291_n98;
  t291_n97: return 0.019836949184536934;
  t291_n98: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n102;
  t291_n99: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n101;
  t291_n100: return 0.06299348920583725;
  t291_n101: return 0.11295817047357559;
  t291_n102: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t291_n104;
  t291_n103: return 0.12733562290668488;
  t291_n104: if (E.getFileProximityDistance() >= 3241672704 /*11.5*/) goto t291_n106;
  t291_n105: return -0.06366676092147827;
  t291_n106: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n108;
  t291_n107: return 0.05008697882294655;
  t291_n108: return 0.10794111341238022;
  t291_n109: return -0.13502247631549835;
  t291_n110: if (E.getNumReferences() >= 3223322624 /*2.5*/) goto t291_n132;
  t291_n111: if (E.getTypeMatchesPreferred() >= 3204448256 /*0.5*/) goto t291_n121;
  t291_n112: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n114;
  t291_n113: return 0.05835979804396629;
  t291_n114: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n116;
  t291_n115: return 0.10448310524225235;
  t291_n116: if (E.getFilterLength() >= 3234856960 /*6.5*/) goto t291_n118;
  t291_n117: return -0.12638165056705475;
  t291_n118: if (E.getSymbolScopeDistance() >= 3239051264 /*9.0*/) goto t291_n120;
  t291_n119: return 0.1145688146352768;
  t291_n120: return 0.05274040251970291;
  t291_n121: if (E.getFileProximityDistance() >= 3230662656 /*4.5*/) goto t291_n131;
  t291_n122: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n124;
  t291_n123: return 0.12794198095798492;
  t291_n124: if (E.getFilterLength() >= 3232759808 /*5.5*/) goto t291_n126;
  t291_n125: return 0.026235757395625114;
  t291_n126: if (E.getFilterLength() >= 3236954112 /*7.5*/) goto t291_n130;
  t291_n127: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t291_n129;
  t291_n128: return 0.0;
  t291_n129: return 0.1045181155204773;
  t291_n130: return -0.00766731658950448;
  t291_n131: return -0.15436714887619019;
  t291_n132: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n152;
  t291_n133: if (E.getFileProximityDistance() >= 3247177728 /*17.5*/) goto t291_n151;
  t291_n134: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Variable))) goto t291_n136;
  t291_n135: return 0.009993339888751507;
  t291_n136: if (E.getNumReferences() >= 3227516928 /*3.5*/) goto t291_n138;
  t291_n137: return -0.17515695095062256;
  t291_n138: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t291_n146;
  t291_n139: if (E.getNumReferences() >= 3236954112 /*7.5*/) goto t291_n143;
  t291_n140: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t291_n142;
  t291_n141: return 0.04061681032180786;
  t291_n142: return 0.0732160359621048;
  t291_n143: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t291_n145;
  t291_n144: return 0.06755934655666351;
  t291_n145: return 0.13326673209667206;
  t291_n146: if (E.getNumReferences() >= 3244818432 /*14.5*/) goto t291_n148;
  t291_n147: return -0.2224569022655487;
  t291_n148: if (E.getNumReferences() >= 3249537024 /*22.0*/) goto t291_n150;
  t291_n149: return 0.10381709039211273;
  t291_n150: return 0.026838945224881172;
  t291_n151: return 0.1099848747253418;
  t291_n152: if (E.getNumReferences() >= 3338667520 /*32774.0*/) goto t291_n154;
  t291_n153: return -0.048518288880586624;
  t291_n154: if (E.getNumReferences() >= 3338968320 /*33949.0*/) goto t291_n156;
  t291_n155: return 0.11126405000686646;
  t291_n156: return 0.00275589432567358;
  t291_n157: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n161;
  t291_n158: if (E.getContextKind() & (BIT(ContextKind_type::CCC_ClassOrStructTag)|BIT(ContextKind_type::CCC_ArrowMemberAccess)|BIT(ContextKind_type::CCC_ClassStructUnion)|BIT(ContextKind_type::CCC_SymbolOrNewName)|BIT(ContextKind_type::CCC_EnumTag)|BIT(ContextKind_type::CCC_TopLevel)|BIT(ContextKind_type::CCC_Namespace)|BIT(ContextKind_type::CCC_UnionTag)|BIT(ContextKind_type::CCC_Symbol)|BIT(ContextKind_type::CCC_ParenthesizedExpression)|BIT(ContextKind_type::CCC_Other)|BIT(ContextKind_type::CCC_DotMemberAccess)|BIT(ContextKind_type::CCC_Type))) goto t291_n160;
  t291_n159: return -0.06327354162931442;
  t291_n160: return 0.34912800788879395;
  t291_n161: return 0.11177556961774826;
  t291_n162: return 0.2065284699201584;
  t291_n163: if (E.getSymbolScopeDistance() >= 3235905536 /*7.0*/) goto t291_n205;
  t291_n164: if (E.getFileProximityDistance() >= 3248750592 /*20.5*/) goto t291_n202;
  t291_n165: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Statement))) goto t291_n177;
  t291_n166: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n176;
  t291_n167: if (E.getContextKind() & (BIT(ContextKind_type::CCC_TopLevel))) goto t291_n169;
  t291_n168: return 0.007292652502655983;
  t291_n169: if (E.getNumReferences() >= 3239051264 /*9.0*/) goto t291_n175;
  t291_n170: if (E.getNumReferences() >= 3225419776 /*3.0*/) goto t291_n174;
  t291_n171: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t291_n173;
  t291_n172: return 0.07703229784965515;
  t291_n173: return -0.4369247555732727;
  t291_n174: return -0.7921183705329895;
  t291_n175: return 0.09365657716989517;
  t291_n176: return 0.048378899693489075;
  t291_n177: if (E.getFileProximityDistance() >= 3236954112 /*7.5*/) goto t291_n187;
  t291_n178: if (E.getNumReferences() >= 3204448256 /*0.5*/) goto t291_n186;
  t291_n179: if (E.getFileProximityDistance() >= 3232759808 /*5.5*/) goto t291_n185;
  t291_n180: if (E.getFileProximityDistance() >= 3227516928 /*3.5*/) goto t291_n184;
  t291_n181: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n183;
  t291_n182: return -0.11597326397895813;
  t291_n183: return 0.1407659649848938;
  t291_n184: return 0.16911838948726654;
  t291_n185: return -0.019939839839935303;
  t291_n186: return -0.006651789415627718;
  t291_n187: if (E.getFileProximityDistance() >= 3238526976 /*8.5*/) goto t291_n195;
  t291_n188: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n194;
  t291_n189: if (E.getFilterLength() >= 3217031168 /*1.5*/) goto t291_n191;
  t291_n190: return 0.11188633739948273;
  t291_n191: if (E.getNumReferences() >= 3233808384 /*6.0*/) goto t291_n193;
  t291_n192: return -0.011203131638467312;
  t291_n193: return 0.11498082429170609;
  t291_n194: return 0.04957350715994835;
  t291_n195: if (E.getSymbolScopeDistance() >= 3212836864 /*1.0*/) goto t291_n197;
  t291_n196: return 0.15181151032447815;
  t291_n197: if (E.getFileProximityDistance() >= 3243769856 /*13.5*/) goto t291_n199;
  t291_n198: return 0.020545735955238342;
  t291_n199: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n201;
  t291_n200: return 0.11003991961479187;
  t291_n201: return -0.11045662313699722;
  t291_n202: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n204;
  t291_n203: return 0.014450003392994404;
  t291_n204: return 0.011388398706912994;
  t291_n205: return -0.006853652652353048;
  t291_n206: if (E.getNumReferences() >= 3232759808 /*5.5*/) goto t291_n208;
  t291_n207: return -0.011584019288420677;
  t291_n208: if (E.getFilterLength() >= 3204448256 /*0.5*/) goto t291_n218;
  t291_n209: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n211;
  t291_n210: return 0.05120832100510597;
  t291_n211: if (E.getNumReferences() >= 3240624128 /*10.5*/) goto t291_n213;
  t291_n212: return 0.013165966607630253;
  t291_n213: if (E.getNumReferences() >= 3244294144 /*14.0*/) goto t291_n215;
  t291_n214: return 0.1577499955892563;
  t291_n215: if (E.getSymbolCategory() & (BIT(SymbolCategory_type::Keyword)|BIT(SymbolCategory_type::Destructor)|BIT(SymbolCategory_type::Operator)|BIT(SymbolCategory_type::Unknown)|BIT(SymbolCategory_type::Constructor)|BIT(SymbolCategory_type::Type)|BIT(SymbolCategory_type::Namespace))) goto t291_n217;
  t291_n216: return -0.2396327704191208;
  t291_n217: return 0.17706002295017242;
  t291_n218: if (E.getContextKind() & (BIT(ContextKind_type::CCC_Expression)|BIT(ContextKind_type::CCC_Type))) goto t291_n220;
  t291_n219: return -0.02430008165538311;
  t291_n220: if (E.getNumReferences() >= 3239575552 /*9.5*/) goto t291_n236;
  t291_n221: if (E.getNumReferences() >= 3238526976 /*8.5*/) goto t291_n229;
  t291_n222: if (E.getFileProximityDistance() >= 3239575552 /*9.5*/) goto t291_n224;
  t291_n223: return 0.0021503656171262264;
  t291_n224: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t291_n228;
  t291_n225: if (E.getHadContextType() >= 3204448256 /*0.5*/) goto t291_n227;
  t291_n226: return 0.10209590941667557;
  t291_n227: return -0.10094248503446579;
  t291_n228: return 0.0565190315246582;
  t291_n229: if (E.getSymbolScopeDistance() >= 3472883712 /*2147483648.0*/) goto t291_n231;
  t291_n230: return 0.07504937052726746;
  t291_n231: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t291_n235;
  t291_n232: if (E.getFilterLength() >= 3223322624 /*2.5*/) goto t291_n234;
  t291_n233: return 0.09303239732980728;
  t291_n234: return 0.1220465898513794;
  t291_n235: return -0.0552414134144783;
  t291_n236: if (E.getNumReferences() >= 3317581824 /*6089.0*/) goto t291_n238;
  t291_n237: return 0.02017456479370594;
  t291_n238: if (E.getSymbolScopeDistance() >= 3231711232 /*5.0*/) goto t291_n252;
  t291_n239: if (E.getSemaFileProximityScore() >= 3197737370 /*0.30000001192092896*/) goto t291_n247;
  t291_n240: if (E.getIsNameInContext() >= 3204448256 /*0.5*/) goto t291_n242;
  t291_n241: return -0.5523847341537476;
  t291_n242: if (E.getFileProximityDistance() >= 3241148416 /*11.0*/) goto t291_n244;
  t291_n243: return 0.135552316904068;
  t291_n244: if (E.getFilterLength() >= 3229614080 /*4.0*/) goto t291_n246;
  t291_n245: return -0.10694114863872528;
  t291_n246: return 0.1076260507106781;
  t291_n247: if (E.getFilterLength() >= 3227516928 /*3.5*/) goto t291_n249;
  t291_n248: return -0.16570794582366943;
  t291_n249: if (E.getFilterLength() >= 3230662656 /*4.5*/) goto t291_n251;
  t291_n250: return 0.08825422823429108;
  t291_n251: return -0.18362212181091309;
  t291_n252: if (E.getFileProximityDistance() >= 3247964160 /*19.0*/) goto t291_n254;
  t291_n253: return 0.027011949568986893;
  t291_n254: return -0.6367723941802979;
}

} // namespace

float Evaluate(const Example& E) {
  float Score = 0;
  Score += EvaluateTree0(E);
  Score += EvaluateTree1(E);
  Score += EvaluateTree2(E);
  Score += EvaluateTree3(E);
  Score += EvaluateTree4(E);
  Score += EvaluateTree5(E);
  Score += EvaluateTree6(E);
  Score += EvaluateTree7(E);
  Score += EvaluateTree8(E);
  Score += EvaluateTree9(E);
  Score += EvaluateTree10(E);
  Score += EvaluateTree11(E);
  Score += EvaluateTree12(E);
  Score += EvaluateTree13(E);
  Score += EvaluateTree14(E);
  Score += EvaluateTree15(E);
  Score += EvaluateTree16(E);
  Score += EvaluateTree17(E);
  Score += EvaluateTree18(E);
  Score += EvaluateTree19(E);
  Score += EvaluateTree20(E);
  Score += EvaluateTree21(E);
  Score += EvaluateTree22(E);
  Score += EvaluateTree23(E);
  Score += EvaluateTree24(E);
  Score += EvaluateTree25(E);
  Score += EvaluateTree26(E);
  Score += EvaluateTree27(E);
  Score += EvaluateTree28(E);
  Score += EvaluateTree29(E);
  Score += EvaluateTree30(E);
  Score += EvaluateTree31(E);
  Score += EvaluateTree32(E);
  Score += EvaluateTree33(E);
  Score += EvaluateTree34(E);
  Score += EvaluateTree35(E);
  Score += EvaluateTree36(E);
  Score += EvaluateTree37(E);
  Score += EvaluateTree38(E);
  Score += EvaluateTree39(E);
  Score += EvaluateTree40(E);
  Score += EvaluateTree41(E);
  Score += EvaluateTree42(E);
  Score += EvaluateTree43(E);
  Score += EvaluateTree44(E);
  Score += EvaluateTree45(E);
  Score += EvaluateTree46(E);
  Score += EvaluateTree47(E);
  Score += EvaluateTree48(E);
  Score += EvaluateTree49(E);
  Score += EvaluateTree50(E);
  Score += EvaluateTree51(E);
  Score += EvaluateTree52(E);
  Score += EvaluateTree53(E);
  Score += EvaluateTree54(E);
  Score += EvaluateTree55(E);
  Score += EvaluateTree56(E);
  Score += EvaluateTree57(E);
  Score += EvaluateTree58(E);
  Score += EvaluateTree59(E);
  Score += EvaluateTree60(E);
  Score += EvaluateTree61(E);
  Score += EvaluateTree62(E);
  Score += EvaluateTree63(E);
  Score += EvaluateTree64(E);
  Score += EvaluateTree65(E);
  Score += EvaluateTree66(E);
  Score += EvaluateTree67(E);
  Score += EvaluateTree68(E);
  Score += EvaluateTree69(E);
  Score += EvaluateTree70(E);
  Score += EvaluateTree71(E);
  Score += EvaluateTree72(E);
  Score += EvaluateTree73(E);
  Score += EvaluateTree74(E);
  Score += EvaluateTree75(E);
  Score += EvaluateTree76(E);
  Score += EvaluateTree77(E);
  Score += EvaluateTree78(E);
  Score += EvaluateTree79(E);
  Score += EvaluateTree80(E);
  Score += EvaluateTree81(E);
  Score += EvaluateTree82(E);
  Score += EvaluateTree83(E);
  Score += EvaluateTree84(E);
  Score += EvaluateTree85(E);
  Score += EvaluateTree86(E);
  Score += EvaluateTree87(E);
  Score += EvaluateTree88(E);
  Score += EvaluateTree89(E);
  Score += EvaluateTree90(E);
  Score += EvaluateTree91(E);
  Score += EvaluateTree92(E);
  Score += EvaluateTree93(E);
  Score += EvaluateTree94(E);
  Score += EvaluateTree95(E);
  Score += EvaluateTree96(E);
  Score += EvaluateTree97(E);
  Score += EvaluateTree98(E);
  Score += EvaluateTree99(E);
  Score += EvaluateTree100(E);
  Score += EvaluateTree101(E);
  Score += EvaluateTree102(E);
  Score += EvaluateTree103(E);
  Score += EvaluateTree104(E);
  Score += EvaluateTree105(E);
  Score += EvaluateTree106(E);
  Score += EvaluateTree107(E);
  Score += EvaluateTree108(E);
  Score += EvaluateTree109(E);
  Score += EvaluateTree110(E);
  Score += EvaluateTree111(E);
  Score += EvaluateTree112(E);
  Score += EvaluateTree113(E);
  Score += EvaluateTree114(E);
  Score += EvaluateTree115(E);
  Score += EvaluateTree116(E);
  Score += EvaluateTree117(E);
  Score += EvaluateTree118(E);
  Score += EvaluateTree119(E);
  Score += EvaluateTree120(E);
  Score += EvaluateTree121(E);
  Score += EvaluateTree122(E);
  Score += EvaluateTree123(E);
  Score += EvaluateTree124(E);
  Score += EvaluateTree125(E);
  Score += EvaluateTree126(E);
  Score += EvaluateTree127(E);
  Score += EvaluateTree128(E);
  Score += EvaluateTree129(E);
  Score += EvaluateTree130(E);
  Score += EvaluateTree131(E);
  Score += EvaluateTree132(E);
  Score += EvaluateTree133(E);
  Score += EvaluateTree134(E);
  Score += EvaluateTree135(E);
  Score += EvaluateTree136(E);
  Score += EvaluateTree137(E);
  Score += EvaluateTree138(E);
  Score += EvaluateTree139(E);
  Score += EvaluateTree140(E);
  Score += EvaluateTree141(E);
  Score += EvaluateTree142(E);
  Score += EvaluateTree143(E);
  Score += EvaluateTree144(E);
  Score += EvaluateTree145(E);
  Score += EvaluateTree146(E);
  Score += EvaluateTree147(E);
  Score += EvaluateTree148(E);
  Score += EvaluateTree149(E);
  Score += EvaluateTree150(E);
  Score += EvaluateTree151(E);
  Score += EvaluateTree152(E);
  Score += EvaluateTree153(E);
  Score += EvaluateTree154(E);
  Score += EvaluateTree155(E);
  Score += EvaluateTree156(E);
  Score += EvaluateTree157(E);
  Score += EvaluateTree158(E);
  Score += EvaluateTree159(E);
  Score += EvaluateTree160(E);
  Score += EvaluateTree161(E);
  Score += EvaluateTree162(E);
  Score += EvaluateTree163(E);
  Score += EvaluateTree164(E);
  Score += EvaluateTree165(E);
  Score += EvaluateTree166(E);
  Score += EvaluateTree167(E);
  Score += EvaluateTree168(E);
  Score += EvaluateTree169(E);
  Score += EvaluateTree170(E);
  Score += EvaluateTree171(E);
  Score += EvaluateTree172(E);
  Score += EvaluateTree173(E);
  Score += EvaluateTree174(E);
  Score += EvaluateTree175(E);
  Score += EvaluateTree176(E);
  Score += EvaluateTree177(E);
  Score += EvaluateTree178(E);
  Score += EvaluateTree179(E);
  Score += EvaluateTree180(E);
  Score += EvaluateTree181(E);
  Score += EvaluateTree182(E);
  Score += EvaluateTree183(E);
  Score += EvaluateTree184(E);
  Score += EvaluateTree185(E);
  Score += EvaluateTree186(E);
  Score += EvaluateTree187(E);
  Score += EvaluateTree188(E);
  Score += EvaluateTree189(E);
  Score += EvaluateTree190(E);
  Score += EvaluateTree191(E);
  Score += EvaluateTree192(E);
  Score += EvaluateTree193(E);
  Score += EvaluateTree194(E);
  Score += EvaluateTree195(E);
  Score += EvaluateTree196(E);
  Score += EvaluateTree197(E);
  Score += EvaluateTree198(E);
  Score += EvaluateTree199(E);
  Score += EvaluateTree200(E);
  Score += EvaluateTree201(E);
  Score += EvaluateTree202(E);
  Score += EvaluateTree203(E);
  Score += EvaluateTree204(E);
  Score += EvaluateTree205(E);
  Score += EvaluateTree206(E);
  Score += EvaluateTree207(E);
  Score += EvaluateTree208(E);
  Score += EvaluateTree209(E);
  Score += EvaluateTree210(E);
  Score += EvaluateTree211(E);
  Score += EvaluateTree212(E);
  Score += EvaluateTree213(E);
  Score += EvaluateTree214(E);
  Score += EvaluateTree215(E);
  Score += EvaluateTree216(E);
  Score += EvaluateTree217(E);
  Score += EvaluateTree218(E);
  Score += EvaluateTree219(E);
  Score += EvaluateTree220(E);
  Score += EvaluateTree221(E);
  Score += EvaluateTree222(E);
  Score += EvaluateTree223(E);
  Score += EvaluateTree224(E);
  Score += EvaluateTree225(E);
  Score += EvaluateTree226(E);
  Score += EvaluateTree227(E);
  Score += EvaluateTree228(E);
  Score += EvaluateTree229(E);
  Score += EvaluateTree230(E);
  Score += EvaluateTree231(E);
  Score += EvaluateTree232(E);
  Score += EvaluateTree233(E);
  Score += EvaluateTree234(E);
  Score += EvaluateTree235(E);
  Score += EvaluateTree236(E);
  Score += EvaluateTree237(E);
  Score += EvaluateTree238(E);
  Score += EvaluateTree239(E);
  Score += EvaluateTree240(E);
  Score += EvaluateTree241(E);
  Score += EvaluateTree242(E);
  Score += EvaluateTree243(E);
  Score += EvaluateTree244(E);
  Score += EvaluateTree245(E);
  Score += EvaluateTree246(E);
  Score += EvaluateTree247(E);
  Score += EvaluateTree248(E);
  Score += EvaluateTree249(E);
  Score += EvaluateTree250(E);
  Score += EvaluateTree251(E);
  Score += EvaluateTree252(E);
  Score += EvaluateTree253(E);
  Score += EvaluateTree254(E);
  Score += EvaluateTree255(E);
  Score += EvaluateTree256(E);
  Score += EvaluateTree257(E);
  Score += EvaluateTree258(E);
  Score += EvaluateTree259(E);
  Score += EvaluateTree260(E);
  Score += EvaluateTree261(E);
  Score += EvaluateTree262(E);
  Score += EvaluateTree263(E);
  Score += EvaluateTree264(E);
  Score += EvaluateTree265(E);
  Score += EvaluateTree266(E);
  Score += EvaluateTree267(E);
  Score += EvaluateTree268(E);
  Score += EvaluateTree269(E);
  Score += EvaluateTree270(E);
  Score += EvaluateTree271(E);
  Score += EvaluateTree272(E);
  Score += EvaluateTree273(E);
  Score += EvaluateTree274(E);
  Score += EvaluateTree275(E);
  Score += EvaluateTree276(E);
  Score += EvaluateTree277(E);
  Score += EvaluateTree278(E);
  Score += EvaluateTree279(E);
  Score += EvaluateTree280(E);
  Score += EvaluateTree281(E);
  Score += EvaluateTree282(E);
  Score += EvaluateTree283(E);
  Score += EvaluateTree284(E);
  Score += EvaluateTree285(E);
  Score += EvaluateTree286(E);
  Score += EvaluateTree287(E);
  Score += EvaluateTree288(E);
  Score += EvaluateTree289(E);
  Score += EvaluateTree290(E);
  Score += EvaluateTree291(E);
  return Score;
}

} // namespace clangd
} // namespace clang
